# coding: utf8
"""
All wordforms are extracted from Norsk Ordbank in Norwegian Bokmål 2005
(CLARINO NB - Språkbanken), Nasjonalbiblioteket, Norway:
https://www.nb.no/sprakbanken/show?serial=oai%3Anb.no%3Asbr-5&lang=en
License:
Creative_Commons-BY (CC-BY) (https://creativecommons.org/licenses/by/4.0/)
"""

from __future__ import unicode_literals

ADJECTIVES_WORDFORMS = {
'H-forma': ('H-forma',),
'H-formede': ('H-formet',),
'H-formet': ('H-formet',),
'H-formete': ('H-formet',),
'H-formetere': ('H-formet',),
'H-formetest': ('H-formet',),
'H-formeteste': ('H-formet',),
'PR-kåt': ('PR-kåt',),
'PR-kåte': ('PR-kåt',),
'PR-kåtere': ('PR-kåt',),
'PR-kåtest': ('PR-kåt',),
'PR-kåteste': ('PR-kåt',),
'T-forma': ('T-forma',),
'T-formede': ('T-formet',),
'T-formet': ('T-formet',),
'T-formete': ('T-formet',),
'T-formetere': ('T-formet',),
'T-formetest': ('T-formet',),
'T-formeteste': ('T-formet',),
'U-forma': ('U-forma',),
'U-formede': ('U-formet',),
'U-formet': ('U-formet',),
'U-formete': ('U-formet',),
'U-formetere': ('U-formet',),
'U-formetest': ('U-formet',),
'U-formeteste': ('U-formet',),
'V-forma': ('V-forma',),
'V-formede': ('V-formet',),
'V-formet': ('V-formet',),
'V-formete': ('V-formet',),
'V-formetere': ('V-formet',),
'V-formetest': ('V-formet',),
'V-formeteste': ('V-formet',),
'abandonerende': ('abandonere',),
'abandonert': ('abandonere',),
'abandonerte': ('abandonere',),
'abbrevierende': ('abbreviere',),
'abbreviert': ('abbreviere',),
'abbrevierte': ('abbreviere',),
'abdiserende': ('abdisere',),
'abdisert': ('abdisere',),
'abdiserte': ('abdisere',),
'abdominal': ('abdominal',),
'abdominale': ('abdominal',),
'abdominalere': ('abdominal',),
'abdominalest': ('abdominal',),
'abdominaleste': ('abdominal',),
'abdominalt': ('abdominal',),
'abessinsk': ('abessinsk',),
'abessinske': ('abessinsk',),
'abessinskere': ('abessinsk',),
'abessinskest': ('abessinsk',),
'abessinskeste': ('abessinsk',),
'abkhasisk': ('abkhasisk',),
'abkhasiske': ('abkhasisk',),
'abkhasiskere': ('abkhasisk',),
'abkhasiskest': ('abkhasisk',),
'abkhasiskeste': ('abkhasisk',),
'ablativisk': ('ablativisk',),
'ablativiske': ('ablativisk',),
'ablativiskere': ('ablativisk',),
'ablativiskest': ('ablativisk',),
'ablativiskeste': ('ablativisk',),
'abnorm': ('abnorm',),
'abnorme': ('abnorm',),
'abnormere': ('abnorm',),
'abnormest': ('abnorm',),
'abnormeste': ('abnorm',),
'abnormt': ('abnorm',),
'abonnerende': ('abonnere',),
'abonnert': ('abonnere',),
'abonnerte': ('abonnere',),
'aborterende': ('abortere',),
'abortert': ('abortere',),
'aborterte': ('abortere',),
'abortiv': ('abortiv',),
'abortive': ('abortiv',),
'abortivere': ('abortiv',),
'abortivest': ('abortiv',),
'abortiveste': ('abortiv',),
'abortivt': ('abortiv',),
'abortsøkende': ('abortsøkende',),
'abrupt': ('abrupt',),
'abrupte': ('abrupt',),
'abruptere': ('abrupt',),
'abruptest': ('abrupt',),
'abrupteste': ('abrupt',),
'absenterende': ('absentere',),
'absentert': ('absentere',),
'absenterte': ('absentere',),
'absolutistisk': ('absolutistisk',),
'absolutistiske': ('absolutistisk',),
'absolutistiskere': ('absolutistisk',),
'absolutistiskest': ('absolutistisk',),
'absolutistiskeste': ('absolutistisk',),
'absolutt': ('absolutt',),
'absolutte': ('absolutt',),
'absoluttere': ('absolutt',),
'absoluttest': ('absolutt',),
'absolutteste': ('absolutt',),
'absolverende': ('absolvere',),
'absolvert': ('absolvere',),
'absolverte': ('absolvere',),
'absorberende': ('absorbere',),
'absorbert': ('absorbere',),
'absorberte': ('absorbere',),
'absorptiv': ('absorptiv',),
'absorptive': ('absorptiv',),
'absorptivere': ('absorptiv',),
'absorptivest': ('absorptiv',),
'absorptiveste': ('absorptiv',),
'absorptivt': ('absorptiv',),
'abstinent': ('abstinent',),
'abstinente': ('abstinent',),
'abstinentere': ('abstinent',),
'abstinentest': ('abstinent',),
'abstinenteste': ('abstinent',),
'abstraherende': ('abstrahere',),
'abstrahert': ('abstrahere',),
'abstraherte': ('abstrahere',),
'abstrakt': ('abstrakt',),
'abstrakte': ('abstrakt',),
'abstraktere': ('abstrakt',),
'abstraktest': ('abstrakt',),
'abstrakteste': ('abstrakt',),
'absurd': ('absurd',),
'absurde': ('absurd',),
'absurdere': ('absurd',),
'absurdest': ('absurd',),
'absurdeste': ('absurd',),
'absurdistisk': ('absurdistisk',),
'absurdistiske': ('absurdistisk',),
'absurdistiskere': ('absurdistisk',),
'absurdistiskest': ('absurdistisk',),
'absurdistiskeste': ('absurdistisk',),
'adapterende': ('adaptere',),
'adaptert': ('adaptere',),
'adapterte': ('adaptere',),
'adaptiv': ('adaptiv',),
'adaptive': ('adaptiv',),
'adaptivere': ('adaptiv',),
'adaptivest': ('adaptiv',),
'adaptiveste': ('adaptiv',),
'adaptivt': ('adaptiv',),
'adderende': ('addere',),
'addert': ('addere',),
'adderte': ('addere',),
'additiv': ('additiv',),
'additive': ('additiv',),
'additivere': ('additiv',),
'additivest': ('additiv',),
'additiveste': ('additiv',),
'additivt': ('additiv',),
'adekvat': ('adekvat',),
'adekvate': ('adekvat',),
'adekvatere': ('adekvat',),
'adekvatest': ('adekvat',),
'adekvateste': ('adekvat',),
'adelig': ('adelig',),
'adelige': ('adelig',),
'adeligere': ('adelig',),
'adeligst': ('adelig',),
'adeligste': ('adelig',),
'adenoid': ('adenoid',),
'adenoide': ('adenoid',),
'adenoidere': ('adenoid',),
'adenoidest': ('adenoid',),
'adenoideste': ('adenoid',),
'adgangsberettiga': ('adgangsberettiga',),
'adgangsberettigede': ('adgangsberettiget',),
'adgangsberettiget': ('adgangsberettiget',),
'adgangsberettigete': ('adgangsberettiget',),
'adgangsberettigetere': ('adgangsberettiget',),
'adgangsberettigetest': ('adgangsberettiget',),
'adgangsberettigeteste': ('adgangsberettiget',),
'adhererende': ('adherere',),
'adherert': ('adherere',),
'adhererte': ('adherere',),
'adjektiverende': ('adjektivere',),
'adjektivert': ('adjektivere',),
'adjektiverte': ('adjektivere',),
'adjektivisk': ('adjektivisk',),
'adjektiviske': ('adjektivisk',),
'adjektiviskere': ('adjektivisk',),
'adjektiviskest': ('adjektivisk',),
'adjektiviskeste': ('adjektivisk',),
'adla': ('adle',),
'adlede': ('adle',),
'adlende': ('adle',),
'adlet': ('adle',),
'adlete': ('adle',),
'adlydende': ('adlyde',),
'adlydt': ('adlyde',),
'adlydte': ('adlyde',),
'administrativ': ('administrativ',),
'administrative': ('administrativ',),
'administrativere': ('administrativ',),
'administrativest': ('administrativ',),
'administrativeste': ('administrativ',),
'administrativt': ('administrativ',),
'administrerende': ('administrere',),
'administrert': ('administrere',),
'administrerte': ('administrere',),
'adonisk': ('adonisk',),
'adoniske': ('adonisk',),
'adoniskere': ('adonisk',),
'adoniskest': ('adonisk',),
'adoniskeste': ('adonisk',),
'adopterende': ('adoptere',),
'adoptert': ('adoptere',),
'adopterte': ('adoptere',),
'adresselaus': ('adresselaus',),
'adresselause': ('adresselaus',),
'adresselausere': ('adresselaus',),
'adresselausest': ('adresselaus',),
'adresselauseste': ('adresselaus',),
'adresselaust': ('adresselaus',),
'adresseløs': ('adresseløs',),
'adresseløse': ('adresseløs',),
'adresseløsere': ('adresseløs',),
'adresseløsest': ('adresseløs',),
'adresseløseste': ('adresseløs',),
'adresseløst': ('adresseløs',),
'adresserende': ('adressere',),
'adressert': ('adressere',),
'adresserte': ('adressere',),
'adsorberende': ('adsorbere',),
'adsorbert': ('adsorbere',),
'adsorberte': ('adsorbere',),
'adstadig': ('adstadig',),
'adstadige': ('adstadig',),
'adstadigere': ('adstadig',),
'adstadigst': ('adstadig',),
'adstadigste': ('adstadig',),
'adstringerende': ('adstringere',),
'adstringert': ('adstringere',),
'adstringerte': ('adstringere',),
'advarende': ('advare',),
'advart': ('advare',),
'advarte': ('advare',),
'advarende': ('advarende',),
'adverbial': ('adverbial',),
'adverbiale': ('adverbial',),
'adverbialere': ('adverbial',),
'adverbialest': ('adverbial',),
'adverbialeste': ('adverbial',),
'adverbialt': ('adverbial',),
'adviserende': ('advisere',),
'advisert': ('advisere',),
'adviserte': ('advisere',),
'advokatorisk': ('advokatorisk',),
'advokatoriske': ('advokatorisk',),
'advokatoriskere': ('advokatorisk',),
'advokatoriskest': ('advokatorisk',),
'advokatoriskeste': ('advokatorisk',),
'aerob': ('aerob',),
'aerobe': ('aerob',),
'aerobere': ('aerob',),
'aerobest': ('aerob',),
'aerobeste': ('aerob',),
'aerobt': ('aerob',),
'aerodynamisk': ('aerodynamisk',),
'aerodynamiske': ('aerodynamisk',),
'aerodynamiskere': ('aerodynamisk',),
'aerodynamiskest': ('aerodynamisk',),
'aerodynamiskeste': ('aerodynamisk',),
'afatisk': ('afatisk',),
'afatiske': ('afatisk',),
'afatiskere': ('afatisk',),
'afatiskest': ('afatisk',),
'afatiskeste': ('afatisk',),
'affekterende': ('affektere',),
'affektert': ('affektere',),
'affekterte': ('affektere',),
'affektert': ('affektert',),
'affekterte': ('affektert',),
'affektertere': ('affektert',),
'affektertest': ('affektert',),
'affekterteste': ('affektert',),
'affektiv': ('affektiv',),
'affektive': ('affektiv',),
'affektivere': ('affektiv',),
'affektivest': ('affektiv',),
'affektiveste': ('affektiv',),
'affektivt': ('affektiv',),
'affektlada': ('affektlada',),
'affektladd': ('affektladd',),
'affektladde': ('affektladd',),
'affektladdere': ('affektladd',),
'affektladdest': ('affektladd',),
'affektladdeste': ('affektladd',),
'affektladede': ('affektladet',),
'affektladet': ('affektladet',),
'affektladete': ('affektladet',),
'affektladetere': ('affektladet',),
'affektladetest': ('affektladet',),
'affektladeteste': ('affektladet',),
'affiserende': ('affisere',),
'affisert': ('affisere',),
'affiserte': ('affisere',),
'afghansk': ('afghansk',),
'afghanske': ('afghansk',),
'afghanskere': ('afghansk',),
'afghanskest': ('afghansk',),
'afghanskeste': ('afghansk',),
'aforistisk': ('aforistisk',),
'aforistiske': ('aforistisk',),
'aforistiskere': ('aforistisk',),
'aforistiskest': ('aforistisk',),
'aforistiskeste': ('aforistisk',),
'afrikaniserende': ('afrikanisere',),
'afrikanisert': ('afrikanisere',),
'afrikaniserte': ('afrikanisere',),
'afrikansk': ('afrikansk',),
'afrikanske': ('afrikansk',),
'afrikanskere': ('afrikansk',),
'afrikanskest': ('afrikansk',),
'afrikanskeste': ('afrikansk',),
'afroamerikansk': ('afroamerikansk',),
'afroamerikanske': ('afroamerikansk',),
'afroamerikanskere': ('afroamerikansk',),
'afroamerikanskest': ('afroamerikansk',),
'afroamerikanskeste': ('afroamerikansk',),
'afroasiatisk': ('afroasiatisk',),
'afroasiatiske': ('afroasiatisk',),
'afroasiatiskere': ('afroasiatisk',),
'afroasiatiskest': ('afroasiatisk',),
'afroasiatiskeste': ('afroasiatisk',),
'aga': ('age',),
'agede': ('age',),
'agende': ('age',),
'aget': ('age',),
'agete': ('age',),
'agelaus': ('agelaus',),
'agelause': ('agelaus',),
'agelausere': ('agelaus',),
'agelausest': ('agelaus',),
'agelauseste': ('agelaus',),
'agelaust': ('agelaus',),
'ageløs': ('ageløs',),
'ageløse': ('ageløs',),
'ageløsere': ('ageløs',),
'ageløsest': ('ageløs',),
'ageløseste': ('ageløs',),
'ageløst': ('ageløs',),
'agerende': ('agere',),
'agert': ('agere',),
'agerte': ('agere',),
'agglutinerende': ('agglutinere',),
'agglutinert': ('agglutinere',),
'agglutinerte': ('agglutinere',),
'aggressiv': ('aggressiv',),
'aggressive': ('aggressiv',),
'aggressivere': ('aggressiv',),
'aggressivest': ('aggressiv',),
'aggressiveste': ('aggressiv',),
'aggressivt': ('aggressiv',),
'agitatorisk': ('agitatorisk',),
'agitatoriske': ('agitatorisk',),
'agitatoriskere': ('agitatorisk',),
'agitatoriskest': ('agitatorisk',),
'agitatoriskeste': ('agitatorisk',),
'agiterende': ('agitere',),
'agitert': ('agitere',),
'agiterte': ('agitere',),
'agnatisk': ('agnatisk',),
'agnatiske': ('agnatisk',),
'agnatiskere': ('agnatisk',),
'agnatiskest': ('agnatisk',),
'agnatiskeste': ('agnatisk',),
'agna': ('agne',),
'agnede': ('agne',),
'agnende': ('agne',),
'agnet': ('agne',),
'agnete': ('agne',),
'agnostisk': ('agnostisk',),
'agnostiske': ('agnostisk',),
'agnostiskere': ('agnostisk',),
'agnostiskest': ('agnostisk',),
'agnostiskeste': ('agnostisk',),
'agrarisk': ('agrarisk',),
'agrariske': ('agrarisk',),
'agrariskere': ('agrarisk',),
'agrariskest': ('agrarisk',),
'agrariskeste': ('agrarisk',),
'agronomisk': ('agronomisk',),
'agronomiske': ('agronomisk',),
'agronomiskere': ('agronomisk',),
'agronomiskest': ('agronomisk',),
'agronomiskeste': ('agronomisk',),
'ahistorisk': ('ahistorisk',),
'ahistoriske': ('ahistorisk',),
'ahistoriskere': ('ahistorisk',),
'ahistoriskest': ('ahistorisk',),
'ahistoriskeste': ('ahistorisk',),
'ajourførende': ('ajourføre',),
'ajourført': ('ajourføre',),
'ajourførte': ('ajourføre',),
'akademisk': ('akademisk',),
'akademiske': ('akademisk',),
'akademiskere': ('akademisk',),
'akademiskest': ('akademisk',),
'akademiskeste': ('akademisk',),
'akende': ('ake',),
'akt': ('ake',),
'akte': ('ake',),
'akka': ('akke',),
'akkede': ('akke',),
'akkende': ('akke',),
'akket': ('akke',),
'akkete': ('akke',),
'akka': ('akke',),
'akkede': ('akke',),
'akkende': ('akke',),
'akket': ('akke',),
'akkete': ('akke',),
'akkederende': ('akkedere',),
'akkedert': ('akkedere',),
'akkederte': ('akkedere',),
'akklimatiserende': ('akklimatisere',),
'akklimatisert': ('akklimatisere',),
'akklimatiserte': ('akklimatisere',),
'akkommoderende': ('akkommodere',),
'akkommodert': ('akkommodere',),
'akkommoderte': ('akkommodere',),
'akkompagnerende': ('akkompagnere',),
'akkompagnert': ('akkompagnere',),
'akkompagnerte': ('akkompagnere',),
'akkorderende': ('akkordere',),
'akkordert': ('akkordere',),
'akkorderte': ('akkordere',),
'akkrediterende': ('akkreditere',),
'akkreditert': ('akkreditere',),
'akkrediterte': ('akkreditere',),
'akkumulerende': ('akkumulere',),
'akkumulert': ('akkumulere',),
'akkumulerte': ('akkumulere',),
'akkusativisk': ('akkusativisk',),
'akkusativiske': ('akkusativisk',),
'akkusativiskere': ('akkusativisk',),
'akkusativiskest': ('akkusativisk',),
'akkusativiskeste': ('akkusativisk',),
'akkvirerende': ('akkvirere',),
'akkvirert': ('akkvirere',),
'akkvirerte': ('akkvirere',),
'akrobatisk': ('akrobatisk',),
'akrobatiske': ('akrobatisk',),
'akrobatiskere': ('akrobatisk',),
'akrobatiskest': ('akrobatisk',),
'akrobatiskeste': ('akrobatisk',),
'akromatisk': ('akromatisk',),
'akromatiske': ('akromatisk',),
'akromatiskere': ('akromatisk',),
'akromatiskest': ('akromatisk',),
'akromatiskeste': ('akromatisk',),
'akselbred': ('akselbred',),
'akselbrede': ('akselbred',),
'akselbredere': ('akselbred',),
'akselbredest': ('akselbred',),
'akselbredeste': ('akselbred',),
'akselbredt': ('akselbred',),
'akselbrei': ('akselbrei',),
'akselbreie': ('akselbrei',),
'akselbreiere': ('akselbrei',),
'akselbreiest': ('akselbrei',),
'akselbreieste': ('akselbrei',),
'akselbreit': ('akselbrei',),
'akselbreitt': ('akselbrei',),
'akselererende': ('akselerere',),
'akselerert': ('akselerere',),
'akselererte': ('akselerere',),
'aksentuerende': ('aksentuere',),
'aksentuert': ('aksentuere',),
'aksentuerte': ('aksentuere',),
'akseptabel': ('akseptabel',),
'akseptabelt': ('akseptabel',),
'akseptable': ('akseptabel',),
'akseptablere': ('akseptabel',),
'akseptablest': ('akseptabel',),
'akseptableste': ('akseptabel',),
'aksepterende': ('akseptere',),
'akseptert': ('akseptere',),
'aksepterte': ('akseptere',),
'aksessorisk': ('aksessorisk',),
'aksessoriske': ('aksessorisk',),
'aksessoriskere': ('aksessorisk',),
'aksessoriskest': ('aksessorisk',),
'aksessoriskeste': ('aksessorisk',),
'aksial': ('aksial',),
'aksiale': ('aksial',),
'aksialere': ('aksial',),
'aksialest': ('aksial',),
'aksialeste': ('aksial',),
'aksialt': ('aksial',),
'aksiomatisk': ('aksiomatisk',),
'aksiomatiske': ('aksiomatisk',),
'aksiomatiskere': ('aksiomatisk',),
'aksiomatiskest': ('aksiomatisk',),
'aksiomatiskeste': ('aksiomatisk',),
'aksjonerende': ('aksjonere',),
'aksjonert': ('aksjonere',),
'aksjonerte': ('aksjonere',),
'aksla': ('aksle',),
'akslede': ('aksle',),
'akslende': ('aksle',),
'akslet': ('aksle',),
'akslete': ('aksle',),
'akslebred': ('akslebred',),
'akslebrede': ('akslebred',),
'akslebredere': ('akslebred',),
'akslebredest': ('akslebred',),
'akslebredeste': ('akslebred',),
'akslebredt': ('akslebred',),
'akslebrei': ('akslebrei',),
'akslebreie': ('akslebrei',),
'akslebreiere': ('akslebrei',),
'akslebreiest': ('akslebrei',),
'akslebreieste': ('akslebrei',),
'akslebreit': ('akslebrei',),
'akslebreitt': ('akslebrei',),
'akta': ('akta',),
'akta': ('akte',),
'aktede': ('akte',),
'aktende': ('akte',),
'aktet': ('akte',),
'aktete': ('akte',),
'akterlig': ('akterlig',),
'akterlige': ('akterlig',),
'akterligere': ('akterlig',),
'akterligst': ('akterlig',),
'akterligste': ('akterlig',),
'akterst': ('akterst',),
'akterste': ('akterst',),
'akterutsegla': ('akterutsegle',),
'akterutseglede': ('akterutsegle',),
'akterutseglende': ('akterutsegle',),
'akterutseglet': ('akterutsegle',),
'akterutseglete': ('akterutsegle',),
'akterutseilende': ('akterutseile',),
'akterutseilt': ('akterutseile',),
'akterutseilte': ('akterutseile',),
'aktede': ('aktet',),
'aktet': ('aktet',),
'aktete': ('aktet',),
'aktetere': ('aktet',),
'aktetest': ('aktet',),
'akteteste': ('aktet',),
'aktiv': ('aktiv',),
'aktive': ('aktiv',),
'aktivere': ('aktiv',),
'aktivest': ('aktiv',),
'aktiveste': ('aktiv',),
'aktivt': ('aktiv',),
'aktiverende': ('aktivere',),
'aktivert': ('aktivere',),
'aktiverte': ('aktivere',),
'aktiviserende': ('aktivisere',),
'aktivisert': ('aktivisere',),
'aktiviserte': ('aktivisere',),
'aktivistisk': ('aktivistisk',),
'aktivistiske': ('aktivistisk',),
'aktivistiskere': ('aktivistisk',),
'aktivistiskest': ('aktivistisk',),
'aktivistiskeste': ('aktivistisk',),
'aktpågivende': ('aktpågivende',),
'akterst': ('aktre',),
'akterste': ('aktre',),
'aktre': ('aktre',),
'aktsom': ('aktsom',),
'aktsomme': ('aktsom',),
'aktsommere': ('aktsom',),
'aktsomst': ('aktsom',),
'aktsomste': ('aktsom',),
'aktsomt': ('aktsom',),
'aktualiserende': ('aktualisere',),
'aktualisert': ('aktualisere',),
'aktualiserte': ('aktualisere',),
'aktuell': ('aktuell',),
'aktuelle': ('aktuell',),
'aktuellere': ('aktuell',),
'aktuellest': ('aktuell',),
'aktuelleste': ('aktuell',),
'aktuelt': ('aktuell',),
'aktverdig': ('aktverdig',),
'aktverdige': ('aktverdig',),
'aktverdigere': ('aktverdig',),
'aktverdigst': ('aktverdig',),
'aktverdigste': ('aktverdig',),
'akustisk': ('akustisk',),
'akustiske': ('akustisk',),
'akustiskere': ('akustisk',),
'akustiskest': ('akustisk',),
'akustiskeste': ('akustisk',),
'akutt': ('akutt',),
'akutte': ('akutt',),
'akuttere': ('akutt',),
'akuttest': ('akutt',),
'akutteste': ('akutt',),
'akvatisk': ('akvatisk',),
'akvatiske': ('akvatisk',),
'akvatiskere': ('akvatisk',),
'akvatiskest': ('akvatisk',),
'akvatiskeste': ('akvatisk',),
'alabasthvit': ('alabasthvit',),
'alabasthvite': ('alabasthvit',),
'alabasthvitere': ('alabasthvit',),
'alabasthvitest': ('alabasthvit',),
'alabasthviteste': ('alabasthvit',),
'alabasthvitt': ('alabasthvit',),
'alabasthvit': ('alabasthvit',),
'alabasthvite': ('alabasthvit',),
'alabasthvitere': ('alabasthvit',),
'alabasthvitest': ('alabasthvit',),
'alabasthviteste': ('alabasthvit',),
'alabasthvitt': ('alabasthvit',),
'alabastkvit': ('alabastkvit',),
'alabastkvite': ('alabastkvit',),
'alabastkvitere': ('alabastkvit',),
'alabastkvitest': ('alabastkvit',),
'alabastkviteste': ('alabastkvit',),
'alabastkvitt': ('alabastkvit',),
'alabastkvit': ('alabastkvit',),
'alabastkvite': ('alabastkvit',),
'alabastkvitere': ('alabastkvit',),
'alabastkvitest': ('alabastkvit',),
'alabastkviteste': ('alabastkvit',),
'alabastkvitt': ('alabastkvit',),
'alarmerende': ('alarmere',),
'alarmert': ('alarmere',),
'alarmerte': ('alarmere',),
'alarmerende': ('alarmerende',),
'alaskisk': ('alaskisk',),
'alaskiske': ('alaskisk',),
'alaskiskere': ('alaskisk',),
'alaskiskest': ('alaskisk',),
'alaskiskeste': ('alaskisk',),
'albansk': ('albansk',),
'albanske': ('albansk',),
'albanskere': ('albansk',),
'albanskest': ('albansk',),
'albanskeste': ('albansk',),
'albin': ('albin',),
'albine': ('albin',),
'albinere': ('albin',),
'albinest': ('albin',),
'albineste': ('albin',),
'albint': ('albin',),
'alboga': ('alboge',),
'albogede': ('alboge',),
'albogende': ('alboge',),
'alboget': ('alboge',),
'albogete': ('alboge',),
'albua': ('albue',),
'albuede': ('albue',),
'albuende': ('albue',),
'albuet': ('albue',),
'albuete': ('albue',),
'alderdommelig': ('alderdommelig',),
'alderdommelige': ('alderdommelig',),
'alderdommeligere': ('alderdommelig',),
'alderdommeligst': ('alderdommelig',),
'alderdommeligste': ('alderdommelig',),
'alderdomssløv': ('alderdomssløv',),
'alderdomssløve': ('alderdomssløv',),
'alderdomssløvere': ('alderdomssløv',),
'alderdomssløvest': ('alderdomssløv',),
'alderdomssløveste': ('alderdomssløv',),
'alderdomssløvt': ('alderdomssløv',),
'aldersbestemmende': ('aldersbestemme',),
'aldersbestemt': ('aldersbestemme',),
'aldersbestemte': ('aldersbestemme',),
'alderstegen': ('alderstegen',),
'alderstegent': ('alderstegen',),
'alderstegne': ('alderstegen',),
'alderstegnere': ('alderstegen',),
'alderstegnest': ('alderstegen',),
'alderstegneste': ('alderstegen',),
'aldra': ('aldre',),
'aldrede': ('aldre',),
'aldrende': ('aldre',),
'aldret': ('aldre',),
'aldrete': ('aldre',),
'aldrende': ('aldrende',),
'aldringsbestandig': ('aldringsbestandig',),
'aldringsbestandige': ('aldringsbestandig',),
'aldringsbestandigere': ('aldringsbestandig',),
'aldringsbestandigst': ('aldringsbestandig',),
'aldringsbestandigste': ('aldringsbestandig',),
'ala': ('ale',),
'alede': ('ale',),
'alende': ('ale',),
'alet': ('ale',),
'alete': ('ale',),
'alt': ('ale',),
'alte': ('ale',),
'aleksandrinsk': ('aleksandrinsk',),
'aleksandrinske': ('aleksandrinsk',),
'aleksandrinskere': ('aleksandrinsk',),
'aleksandrinskest': ('aleksandrinsk',),
'aleksandrinskeste': ('aleksandrinsk',),
'alemannisk': ('alemannisk',),
'alemanniske': ('alemannisk',),
'alemanniskere': ('alemannisk',),
'alemanniskest': ('alemannisk',),
'alemanniskeste': ('alemannisk',),
'aleutisk': ('aleutisk',),
'aleutiske': ('aleutisk',),
'aleutiskere': ('aleutisk',),
'aleutiskest': ('aleutisk',),
'aleutiskeste': ('aleutisk',),
'alfabetiserende': ('alfabetisere',),
'alfabetisert': ('alfabetisere',),
'alfabetiserte': ('alfabetisere',),
'alfabetisk': ('alfabetisk',),
'alfabetiske': ('alfabetisk',),
'alfabetiskere': ('alfabetisk',),
'alfabetiskest': ('alfabetisk',),
'alfabetiskeste': ('alfabetisk',),
'alfanumerisk': ('alfanumerisk',),
'alfanumeriske': ('alfanumerisk',),
'alfanumeriskere': ('alfanumerisk',),
'alfanumeriskest': ('alfanumerisk',),
'alfanumeriskeste': ('alfanumerisk',),
'algebraisk': ('algebraisk',),
'algebraiske': ('algebraisk',),
'algebraiskere': ('algebraisk',),
'algebraiskest': ('algebraisk',),
'algebraiskeste': ('algebraisk',),
'algerisk': ('algerisk',),
'algeriske': ('algerisk',),
'algeriskere': ('algerisk',),
'algeriskest': ('algerisk',),
'algeriskeste': ('algerisk',),
'algonkinsk': ('algonkinsk',),
'algonkinske': ('algonkinsk',),
'algonkinskere': ('algonkinsk',),
'algonkinskest': ('algonkinsk',),
'algonkinskeste': ('algonkinsk',),
'alienerende': ('alienere',),
'alienert': ('alienere',),
'alienerte': ('alienere',),
'alifatisk': ('alifatisk',),
'alifatiske': ('alifatisk',),
'alifatiskere': ('alifatisk',),
'alifatiskest': ('alifatisk',),
'alifatiskeste': ('alifatisk',),
'alkalisk': ('alkalisk',),
'alkaliske': ('alkalisk',),
'alkaliskere': ('alkalisk',),
'alkaliskest': ('alkalisk',),
'alkaliskeste': ('alkalisk',),
'alkoholholdig': ('alkoholholdig',),
'alkoholholdige': ('alkoholholdig',),
'alkoholholdigere': ('alkoholholdig',),
'alkoholholdigst': ('alkoholholdig',),
'alkoholholdigste': ('alkoholholdig',),
'alkoholiserende': ('alkoholisere',),
'alkoholisert': ('alkoholisere',),
'alkoholiserte': ('alkoholisere',),
'alkoholisk': ('alkoholisk',),
'alkoholiske': ('alkoholisk',),
'alkoholiskere': ('alkoholisk',),
'alkoholiskest': ('alkoholisk',),
'alkoholiskeste': ('alkoholisk',),
'alkoholpåvirka': ('alkoholpåvirka',),
'alkoholpåvirkede': ('alkoholpåvirket',),
'alkoholpåvirket': ('alkoholpåvirket',),
'alkoholpåvirkete': ('alkoholpåvirket',),
'alkoholpåvirketere': ('alkoholpåvirket',),
'alkoholpåvirketest': ('alkoholpåvirket',),
'alkoholpåvirketeste': ('alkoholpåvirket',),
'alkoholskada': ('alkoholskada',),
'alkoholskadd': ('alkoholskadd',),
'alkoholskadde': ('alkoholskadd',),
'alkoholskaddere': ('alkoholskadd',),
'alkoholskaddest': ('alkoholskadd',),
'alkoholskaddeste': ('alkoholskadd',),
'alkoholskadede': ('alkoholskadet',),
'alkoholskadet': ('alkoholskadet',),
'alkoholskadete': ('alkoholskadet',),
'alkoholskadetere': ('alkoholskadet',),
'alkoholskadetest': ('alkoholskadet',),
'alkoholskadeteste': ('alkoholskadet',),
'alkoholsvak': ('alkoholsvak',),
'alkoholsvake': ('alkoholsvak',),
'alkoholsvakere': ('alkoholsvak',),
'alkoholsvakest': ('alkoholsvak',),
'alkoholsvakeste': ('alkoholsvak',),
'alkoholsvakt': ('alkoholsvak',),
'all right': ('all right',),
'all righte': ('all right',),
'all rightere': ('all right',),
'all rightest': ('all right',),
'all righteste': ('all right',),
'all round': ('all round',),
'all slags': ('all slags',),
'allegorisk': ('allegorisk',),
'allegoriske': ('allegorisk',),
'allegoriskere': ('allegorisk',),
'allegoriskest': ('allegorisk',),
'allegoriskeste': ('allegorisk',),
'allehånde': ('allehånde',),
'allel': ('allel',),
'allele': ('allel',),
'allelere': ('allel',),
'allelest': ('allel',),
'alleleste': ('allel',),
'allelt': ('allel',),
'allergisk': ('allergisk',),
'allergiske': ('allergisk',),
'allergiskere': ('allergisk',),
'allergiskest': ('allergisk',),
'allergiskeste': ('allergisk',),
'allestedsnærværende': ('allestedsnærværende',),
'alleuropeisk': ('alleuropeisk',),
'alleuropeiske': ('alleuropeisk',),
'alleuropeiskere': ('alleuropeisk',),
'alleuropeiskest': ('alleuropeisk',),
'alleuropeiskeste': ('alleuropeisk',),
'allierende': ('alliere',),
'alliert': ('alliere',),
'allierte': ('alliere',),
'alliert': ('alliert',),
'allierte': ('alliert',),
'alliertere': ('alliert',),
'alliertest': ('alliert',),
'allierteste': ('alliert',),
'allittererende': ('allitterere',),
'allitterert': ('allitterere',),
'allittererte': ('allitterere',),
'allmektig': ('allmektig',),
'allmektige': ('allmektig',),
'allmektigere': ('allmektig',),
'allmektigst': ('allmektig',),
'allmektigste': ('allmektig',),
'allmenn': ('allmenn',),
'allmenne': ('allmenn',),
'allmennere': ('allmenn',),
'allmennest': ('allmenn',),
'allmenneste': ('allmenn',),
'allment': ('allmenn',),
'allmenn-nyttig': ('allmenn-nyttig',),
'allmenn-nyttige': ('allmenn-nyttig',),
'allmenn-nyttigere': ('allmenn-nyttig',),
'allmenn-nyttigst': ('allmenn-nyttig',),
'allmenn-nyttigste': ('allmenn-nyttig',),
'allmenndannende': ('allmenndannende',),
'allmenngyldig': ('allmenngyldig',),
'allmenngyldige': ('allmenngyldig',),
'allmenngyldigere': ('allmenngyldig',),
'allmenngyldigst': ('allmenngyldig',),
'allmenngyldigste': ('allmenngyldig',),
'allmennmenneskelig': ('allmennmenneskelig',),
'allmennmenneskelige': ('allmennmenneskelig',),
'allmennmenneskeligere': ('allmennmenneskelig',),
'allmennmenneskeligst': ('allmennmenneskelig',),
'allmennmenneskeligste': ('allmennmenneskelig',),
'allmennpraktiserende': ('allmennpraktiserende',),
'allmennpreventiv': ('allmennpreventiv',),
'allmennpreventive': ('allmennpreventiv',),
'allmennpreventivere': ('allmennpreventiv',),
'allmennpreventivest': ('allmennpreventiv',),
'allmennpreventiveste': ('allmennpreventiv',),
'allmennpreventivt': ('allmennpreventiv',),
'allmennyttig': ('allmennyttig',),
'allmennyttige': ('allmennyttig',),
'allmennyttigere': ('allmennyttig',),
'allmennyttigst': ('allmennyttig',),
'allmennyttigste': ('allmennyttig',),
'allofonisk': ('allofonisk',),
'allofoniske': ('allofonisk',),
'allofoniskere': ('allofonisk',),
'allofoniskest': ('allofonisk',),
'allofoniskeste': ('allofonisk',),
'allokerende': ('allokere',),
'allokert': ('allokere',),
'allokerte': ('allokere',),
'allomorfisk': ('allomorfisk',),
'allomorfiske': ('allomorfisk',),
'allomorfiskere': ('allomorfisk',),
'allomorfiskest': ('allomorfisk',),
'allomorfiskeste': ('allomorfisk',),
'allsidig': ('allsidig',),
'allsidige': ('allsidig',),
'allsidigere': ('allsidig',),
'allsidigst': ('allsidig',),
'allsidigste': ('allsidig',),
'allslags': ('allslags',),
'alltysk': ('alltysk',),
'alltyske': ('alltysk',),
'alltyskere': ('alltysk',),
'alltyskest': ('alltysk',),
'alltyskeste': ('alltysk',),
'alluderende': ('alludere',),
'alludert': ('alludere',),
'alluderte': ('alludere',),
'alluvial': ('alluvial',),
'alluviale': ('alluvial',),
'alluvialere': ('alluvial',),
'alluvialest': ('alluvial',),
'alluvialeste': ('alluvial',),
'alluvialt': ('alluvial',),
'allvitende': ('allvitende',),
'alminnelig': ('alminnelig',),
'alminnelige': ('alminnelig',),
'alminneligere': ('alminnelig',),
'alminneligst': ('alminnelig',),
'alminneligste': ('alminnelig',),
'alpin': ('alpin',),
'alpine': ('alpin',),
'alpinere': ('alpin',),
'alpinest': ('alpin',),
'alpineste': ('alpin',),
'alpint': ('alpin',),
'alpinsk': ('alpinsk',),
'alpinske': ('alpinsk',),
'alpinskere': ('alpinsk',),
'alpinskest': ('alpinsk',),
'alpinskeste': ('alpinsk',),
'alsasisk': ('alsasisk',),
'alsasiske': ('alsasisk',),
'alsasiskere': ('alsasisk',),
'alsasiskest': ('alsasisk',),
'alsasiskeste': ('alsasisk',),
'alskens': ('alskens',),
'altaisk': ('altaisk',),
'altaiske': ('altaisk',),
'altaiskere': ('altaisk',),
'altaiskest': ('altaisk',),
'altaiskeste': ('altaisk',),
'altererende': ('alterere',),
'alterert': ('alterere',),
'altererte': ('alterere',),
'alternativ': ('alternativ',),
'alternative': ('alternativ',),
'alternativere': ('alternativ',),
'alternativest': ('alternativ',),
'alternativeste': ('alternativ',),
'alternativt': ('alternativ',),
'alternerende': ('alternere',),
'alternert': ('alternere',),
'alternerte': ('alternere',),
'altetende': ('altetende',),
'altgjennomtrengende': ('altgjennomtrengende',),
'altomfattende': ('altomfattende',),
'altomspennende': ('altomspennende',),
'altoppslukende': ('altoppslukende',),
'altruistisk': ('altruistisk',),
'altruistiske': ('altruistisk',),
'altruistiskere': ('altruistisk',),
'altruistiskest': ('altruistisk',),
'altruistiskeste': ('altruistisk',),
'aluminerende': ('aluminere',),
'aluminert': ('aluminere',),
'aluminerte': ('aluminere',),
'alveolar': ('alveolar',),
'alveolare': ('alveolar',),
'alveolarere': ('alveolar',),
'alveolarest': ('alveolar',),
'alveolareste': ('alveolar',),
'alveolart': ('alveolar',),
'alvorlig': ('alvorlig',),
'alvorlige': ('alvorlig',),
'alvorligere': ('alvorlig',),
'alvorligst': ('alvorlig',),
'alvorligste': ('alvorlig',),
'alvorsfull': ('alvorsfull',),
'alvorsfulle': ('alvorsfull',),
'alvorsfullere': ('alvorsfull',),
'alvorsfullest': ('alvorsfull',),
'alvorsfulleste': ('alvorsfull',),
'alvorsfullt': ('alvorsfull',),
'alvorstung': ('alvorstung',),
'alvorstunge': ('alvorstung',),
'alvorstungere': ('alvorstung',),
'alvorstungest': ('alvorstung',),
'alvorstungeste': ('alvorstung',),
'alvorstungt': ('alvorstung',),
'alvorstyngre': ('alvorstung',),
'alvorstyngst': ('alvorstung',),
'alvorstyngste': ('alvorstung',),
'amalgamerende': ('amalgamere',),
'amalgamert': ('amalgamere',),
'amalgamerte': ('amalgamere',),
'amatørmessig': ('amatørmessig',),
'amatørmessige': ('amatørmessig',),
'amatørmessigere': ('amatørmessig',),
'amatørmessigst': ('amatørmessig',),
'amatørmessigste': ('amatørmessig',),
'ambiguøs': ('ambiguøs',),
'ambiguøse': ('ambiguøs',),
'ambiguøsere': ('ambiguøs',),
'ambiguøsest': ('ambiguøs',),
'ambiguøseste': ('ambiguøs',),
'ambiguøst': ('ambiguøs',),
'ambisiøs': ('ambisiøs',),
'ambisiøse': ('ambisiøs',),
'ambisiøsere': ('ambisiøs',),
'ambisiøsest': ('ambisiøs',),
'ambisiøseste': ('ambisiøs',),
'ambisiøst': ('ambisiøs',),
'ambivalent': ('ambivalent',),
'ambivalente': ('ambivalent',),
'ambivalentere': ('ambivalent',),
'ambivalentest': ('ambivalent',),
'ambivalenteste': ('ambivalent',),
'ambrosiansk': ('ambrosiansk',),
'ambrosianske': ('ambrosiansk',),
'ambrosianskere': ('ambrosiansk',),
'ambrosianskest': ('ambrosiansk',),
'ambrosianskeste': ('ambrosiansk',),
'ambrosisk': ('ambrosisk',),
'ambrosiske': ('ambrosisk',),
'ambrosiskere': ('ambrosisk',),
'ambrosiskest': ('ambrosisk',),
'ambrosiskeste': ('ambrosisk',),
'ambulant': ('ambulant',),
'ambulante': ('ambulant',),
'ambulantere': ('ambulant',),
'ambulantest': ('ambulant',),
'ambulanteste': ('ambulant',),
'ambulatorisk': ('ambulatorisk',),
'ambulatoriske': ('ambulatorisk',),
'ambulatoriskere': ('ambulatorisk',),
'ambulatoriskest': ('ambulatorisk',),
'ambulatoriskeste': ('ambulatorisk',),
'ambulerende': ('ambulere',),
'ambulert': ('ambulere',),
'ambulerte': ('ambulere',),
'ambulerende': ('ambulerende',),
'amerikaniserende': ('amerikanisere',),
'amerikanisert': ('amerikanisere',),
'amerikaniserte': ('amerikanisere',),
'amerikansk': ('amerikansk',),
'amerikanske': ('amerikansk',),
'amerikanskere': ('amerikansk',),
'amerikanskest': ('amerikansk',),
'amerikanskeste': ('amerikansk',),
'amfibisk': ('amfibisk',),
'amfibiske': ('amfibisk',),
'amfibiskere': ('amfibisk',),
'amfibiskest': ('amfibisk',),
'amfibiskeste': ('amfibisk',),
'amma': ('amme',),
'ammede': ('amme',),
'ammende': ('amme',),
'ammet': ('amme',),
'ammete': ('amme',),
'amoralsk': ('amoralsk',),
'amoralske': ('amoralsk',),
'amoralskere': ('amoralsk',),
'amoralskest': ('amoralsk',),
'amoralskeste': ('amoralsk',),
'amorf': ('amorf',),
'amorfe': ('amorf',),
'amorfere': ('amorf',),
'amorfest': ('amorf',),
'amorfeste': ('amorf',),
'amorft': ('amorf',),
'amortisabel': ('amortisabel',),
'amortisabelt': ('amortisabel',),
'amortisable': ('amortisabel',),
'amortisablere': ('amortisabel',),
'amortisablest': ('amortisabel',),
'amortisableste': ('amortisabel',),
'amortiserende': ('amortisere',),
'amortisert': ('amortisere',),
'amortiserte': ('amortisere',),
'amorøs': ('amorøs',),
'amorøse': ('amorøs',),
'amorøsere': ('amorøs',),
'amorøsest': ('amorøs',),
'amorøseste': ('amorøs',),
'amorøst': ('amorøs',),
'amper': ('amper',),
'ampert': ('amper',),
'ampre': ('amper',),
'amprere': ('amper',),
'amprest': ('amper',),
'ampreste': ('amper',),
'amputerende': ('amputere',),
'amputert': ('amputere',),
'amputerte': ('amputere',),
'amøbisk': ('amøbisk',),
'amøbiske': ('amøbisk',),
'amøbiskere': ('amøbisk',),
'amøbiskest': ('amøbisk',),
'amøbiskeste': ('amøbisk',),
'amøboid': ('amøboid',),
'amøboide': ('amøboid',),
'amøboidere': ('amøboid',),
'amøboidest': ('amøboid',),
'amøboideste': ('amøboid',),
'anabol': ('anabol',),
'anabole': ('anabol',),
'anabolere': ('anabol',),
'anabolest': ('anabol',),
'anaboleste': ('anabol',),
'anabolt': ('anabol',),
'anabolsk': ('anabolsk',),
'anabolske': ('anabolsk',),
'anabolskere': ('anabolsk',),
'anabolskest': ('anabolsk',),
'anabolskeste': ('anabolsk',),
'anaerob': ('anaerob',),
'anaerobe': ('anaerob',),
'anaerobere': ('anaerob',),
'anaerobest': ('anaerob',),
'anaerobeste': ('anaerob',),
'anaerobt': ('anaerob',),
'anaforisk': ('anaforisk',),
'anaforiske': ('anaforisk',),
'anaforiskere': ('anaforisk',),
'anaforiskest': ('anaforisk',),
'anaforiskeste': ('anaforisk',),
'anakolutisk': ('anakolutisk',),
'anakolutiske': ('anakolutisk',),
'anakolutiskere': ('anakolutisk',),
'anakolutiskest': ('anakolutisk',),
'anakolutiskeste': ('anakolutisk',),
'anakreontisk': ('anakreontisk',),
'anakreontiske': ('anakreontisk',),
'anakreontiskere': ('anakreontisk',),
'anakreontiskest': ('anakreontisk',),
'anakreontiskeste': ('anakreontisk',),
'anakronistisk': ('anakronistisk',),
'anakronistiske': ('anakronistisk',),
'anakronistiskere': ('anakronistisk',),
'anakronistiskest': ('anakronistisk',),
'anakronistiskeste': ('anakronistisk',),
'anal': ('anal',),
'anale': ('anal',),
'analere': ('anal',),
'analest': ('anal',),
'analeste': ('anal',),
'analt': ('anal',),
'analog': ('analog',),
'analoge': ('analog',),
'analogere': ('analog',),
'analogest': ('analog',),
'analogeste': ('analog',),
'analogt': ('analog',),
'analogisk': ('analogisk',),
'analogiske': ('analogisk',),
'analogiskere': ('analogisk',),
'analogiskest': ('analogisk',),
'analogiskeste': ('analogisk',),
'analyserende': ('analysere',),
'analysert': ('analysere',),
'analyserte': ('analysere',),
'analytisk': ('analytisk',),
'analytiske': ('analytisk',),
'analytiskere': ('analytisk',),
'analytiskest': ('analytisk',),
'analytiskeste': ('analytisk',),
'anapestisk': ('anapestisk',),
'anapestiske': ('anapestisk',),
'anapestiskere': ('anapestisk',),
'anapestiskest': ('anapestisk',),
'anapestiskeste': ('anapestisk',),
'anarkisk': ('anarkisk',),
'anarkiske': ('anarkisk',),
'anarkiskere': ('anarkisk',),
'anarkiskest': ('anarkisk',),
'anarkiskeste': ('anarkisk',),
'anarkistisk': ('anarkistisk',),
'anarkistiske': ('anarkistisk',),
'anarkistiskere': ('anarkistisk',),
'anarkistiskest': ('anarkistisk',),
'anarkistiskeste': ('anarkistisk',),
'anatomisk': ('anatomisk',),
'anatomiske': ('anatomisk',),
'anatomiskere': ('anatomisk',),
'anatomiskest': ('anatomisk',),
'anatomiskeste': ('anatomisk',),
'anbefalende': ('anbefale',),
'anbefalt': ('anbefale',),
'anbefalte': ('anbefale',),
'anbefalelsesverdig': ('anbefalelsesverdig',),
'anbefalelsesverdige': ('anbefalelsesverdig',),
'anbefalelsesverdigere': ('anbefalelsesverdig',),
'anbefalelsesverdigst': ('anbefalelsesverdig',),
'anbefalelsesverdigste': ('anbefalelsesverdig',),
'anbragt': ('anbringe',),
'anbragte': ('anbringe',),
'anbrakt': ('anbringe',),
'anbrakte': ('anbringe',),
'anbringende': ('anbringe',),
'andaktsfull': ('andaktsfull',),
'andaktsfulle': ('andaktsfull',),
'andaktsfullere': ('andaktsfull',),
'andaktsfullest': ('andaktsfull',),
'andaktsfulleste': ('andaktsfull',),
'andaktsfullt': ('andaktsfull',),
'andalusisk': ('andalusisk',),
'andalusiske': ('andalusisk',),
'andalusiskere': ('andalusisk',),
'andalusiskest': ('andalusisk',),
'andalusiskeste': ('andalusisk',),
'anda': ('ande',),
'andede': ('ande',),
'andende': ('ande',),
'andet': ('ande',),
'andete': ('ande',),
'andektig': ('andektig',),
'andektige': ('andektig',),
'andektigere': ('andektig',),
'andektigst': ('andektig',),
'andektigste': ('andektig',),
'andinsk': ('andinsk',),
'andinske': ('andinsk',),
'andinskere': ('andinsk',),
'andinskest': ('andinsk',),
'andinskeste': ('andinsk',),
'andorransk': ('andorransk',),
'andorranske': ('andorransk',),
'andorranskere': ('andorransk',),
'andorranskest': ('andorransk',),
'andorranskeste': ('andorransk',),
'andpusten': ('andpusten',),
'andpustent': ('andpusten',),
'andpustne': ('andpusten',),
'andpustnere': ('andpusten',),
'andpustnest': ('andpusten',),
'andpustneste': ('andpusten',),
'andradd': ('andra',),
'andradde': ('andra',),
'andragende': ('andra',),
'andratt': ('andra',),
'andratte': ('andra',),
'andre': ('andre',),
'andrehånds': ('andrehånds',),
'andreklasses': ('andreklasses',),
'andrerangs': ('andrerangs',),
'androgen': ('androgen',),
'androgene': ('androgen',),
'androgenere': ('androgen',),
'androgenest': ('androgen',),
'androgeneste': ('androgen',),
'androgent': ('androgen',),
'androgyn': ('androgyn',),
'androgyne': ('androgyn',),
'androgynere': ('androgyn',),
'androgynest': ('androgyn',),
'androgyneste': ('androgyn',),
'androgynt': ('androgyn',),
'anduva': ('anduve',),
'anduvede': ('anduve',),
'anduvende': ('anduve',),
'anduvet': ('anduve',),
'anduvete': ('anduve',),
'andøva': ('andøve',),
'andøvd': ('andøve',),
'andøvde': ('andøve',),
'andøvede': ('andøve',),
'andøvende': ('andøve',),
'andøvet': ('andøve',),
'andøvete': ('andøve',),
'anende': ('ane',),
'ant': ('ane',),
'ante': ('ane',),
'anekdotisk': ('anekdotisk',),
'anekdotiske': ('anekdotisk',),
'anekdotiskere': ('anekdotisk',),
'anekdotiskest': ('anekdotisk',),
'anekdotiskeste': ('anekdotisk',),
'anemisk': ('anemisk',),
'anemiske': ('anemisk',),
'anemiskere': ('anemisk',),
'anemiskest': ('anemisk',),
'anemiskeste': ('anemisk',),
'anemofil': ('anemofil',),
'anemofile': ('anemofil',),
'anemofilere': ('anemofil',),
'anemofilest': ('anemofil',),
'anemofileste': ('anemofil',),
'anemofilt': ('anemofil',),
'anerkjennende': ('anerkjenne',),
'anerkjent': ('anerkjenne',),
'anerkjente': ('anerkjenne',),
'anerkjennelsesverdig': ('anerkjennelsesverdig',),
'anerkjennelsesverdige': ('anerkjennelsesverdig',),
'anerkjennelsesverdigere': ('anerkjennelsesverdig',),
'anerkjennelsesverdigst': ('anerkjennelsesverdig',),
'anerkjennelsesverdigste': ('anerkjennelsesverdig',),
'anerkjennende': ('anerkjennende',),
'anerkjent': ('anerkjent',),
'anerkjente': ('anerkjent',),
'anerkjentere': ('anerkjent',),
'anerkjentest': ('anerkjent',),
'anerkjenteste': ('anerkjent',),
'anesteserende': ('anestesere',),
'anestesert': ('anestesere',),
'anesteserte': ('anestesere',),
'anestetisk': ('anestetisk',),
'anestetiske': ('anestetisk',),
'anestetiskere': ('anestetisk',),
'anestetiskest': ('anestetisk',),
'anestetiskeste': ('anestetisk',),
'anfallende': ('anfalle',),
'anfalt': ('anfalle',),
'anfalte': ('anfalle',),
'anfekta': ('anfekte',),
'anfektede': ('anfekte',),
'anfektende': ('anfekte',),
'anfektet': ('anfekte',),
'anfektete': ('anfekte',),
'anførende': ('anføre',),
'anført': ('anføre',),
'anførte': ('anføre',),
'anga': ('ange',),
'angede': ('ange',),
'angende': ('ange',),
'anget': ('ange',),
'angete': ('ange',),
'angelsaksisk': ('angelsaksisk',),
'angelsaksiske': ('angelsaksisk',),
'angelsaksiskere': ('angelsaksisk',),
'angelsaksiskest': ('angelsaksisk',),
'angelsaksiskeste': ('angelsaksisk',),
'angerfull': ('angerfull',),
'angerfulle': ('angerfull',),
'angerfullere': ('angerfull',),
'angerfullest': ('angerfull',),
'angerfulleste': ('angerfull',),
'angerfullt': ('angerfull',),
'angiende': ('angi',),
'angitt': ('angi',),
'angitte': ('angi',),
'angivende': ('angi',),
'angivelig': ('angivelig',),
'angivelige': ('angivelig',),
'angiveligere': ('angivelig',),
'angiveligst': ('angivelig',),
'angiveligste': ('angivelig',),
'angiversk': ('angiversk',),
'angiverske': ('angiversk',),
'angiverskere': ('angiversk',),
'angiverskest': ('angiversk',),
'angiverskeste': ('angiversk',),
'angjeldende': ('angjeldende',),
'angla': ('angle',),
'anglede': ('angle',),
'anglende': ('angle',),
'anglet': ('angle',),
'anglete': ('angle',),
'anglifiserende': ('anglifisere',),
'anglifisert': ('anglifisere',),
'anglifiserte': ('anglifisere',),
'anglikansk': ('anglikansk',),
'anglikanske': ('anglikansk',),
'anglikanskere': ('anglikansk',),
'anglikanskest': ('anglikansk',),
'anglikanskeste': ('anglikansk',),
'angliserende': ('anglisere',),
'anglisert': ('anglisere',),
'angliserte': ('anglisere',),
'angloamerikansk': ('angloamerikansk',),
'angloamerikanske': ('angloamerikansk',),
'angloamerikanskere': ('angloamerikansk',),
'angloamerikanskest': ('angloamerikansk',),
'angloamerikanskeste': ('angloamerikansk',),
'anglofil': ('anglofil',),
'anglofile': ('anglofil',),
'anglofilere': ('anglofil',),
'anglofilest': ('anglofil',),
'anglofileste': ('anglofil',),
'anglofilt': ('anglofil',),
'angolansk': ('angolansk',),
'angolanske': ('angolansk',),
'angolanskere': ('angolansk',),
'angolanskest': ('angolansk',),
'angolanskeste': ('angolansk',),
'angra': ('angre',),
'angrede': ('angre',),
'angrende': ('angre',),
'angret': ('angre',),
'angrete': ('angre',),
'angrende': ('angrende',),
'angrepslysten': ('angrepslysten',),
'angrepslystent': ('angrepslysten',),
'angrepslystne': ('angrepslysten',),
'angrepslystnere': ('angrepslysten',),
'angrepslystnest': ('angrepslysten',),
'angrepslystneste': ('angrepslysten',),
'angrepen': ('angripe',),
'angrepet': ('angripe',),
'angrepne': ('angripe',),
'angripende': ('angripe',),
'angripelig': ('angripelig',),
'angripelige': ('angripelig',),
'angripeligere': ('angripelig',),
'angripeligst': ('angripelig',),
'angripeligste': ('angripelig',),
'angstbitersk': ('angstbitersk',),
'angstbiterske': ('angstbitersk',),
'angstbiterskere': ('angstbitersk',),
'angstbiterskest': ('angstbitersk',),
'angstbiterskeste': ('angstbitersk',),
'angulær': ('angulær',),
'angulære': ('angulær',),
'angulærere': ('angulær',),
'angulærest': ('angulær',),
'angulæreste': ('angulær',),
'angulært': ('angulær',),
'angående': ('angå',),
'angått': ('angå',),
'angåtte': ('angå',),
'anholdende': ('anholde',),
'anholdt': ('anholde',),
'anholdte': ('anholde',),
'animal': ('animal',),
'animale': ('animal',),
'animalere': ('animal',),
'animalest': ('animal',),
'animaleste': ('animal',),
'animalt': ('animal',),
'animaliserende': ('animalisere',),
'animalisert': ('animalisere',),
'animaliserte': ('animalisere',),
'animalsk': ('animalsk',),
'animalske': ('animalsk',),
'animalskere': ('animalsk',),
'animalskest': ('animalsk',),
'animalskeste': ('animalsk',),
'animerende': ('animere',),
'animert': ('animere',),
'animerte': ('animere',),
'animistisk': ('animistisk',),
'animistiske': ('animistisk',),
'animistiskere': ('animistisk',),
'animistiskest': ('animistisk',),
'animistiskeste': ('animistisk',),
'anka': ('anke',),
'ankede': ('anke',),
'ankende': ('anke',),
'anket': ('anke',),
'ankete': ('anke',),
'ankeldjup': ('ankeldjup',),
'ankeldjupe': ('ankeldjup',),
'ankeldjupere': ('ankeldjup',),
'ankeldjupest': ('ankeldjup',),
'ankeldjupeste': ('ankeldjup',),
'ankeldjupt': ('ankeldjup',),
'ankeldyp': ('ankeldyp',),
'ankeldype': ('ankeldyp',),
'ankeldypere': ('ankeldyp',),
'ankeldypest': ('ankeldyp',),
'ankeldypeste': ('ankeldyp',),
'ankeldypt': ('ankeldyp',),
'ankelsid': ('ankelsid',),
'ankelside': ('ankelsid',),
'ankelsidere': ('ankelsid',),
'ankelsidest': ('ankelsid',),
'ankelsideste': ('ankelsid',),
'ankelsidt': ('ankelsid',),
'anklaga': ('anklage',),
'anklagd': ('anklage',),
'anklagde': ('anklage',),
'anklagede': ('anklage',),
'anklagende': ('anklage',),
'anklaget': ('anklage',),
'anklagete': ('anklage',),
'ankommen': ('ankomme',),
'ankommende': ('ankomme',),
'ankommet': ('ankomme',),
'ankomne': ('ankomme',),
'ankra': ('ankre',),
'ankrede': ('ankre',),
'ankrende': ('ankre',),
'ankret': ('ankre',),
'ankrete': ('ankre',),
'anlagt': ('anlagt',),
'anlagte': ('anlagt',),
'anlagtere': ('anlagt',),
'anlagtest': ('anlagt',),
'anlagteste': ('anlagt',),
'anlagt': ('anlegge',),
'anlagte': ('anlegge',),
'anleggende': ('anlegge',),
'anløpende': ('anløpe',),
'anløpet': ('anløpe',),
'anløpt': ('anløpe',),
'anløpte': ('anløpe',),
'anløpen': ('anløpen',),
'anløpent': ('anløpen',),
'anløpne': ('anløpen',),
'anløpnere': ('anløpen',),
'anløpnest': ('anløpen',),
'anløpneste': ('anløpen',),
'anmassa': ('anmasse',),
'anmassede': ('anmasse',),
'anmassende': ('anmasse',),
'anmasset': ('anmasse',),
'anmassete': ('anmasse',),
'anmassende': ('anmassende',),
'anmeldende': ('anmelde',),
'anmeldt': ('anmelde',),
'anmeldte': ('anmelde',),
'anmerka': ('anmerke',),
'anmerkede': ('anmerke',),
'anmerkende': ('anmerke',),
'anmerket': ('anmerke',),
'anmerkete': ('anmerke',),
'anmoda': ('anmode',),
'anmodede': ('anmode',),
'anmodende': ('anmode',),
'anmodet': ('anmode',),
'anmodete': ('anmode',),
'annalistisk': ('annalistisk',),
'annalistiske': ('annalistisk',),
'annalistiskere': ('annalistisk',),
'annalistiskest': ('annalistisk',),
'annalistiskeste': ('annalistisk',),
'annamma': ('annamme',),
'annammede': ('annamme',),
'annammende': ('annamme',),
'annammet': ('annamme',),
'annammete': ('annamme',),
'annekterende': ('annektere',),
'annektert': ('annektere',),
'annekterte': ('annektere',),
'annenhånds': ('annenhånds',),
'annenklasses': ('annenklasses',),
'annenrangs': ('annenrangs',),
'annerledes': ('annerledes',),
'annerledestenkende': ('annerledestenkende',),
'annleis': ('annleis',),
'annleistenkende': ('annleistenkende',),
'annonserende': ('annonsere',),
'annonsert': ('annonsere',),
'annonserte': ('annonsere',),
'annuell': ('annuell',),
'annuelle': ('annuell',),
'annuellere': ('annuell',),
'annuellest': ('annuell',),
'annuelleste': ('annuell',),
'annuelt': ('annuell',),
'annullerende': ('annullere',),
'annullert': ('annullere',),
'annullerte': ('annullere',),
'anodiserende': ('anodisere',),
'anodisert': ('anodisere',),
'anodiserte': ('anodisere',),
'anodisk': ('anodisk',),
'anodiske': ('anodisk',),
'anodiskere': ('anodisk',),
'anodiskest': ('anodisk',),
'anodiskeste': ('anodisk',),
'anomal': ('anomal',),
'anomale': ('anomal',),
'anomalere': ('anomal',),
'anomalest': ('anomal',),
'anomaleste': ('anomal',),
'anomalt': ('anomal',),
'anonym': ('anonym',),
'anonyme': ('anonym',),
'anonymere': ('anonym',),
'anonymest': ('anonym',),
'anonymeste': ('anonym',),
'anonymt': ('anonym',),
'anordna': ('anordne',),
'anordnede': ('anordne',),
'anordnende': ('anordne',),
'anordnet': ('anordne',),
'anordnete': ('anordne',),
'anorganisk': ('anorganisk',),
'anorganiske': ('anorganisk',),
'anorganiskere': ('anorganisk',),
'anorganiskest': ('anorganisk',),
'anorganiskeste': ('anorganisk',),
'anormal': ('anormal',),
'anormale': ('anormal',),
'anormalere': ('anormal',),
'anormalest': ('anormal',),
'anormaleste': ('anormal',),
'anormalt': ('anormal',),
'anretta': ('anrette',),
'anrettede': ('anrette',),
'anrettende': ('anrette',),
'anrettet': ('anrette',),
'anrettete': ('anrette',),
'anrika': ('anrike',),
'anrikede': ('anrike',),
'anrikende': ('anrike',),
'anriket': ('anrike',),
'anrikete': ('anrike',),
'anropende': ('anrope',),
'anropt': ('anrope',),
'anropte': ('anrope',),
'ansatt': ('ansatt',),
'ansatte': ('ansatt',),
'ansattere': ('ansatt',),
'ansattest': ('ansatt',),
'ansatteste': ('ansatt',),
'ansa': ('anse',),
'ansede': ('anse',),
'ansende': ('anse',),
'anset': ('anse',),
'ansete': ('anse',),
'anst': ('anse',),
'anste': ('anse',),
'anseende': ('anse',),
'ansett': ('anse',),
'ansette': ('anse',),
'anselig': ('anselig',),
'anselige': ('anselig',),
'anseligere': ('anselig',),
'anseligst': ('anselig',),
'anseligste': ('anselig',),
'ansett': ('ansett',),
'ansette': ('ansett',),
'ansettere': ('ansett',),
'ansettest': ('ansett',),
'ansetteste': ('ansett',),
'ansatt': ('ansette',),
'ansatte': ('ansette',),
'ansettende': ('ansette',),
'anskaffa': ('anskaffe',),
'anskaffede': ('anskaffe',),
'anskaffende': ('anskaffe',),
'anskaffet': ('anskaffe',),
'anskaffete': ('anskaffe',),
'anskreven': ('anskreven',),
'anskrevet': ('anskreven',),
'anskrevne': ('anskreven',),
'anskrevnere': ('anskreven',),
'anskrevnest': ('anskreven',),
'anskrevneste': ('anskreven',),
'anskrevet': ('anskrevet',),
'anskrevne': ('anskrevet',),
'anskrevnere': ('anskrevet',),
'anskrevnest': ('anskrevet',),
'anskrevneste': ('anskrevet',),
'anskua': ('anskue',),
'anskuede': ('anskue',),
'anskuende': ('anskue',),
'anskuet': ('anskue',),
'anskuete': ('anskue',),
'anskuelig': ('anskuelig',),
'anskuelige': ('anskuelig',),
'anskueligere': ('anskuelig',),
'anskueligst': ('anskuelig',),
'anskueligste': ('anskuelig',),
'anskueliggjort': ('anskueliggjøre',),
'anskueliggjorte': ('anskueliggjøre',),
'anskueliggjørende': ('anskueliggjøre',),
'anslående': ('anslå',),
'anslått': ('anslå',),
'anslåtte': ('anslå',),
'anspennende': ('anspenne',),
'anspent': ('anspenne',),
'anspente': ('anspenne',),
'anspent': ('anspent',),
'anspente': ('anspent',),
'anspentere': ('anspent',),
'anspentest': ('anspent',),
'anspenteste': ('anspent',),
'anspora': ('anspore',),
'ansporede': ('anspore',),
'ansporende': ('anspore',),
'ansporet': ('anspore',),
'ansporete': ('anspore',),
'ansport': ('anspore',),
'ansporte': ('anspore',),
'ansporende': ('ansporende',),
'anstendig': ('anstendig',),
'anstendige': ('anstendig',),
'anstendigere': ('anstendig',),
'anstendigst': ('anstendig',),
'anstendigste': ('anstendig',),
'anstifta': ('anstifte',),
'anstiftede': ('anstifte',),
'anstiftende': ('anstifte',),
'anstiftet': ('anstifte',),
'anstiftete': ('anstifte',),
'anstillende': ('anstille',),
'anstilt': ('anstille',),
'anstilte': ('anstille',),
'anstrengende': ('anstrenge',),
'anstrengt': ('anstrenge',),
'anstrengte': ('anstrenge',),
'anstrengende': ('anstrengende',),
'anstrengt': ('anstrengt',),
'anstrengte': ('anstrengt',),
'anstrengtere': ('anstrengt',),
'anstrengtest': ('anstrengt',),
'anstrengteste': ('anstrengt',),
'anstrøken': ('anstrøken',),
'anstrøkent': ('anstrøken',),
'anstrøket': ('anstrøken',),
'anstrøkne': ('anstrøken',),
'anstrøknere': ('anstrøken',),
'anstrøknest': ('anstrøken',),
'anstrøkneste': ('anstrøken',),
'anstående': ('anstå',),
'anstått': ('anstå',),
'anståtte': ('anstå',),
'anstøtelig': ('anstøtelig',),
'anstøtelige': ('anstøtelig',),
'anstøteligere': ('anstøtelig',),
'anstøteligst': ('anstøtelig',),
'anstøteligste': ('anstøtelig',),
'anstøtende': ('anstøtende',),
'ansvarlig': ('ansvarlig',),
'ansvarlige': ('ansvarlig',),
'ansvarligere': ('ansvarlig',),
'ansvarligst': ('ansvarlig',),
'ansvarligste': ('ansvarlig',),
'ansvarsbevisst': ('ansvarsbevisst',),
'ansvarsbevisste': ('ansvarsbevisst',),
'ansvarsbevisstere': ('ansvarsbevisst',),
'ansvarsbevisstest': ('ansvarsbevisst',),
'ansvarsbevissteste': ('ansvarsbevisst',),
'ansvarsfull': ('ansvarsfull',),
'ansvarsfulle': ('ansvarsfull',),
'ansvarsfullere': ('ansvarsfull',),
'ansvarsfullest': ('ansvarsfull',),
'ansvarsfulleste': ('ansvarsfull',),
'ansvarsfullt': ('ansvarsfull',),
'ansvarshavende': ('ansvarshavende',),
'ansvarslaus': ('ansvarslaus',),
'ansvarslause': ('ansvarslaus',),
'ansvarslausere': ('ansvarslaus',),
'ansvarslausest': ('ansvarslaus',),
'ansvarslauseste': ('ansvarslaus',),
'ansvarslaust': ('ansvarslaus',),
'ansvarsløs': ('ansvarsløs',),
'ansvarsløse': ('ansvarsløs',),
'ansvarsløsere': ('ansvarsløs',),
'ansvarsløsest': ('ansvarsløs',),
'ansvarsløseste': ('ansvarsløs',),
'ansvarsløst': ('ansvarsløs',),
'ansvarstung': ('ansvarstung',),
'ansvarstunge': ('ansvarstung',),
'ansvarstungere': ('ansvarstung',),
'ansvarstungest': ('ansvarstung',),
'ansvarstungeste': ('ansvarstung',),
'ansvarstungt': ('ansvarstung',),
'ansvarstyngre': ('ansvarstung',),
'ansvarstyngst': ('ansvarstung',),
'ansvarstyngste': ('ansvarstung',),
'ansøkende': ('ansøke',),
'ansøkt': ('ansøke',),
'ansøkte': ('ansøke',),
'antakende': ('anta',),
'antatt': ('anta',),
'antatte': ('anta',),
'antagonistisk': ('antagonistisk',),
'antagonistiske': ('antagonistisk',),
'antagonistiskere': ('antagonistisk',),
'antagonistiskest': ('antagonistisk',),
'antagonistiskeste': ('antagonistisk',),
'antakelig': ('antakelig',),
'antakelige': ('antakelig',),
'antakeligere': ('antakelig',),
'antakeligst': ('antakelig',),
'antakeligste': ('antakelig',),
'antarktisk': ('antarktisk',),
'antarktiske': ('antarktisk',),
'antarktiskere': ('antarktisk',),
'antarktiskest': ('antarktisk',),
'antarktiskeste': ('antarktisk',),
'antasta': ('antaste',),
'antastede': ('antaste',),
'antastende': ('antaste',),
'antastet': ('antaste',),
'antastete': ('antaste',),
'antedaterende': ('antedatere',),
'antedatert': ('antedatere',),
'antedaterte': ('antedatere',),
'antediluvial': ('antediluvial',),
'antediluviale': ('antediluvial',),
'antediluvialere': ('antediluvial',),
'antediluvialest': ('antediluvial',),
'antediluvialeste': ('antediluvial',),
'antediluvialt': ('antediluvial',),
'antediluviansk': ('antediluviansk',),
'antediluvianske': ('antediluviansk',),
'antediluvianskere': ('antediluviansk',),
'antediluvianskest': ('antediluviansk',),
'antediluvianskeste': ('antediluviansk',),
'antegna': ('antegne',),
'antegnede': ('antegne',),
'antegnende': ('antegne',),
'antegnet': ('antegne',),
'antegnete': ('antegne',),
'antennende': ('antenne',),
'antent': ('antenne',),
'antente': ('antenne',),
'antennelig': ('antennelig',),
'antennelige': ('antennelig',),
'antenneligere': ('antennelig',),
'antenneligst': ('antennelig',),
'antenneligste': ('antennelig',),
'antesiperende': ('antesipere',),
'antesipert': ('antesipere',),
'antesiperte': ('antesipere',),
'antibiotisk': ('antibiotisk',),
'antibiotiske': ('antibiotisk',),
'antibiotiskere': ('antibiotisk',),
'antibiotiskest': ('antibiotisk',),
'antibiotiskeste': ('antibiotisk',),
'antidemokratisk': ('antidemokratisk',),
'antidemokratiske': ('antidemokratisk',),
'antidemokratiskere': ('antidemokratisk',),
'antidemokratiskest': ('antidemokratisk',),
'antidemokratiskeste': ('antidemokratisk',),
'antigen': ('antigen',),
'antigene': ('antigen',),
'antigenere': ('antigen',),
'antigenest': ('antigen',),
'antigeneste': ('antigen',),
'antigent': ('antigen',),
'antiguansk': ('antiguansk',),
'antiguanske': ('antiguansk',),
'antiguanskere': ('antiguansk',),
'antiguanskest': ('antiguansk',),
'antiguanskeste': ('antiguansk',),
'antikiserende': ('antikisere',),
'antikisert': ('antikisere',),
'antikiserte': ('antikisere',),
'antikk': ('antikk',),
'antikke': ('antikk',),
'antikkere': ('antikk',),
'antikkest': ('antikk',),
'antikkeste': ('antikk',),
'antikt': ('antikk',),
'antiklerikal': ('antiklerikal',),
'antiklerikale': ('antiklerikal',),
'antiklerikalere': ('antiklerikal',),
'antiklerikalest': ('antiklerikal',),
'antiklerikaleste': ('antiklerikal',),
'antiklerikalt': ('antiklerikal',),
'antikommunistisk': ('antikommunistisk',),
'antikommunistiske': ('antikommunistisk',),
'antikommunistiskere': ('antikommunistisk',),
'antikommunistiskest': ('antikommunistisk',),
'antikommunistiskeste': ('antikommunistisk',),
'antikrympbehandla': ('antikrympbehandle',),
'antikrympbehandlede': ('antikrympbehandle',),
'antikrympbehandlende': ('antikrympbehandle',),
'antikrympbehandlet': ('antikrympbehandle',),
'antikrympbehandlete': ('antikrympbehandle',),
'antikrøllbehandla': ('antikrøllbehandle',),
'antikrøllbehandlede': ('antikrøllbehandle',),
'antikrøllbehandlende': ('antikrøllbehandle',),
'antikrøllbehandlet': ('antikrøllbehandle',),
'antikrøllbehandlete': ('antikrøllbehandle',),
'antikvarisk': ('antikvarisk',),
'antikvariske': ('antikvarisk',),
'antikvariskere': ('antikvarisk',),
'antikvariskest': ('antikvarisk',),
'antikvariskeste': ('antikvarisk',),
'antikvert': ('antikvert',),
'antikverte': ('antikvert',),
'antikvertere': ('antikvert',),
'antikvertest': ('antikvert',),
'antikverteste': ('antikvert',),
'antimilitaristisk': ('antimilitaristisk',),
'antimilitaristiske': ('antimilitaristisk',),
'antimilitaristiskere': ('antimilitaristisk',),
'antimilitaristiskest': ('antimilitaristisk',),
'antimilitaristiskeste': ('antimilitaristisk',),
'antipatisk': ('antipatisk',),
'antipatiske': ('antipatisk',),
'antipatiskere': ('antipatisk',),
'antipatiskest': ('antipatisk',),
'antipatiskeste': ('antipatisk',),
'antipodisk': ('antipodisk',),
'antipodiske': ('antipodisk',),
'antipodiskere': ('antipodisk',),
'antipodiskest': ('antipodisk',),
'antipodiskeste': ('antipodisk',),
'antirefleksbehandla': ('antirefleksbehandle',),
'antirefleksbehandlede': ('antirefleksbehandle',),
'antirefleksbehandlende': ('antirefleksbehandle',),
'antirefleksbehandlet': ('antirefleksbehandle',),
'antirefleksbehandlete': ('antirefleksbehandle',),
'antirustbehandla': ('antirustbehandle',),
'antirustbehandlede': ('antirustbehandle',),
'antirustbehandlende': ('antirustbehandle',),
'antirustbehandlet': ('antirustbehandle',),
'antirustbehandlete': ('antirustbehandle',),
'antisemittisk': ('antisemittisk',),
'antisemittiske': ('antisemittisk',),
'antisemittiskere': ('antisemittisk',),
'antisemittiskest': ('antisemittisk',),
'antisemittiskeste': ('antisemittisk',),
'antiseptisk': ('antiseptisk',),
'antiseptiske': ('antiseptisk',),
'antiseptiskere': ('antiseptisk',),
'antiseptiskest': ('antiseptisk',),
'antiseptiskeste': ('antiseptisk',),
'antistatbehandla': ('antistatbehandle',),
'antistatbehandlede': ('antistatbehandle',),
'antistatbehandlende': ('antistatbehandle',),
'antistatbehandlet': ('antistatbehandle',),
'antistatbehandlete': ('antistatbehandle',),
'antistatisk': ('antistatisk',),
'antistatiske': ('antistatisk',),
'antistatiskere': ('antistatisk',),
'antistatiskest': ('antistatisk',),
'antistatiskeste': ('antistatisk',),
'antitetisk': ('antitetisk',),
'antitetiske': ('antitetisk',),
'antitetiskere': ('antitetisk',),
'antitetiskest': ('antitetisk',),
'antitetiskeste': ('antitetisk',),
'antitoksisk': ('antitoksisk',),
'antitoksiske': ('antitoksisk',),
'antitoksiskere': ('antitoksisk',),
'antitoksiskest': ('antitoksisk',),
'antitoksiskeste': ('antitoksisk',),
'antologisk': ('antologisk',),
'antologiske': ('antologisk',),
'antologiskere': ('antologisk',),
'antologiskest': ('antologisk',),
'antologiskeste': ('antologisk',),
'antonym': ('antonym',),
'antonyme': ('antonym',),
'antonymere': ('antonym',),
'antonymest': ('antonym',),
'antonymeste': ('antonym',),
'antonymt': ('antonym',),
'antropofobisk': ('antropofobisk',),
'antropofobiske': ('antropofobisk',),
'antropofobiskere': ('antropofobisk',),
'antropofobiskest': ('antropofobisk',),
'antropofobiskeste': ('antropofobisk',),
'antropologisk': ('antropologisk',),
'antropologiske': ('antropologisk',),
'antropologiskere': ('antropologisk',),
'antropologiskest': ('antropologisk',),
'antropologiskeste': ('antropologisk',),
'antropomorf': ('antropomorf',),
'antropomorfe': ('antropomorf',),
'antropomorfere': ('antropomorf',),
'antropomorfest': ('antropomorf',),
'antropomorfeste': ('antropomorf',),
'antropomorft': ('antropomorf',),
'antroposofisk': ('antroposofisk',),
'antroposofiske': ('antroposofisk',),
'antroposofiskere': ('antroposofisk',),
'antroposofiskest': ('antroposofisk',),
'antroposofiskeste': ('antroposofisk',),
'antrukket': ('antrukket',),
'antrukne': ('antrukket',),
'antruknere': ('antrukket',),
'antruknest': ('antrukket',),
'antrukneste': ('antrukket',),
'antyda': ('antyde',),
'antydede': ('antyde',),
'antydende': ('antyde',),
'antydet': ('antyde',),
'antydete': ('antyde',),
'anvendende': ('anvende',),
'anvendt': ('anvende',),
'anvendte': ('anvende',),
'anvendelig': ('anvendelig',),
'anvendelige': ('anvendelig',),
'anvendeligere': ('anvendelig',),
'anvendeligst': ('anvendelig',),
'anvendeligste': ('anvendelig',),
'anvendt': ('anvendt',),
'anvendte': ('anvendt',),
'anvendtere': ('anvendt',),
'anvendtest': ('anvendt',),
'anvendteste': ('anvendt',),
'anvisende': ('anvise',),
'anvist': ('anvise',),
'anviste': ('anvise',),
'apalgrå': ('apalgrå',),
'apalgråe': ('apalgrå',),
'apalgråere': ('apalgrå',),
'apalgråest': ('apalgrå',),
'apalgråeste': ('apalgrå',),
'apalgrått': ('apalgrå',),
'aparte': ('aparte',),
'apatisk': ('apatisk',),
'apatiske': ('apatisk',),
'apatiskere': ('apatisk',),
'apatiskest': ('apatisk',),
'apatiskeste': ('apatisk',),
'apa': ('ape',),
'apede': ('ape',),
'apende': ('ape',),
'apet': ('ape',),
'apete': ('ape',),
'apt': ('ape',),
'apte': ('ape',),
'apikal': ('apikal',),
'apikale': ('apikal',),
'apikalere': ('apikal',),
'apikalest': ('apikal',),
'apikaleste': ('apikal',),
'apikalt': ('apikal',),
'apokalyptisk': ('apokalyptisk',),
'apokalyptiske': ('apokalyptisk',),
'apokalyptiskere': ('apokalyptisk',),
'apokalyptiskest': ('apokalyptisk',),
'apokalyptiskeste': ('apokalyptisk',),
'apokoperende': ('apokopere',),
'apokopert': ('apokopere',),
'apokoperte': ('apokopere',),
'apokryf': ('apokryf',),
'apokryfe': ('apokryf',),
'apokryfere': ('apokryf',),
'apokryfest': ('apokryf',),
'apokryfeste': ('apokryf',),
'apokryft': ('apokryf',),
'apokryfisk': ('apokryfisk',),
'apokryfiske': ('apokryfisk',),
'apokryfiskere': ('apokryfisk',),
'apokryfiskest': ('apokryfisk',),
'apokryfiskeste': ('apokryfisk',),
'apolitisk': ('apolitisk',),
'apolitiske': ('apolitisk',),
'apolitiskere': ('apolitisk',),
'apolitiskest': ('apolitisk',),
'apolitiskeste': ('apolitisk',),
'apollinsk': ('apollinsk',),
'apollinske': ('apollinsk',),
'apollinskere': ('apollinsk',),
'apollinskest': ('apollinsk',),
'apollinskeste': ('apollinsk',),
'apologetisk': ('apologetisk',),
'apologetiske': ('apologetisk',),
'apologetiskere': ('apologetisk',),
'apologetiskest': ('apologetisk',),
'apologetiskeste': ('apologetisk',),
'apoplektisk': ('apoplektisk',),
'apoplektiske': ('apoplektisk',),
'apoplektiskere': ('apoplektisk',),
'apoplektiskest': ('apoplektisk',),
'apoplektiskeste': ('apoplektisk',),
'aposteriorisk': ('aposteriorisk',),
'aposterioriske': ('aposteriorisk',),
'aposterioriskere': ('aposteriorisk',),
'aposterioriskest': ('aposteriorisk',),
'aposterioriskeste': ('aposteriorisk',),
'apostolisk': ('apostolisk',),
'apostoliske': ('apostolisk',),
'apostoliskere': ('apostolisk',),
'apostoliskest': ('apostolisk',),
'apostoliskeste': ('apostolisk',),
'apostroferende': ('apostrofere',),
'apostrofert': ('apostrofere',),
'apostroferte': ('apostrofere',),
'appellabel': ('appellabel',),
'appellabelt': ('appellabel',),
'appellable': ('appellabel',),
'appellablere': ('appellabel',),
'appellablest': ('appellabel',),
'appellableste': ('appellabel',),
'appellativisk': ('appellativisk',),
'appellativiske': ('appellativisk',),
'appellativiskere': ('appellativisk',),
'appellativiskest': ('appellativisk',),
'appellativiskeste': ('appellativisk',),
'appellerende': ('appellere',),
'appellert': ('appellere',),
'appellerte': ('appellere',),
'appetittlig': ('appetittlig',),
'appetittlige': ('appetittlig',),
'appetittligere': ('appetittlig',),
'appetittligst': ('appetittlig',),
'appetittligste': ('appetittlig',),
'appetittvekkende': ('appetittvekkende',),
'applauderende': ('applaudere',),
'applaudert': ('applaudere',),
'applauderte': ('applaudere',),
'applikerende': ('applikere',),
'applikert': ('applikere',),
'applikerte': ('applikere',),
'appliserende': ('applisere',),
'applisert': ('applisere',),
'appliserte': ('applisere',),
'apporterende': ('apportere',),
'apportert': ('apportere',),
'apporterte': ('apportere',),
'apposisjonell': ('apposisjonell',),
'apposisjonelle': ('apposisjonell',),
'apposisjonellere': ('apposisjonell',),
'apposisjonellest': ('apposisjonell',),
'apposisjonelleste': ('apposisjonell',),
'apposisjonelt': ('apposisjonell',),
'appreterende': ('appretere',),
'appretert': ('appretere',),
'appreterte': ('appretere',),
'approberende': ('approbere',),
'approbert': ('approbere',),
'approberte': ('approbere',),
'approksimativ': ('approksimativ',),
'approksimative': ('approksimativ',),
'approksimativere': ('approksimativ',),
'approksimativest': ('approksimativ',),
'approksimativeste': ('approksimativ',),
'approksimativt': ('approksimativ',),
'approprierende': ('appropriere',),
'appropriert': ('appropriere',),
'approprierte': ('appropriere',),
'aprikosfarga': ('aprikosfarga',),
'aprikosfargede': ('aprikosfarget',),
'aprikosfarget': ('aprikosfarget',),
'aprikosfargete': ('aprikosfarget',),
'aprikosfargetere': ('aprikosfarget',),
'aprikosfargetest': ('aprikosfarget',),
'aprikosfargeteste': ('aprikosfarget',),
'apriorisk': ('apriorisk',),
'aprioriske': ('apriorisk',),
'aprioriskere': ('apriorisk',),
'aprioriskest': ('apriorisk',),
'aprioriskeste': ('apriorisk',),
'apsidal': ('apsidal',),
'apsidale': ('apsidal',),
'apsidalere': ('apsidal',),
'apsidalest': ('apsidal',),
'apsidaleste': ('apsidal',),
'apsidalt': ('apsidal',),
'apterende': ('aptere',),
'aptert': ('aptere',),
'apterte': ('aptere',),
'arabisk': ('arabisk',),
'arabiske': ('arabisk',),
'arabiskere': ('arabisk',),
'arabiskest': ('arabisk',),
'arabiskeste': ('arabisk',),
'arameisk': ('arameisk',),
'arameiske': ('arameisk',),
'arameiskere': ('arameisk',),
'arameiskest': ('arameisk',),
'arameiskeste': ('arameisk',),
'arbeida': ('arbeide',),
'arbeidd': ('arbeide',),
'arbeidde': ('arbeide',),
'arbeidede': ('arbeide',),
'arbeidende': ('arbeide',),
'arbeidet': ('arbeide',),
'arbeidete': ('arbeide',),
'arbeidsbesparende': ('arbeidsbesparende',),
'arbeidsdyktig': ('arbeidsdyktig',),
'arbeidsdyktige': ('arbeidsdyktig',),
'arbeidsdyktigere': ('arbeidsdyktig',),
'arbeidsdyktigst': ('arbeidsdyktig',),
'arbeidsdyktigste': ('arbeidsdyktig',),
'arbeidsfør': ('arbeidsfør',),
'arbeidsføre': ('arbeidsfør',),
'arbeidsførere': ('arbeidsfør',),
'arbeidsførest': ('arbeidsfør',),
'arbeidsføreste': ('arbeidsfør',),
'arbeidsført': ('arbeidsfør',),
'arbeidsglad': ('arbeidsglad',),
'arbeidsglade': ('arbeidsglad',),
'arbeidsgladere': ('arbeidsglad',),
'arbeidsgladest': ('arbeidsglad',),
'arbeidsgladeste': ('arbeidsglad',),
'arbeidsintensiv': ('arbeidsintensiv',),
'arbeidsintensive': ('arbeidsintensiv',),
'arbeidsintensivere': ('arbeidsintensiv',),
'arbeidsintensivest': ('arbeidsintensiv',),
'arbeidsintensiveste': ('arbeidsintensiv',),
'arbeidsintensivt': ('arbeidsintensiv',),
'arbeidskrevende': ('arbeidskrevende',),
'arbeidslaus': ('arbeidslaus',),
'arbeidslause': ('arbeidslaus',),
'arbeidslausere': ('arbeidslaus',),
'arbeidslausest': ('arbeidslaus',),
'arbeidslauseste': ('arbeidslaus',),
'arbeidslaust': ('arbeidslaus',),
'arbeidsledig': ('arbeidsledig',),
'arbeidsledige': ('arbeidsledig',),
'arbeidsledigere': ('arbeidsledig',),
'arbeidsledigst': ('arbeidsledig',),
'arbeidsledigste': ('arbeidsledig',),
'arbeidsløs': ('arbeidsløs',),
'arbeidsløse': ('arbeidsløs',),
'arbeidsløsere': ('arbeidsløs',),
'arbeidsløsest': ('arbeidsløs',),
'arbeidsløseste': ('arbeidsløs',),
'arbeidsløst': ('arbeidsløs',),
'arbeidsom': ('arbeidsom',),
'arbeidsomme': ('arbeidsom',),
'arbeidsommere': ('arbeidsom',),
'arbeidsomst': ('arbeidsom',),
'arbeidsomste': ('arbeidsom',),
'arbeidsomt': ('arbeidsom',),
'arbeidssparende': ('arbeidssparende',),
'arbeidsudyktig': ('arbeidsudyktig',),
'arbeidsudyktige': ('arbeidsudyktig',),
'arbeidsudyktigere': ('arbeidsudyktig',),
'arbeidsudyktigst': ('arbeidsudyktig',),
'arbeidsudyktigste': ('arbeidsudyktig',),
'arbeidsufør': ('arbeidsufør',),
'arbeidsuføre': ('arbeidsufør',),
'arbeidsuførere': ('arbeidsufør',),
'arbeidsuførest': ('arbeidsufør',),
'arbeidsuføreste': ('arbeidsufør',),
'arbeidsuført': ('arbeidsufør',),
'arbitrær': ('arbitrær',),
'arbitrære': ('arbitrær',),
'arbitrærere': ('arbitrær',),
'arbitrærest': ('arbitrær',),
'arbitræreste': ('arbitrær',),
'arbitrært': ('arbitrær',),
'arda': ('arde',),
'ardede': ('arde',),
'ardende': ('arde',),
'ardet': ('arde',),
'ardete': ('arde',),
'arg': ('arg',),
'arge': ('arg',),
'argere': ('arg',),
'argest': ('arg',),
'argeste': ('arg',),
'argt': ('arg',),
'arga': ('arge',),
'argede': ('arge',),
'argende': ('arge',),
'arget': ('arge',),
'argete': ('arge',),
'argentinsk': ('argentinsk',),
'argentinske': ('argentinsk',),
'argentinskere': ('argentinsk',),
'argentinskest': ('argentinsk',),
'argentinskeste': ('argentinsk',),
'argumenterende': ('argumentere',),
'argumentert': ('argumentere',),
'argumenterte': ('argumentere',),
'arid': ('arid',),
'aride': ('arid',),
'aridere': ('arid',),
'aridest': ('arid',),
'arideste': ('arid',),
'arisk': ('arisk',),
'ariske': ('arisk',),
'ariskere': ('arisk',),
'ariskest': ('arisk',),
'ariskeste': ('arisk',),
'aristokratisk': ('aristokratisk',),
'aristokratiske': ('aristokratisk',),
'aristokratiskere': ('aristokratisk',),
'aristokratiskest': ('aristokratisk',),
'aristokratiskeste': ('aristokratisk',),
'aristotelisk': ('aristotelisk',),
'aristoteliske': ('aristotelisk',),
'aristoteliskere': ('aristotelisk',),
'aristoteliskest': ('aristotelisk',),
'aristoteliskeste': ('aristotelisk',),
'aritmetisk': ('aritmetisk',),
'aritmetiske': ('aritmetisk',),
'aritmetiskere': ('aritmetisk',),
'aritmetiskest': ('aritmetisk',),
'aritmetiskeste': ('aritmetisk',),
'arkaiserende': ('arkaisere',),
'arkaisert': ('arkaisere',),
'arkaiserte': ('arkaisere',),
'arkaisk': ('arkaisk',),
'arkaiske': ('arkaisk',),
'arkaiskere': ('arkaisk',),
'arkaiskest': ('arkaisk',),
'arkaiskeste': ('arkaisk',),
'arkaistisk': ('arkaistisk',),
'arkaistiske': ('arkaistisk',),
'arkaistiskere': ('arkaistisk',),
'arkaistiskest': ('arkaistisk',),
'arkaistiskeste': ('arkaistisk',),
'arkebuserende': ('arkebusere',),
'arkebusert': ('arkebusere',),
'arkebuserte': ('arkebusere',),
'arkeologisk': ('arkeologisk',),
'arkeologiske': ('arkeologisk',),
'arkeologiskere': ('arkeologisk',),
'arkeologiskest': ('arkeologisk',),
'arkeologiskeste': ('arkeologisk',),
'arketypisk': ('arketypisk',),
'arketypiske': ('arketypisk',),
'arketypiskere': ('arketypisk',),
'arketypiskest': ('arketypisk',),
'arketypiskeste': ('arketypisk',),
'arkitektonisk': ('arkitektonisk',),
'arkitektoniske': ('arkitektonisk',),
'arkitektoniskere': ('arkitektonisk',),
'arkitektoniskest': ('arkitektonisk',),
'arkitektoniskeste': ('arkitektonisk',),
'arkitekttegna': ('arkitekttegna',),
'arkitekttegnede': ('arkitekttegnet',),
'arkitekttegnet': ('arkitekttegnet',),
'arkitekttegnete': ('arkitekttegnet',),
'arkitekttegnetere': ('arkitekttegnet',),
'arkitekttegnetest': ('arkitekttegnet',),
'arkitekttegneteste': ('arkitekttegnet',),
'arkiverende': ('arkivere',),
'arkivert': ('arkivere',),
'arkiverte': ('arkivere',),
'arktisk': ('arktisk',),
'arktiske': ('arktisk',),
'arktiskere': ('arktisk',),
'arktiskest': ('arktisk',),
'arktiskeste': ('arktisk',),
'arm': ('arm',),
'arme': ('arm',),
'armere': ('arm',),
'armest': ('arm',),
'armeste': ('arm',),
'armt': ('arm',),
'arma': ('arme',),
'armede': ('arme',),
'armende': ('arme',),
'armet': ('arme',),
'armete': ('arme',),
'armensk': ('armensk',),
'armenske': ('armensk',),
'armenskere': ('armensk',),
'armenskest': ('armensk',),
'armenskeste': ('armensk',),
'armerende': ('armere',),
'armert': ('armere',),
'armerte': ('armere',),
'armodslig': ('armodslig',),
'armodslige': ('armodslig',),
'armodsligere': ('armodslig',),
'armodsligst': ('armodslig',),
'armodsligste': ('armodslig',),
'aromatiserende': ('aromatisere',),
'aromatisert': ('aromatisere',),
'aromatiserte': ('aromatisere',),
'aromatisk': ('aromatisk',),
'aromatiske': ('aromatisk',),
'aromatiskere': ('aromatisk',),
'aromatiskest': ('aromatisk',),
'aromatiskeste': ('aromatisk',),
'arrangerende': ('arrangere',),
'arrangert': ('arrangere',),
'arrangerte': ('arrangere',),
'arresterende': ('arrestere',),
'arrestert': ('arrestere',),
'arresterte': ('arrestere',),
'arret': ('arret',),
'arrete': ('arret',),
'arretere': ('arret',),
'arretest': ('arret',),
'arreteste': ('arret',),
'arrete': ('arrete',),
'arreterende': ('arretere',),
'arretert': ('arretere',),
'arreterte': ('arretere',),
'arrig': ('arrig',),
'arrige': ('arrig',),
'arrigere': ('arrig',),
'arrigst': ('arrig',),
'arrigste': ('arrig',),
'arriverende': ('arrivere',),
'arrivert': ('arrivere',),
'arriverte': ('arrivere',),
'arrogant': ('arrogant',),
'arrogante': ('arrogant',),
'arrogantere': ('arrogant',),
'arrogantest': ('arrogant',),
'arroganteste': ('arrogant',),
'arronderende': ('arrondere',),
'arrondert': ('arrondere',),
'arronderte': ('arrondere',),
'arsenikkholdig': ('arsenikkholdig',),
'arsenikkholdige': ('arsenikkholdig',),
'arsenikkholdigere': ('arsenikkholdig',),
'arsenikkholdigst': ('arsenikkholdig',),
'arsenikkholdigste': ('arsenikkholdig',),
'arta': ('arte',),
'artede': ('arte',),
'artende': ('arte',),
'artet': ('arte',),
'artete': ('arte',),
'arteriell': ('arteriell',),
'arterielle': ('arteriell',),
'arteriellere': ('arteriell',),
'arteriellest': ('arteriell',),
'arterielleste': ('arteriell',),
'arterielt': ('arteriell',),
'artesisk': ('artesisk',),
'artesiske': ('artesisk',),
'artesiskere': ('artesisk',),
'artesiskest': ('artesisk',),
'artesiskeste': ('artesisk',),
'artifisiell': ('artifisiell',),
'artifisielle': ('artifisiell',),
'artifisiellere': ('artifisiell',),
'artifisiellest': ('artifisiell',),
'artifisielleste': ('artifisiell',),
'artifisielt': ('artifisiell',),
'artig': ('artig',),
'artige': ('artig',),
'artigere': ('artig',),
'artigst': ('artig',),
'artigste': ('artig',),
'artikulatorisk': ('artikulatorisk',),
'artikulatoriske': ('artikulatorisk',),
'artikulatoriskere': ('artikulatorisk',),
'artikulatoriskest': ('artikulatorisk',),
'artikulatoriskeste': ('artikulatorisk',),
'artikulerende': ('artikulere',),
'artikulert': ('artikulere',),
'artikulerte': ('artikulere',),
'artistisk': ('artistisk',),
'artistiske': ('artistisk',),
'artistiskere': ('artistisk',),
'artistiskest': ('artistisk',),
'artistiskeste': ('artistisk',),
'artsbestemmende': ('artsbestemme',),
'artsbestemt': ('artsbestemme',),
'artsbestemte': ('artsbestemme',),
'artsfattig': ('artsfattig',),
'artsfattige': ('artsfattig',),
'artsfattigere': ('artsfattig',),
'artsfattigst': ('artsfattig',),
'artsfattigste': ('artsfattig',),
'artsforskjellig': ('artsforskjellig',),
'artsforskjellige': ('artsforskjellig',),
'artsforskjelligere': ('artsforskjellig',),
'artsforskjelligst': ('artsforskjellig',),
'artsforskjelligste': ('artsforskjellig',),
'artsrein': ('artsrein',),
'artsreine': ('artsrein',),
'artsreinere': ('artsrein',),
'artsreinest': ('artsrein',),
'artsreineste': ('artsrein',),
'artsreint': ('artsrein',),
'artsren': ('artsren',),
'artsrene': ('artsren',),
'artsrenere': ('artsren',),
'artsrenest': ('artsren',),
'artsreneste': ('artsren',),
'artsrent': ('artsren',),
'artsrik': ('artsrik',),
'artsrike': ('artsrik',),
'artsrikere': ('artsrik',),
'artsrikest': ('artsrik',),
'artsrikeste': ('artsrik',),
'artsrikt': ('artsrik',),
'artstypisk': ('artstypisk',),
'artstypiske': ('artstypisk',),
'artstypiskere': ('artstypisk',),
'artstypiskest': ('artstypisk',),
'artstypiskeste': ('artstypisk',),
'arva': ('arve',),
'arvede': ('arve',),
'arvende': ('arve',),
'arvet': ('arve',),
'arvete': ('arve',),
'arveberettiga': ('arveberettiga',),
'arveberettigede': ('arveberettiget',),
'arveberettiget': ('arveberettiget',),
'arveberettigete': ('arveberettiget',),
'arveberettigetere': ('arveberettiget',),
'arveberettigetest': ('arveberettiget',),
'arveberettigeteste': ('arveberettiget',),
'arvelaus': ('arvelaus',),
'arvelause': ('arvelaus',),
'arvelausere': ('arvelaus',),
'arvelausest': ('arvelaus',),
'arvelauseste': ('arvelaus',),
'arvelaust': ('arvelaus',),
'arvelig': ('arvelig',),
'arvelige': ('arvelig',),
'arveligere': ('arvelig',),
'arveligst': ('arvelig',),
'arveligste': ('arvelig',),
'arveløs': ('arveløs',),
'arveløse': ('arveløs',),
'arveløsere': ('arveløs',),
'arveløsest': ('arveløs',),
'arveløseste': ('arveløs',),
'arveløst': ('arveløs',),
'asa': ('ase',),
'asende': ('ase',),
'ast': ('ase',),
'aste': ('ase',),
'aseksuell': ('aseksuell',),
'aseksuelle': ('aseksuell',),
'aseksuellere': ('aseksuell',),
'aseksuellest': ('aseksuell',),
'aseksuelleste': ('aseksuell',),
'aseksuelt': ('aseksuell',),
'aseptisk': ('aseptisk',),
'aseptiske': ('aseptisk',),
'aseptiskere': ('aseptisk',),
'aseptiskest': ('aseptisk',),
'aseptiskeste': ('aseptisk',),
'aserbajdsjansk': ('aserbajdsjansk',),
'aserbajdsjanske': ('aserbajdsjansk',),
'aserbajdsjanskere': ('aserbajdsjansk',),
'aserbajdsjanskest': ('aserbajdsjansk',),
'aserbajdsjanskeste': ('aserbajdsjansk',),
'aset': ('aset',),
'asete': ('aset',),
'asetere': ('aset',),
'asetest': ('aset',),
'aseteste': ('aset',),
'asete': ('asete',),
'asfalterende': ('asfaltere',),
'asfaltert': ('asfaltere',),
'asfalterte': ('asfaltere',),
'asiatisk': ('asiatisk',),
'asiatiske': ('asiatisk',),
'asiatiskere': ('asiatisk',),
'asiatiskest': ('asiatisk',),
'asiatiskeste': ('asiatisk',),
'askeblond': ('askeblond',),
'askeblonde': ('askeblond',),
'askeblondere': ('askeblond',),
'askeblondest': ('askeblond',),
'askeblondeste': ('askeblond',),
'askeblondt': ('askeblond',),
'askeblond': ('askeblond',),
'askeblonde': ('askeblond',),
'askeblondere': ('askeblond',),
'askeblondest': ('askeblond',),
'askeblondeste': ('askeblond',),
'askeblondt': ('askeblond',),
'askegrå': ('askegrå',),
'askegråe': ('askegrå',),
'askegråere': ('askegrå',),
'askegråest': ('askegrå',),
'askegråeste': ('askegrå',),
'askegrått': ('askegrå',),
'askegrå': ('askegrå',),
'askegråe': ('askegrå',),
'askegråere': ('askegrå',),
'askegråest': ('askegrå',),
'askegråeste': ('askegrå',),
'askegrått': ('askegrå',),
'askenasisk': ('askenasisk',),
'askenasiske': ('askenasisk',),
'askenasiskere': ('askenasisk',),
'askenasiskest': ('askenasisk',),
'askenasiskeste': ('askenasisk',),
'asketisk': ('asketisk',),
'asketiske': ('asketisk',),
'asketiskere': ('asketisk',),
'asketiskest': ('asketisk',),
'asketiskeste': ('asketisk',),
'asomatisk': ('asomatisk',),
'asomatiske': ('asomatisk',),
'asomatiskere': ('asomatisk',),
'asomatiskest': ('asomatisk',),
'asomatiskeste': ('asomatisk',),
'asosial': ('asosial',),
'asosiale': ('asosial',),
'asosialere': ('asosial',),
'asosialest': ('asosial',),
'asosialeste': ('asosial',),
'asosialt': ('asosial',),
'aspiratorisk': ('aspiratorisk',),
'aspiratoriske': ('aspiratorisk',),
'aspiratoriskere': ('aspiratorisk',),
'aspiratoriskest': ('aspiratorisk',),
'aspiratoriskeste': ('aspiratorisk',),
'aspirerende': ('aspirere',),
'aspirert': ('aspirere',),
'aspirerte': ('aspirere',),
'assimilatorisk': ('assimilatorisk',),
'assimilatoriske': ('assimilatorisk',),
'assimilatoriskere': ('assimilatorisk',),
'assimilatoriskest': ('assimilatorisk',),
'assimilatoriskeste': ('assimilatorisk',),
'assimilerende': ('assimilere',),
'assimilert': ('assimilere',),
'assimilerte': ('assimilere',),
'assisterende': ('assistere',),
'assistert': ('assistere',),
'assisterte': ('assistere',),
'assorterende': ('assortere',),
'assortert': ('assortere',),
'assorterte': ('assortere',),
'assosiativ': ('assosiativ',),
'assosiative': ('assosiativ',),
'assosiativere': ('assosiativ',),
'assosiativest': ('assosiativ',),
'assosiativeste': ('assosiativ',),
'assosiativt': ('assosiativ',),
'assosierende': ('assosiere',),
'assosiert': ('assosiere',),
'assosierte': ('assosiere',),
'assurerende': ('assurere',),
'assurert': ('assurere',),
'assurerte': ('assurere',),
'assyrisk': ('assyrisk',),
'assyriske': ('assyrisk',),
'assyriskere': ('assyrisk',),
'assyriskest': ('assyrisk',),
'assyriskeste': ('assyrisk',),
'astenisk': ('astenisk',),
'asteniske': ('astenisk',),
'asteniskere': ('astenisk',),
'asteniskest': ('astenisk',),
'asteniskeste': ('astenisk',),
'astigmatisk': ('astigmatisk',),
'astigmatiske': ('astigmatisk',),
'astigmatiskere': ('astigmatisk',),
'astigmatiskest': ('astigmatisk',),
'astigmatiskeste': ('astigmatisk',),
'astmasjuk': ('astmasjuk',),
'astmasjuke': ('astmasjuk',),
'astmasjukere': ('astmasjuk',),
'astmasjukest': ('astmasjuk',),
'astmasjukeste': ('astmasjuk',),
'astmasjukt': ('astmasjuk',),
'astmasyk': ('astmasyk',),
'astmasyke': ('astmasyk',),
'astmasykere': ('astmasyk',),
'astmasykest': ('astmasyk',),
'astmasykeste': ('astmasyk',),
'astmasykt': ('astmasyk',),
'astmatisk': ('astmatisk',),
'astmatiske': ('astmatisk',),
'astmatiskere': ('astmatisk',),
'astmatiskest': ('astmatisk',),
'astmatiskeste': ('astmatisk',),
'astral': ('astral',),
'astrale': ('astral',),
'astralere': ('astral',),
'astralest': ('astral',),
'astraleste': ('astral',),
'astralt': ('astral',),
'astringerende': ('astringere',),
'astringert': ('astringere',),
'astringerte': ('astringere',),
'astrofysisk': ('astrofysisk',),
'astrofysiske': ('astrofysisk',),
'astrofysiskere': ('astrofysisk',),
'astrofysiskest': ('astrofysisk',),
'astrofysiskeste': ('astrofysisk',),
'astrologisk': ('astrologisk',),
'astrologiske': ('astrologisk',),
'astrologiskere': ('astrologisk',),
'astrologiskest': ('astrologisk',),
'astrologiskeste': ('astrologisk',),
'astronomisk': ('astronomisk',),
'astronomiske': ('astronomisk',),
'astronomiskere': ('astronomisk',),
'astronomiskest': ('astronomisk',),
'astronomiskeste': ('astronomisk',),
'asurblå': ('asurblå',),
'asurblåe': ('asurblå',),
'asurblåere': ('asurblå',),
'asurblåest': ('asurblå',),
'asurblåeste': ('asurblå',),
'asurblått': ('asurblå',),
'asymmetrisk': ('asymmetrisk',),
'asymmetriske': ('asymmetrisk',),
'asymmetriskere': ('asymmetrisk',),
'asymmetriskest': ('asymmetrisk',),
'asymmetriskeste': ('asymmetrisk',),
'asymptotisk': ('asymptotisk',),
'asymptotiske': ('asymptotisk',),
'asymptotiskere': ('asymptotisk',),
'asymptotiskest': ('asymptotisk',),
'asymptotiskeste': ('asymptotisk',),
'asyndetisk': ('asyndetisk',),
'asyndetiske': ('asyndetisk',),
'asyndetiskere': ('asyndetisk',),
'asyndetiskest': ('asyndetisk',),
'asyndetiskeste': ('asyndetisk',),
'asynkron': ('asynkron',),
'asynkrone': ('asynkron',),
'asynkronere': ('asynkron',),
'asynkronest': ('asynkron',),
'asynkroneste': ('asynkron',),
'asynkront': ('asynkron',),
'atal': ('atal',),
'atale': ('atal',),
'atalere': ('atal',),
'atalest': ('atal',),
'ataleste': ('atal',),
'atalt': ('atal',),
'atavistisk': ('atavistisk',),
'atavistiske': ('atavistisk',),
'atavistiskere': ('atavistisk',),
'atavistiskest': ('atavistisk',),
'atavistiskeste': ('atavistisk',),
'ateistisk': ('ateistisk',),
'ateistiske': ('ateistisk',),
'ateistiskere': ('ateistisk',),
'ateistiskest': ('ateistisk',),
'ateistiskeste': ('ateistisk',),
'atensk': ('atensk',),
'atenske': ('atensk',),
'atenskere': ('atensk',),
'atenskest': ('atensk',),
'atenskeste': ('atensk',),
'athensk': ('athensk',),
'athenske': ('athensk',),
'athenskere': ('athensk',),
'athenskest': ('athensk',),
'athenskeste': ('athensk',),
'atlantisk': ('atlantisk',),
'atlantiske': ('atlantisk',),
'atlantiskere': ('atlantisk',),
'atlantiskest': ('atlantisk',),
'atlantiskeste': ('atlantisk',),
'atlantocanadisk': ('atlantocanadisk',),
'atlantocanadiske': ('atlantocanadisk',),
'atlantocanadiskere': ('atlantocanadisk',),
'atlantocanadiskest': ('atlantocanadisk',),
'atlantocanadiskeste': ('atlantocanadisk',),
'atlantokanadisk': ('atlantokanadisk',),
'atlantokanadiske': ('atlantokanadisk',),
'atlantokanadiskere': ('atlantokanadisk',),
'atlantokanadiskest': ('atlantokanadisk',),
'atlantokanadiskeste': ('atlantokanadisk',),
'atlantoskandisk': ('atlantoskandisk',),
'atlantoskandiske': ('atlantoskandisk',),
'atlantoskandiskere': ('atlantoskandisk',),
'atlantoskandiskest': ('atlantoskandisk',),
'atlantoskandiskeste': ('atlantoskandisk',),
'atletisk': ('atletisk',),
'atletiske': ('atletisk',),
'atletiskere': ('atletisk',),
'atletiskest': ('atletisk',),
'atletiskeste': ('atletisk',),
'atmosfærisk': ('atmosfærisk',),
'atmosfæriske': ('atmosfærisk',),
'atmosfæriskere': ('atmosfærisk',),
'atmosfæriskest': ('atmosfærisk',),
'atmosfæriskeste': ('atmosfærisk',),
'atoksisk': ('atoksisk',),
'atoksiske': ('atoksisk',),
'atoksiskere': ('atoksisk',),
'atoksiskest': ('atoksisk',),
'atoksiskeste': ('atoksisk',),
'atomar': ('atomar',),
'atomare': ('atomar',),
'atomarere': ('atomar',),
'atomarest': ('atomar',),
'atomareste': ('atomar',),
'atomart': ('atomar',),
'atomdrevet': ('atomdrevet',),
'atomdrevne': ('atomdrevet',),
'atomdrevnere': ('atomdrevet',),
'atomdrevnest': ('atomdrevet',),
'atomdrevneste': ('atomdrevet',),
'atomiserende': ('atomisere',),
'atomisert': ('atomisere',),
'atomiserte': ('atomisere',),
'atomistisk': ('atomistisk',),
'atomistiske': ('atomistisk',),
'atomistiskere': ('atomistisk',),
'atomistiskest': ('atomistisk',),
'atomistiskeste': ('atomistisk',),
'atomær': ('atomær',),
'atomære': ('atomær',),
'atomærere': ('atomær',),
'atomærest': ('atomær',),
'atomæreste': ('atomær',),
'atomært': ('atomær',),
'atonal': ('atonal',),
'atonale': ('atonal',),
'atonalere': ('atonal',),
'atonalest': ('atonal',),
'atonaleste': ('atonal',),
'atonalt': ('atonal',),
'atrofierende': ('atrofiere',),
'atrofiert': ('atrofiere',),
'atrofierte': ('atrofiere',),
'atrofisk': ('atrofisk',),
'atrofiske': ('atrofisk',),
'atrofiskere': ('atrofisk',),
'atrofiskest': ('atrofisk',),
'atrofiskeste': ('atrofisk',),
'atskillende': ('atskille',),
'atskilt': ('atskille',),
'atskilte': ('atskille',),
'atskillig': ('atskillig',),
'atskillige': ('atskillig',),
'atskilligere': ('atskillig',),
'atskilligst': ('atskillig',),
'atskilligste': ('atskillig',),
'atskilt': ('atskilt',),
'atskilte': ('atskilt',),
'atskiltere': ('atskilt',),
'atskiltest': ('atskilt',),
'atskilteste': ('atskilt',),
'atspredd': ('atspre',),
'atspredde': ('atspre',),
'atspredt': ('atspre',),
'atspredte': ('atspre',),
'atspreende': ('atspre',),
'atspredd': ('atsprede',),
'atspredde': ('atsprede',),
'atspredende': ('atsprede',),
'atspredt': ('atsprede',),
'atspredte': ('atsprede',),
'atspredt': ('atspredt',),
'atspredte': ('atspredt',),
'atspredtere': ('atspredt',),
'atspredtest': ('atspredt',),
'atspredteste': ('atspredt',),
'attacherende': ('attachere',),
'attachert': ('attachere',),
'attacherte': ('attachere',),
'attakkerende': ('attakkere',),
'attakkert': ('attakkere',),
'attakkerte': ('attakkere',),
'attende': ('attende',),
'attenårig': ('attenårig',),
'attenårige': ('attenårig',),
'attenårigere': ('attenårig',),
'attenårigst': ('attenårig',),
'attenårigste': ('attenårig',),
'attenårs': ('attenårs',),
'attesterende': ('attestere',),
'attestert': ('attestere',),
'attesterte': ('attestere',),
'attisk': ('attisk',),
'attiske': ('attisk',),
'attiskere': ('attisk',),
'attiskest': ('attisk',),
'attiskeste': ('attisk',),
'attraherende': ('attrahere',),
'attrahert': ('attrahere',),
'attraherte': ('attrahere',),
'attraktiv': ('attraktiv',),
'attraktive': ('attraktiv',),
'attraktivere': ('attraktiv',),
'attraktivest': ('attraktiv',),
'attraktiveste': ('attraktiv',),
'attraktivt': ('attraktiv',),
'attributiv': ('attributiv',),
'attributive': ('attributiv',),
'attributivere': ('attributiv',),
'attributivest': ('attributiv',),
'attributiveste': ('attributiv',),
'attributivt': ('attributiv',),
'attrådd': ('attrå',),
'attrådde': ('attrå',),
'attrående': ('attrå',),
'attråvekkende': ('attråvekkende',),
'attråverdig': ('attråverdig',),
'attråverdige': ('attråverdig',),
'attråverdigere': ('attråverdig',),
'attråverdigst': ('attråverdig',),
'attråverdigste': ('attråverdig',),
'atypisk': ('atypisk',),
'atypiske': ('atypisk',),
'atypiskere': ('atypisk',),
'atypiskest': ('atypisk',),
'atypiskeste': ('atypisk',),
'audienssøkende': ('audienssøkende',),
'audiologisk': ('audiologisk',),
'audiologiske': ('audiologisk',),
'audiologiskere': ('audiologisk',),
'audiologiskest': ('audiologisk',),
'audiologiskeste': ('audiologisk',),
'audiovisuell': ('audiovisuell',),
'audiovisuelle': ('audiovisuell',),
'audiovisuellere': ('audiovisuell',),
'audiovisuellest': ('audiovisuell',),
'audiovisuelleste': ('audiovisuell',),
'audiovisuelt': ('audiovisuell',),
'auditiv': ('auditiv',),
'auditive': ('auditiv',),
'auditivere': ('auditiv',),
'auditivest': ('auditiv',),
'auditiveste': ('auditiv',),
'auditivt': ('auditiv',),
'augsburgsk': ('augsburgsk',),
'augsburgske': ('augsburgsk',),
'augsburgskere': ('augsburgsk',),
'augsburgskest': ('augsburgsk',),
'augsburgskeste': ('augsburgsk',),
'augustinsk': ('augustinsk',),
'augustinske': ('augustinsk',),
'augustinskere': ('augustinsk',),
'augustinskest': ('augustinsk',),
'augustinskeste': ('augustinsk',),
'auka': ('auke',),
'aukede': ('auke',),
'aukende': ('auke',),
'auket': ('auke',),
'aukete': ('auke',),
'aukt': ('auke',),
'aukte': ('auke',),
'auksjonerende': ('auksjonere',),
'auksjonert': ('auksjonere',),
'auksjonerte': ('auksjonere',),
'aura': ('aure',),
'aurede': ('aure',),
'aurende': ('aure',),
'auret': ('aure',),
'aurete': ('aure',),
'auret': ('auret',),
'aurete': ('auret',),
'auretere': ('auret',),
'auretest': ('auret',),
'aureteste': ('auret',),
'aurete': ('aurete',),
'ausende': ('ause',),
'aust': ('ause',),
'auste': ('ause',),
'austafjelsk': ('austafjelsk',),
'austafjelske': ('austafjelsk',),
'austafjelskere': ('austafjelsk',),
'austafjelskest': ('austafjelsk',),
'austafjelskeste': ('austafjelsk',),
'austasiatisk': ('austasiatisk',),
'austasiatiske': ('austasiatisk',),
'austasiatiskere': ('austasiatisk',),
'austasiatiskest': ('austasiatisk',),
'austasiatiskeste': ('austasiatisk',),
'austeuropeisk': ('austeuropeisk',),
'austeuropeiske': ('austeuropeisk',),
'austeuropeiskere': ('austeuropeisk',),
'austeuropeiskest': ('austeuropeisk',),
'austeuropeiskeste': ('austeuropeisk',),
'austgermansk': ('austgermansk',),
'austgermanske': ('austgermansk',),
'austgermanskere': ('austgermansk',),
'austgermanskest': ('austgermansk',),
'austgermanskeste': ('austgermansk',),
'austgermansk': ('austgermansk',),
'austgermanske': ('austgermansk',),
'austgermanskere': ('austgermansk',),
'austgermanskest': ('austgermansk',),
'austgermanskeste': ('austgermansk',),
'austgermansk': ('austgermansk',),
'austgermanske': ('austgermansk',),
'austgermanskere': ('austgermansk',),
'austgermanskest': ('austgermansk',),
'austgermanskeste': ('austgermansk',),
'austgotisk': ('austgotisk',),
'austgotiske': ('austgotisk',),
'austgotiskere': ('austgotisk',),
'austgotiskest': ('austgotisk',),
'austgotiskeste': ('austgotisk',),
'austlandsk': ('austlandsk',),
'austlandske': ('austlandsk',),
'austlandskere': ('austlandsk',),
'austlandskest': ('austlandsk',),
'austlandskeste': ('austlandsk',),
'austlig': ('austlig',),
'austlige': ('austlig',),
'austligere': ('austlig',),
'austligst': ('austlig',),
'austligste': ('austlig',),
'austnordisk': ('austnordisk',),
'austnordiske': ('austnordisk',),
'austnordiskere': ('austnordisk',),
'austnordiskest': ('austnordisk',),
'austnordiskeste': ('austnordisk',),
'austnordisk': ('austnordisk',),
'austnordiske': ('austnordisk',),
'austnordiskere': ('austnordisk',),
'austnordiskest': ('austnordisk',),
'austnordiskeste': ('austnordisk',),
'austnordisk': ('austnordisk',),
'austnordiske': ('austnordisk',),
'austnordiskere': ('austnordisk',),
'austnordiskest': ('austnordisk',),
'austnordiskeste': ('austnordisk',),
'austnorsk': ('austnorsk',),
'austnorske': ('austnorsk',),
'austnorskere': ('austnorsk',),
'austnorskest': ('austnorsk',),
'austnorskeste': ('austnorsk',),
'australsk': ('australsk',),
'australske': ('australsk',),
'australskere': ('australsk',),
'australskest': ('australsk',),
'australskeste': ('australsk',),
'austre': ('austre',),
'austromarxistisk': ('austromarxistisk',),
'austromarxistiske': ('austromarxistisk',),
'austromarxistiskere': ('austromarxistisk',),
'austromarxistiskest': ('austromarxistisk',),
'austromarxistiskeste': ('austromarxistisk',),
'austromersk': ('austromersk',),
'austromerske': ('austromersk',),
'austromerskere': ('austromersk',),
'austromerskest': ('austromersk',),
'austromerskeste': ('austromersk',),
'austtysk': ('austtysk',),
'austtyske': ('austtysk',),
'austtyskere': ('austtysk',),
'austtyskest': ('austtysk',),
'austtyskeste': ('austtysk',),
'austvendt': ('austvendt',),
'austvendte': ('austvendt',),
'austvendtere': ('austvendt',),
'austvendtest': ('austvendt',),
'austvendteste': ('austvendt',),
'autentisk': ('autentisk',),
'autentiske': ('autentisk',),
'autentiskere': ('autentisk',),
'autentiskest': ('autentisk',),
'autentiskeste': ('autentisk',),
'autistisk': ('autistisk',),
'autistiske': ('autistisk',),
'autistiskere': ('autistisk',),
'autistiskest': ('autistisk',),
'autistiskeste': ('autistisk',),
'autobiografisk': ('autobiografisk',),
'autobiografiske': ('autobiografisk',),
'autobiografiskere': ('autobiografisk',),
'autobiografiskest': ('autobiografisk',),
'autobiografiskeste': ('autobiografisk',),
'autodidaktisk': ('autodidaktisk',),
'autodidaktiske': ('autodidaktisk',),
'autodidaktiskere': ('autodidaktisk',),
'autodidaktiskest': ('autodidaktisk',),
'autodidaktiskeste': ('autodidaktisk',),
'autogen': ('autogen',),
'autogene': ('autogen',),
'autogenere': ('autogen',),
'autogenest': ('autogen',),
'autogeneste': ('autogen',),
'autogent': ('autogen',),
'autoklaverende': ('autoklavere',),
'autoklavert': ('autoklavere',),
'autoklaverte': ('autoklavere',),
'autokratisk': ('autokratisk',),
'autokratiske': ('autokratisk',),
'autokratiskere': ('autokratisk',),
'autokratiskest': ('autokratisk',),
'autokratiskeste': ('autokratisk',),
'automatiserende': ('automatisere',),
'automatisert': ('automatisere',),
'automatiserte': ('automatisere',),
'automatisk': ('automatisk',),
'automatiske': ('automatisk',),
'automatiskere': ('automatisk',),
'automatiskest': ('automatisk',),
'automatiskeste': ('automatisk',),
'autonom': ('autonom',),
'autonome': ('autonom',),
'autonomere': ('autonom',),
'autonomest': ('autonom',),
'autonomeste': ('autonom',),
'autonomt': ('autonom',),
'autoral': ('autoral',),
'autorale': ('autoral',),
'autoralere': ('autoral',),
'autoralest': ('autoral',),
'autoraleste': ('autoral',),
'autoralt': ('autoral',),
'autoriserende': ('autorisere',),
'autorisert': ('autorisere',),
'autoriserte': ('autorisere',),
'autoritativ': ('autoritativ',),
'autoritative': ('autoritativ',),
'autoritativere': ('autoritativ',),
'autoritativest': ('autoritativ',),
'autoritativeste': ('autoritativ',),
'autoritativt': ('autoritativ',),
'autoritær': ('autoritær',),
'autoritære': ('autoritær',),
'autoritærere': ('autoritær',),
'autoritærest': ('autoritær',),
'autoritæreste': ('autoritær',),
'autoritært': ('autoritær',),
'avalerende': ('avalere',),
'avalert': ('avalere',),
'avalerte': ('avalere',),
'avanserende': ('avansere',),
'avansert': ('avansere',),
'avanserte': ('avansere',),
'avantgardistisk': ('avantgardistisk',),
'avantgardistiske': ('avantgardistisk',),
'avantgardistiskere': ('avantgardistisk',),
'avantgardistiskest': ('avantgardistisk',),
'avantgardistiskeste': ('avantgardistisk',),
'avbaklig': ('avbaklig',),
'avbaklige': ('avbaklig',),
'avbakligere': ('avbaklig',),
'avbakligst': ('avbaklig',),
'avbakligste': ('avbaklig',),
'avbalanserende': ('avbalansere',),
'avbalansert': ('avbalansere',),
'avbalanserte': ('avbalansere',),
'avbalansert': ('avbalansert',),
'avbalanserte': ('avbalansert',),
'avbalansertere': ('avbalansert',),
'avbalansertest': ('avbalansert',),
'avbalanserteste': ('avbalansert',),
'avbestillende': ('avbestille',),
'avbestilt': ('avbestille',),
'avbestilte': ('avbestille',),
'avbetalende': ('avbetale',),
'avbetalt': ('avbetale',),
'avbetalte': ('avbetale',),
'avbilda': ('avbilde',),
'avbildede': ('avbilde',),
'avbildende': ('avbilde',),
'avbildet': ('avbilde',),
'avbildete': ('avbilde',),
'avbindende': ('avbinde',),
'avbunden': ('avbinde',),
'avbundet': ('avbinde',),
'avbundne': ('avbinde',),
'avbleikede': ('avbleiket',),
'avbleiket': ('avbleiket',),
'avbleikete': ('avbleiket',),
'avbleiketere': ('avbleiket',),
'avbleiketest': ('avbleiket',),
'avbleiketeste': ('avbleiket',),
'avbleikt': ('avbleikt',),
'avbleikte': ('avbleikt',),
'avbleiktere': ('avbleikt',),
'avbleiktest': ('avbleikt',),
'avbleikteste': ('avbleikt',),
'avblekede': ('avbleket',),
'avbleket': ('avbleket',),
'avblekete': ('avbleket',),
'avbleketere': ('avbleket',),
'avbleketest': ('avbleket',),
'avbleketeste': ('avbleket',),
'avblekt': ('avblekt',),
'avblekte': ('avblekt',),
'avblektere': ('avblekt',),
'avblektest': ('avblekt',),
'avblekteste': ('avblekt',),
'avblomstra': ('avblomstra',),
'avblomstrede': ('avblomstret',),
'avblomstret': ('avblomstret',),
'avblomstrete': ('avblomstret',),
'avblomstretere': ('avblomstret',),
'avblomstretest': ('avblomstret',),
'avblomstreteste': ('avblomstret',),
'avblåsende': ('avblåse',),
'avblåst': ('avblåse',),
'avblåste': ('avblåse',),
'avbrutt': ('avbryte',),
'avbrutte': ('avbryte',),
'avbrytende': ('avbryte',),
'avbøtende': ('avbøte',),
'avbøtt': ('avbøte',),
'avbøtte': ('avbøte',),
'avbøya': ('avbøye',),
'avbøyd': ('avbøye',),
'avbøyde': ('avbøye',),
'avbøyede': ('avbøye',),
'avbøyende': ('avbøye',),
'avbøyet': ('avbøye',),
'avbøyete': ('avbøye',),
'avdampa': ('avdampe',),
'avdampede': ('avdampe',),
'avdampende': ('avdampe',),
'avdampet': ('avdampe',),
'avdampete': ('avdampe',),
'avdanka': ('avdanka',),
'avdankede': ('avdanket',),
'avdanket': ('avdanket',),
'avdankete': ('avdanket',),
'avdanketere': ('avdanket',),
'avdanketest': ('avdanket',),
'avdanketeste': ('avdanket',),
'avdekka': ('avdekke',),
'avdekkede': ('avdekke',),
'avdekkende': ('avdekke',),
'avdekket': ('avdekke',),
'avdekkete': ('avdekke',),
'avdekt': ('avdekke',),
'avdekte': ('avdekke',),
'avdelende': ('avdele',),
'avdelt': ('avdele',),
'avdelte': ('avdele',),
'avdempa': ('avdempe',),
'avdempede': ('avdempe',),
'avdempende': ('avdempe',),
'avdempet': ('avdempe',),
'avdempete': ('avdempe',),
'avdradd': ('avdra',),
'avdradde': ('avdra',),
'avdragende': ('avdra',),
'avdratt': ('avdra',),
'avdratte': ('avdra',),
'avdragsfri': ('avdragsfri',),
'avdragsfrie': ('avdragsfri',),
'avdragsfriere': ('avdragsfri',),
'avdragsfriest': ('avdragsfri',),
'avdragsfrieste': ('avdragsfri',),
'avdragsfritt': ('avdragsfri',),
'avdramatiserende': ('avdramatisere',),
'avdramatisert': ('avdramatisere',),
'avdramatiserte': ('avdramatisere',),
'avduka': ('avduke',),
'avdukede': ('avduke',),
'avdukende': ('avduke',),
'avduket': ('avduke',),
'avdukete': ('avduke',),
'avdød': ('avdød',),
'avdøde': ('avdød',),
'avdødere': ('avdød',),
'avdødest': ('avdød',),
'avdødeste': ('avdød',),
'avdødt': ('avdød',),
'averterende': ('avertere',),
'avertert': ('avertere',),
'averterte': ('avertere',),
'avfalma': ('avfalma',),
'avfalmede': ('avfalmet',),
'avfalmet': ('avfalmet',),
'avfalmete': ('avfalmet',),
'avfalmetere': ('avfalmet',),
'avfalmetest': ('avfalmet',),
'avfalmeteste': ('avfalmet',),
'avfasa': ('avfase',),
'avfasede': ('avfase',),
'avfasende': ('avfase',),
'avfaset': ('avfase',),
'avfasete': ('avfase',),
'avfatta': ('avfatte',),
'avfattede': ('avfatte',),
'avfattende': ('avfatte',),
'avfattet': ('avfatte',),
'avfattete': ('avfatte',),
'avfeia': ('avfeie',),
'avfeid': ('avfeie',),
'avfeide': ('avfeie',),
'avfeiede': ('avfeie',),
'avfeiende': ('avfeie',),
'avfeiet': ('avfeie',),
'avfeiete': ('avfeie',),
'avfeldig': ('avfeldig',),
'avfeldige': ('avfeldig',),
'avfeldigere': ('avfeldig',),
'avfeldigst': ('avfeldig',),
'avfeldigste': ('avfeldig',),
'avferdiga': ('avferdige',),
'avferdigede': ('avferdige',),
'avferdigende': ('avferdige',),
'avferdiget': ('avferdige',),
'avferdigete': ('avferdige',),
'avfetta': ('avfette',),
'avfettede': ('avfette',),
'avfettende': ('avfette',),
'avfettet': ('avfette',),
'avfettete': ('avfette',),
'avfinnende': ('avfinne',),
'avfunne': ('avfinne',),
'avfunnen': ('avfinne',),
'avfunnet': ('avfinne',),
'avfolka': ('avfolke',),
'avfolkede': ('avfolke',),
'avfolkende': ('avfolke',),
'avfolket': ('avfolke',),
'avfolkete': ('avfolke',),
'avfyrende': ('avfyre',),
'avfyrt': ('avfyre',),
'avfyrte': ('avfyre',),
'avfødende': ('avføde',),
'avfødt': ('avføde',),
'avfødte': ('avføde',),
'avførende': ('avføre',),
'avført': ('avføre',),
'avførte': ('avføre',),
'avførende': ('avførende',),
'avgiende': ('avgi',),
'avgitt': ('avgi',),
'avgitte': ('avgi',),
'avgivende': ('avgi',),
'avgiftsfri': ('avgiftsfri',),
'avgiftsfrie': ('avgiftsfri',),
'avgiftsfriere': ('avgiftsfri',),
'avgiftsfriest': ('avgiftsfri',),
'avgiftsfrieste': ('avgiftsfri',),
'avgiftsfritt': ('avgiftsfri',),
'avgiftspliktig': ('avgiftspliktig',),
'avgiftspliktige': ('avgiftspliktig',),
'avgiftspliktigere': ('avgiftspliktig',),
'avgiftspliktigst': ('avgiftspliktig',),
'avgiftspliktigste': ('avgiftspliktig',),
'avgjort': ('avgjort',),
'avgjorte': ('avgjort',),
'avgjortere': ('avgjort',),
'avgjortest': ('avgjort',),
'avgjorteste': ('avgjort',),
'avgjort': ('avgjøre',),
'avgjorte': ('avgjøre',),
'avgjørende': ('avgjøre',),
'avgjørende': ('avgjørende',),
'avglemt': ('avglemt',),
'avglemte': ('avglemt',),
'avglemtere': ('avglemt',),
'avglemtest': ('avglemt',),
'avglemteste': ('avglemt',),
'avglømt': ('avglømt',),
'avglømte': ('avglømt',),
'avglømtere': ('avglømt',),
'avglømtest': ('avglømt',),
'avglømteste': ('avglømt',),
'avgrensa': ('avgrense',),
'avgrensede': ('avgrense',),
'avgrensende': ('avgrense',),
'avgrenset': ('avgrense',),
'avgrensete': ('avgrense',),
'avgrunnsdjup': ('avgrunnsdjup',),
'avgrunnsdjupe': ('avgrunnsdjup',),
'avgrunnsdjupere': ('avgrunnsdjup',),
'avgrunnsdjupest': ('avgrunnsdjup',),
'avgrunnsdjupeste': ('avgrunnsdjup',),
'avgrunnsdjupt': ('avgrunnsdjup',),
'avgrunnsdyp': ('avgrunnsdyp',),
'avgrunnsdype': ('avgrunnsdyp',),
'avgrunnsdypere': ('avgrunnsdyp',),
'avgrunnsdypest': ('avgrunnsdyp',),
'avgrunnsdypeste': ('avgrunnsdyp',),
'avgrunnsdypt': ('avgrunnsdyp',),
'avgrunnsmørk': ('avgrunnsmørk',),
'avgrunnsmørke': ('avgrunnsmørk',),
'avgrunnsmørkere': ('avgrunnsmørk',),
'avgrunnsmørkest': ('avgrunnsmørk',),
'avgrunnsmørkeste': ('avgrunnsmørk',),
'avgrunnsmørkt': ('avgrunnsmørk',),
'avgående': ('avgå',),
'avgått': ('avgå',),
'avgåtte': ('avgå',),
'avgående': ('avgående',),
'avgått': ('avgått',),
'avgåtte': ('avgått',),
'avgåttere': ('avgått',),
'avgåttest': ('avgått',),
'avgåtteste': ('avgått',),
'avheimla': ('avheimle',),
'avheimlede': ('avheimle',),
'avheimlende': ('avheimle',),
'avheimlet': ('avheimle',),
'avheimlete': ('avheimle',),
'avhenda': ('avhende',),
'avhendede': ('avhende',),
'avhendende': ('avhende',),
'avhendet': ('avhende',),
'avhendete': ('avhende',),
'avhendelig': ('avhendelig',),
'avhendelige': ('avhendelig',),
'avhendeligere': ('avhendelig',),
'avhendeligst': ('avhendelig',),
'avhendeligste': ('avhendelig',),
'avhengende': ('avhenge',),
'avhengt': ('avhenge',),
'avhengte': ('avhenge',),
'avhengig': ('avhengig',),
'avhengige': ('avhengig',),
'avhengigere': ('avhengig',),
'avhengigst': ('avhengig',),
'avhengigste': ('avhengig',),
'avhenta': ('avhente',),
'avhentede': ('avhente',),
'avhentende': ('avhente',),
'avhentet': ('avhente',),
'avhentete': ('avhente',),
'avherda': ('avherde',),
'avherdede': ('avherde',),
'avherdende': ('avherde',),
'avherdet': ('avherde',),
'avherdete': ('avherde',),
'avhjelpende': ('avhjelpe',),
'avhjulpen': ('avhjelpe',),
'avhjulpet': ('avhjelpe',),
'avhjulpne': ('avhjelpe',),
'avhjemla': ('avhjemle',),
'avhjemlede': ('avhjemle',),
'avhjemlende': ('avhjemle',),
'avhjemlet': ('avhjemle',),
'avhjemlete': ('avhjemle',),
'avholdende': ('avholde',),
'avholdt': ('avholde',),
'avholdte': ('avholde',),
'avholdende': ('avholdende',),
'avholdt': ('avholdt',),
'avholdte': ('avholdt',),
'avholdtere': ('avholdt',),
'avholdtest': ('avholdt',),
'avholdteste': ('avholdt',),
'avhørende': ('avhøre',),
'avhørt': ('avhøre',),
'avhørte': ('avhøre',),
'aviatisk': ('aviatisk',),
'aviatiske': ('aviatisk',),
'aviatiskere': ('aviatisk',),
'aviatiskest': ('aviatisk',),
'aviatiskeste': ('aviatisk',),
'avindsjuk': ('avindsjuk',),
'avindsjuke': ('avindsjuk',),
'avindsjukere': ('avindsjuk',),
'avindsjukest': ('avindsjuk',),
'avindsjukeste': ('avindsjuk',),
'avindsjukt': ('avindsjuk',),
'avindsyk': ('avindsyk',),
'avindsyke': ('avindsyk',),
'avindsykere': ('avindsyk',),
'avindsykest': ('avindsyk',),
'avindsykeste': ('avindsyk',),
'avindsykt': ('avindsyk',),
'avisende': ('avise',),
'avist': ('avise',),
'aviste': ('avise',),
'avkanta': ('avkante',),
'avkantede': ('avkante',),
'avkantende': ('avkante',),
'avkantet': ('avkante',),
'avkantete': ('avkante',),
'avkjølende': ('avkjøle',),
'avkjølt': ('avkjøle',),
'avkjølte': ('avkjøle',),
'avkjønna': ('avkjønne',),
'avkjønnede': ('avkjønne',),
'avkjønnende': ('avkjønne',),
'avkjønnet': ('avkjønne',),
'avkjønnete': ('avkjønne',),
'avklarende': ('avklare',),
'avklart': ('avklare',),
'avklarte': ('avklare',),
'avkledd': ('avkle',),
'avkledde': ('avkle',),
'avkledende': ('avkle',),
'avkleende': ('avkle',),
'avkledd': ('avkledd',),
'avkledde': ('avkledd',),
'avkleddere': ('avkledd',),
'avkleddest': ('avkledd',),
'avkleddeste': ('avkledd',),
'avkoda': ('avkode',),
'avkodede': ('avkode',),
'avkodende': ('avkode',),
'avkodet': ('avkode',),
'avkodete': ('avkode',),
'avkokende': ('avkoke',),
'avkokt': ('avkoke',),
'avkokte': ('avkoke',),
'avkoloniserende': ('avkolonisere',),
'avkolonisert': ('avkolonisere',),
'avkoloniserte': ('avkolonisere',),
'avkorta': ('avkorte',),
'avkortede': ('avkorte',),
'avkortende': ('avkorte',),
'avkortet': ('avkorte',),
'avkortete': ('avkorte',),
'avkrefta': ('avkrefte',),
'avkreftede': ('avkrefte',),
'avkreftende': ('avkrefte',),
'avkreftet': ('avkrefte',),
'avkreftete': ('avkrefte',),
'avkreva': ('avkreve',),
'avkrevd': ('avkreve',),
'avkrevde': ('avkreve',),
'avkrevede': ('avkreve',),
'avkrevende': ('avkreve',),
'avkrevet': ('avkreve',),
'avkrevete': ('avkreve',),
'avkriminaliserende': ('avkriminalisere',),
'avkriminalisert': ('avkriminalisere',),
'avkriminaliserte': ('avkriminalisere',),
'avkristna': ('avkristne',),
'avkristnede': ('avkristne',),
'avkristnende': ('avkristne',),
'avkristnet': ('avkristne',),
'avkristnete': ('avkristne',),
'avlagt': ('avlagt',),
'avlagte': ('avlagt',),
'avlagtere': ('avlagt',),
'avlagtest': ('avlagt',),
'avlagteste': ('avlagt',),
'avlang': ('avlang',),
'avlange': ('avlang',),
'avlangt': ('avlang',),
'avlenger': ('avlang',),
'avlengre': ('avlang',),
'avlengst': ('avlang',),
'avlengste': ('avlang',),
'avlasta': ('avlaste',),
'avlastede': ('avlaste',),
'avlastende': ('avlaste',),
'avlastet': ('avlaste',),
'avlastete': ('avlaste',),
'avla': ('avle',),
'avlede': ('avle',),
'avlende': ('avle',),
'avlet': ('avle',),
'avlete': ('avle',),
'avleda': ('avlede',),
'avledede': ('avlede',),
'avledende': ('avlede',),
'avledet': ('avlede',),
'avledete': ('avlede',),
'avledyktig': ('avledyktig',),
'avledyktige': ('avledyktig',),
'avledyktigere': ('avledyktig',),
'avledyktigst': ('avledyktig',),
'avledyktigste': ('avledyktig',),
'avlagt': ('avlegge',),
'avlagte': ('avlegge',),
'avleggende': ('avlegge',),
'avleggs': ('avleggs',),
'avleggse': ('avleggs',),
'avleggsere': ('avleggs',),
'avleggsest': ('avleggs',),
'avleggseste': ('avleggs',),
'avleid': ('avleie',),
'avleidd': ('avleie',),
'avleidde': ('avleie',),
'avleide': ('avleie',),
'avleiende': ('avleie',),
'avleira': ('avleire',),
'avleirede': ('avleire',),
'avleirende': ('avleire',),
'avleiret': ('avleire',),
'avleirete': ('avleire',),
'avlesbar': ('avlesbar',),
'avlesbare': ('avlesbar',),
'avlesbarere': ('avlesbar',),
'avlesbarest': ('avlesbar',),
'avlesbareste': ('avlesbar',),
'avlesbart': ('avlesbar',),
'avlesende': ('avlese',),
'avlest': ('avlese',),
'avleste': ('avlese',),
'avleverende': ('avlevere',),
'avlevert': ('avlevere',),
'avleverte': ('avlevere',),
'avliva': ('avlive',),
'avlivede': ('avlive',),
'avlivende': ('avlive',),
'avlivet': ('avlive',),
'avlivete': ('avlive',),
'avlokka': ('avlokke',),
'avlokkede': ('avlokke',),
'avlokkende': ('avlokke',),
'avlokket': ('avlokke',),
'avlokkete': ('avlokke',),
'avlsproduktiv': ('avlsproduktiv',),
'avlsproduktive': ('avlsproduktiv',),
'avlsproduktivere': ('avlsproduktiv',),
'avlsproduktivest': ('avlsproduktiv',),
'avlsproduktiveste': ('avlsproduktiv',),
'avlsproduktivt': ('avlsproduktiv',),
'avlurende': ('avlure',),
'avlurt': ('avlure',),
'avlurte': ('avlure',),
'avlusa': ('avluse',),
'avlusede': ('avluse',),
'avlusende': ('avluse',),
'avluset': ('avluse',),
'avlusete': ('avluse',),
'avlust': ('avluse',),
'avluste': ('avluse',),
'avlysende': ('avlyse',),
'avlyst': ('avlyse',),
'avlyste': ('avlyse',),
'avlytta': ('avlytte',),
'avlyttede': ('avlytte',),
'avlyttende': ('avlytte',),
'avlyttet': ('avlytte',),
'avlyttete': ('avlytte',),
'avlåsende': ('avlåse',),
'avlåst': ('avlåse',),
'avlåste': ('avlåse',),
'avlønna': ('avlønne',),
'avlønnede': ('avlønne',),
'avlønnende': ('avlønne',),
'avlønnet': ('avlønne',),
'avlønnete': ('avlønne',),
'avlønt': ('avlønne',),
'avlønte': ('avlønne',),
'avløsende': ('avløse',),
'avløst': ('avløse',),
'avløste': ('avløse',),
'avløysende': ('avløyse',),
'avløyst': ('avløyse',),
'avløyste': ('avløyse',),
'avmagnetiserende': ('avmagnetisere',),
'avmagnetisert': ('avmagnetisere',),
'avmagnetiserte': ('avmagnetisere',),
'avmagra': ('avmagre',),
'avmagrede': ('avmagre',),
'avmagrende': ('avmagre',),
'avmagret': ('avmagre',),
'avmagrete': ('avmagre',),
'avmarsjerende': ('avmarsjere',),
'avmarsjert': ('avmarsjere',),
'avmarsjerte': ('avmarsjere',),
'avmektig': ('avmektig',),
'avmektige': ('avmektig',),
'avmektigere': ('avmektig',),
'avmektigst': ('avmektig',),
'avmektigste': ('avmektig',),
'avmerka': ('avmerke',),
'avmerkede': ('avmerke',),
'avmerkende': ('avmerke',),
'avmerket': ('avmerke',),
'avmerkete': ('avmerke',),
'avmilitariserende': ('avmilitarisere',),
'avmilitarisert': ('avmilitarisere',),
'avmilitariserte': ('avmilitarisere',),
'avmytologiserende': ('avmytologisere',),
'avmytologisert': ('avmytologisere',),
'avmytologiserte': ('avmytologisere',),
'avmålende': ('avmåle',),
'avmålt': ('avmåle',),
'avmålte': ('avmåle',),
'avmålt': ('avmålt',),
'avmålte': ('avmålt',),
'avmåltere': ('avmålt',),
'avmåltest': ('avmålt',),
'avmålteste': ('avmålt',),
'avmønstra': ('avmønstre',),
'avmønstrede': ('avmønstre',),
'avmønstrende': ('avmønstre',),
'avmønstret': ('avmønstre',),
'avmønstrete': ('avmønstre',),
'avnasjonaliserende': ('avnasjonalisere',),
'avnasjonalisert': ('avnasjonalisere',),
'avnasjonaliserte': ('avnasjonalisere',),
'avnorska': ('avnorske',),
'avnorskede': ('avnorske',),
'avnorskende': ('avnorske',),
'avnorsket': ('avnorske',),
'avnorskete': ('avnorske',),
'avokadogrøn': ('avokadogrøn',),
'avokadogrøne': ('avokadogrøn',),
'avokadogrønere': ('avokadogrøn',),
'avokadogrønest': ('avokadogrøn',),
'avokadogrøneste': ('avokadogrøn',),
'avokadogrønt': ('avokadogrøn',),
'avokadogrønn': ('avokadogrønn',),
'avokadogrønne': ('avokadogrønn',),
'avokadogrønnere': ('avokadogrønn',),
'avokadogrønnest': ('avokadogrønn',),
'avokadogrønneste': ('avokadogrønn',),
'avokadogrønt': ('avokadogrønn',),
'avpassa': ('avpasse',),
'avpassede': ('avpasse',),
'avpassende': ('avpasse',),
'avpasset': ('avpasse',),
'avpassete': ('avpasse',),
'avpatruljerende': ('avpatruljere',),
'avpatruljert': ('avpatruljere',),
'avpatruljerte': ('avpatruljere',),
'avpolitiserende': ('avpolitisere',),
'avpolitisert': ('avpolitisere',),
'avpolitiserte': ('avpolitisere',),
'avreagerende': ('avreagere',),
'avreagert': ('avreagere',),
'avreagerte': ('avreagere',),
'avretta': ('avrette',),
'avrettede': ('avrette',),
'avrettende': ('avrette',),
'avrettet': ('avrette',),
'avrettete': ('avrette',),
'avrima': ('avrime',),
'avrimede': ('avrime',),
'avrimende': ('avrime',),
'avrimet': ('avrime',),
'avrimete': ('avrime',),
'avrunda': ('avrunde',),
'avrundede': ('avrunde',),
'avrundende': ('avrunde',),
'avrundet': ('avrunde',),
'avrundete': ('avrunde',),
'avrusa': ('avruse',),
'avrusede': ('avruse',),
'avrusende': ('avruse',),
'avruset': ('avruse',),
'avrusete': ('avruse',),
'avrusta': ('avruste',),
'avrustede': ('avruste',),
'avrustende': ('avruste',),
'avrustet': ('avruste',),
'avrustete': ('avruste',),
'avrusta': ('avruste',),
'avrustede': ('avruste',),
'avrustende': ('avruste',),
'avrustet': ('avruste',),
'avrustete': ('avruste',),
'avsanna': ('avsanne',),
'avsannede': ('avsanne',),
'avsannende': ('avsanne',),
'avsannet': ('avsanne',),
'avsannete': ('avsanne',),
'avseende': ('avse',),
'avsett': ('avse',),
'avsette': ('avse',),
'avsendende': ('avsende',),
'avsendt': ('avsende',),
'avsendte': ('avsende',),
'avsatt': ('avsette',),
'avsatte': ('avsette',),
'avsettende': ('avsette',),
'avsagt': ('avsi',),
'avsagte': ('avsi',),
'avsiende': ('avsi',),
'avsides': ('avsides',),
'avsidesliggende': ('avsidesliggende',),
'avsilende': ('avsile',),
'avsilt': ('avsile',),
'avsilte': ('avsile',),
'avsindig': ('avsindig',),
'avsindige': ('avsindig',),
'avsindigere': ('avsindig',),
'avsindigst': ('avsindig',),
'avsindigste': ('avsindig',),
'avsjela': ('avsjela',),
'avsjelede': ('avsjelet',),
'avsjelet': ('avsjelet',),
'avsjelete': ('avsjelet',),
'avsjeletere': ('avsjelet',),
'avsjeletest': ('avsjelet',),
'avsjeleteste': ('avsjelet',),
'avsjelt': ('avsjelt',),
'avsjelte': ('avsjelt',),
'avsjeltere': ('avsjelt',),
'avsjeltest': ('avsjelt',),
'avsjelteste': ('avsjelt',),
'avskaffa': ('avskaffe',),
'avskaffede': ('avskaffe',),
'avskaffende': ('avskaffe',),
'avskaffet': ('avskaffe',),
'avskaffete': ('avskaffe',),
'avskalla': ('avskalle',),
'avskallede': ('avskalle',),
'avskallende': ('avskalle',),
'avskallet': ('avskalle',),
'avskallete': ('avskalle',),
'avskilta': ('avskilte',),
'avskiltede': ('avskilte',),
'avskiltende': ('avskilte',),
'avskiltet': ('avskilte',),
'avskiltete': ('avskilte',),
'avskipa': ('avskipe',),
'avskipede': ('avskipe',),
'avskipende': ('avskipe',),
'avskipet': ('avskipe',),
'avskipete': ('avskipe',),
'avskjediga': ('avskjedige',),
'avskjedigede': ('avskjedige',),
'avskjedigende': ('avskjedige',),
'avskjediget': ('avskjedige',),
'avskjedigete': ('avskjedige',),
'avskjerma': ('avskjerme',),
'avskjermede': ('avskjerme',),
'avskjermende': ('avskjerme',),
'avskjermet': ('avskjerme',),
'avskjermete': ('avskjerme',),
'avskjærende': ('avskjære',),
'avskåren': ('avskjære',),
'avskåret': ('avskjære',),
'avskårne': ('avskjære',),
'avskoga': ('avskoge',),
'avskogede': ('avskoge',),
'avskogende': ('avskoge',),
'avskoget': ('avskoge',),
'avskogete': ('avskoge',),
'avskrapa': ('avskrape',),
'avskrapede': ('avskrape',),
'avskrapende': ('avskrape',),
'avskrapet': ('avskrape',),
'avskrapete': ('avskrape',),
'avskrapt': ('avskrape',),
'avskrapte': ('avskrape',),
'avskrekka': ('avskrekke',),
'avskrekkede': ('avskrekke',),
'avskrekkende': ('avskrekke',),
'avskrekket': ('avskrekke',),
'avskrekkete': ('avskrekke',),
'avskrekkende': ('avskrekkende',),
'avskreven': ('avskrive',),
'avskrevet': ('avskrive',),
'avskrevne': ('avskrive',),
'avskrivende': ('avskrive',),
'avskydd': ('avsky',),
'avskydde': ('avsky',),
'avskyende': ('avsky',),
'avskyelig': ('avskyelig',),
'avskyelige': ('avskyelig',),
'avskyeligere': ('avskyelig',),
'avskyeligst': ('avskyelig',),
'avskyeligste': ('avskyelig',),
'avskyvekkende': ('avskyvekkende',),
'avskåren': ('avskåren',),
'avskåret': ('avskåren',),
'avskårne': ('avskåren',),
'avskårnere': ('avskåren',),
'avskårnest': ('avskåren',),
'avskårneste': ('avskåren',),
'avskåret': ('avskåret',),
'avskårne': ('avskåret',),
'avskårnere': ('avskåret',),
'avskårnest': ('avskåret',),
'avskårneste': ('avskåret',),
'avslappa': ('avslappa',),
'avslappede': ('avslappet',),
'avslappet': ('avslappet',),
'avslappete': ('avslappet',),
'avslappetere': ('avslappet',),
'avslappetest': ('avslappet',),
'avslappeteste': ('avslappet',),
'avslepen': ('avslepen',),
'avslepent': ('avslepen',),
'avslepne': ('avslepen',),
'avslepnere': ('avslepen',),
'avslepnest': ('avslepen',),
'avslepneste': ('avslepen',),
'avslutta': ('avslutte',),
'avsluttede': ('avslutte',),
'avsluttende': ('avslutte',),
'avsluttet': ('avslutte',),
'avsluttete': ('avslutte',),
'avsluttende': ('avsluttende',),
'avslående': ('avslå',),
'avslått': ('avslå',),
'avslåtte': ('avslå',),
'avsløra': ('avsløre',),
'avslørede': ('avsløre',),
'avslørende': ('avsløre',),
'avsløret': ('avsløre',),
'avslørete': ('avsløre',),
'avslørt': ('avsløre',),
'avslørte': ('avsløre',),
'avslørende': ('avslørende',),
'avsondra': ('avsondre',),
'avsondrede': ('avsondre',),
'avsondrende': ('avsondre',),
'avsondret': ('avsondre',),
'avsondrete': ('avsondre',),
'avsona': ('avsone',),
'avsonede': ('avsone',),
'avsonende': ('avsone',),
'avsonet': ('avsone',),
'avsonete': ('avsone',),
'avsont': ('avsone',),
'avsonte': ('avsone',),
'avspalta': ('avspalte',),
'avspaltede': ('avspalte',),
'avspaltende': ('avspalte',),
'avspaltet': ('avspalte',),
'avspaltete': ('avspalte',),
'avspaserende': ('avspasere',),
'avspasert': ('avspasere',),
'avspaserte': ('avspasere',),
'avspeila': ('avspeile',),
'avspeilede': ('avspeile',),
'avspeilende': ('avspeile',),
'avspeilet': ('avspeile',),
'avspeilete': ('avspeile',),
'avspeilt': ('avspeile',),
'avspeilte': ('avspeile',),
'avspent': ('avspent',),
'avspente': ('avspent',),
'avspentere': ('avspent',),
'avspentest': ('avspent',),
'avspenteste': ('avspent',),
'avsperra': ('avsperre',),
'avsperrede': ('avsperre',),
'avsperrende': ('avsperre',),
'avsperret': ('avsperre',),
'avsperrete': ('avsperre',),
'avspisende': ('avspise',),
'avspist': ('avspise',),
'avspiste': ('avspise',),
'avspora': ('avspore',),
'avsporede': ('avspore',),
'avsporende': ('avspore',),
'avsporet': ('avspore',),
'avsporete': ('avspore',),
'avsport': ('avspore',),
'avsporte': ('avspore',),
'avstedkommen': ('avstedkomme',),
'avstedkommende': ('avstedkomme',),
'avstedkommet': ('avstedkomme',),
'avstedkomne': ('avstedkomme',),
'avstemmende': ('avstemme',),
'avstemt': ('avstemme',),
'avstemte': ('avstemme',),
'avstengt': ('avstengt',),
'avstengte': ('avstengt',),
'avstengtere': ('avstengt',),
'avstengtest': ('avstengt',),
'avstengteste': ('avstengt',),
'avstikkende': ('avstikkende',),
'avstiva': ('avstive',),
'avstivede': ('avstive',),
'avstivende': ('avstive',),
'avstivet': ('avstive',),
'avstivete': ('avstive',),
'avstraffa': ('avstraffe',),
'avstraffede': ('avstraffe',),
'avstraffende': ('avstraffe',),
'avstraffet': ('avstraffe',),
'avstraffete': ('avstraffe',),
'avstressa': ('avstresse',),
'avstressede': ('avstresse',),
'avstressende': ('avstresse',),
'avstresset': ('avstresse',),
'avstressete': ('avstresse',),
'avstumpa': ('avstumpa',),
'avstumpede': ('avstumpet',),
'avstumpet': ('avstumpet',),
'avstumpete': ('avstumpet',),
'avstumpetere': ('avstumpet',),
'avstumpetest': ('avstumpet',),
'avstumpeteste': ('avstumpet',),
'avstående': ('avstå',),
'avstått': ('avstå',),
'avståtte': ('avstå',),
'avstøpende': ('avstøpe',),
'avstøpt': ('avstøpe',),
'avstøpte': ('avstøpe',),
'avsvekka': ('avsvekke',),
'avsvekkede': ('avsvekke',),
'avsvekkende': ('avsvekke',),
'avsvekket': ('avsvekke',),
'avsvekkete': ('avsvekke',),
'avsvekt': ('avsvekke',),
'avsvekte': ('avsvekke',),
'avsverga': ('avsverge',),
'avsvergede': ('avsverge',),
'avsvergende': ('avsverge',),
'avsverget': ('avsverge',),
'avsvergete': ('avsverge',),
'avsvoren': ('avsverge',),
'avsvoret': ('avsverge',),
'avsvorne': ('avsverge',),
'avsverja': ('avsverje',),
'avsverjede': ('avsverje',),
'avsverjende': ('avsverje',),
'avsverjet': ('avsverje',),
'avsverjete': ('avsverje',),
'avsvoren': ('avsverje',),
'avsvoret': ('avsverje',),
'avsvorne': ('avsverje',),
'avsvidd': ('avsvi',),
'avsvidde': ('avsvi',),
'avsviende': ('avsvi',),
'avsungen': ('avsynge',),
'avsunget': ('avsynge',),
'avsungne': ('avsynge',),
'avsyngende': ('avsynge',),
'avtakende': ('avta',),
'avtatt': ('avta',),
'avtatte': ('avta',),
'avtagende': ('avtagende',),
'avtakbar': ('avtakbar',),
'avtakbare': ('avtakbar',),
'avtakbarere': ('avtakbar',),
'avtakbarest': ('avtakbar',),
'avtakbareste': ('avtakbar',),
'avtakbart': ('avtakbar',),
'avtakende': ('avtakende',),
'avtala': ('avtale',),
'avtalende': ('avtale',),
'avtalt': ('avtale',),
'avtalte': ('avtale',),
'avtalefesta': ('avtalefeste',),
'avtalefestede': ('avtalefeste',),
'avtalefestende': ('avtalefeste',),
'avtalefestet': ('avtalefeste',),
'avtalefestete': ('avtalefeste',),
'avtegna': ('avtegne',),
'avtegnede': ('avtegne',),
'avtegnende': ('avtegne',),
'avtegnet': ('avtegne',),
'avtegnete': ('avtegne',),
'avtjenende': ('avtjene',),
'avtjent': ('avtjene',),
'avtjente': ('avtjene',),
'avtrappa': ('avtrappe',),
'avtrappede': ('avtrappe',),
'avtrappende': ('avtrappe',),
'avtrappet': ('avtrappe',),
'avtrappete': ('avtrappe',),
'avtroppende': ('avtroppende',),
'avtvingende': ('avtvinge',),
'avtvungen': ('avtvinge',),
'avtvunget': ('avtvinge',),
'avtvungne': ('avtvinge',),
'avundsjuk': ('avundsjuk',),
'avundsjuke': ('avundsjuk',),
'avundsjukere': ('avundsjuk',),
'avundsjukest': ('avundsjuk',),
'avundsjukeste': ('avundsjuk',),
'avundsjukt': ('avundsjuk',),
'avveid': ('avveie',),
'avveide': ('avveie',),
'avveiede': ('avveie',),
'avveiende': ('avveie',),
'avveiet': ('avveie',),
'avveiete': ('avveie',),
'avvekslende': ('avvekslende',),
'avvendende': ('avvende',),
'avvendt': ('avvende',),
'avvendte': ('avvende',),
'avvendelig': ('avvendelig',),
'avvendelige': ('avvendelig',),
'avvendeligere': ('avvendelig',),
'avvendeligst': ('avvendelig',),
'avvendeligste': ('avvendelig',),
'avvenna': ('avvenne',),
'avvennede': ('avvenne',),
'avvennende': ('avvenne',),
'avvennet': ('avvenne',),
'avvennete': ('avvenne',),
'avvent': ('avvenne',),
'avvente': ('avvenne',),
'avventa': ('avvente',),
'avventede': ('avvente',),
'avventende': ('avvente',),
'avventet': ('avvente',),
'avventete': ('avvente',),
'avventende': ('avventende',),
'avverga': ('avverge',),
'avvergede': ('avverge',),
'avvergende': ('avverge',),
'avverget': ('avverge',),
'avvergete': ('avverge',),
'avvergende': ('avvergende',),
'avverja': ('avverje',),
'avverjede': ('avverje',),
'avverjende': ('avverje',),
'avverjet': ('avverje',),
'avverjete': ('avverje',),
'avverjende': ('avverjende',),
'avveken': ('avvike',),
'avveket': ('avvike',),
'avvekne': ('avvike',),
'avvikende': ('avvike',),
'avvikende': ('avvikende',),
'avvikla': ('avvikle',),
'avviklede': ('avvikle',),
'avviklende': ('avvikle',),
'avviklet': ('avvikle',),
'avviklete': ('avvikle',),
'avvirka': ('avvirke',),
'avvirkede': ('avvirke',),
'avvirkende': ('avvirke',),
'avvirket': ('avvirke',),
'avvirkete': ('avvirke',),
'avvisende': ('avvise',),
'avvist': ('avvise',),
'avviste': ('avvise',),
'avvisende': ('avvisende',),
'avvæpna': ('avvæpne',),
'avvæpnede': ('avvæpne',),
'avvæpnende': ('avvæpne',),
'avvæpnet': ('avvæpne',),
'avvæpnete': ('avvæpne',),
'aztekisk': ('aztekisk',),
'aztekiske': ('aztekisk',),
'aztekiskere': ('aztekisk',),
'aztekiskest': ('aztekisk',),
'aztekiskeste': ('aztekisk',),
'babelsk': ('babelsk',),
'babelske': ('babelsk',),
'babelskere': ('babelsk',),
'babelskest': ('babelsk',),
'babelskeste': ('babelsk',),
'babla': ('bable',),
'bablede': ('bable',),
'bablende': ('bable',),
'bablet': ('bable',),
'bablete': ('bable',),
'bablet': ('bablet',),
'bablete': ('bablet',),
'babletere': ('bablet',),
'babletest': ('bablet',),
'bableteste': ('bablet',),
'bablete': ('bablete',),
'babylonisk': ('babylonisk',),
'babyloniske': ('babylonisk',),
'babyloniskere': ('babylonisk',),
'babyloniskest': ('babylonisk',),
'babyloniskeste': ('babylonisk',),
'babylonsk': ('babylonsk',),
'babylonske': ('babylonsk',),
'babylonskere': ('babylonsk',),
'babylonskest': ('babylonsk',),
'babylonskeste': ('babylonsk',),
'bada': ('bade',),
'badede': ('bade',),
'badende': ('bade',),
'badet': ('bade',),
'badete': ('bade',),
'bagatelliserende': ('bagatellisere',),
'bagatellisert': ('bagatellisere',),
'bagatelliserte': ('bagatellisere',),
'bagatellmessig': ('bagatellmessig',),
'bagatellmessige': ('bagatellmessig',),
'bagatellmessigere': ('bagatellmessig',),
'bagatellmessigst': ('bagatellmessig',),
'bagatellmessigste': ('bagatellmessig',),
'bahamansk': ('bahamansk',),
'bahamanske': ('bahamansk',),
'bahamanskere': ('bahamansk',),
'bahamanskest': ('bahamansk',),
'bahamanskeste': ('bahamansk',),
'bahrainsk': ('bahrainsk',),
'bahrainske': ('bahrainsk',),
'bahrainskere': ('bahrainsk',),
'bahrainskest': ('bahrainsk',),
'bahrainskeste': ('bahrainsk',),
'baissa': ('baisse',),
'baissede': ('baisse',),
'baissende': ('baisse',),
'baisset': ('baisse',),
'baissete': ('baisse',),
'bakbindende': ('bakbinde',),
'bakbunden': ('bakbinde',),
'bakbundet': ('bakbinde',),
'bakbundne': ('bakbinde',),
'baka': ('bake',),
'bakende': ('bake',),
'bakt': ('bake',),
'bakte': ('bake',),
'bakerst': ('bakerst',),
'bakerste': ('bakerst',),
'bakglatt': ('bakglatt',),
'bakglatte': ('bakglatt',),
'bakglattere': ('bakglatt',),
'bakglattest': ('bakglatt',),
'bakglatteste': ('bakglatt',),
'bakhjulsdrevet': ('bakhjulsdrevet',),
'bakhjulsdrevne': ('bakhjulsdrevet',),
'bakhjulsdrevnere': ('bakhjulsdrevet',),
'bakhjulsdrevnest': ('bakhjulsdrevet',),
'bakhjulsdrevneste': ('bakhjulsdrevet',),
'bakkantisk': ('bakkantisk',),
'bakkantiske': ('bakkantisk',),
'bakkantiskere': ('bakkantisk',),
'bakkantiskest': ('bakkantisk',),
'bakkantiskeste': ('bakkantisk',),
'bakka': ('bakke',),
'bakkede': ('bakke',),
'bakkende': ('bakke',),
'bakket': ('bakke',),
'bakkete': ('bakke',),
'bakka': ('bakke',),
'bakkede': ('bakke',),
'bakkende': ('bakke',),
'bakket': ('bakke',),
'bakkete': ('bakke',),
'bakket': ('bakket',),
'bakkete': ('bakket',),
'bakketere': ('bakket',),
'bakketest': ('bakket',),
'bakketeste': ('bakket',),
'bakkete': ('bakkete',),
'bakknappa': ('bakknappa',),
'bakknappede': ('bakknappet',),
'bakknappet': ('bakknappet',),
'bakknappete': ('bakknappet',),
'bakknappetere': ('bakknappet',),
'bakknappetest': ('bakknappet',),
'bakknappeteste': ('bakknappet',),
'bakoverbøyd': ('bakoverbøyd',),
'bakoverbøyde': ('bakoverbøyd',),
'bakoverbøydere': ('bakoverbøyd',),
'bakoverbøydest': ('bakoverbøyd',),
'bakoverbøydeste': ('bakoverbøyd',),
'bakerst': ('bakre',),
'bakerste': ('bakre',),
'bakre': ('bakre',),
'baksa': ('bakse',),
'baksede': ('bakse',),
'baksende': ('bakse',),
'bakset': ('bakse',),
'baksete': ('bakse',),
'baksnakka': ('baksnakke',),
'baksnakkede': ('baksnakke',),
'baksnakkende': ('baksnakke',),
'baksnakket': ('baksnakke',),
'baksnakkete': ('baksnakke',),
'bakstreversk': ('bakstreversk',),
'bakstreverske': ('bakstreversk',),
'bakstreverskere': ('bakstreversk',),
'bakstreverskest': ('bakstreversk',),
'bakstreverskeste': ('bakstreversk',),
'baktala': ('baktale',),
'baktalende': ('baktale',),
'baktalt': ('baktale',),
'baktalte': ('baktale',),
'baktericid': ('baktericid',),
'bakteriedrepende': ('bakteriedrepende',),
'bakteriell': ('bakteriell',),
'bakterielle': ('bakteriell',),
'bakteriellere': ('bakteriell',),
'bakteriellest': ('bakteriell',),
'bakterielleste': ('bakteriell',),
'bakterielt': ('bakteriell',),
'bakteriologisk': ('bakteriologisk',),
'bakteriologiske': ('bakteriologisk',),
'bakteriologiskere': ('bakteriologisk',),
'bakteriologiskest': ('bakteriologisk',),
'bakteriologiskeste': ('bakteriologisk',),
'baktung': ('baktung',),
'baktunge': ('baktung',),
'baktungere': ('baktung',),
'baktungest': ('baktung',),
'baktungeste': ('baktung',),
'baktungt': ('baktung',),
'baktyngre': ('baktung',),
'baktyngst': ('baktung',),
'baktyngste': ('baktung',),
'bakvaska': ('bakvaske',),
'bakvaskede': ('bakvaske',),
'bakvaskende': ('bakvaske',),
'bakvasket': ('bakvaske',),
'bakvaskete': ('bakvaske',),
'bakvendt': ('bakvendt',),
'bakvendte': ('bakvendt',),
'bakvendtere': ('bakvendt',),
'bakvendtest': ('bakvendt',),
'bakvendteste': ('bakvendt',),
'balanserende': ('balansere',),
'balansert': ('balansere',),
'balanserte': ('balansere',),
'bala': ('bale',),
'balede': ('bale',),
'balende': ('bale',),
'balet': ('bale',),
'balete': ('bale',),
'balt': ('bale',),
'balte': ('bale',),
'balinesisk': ('balinesisk',),
'balinesiske': ('balinesisk',),
'balinesiskere': ('balinesisk',),
'balinesiskest': ('balinesisk',),
'balinesiskeste': ('balinesisk',),
'balkaniserende': ('balkanisere',),
'balkanisert': ('balkanisere',),
'balkaniserte': ('balkanisere',),
'balkansk': ('balkansk',),
'balkanske': ('balkansk',),
'balkanskere': ('balkansk',),
'balkanskest': ('balkansk',),
'balkanskeste': ('balkansk',),
'ballasta': ('ballaste',),
'ballastede': ('ballaste',),
'ballastende': ('ballaste',),
'ballastet': ('ballaste',),
'ballastete': ('ballaste',),
'balla': ('balle',),
'ballede': ('balle',),
'ballende': ('balle',),
'ballet': ('balle',),
'ballete': ('balle',),
'ballistisk': ('ballistisk',),
'ballistiske': ('ballistisk',),
'ballistiskere': ('ballistisk',),
'ballistiskest': ('ballistisk',),
'ballistiskeste': ('ballistisk',),
'ballongforma': ('ballongforma',),
'ballongformede': ('ballongformet',),
'ballongformet': ('ballongformet',),
'ballongformete': ('ballongformet',),
'ballongformetere': ('ballongformet',),
'ballongformetest': ('ballongformet',),
'ballongformeteste': ('ballongformet',),
'ballotterende': ('ballottere',),
'ballottert': ('ballottere',),
'ballotterte': ('ballottere',),
'balsamerende': ('balsamere',),
'balsamert': ('balsamere',),
'balsamerte': ('balsamere',),
'balstyren': ('balstyren',),
'balstyrent': ('balstyren',),
'balstyrne': ('balstyren',),
'balstyrnere': ('balstyren',),
'balstyrnest': ('balstyren',),
'balstyrneste': ('balstyren',),
'balstyrig': ('balstyrig',),
'balstyrige': ('balstyrig',),
'balstyrigere': ('balstyrig',),
'balstyrigst': ('balstyrig',),
'balstyrigste': ('balstyrig',),
'baltisk': ('baltisk',),
'baltiske': ('baltisk',),
'baltiskere': ('baltisk',),
'baltiskest': ('baltisk',),
'baltiskeste': ('baltisk',),
'banal': ('banal',),
'banale': ('banal',),
'banalere': ('banal',),
'banalest': ('banal',),
'banaleste': ('banal',),
'banalt': ('banal',),
'banaliserende': ('banalisere',),
'banalisert': ('banalisere',),
'banaliserte': ('banalisere',),
'bandasjerende': ('bandasjere',),
'bandasjert': ('bandasjere',),
'bandasjerte': ('bandasjere',),
'banda': ('bande',),
'bandede': ('bande',),
'bandende': ('bande',),
'bandet': ('bande',),
'bandete': ('bande',),
'bandlagt': ('bandlegge',),
'bandlagte': ('bandlegge',),
'bandleggende': ('bandlegge',),
'bana': ('bane',),
'banede': ('bane',),
'banende': ('bane',),
'banet': ('bane',),
'banete': ('bane',),
'bant': ('bane',),
'bante': ('bane',),
'banebrytende': ('banebrytende',),
'banepålagt': ('banepålagt',),
'banepålagte': ('banepålagt',),
'banepålagtere': ('banepålagt',),
'banepålagtest': ('banepålagt',),
'banepålagteste': ('banepålagt',),
'bange': ('bange',),
'bangladeshisk': ('bangladeshisk',),
'bangladeshiske': ('bangladeshisk',),
'bangladeshiskere': ('bangladeshisk',),
'bangladeshiskest': ('bangladeshisk',),
'bangladeshiskeste': ('bangladeshisk',),
'banka': ('banke',),
'bankede': ('banke',),
'bankende': ('banke',),
'banket': ('banke',),
'bankete': ('banke',),
'bankerott': ('bankerott',),
'bankerotte': ('bankerott',),
'bankerottere': ('bankerott',),
'bankerottest': ('bankerott',),
'bankerotteste': ('bankerott',),
'banna': ('banne',),
'bannede': ('banne',),
'bannende': ('banne',),
'bannet': ('banne',),
'bannete': ('banne',),
'bant': ('banne',),
'bante': ('banne',),
'bannlysende': ('bannlyse',),
'bannlyst': ('bannlyse',),
'bannlyste': ('bannlyse',),
'bannsatt': ('bannsette',),
'bannsatte': ('bannsette',),
'bannsettende': ('bannsette',),
'baptistisk': ('baptistisk',),
'baptistiske': ('baptistisk',),
'baptistiskere': ('baptistisk',),
'baptistiskest': ('baptistisk',),
'baptistiskeste': ('baptistisk',),
'bar': ('bar',),
'bare': ('bar',),
'barere': ('bar',),
'barest': ('bar',),
'bareste': ('bar',),
'bart': ('bar',),
'bararma': ('bararma',),
'bararmede': ('bararmet',),
'bararmet': ('bararmet',),
'bararmete': ('bararmet',),
'bararmetere': ('bararmet',),
'bararmetest': ('bararmet',),
'bararmeteste': ('bararmet',),
'barbadisk': ('barbadisk',),
'barbadiske': ('barbadisk',),
'barbadiskere': ('barbadisk',),
'barbadiskest': ('barbadisk',),
'barbadiskeste': ('barbadisk',),
'barbarisk': ('barbarisk',),
'barbariske': ('barbarisk',),
'barbariskere': ('barbarisk',),
'barbariskest': ('barbarisk',),
'barbariskeste': ('barbarisk',),
'barbeint': ('barbeint',),
'barbeinte': ('barbeint',),
'barbeintere': ('barbeint',),
'barbeintest': ('barbeint',),
'barbeinteste': ('barbeint',),
'barbent': ('barbent',),
'barbente': ('barbent',),
'barbentere': ('barbent',),
'barbentest': ('barbent',),
'barbenteste': ('barbent',),
'barberende': ('barbere',),
'barbert': ('barbere',),
'barberte': ('barbere',),
'bardunerende': ('bardunere',),
'bardunert': ('bardunere',),
'bardunerte': ('bardunere',),
'bardus': ('bardus',),
'barduse': ('bardus',),
'bardusere': ('bardus',),
'bardusest': ('bardus',),
'barduseste': ('bardus',),
'bardust': ('bardus',),
'bara': ('bare',),
'barede': ('bare',),
'barende': ('bare',),
'baret': ('bare',),
'barete': ('bare',),
'barfota': ('barfota',),
'barfotede': ('barfotet',),
'barfotet': ('barfotet',),
'barfotete': ('barfotet',),
'barfotetere': ('barfotet',),
'barfotetest': ('barfotet',),
'barfoteteste': ('barfotet',),
'barfrosne': ('barfrossen',),
'barfrosnere': ('barfrossen',),
'barfrosnest': ('barfrossen',),
'barfrosneste': ('barfrossen',),
'barfrossen': ('barfrossen',),
'barfrosset': ('barfrossen',),
'barfrosne': ('barfrosset',),
'barfrosnere': ('barfrosset',),
'barfrosnest': ('barfrosset',),
'barfrosneste': ('barfrosset',),
'barfrosset': ('barfrosset',),
'barføtt': ('barføtt',),
'barføtte': ('barføtt',),
'barføttere': ('barføtt',),
'barføttest': ('barføtt',),
'barføtteste': ('barføtt',),
'barhoda': ('barhoda',),
'barhodede': ('barhodet',),
'barhodet': ('barhodet',),
'barhodete': ('barhodet',),
'barhodetere': ('barhodet',),
'barhodetest': ('barhodet',),
'barhodeteste': ('barhodet',),
'barka': ('barka',),
'barka': ('barke',),
'barkede': ('barke',),
'barkende': ('barke',),
'barket': ('barke',),
'barkete': ('barke',),
'barkede': ('barket',),
'barket': ('barket',),
'barkete': ('barket',),
'barketere': ('barket',),
'barketest': ('barket',),
'barketeste': ('barket',),
'barmhjertig': ('barmhjertig',),
'barmhjertige': ('barmhjertig',),
'barmhjertigere': ('barmhjertig',),
'barmhjertigst': ('barmhjertig',),
'barmhjertigste': ('barmhjertig',),
'barnaktig': ('barnaktig',),
'barnaktige': ('barnaktig',),
'barnaktigere': ('barnaktig',),
'barnaktigst': ('barnaktig',),
'barnaktigste': ('barnaktig',),
'barnefødd': ('barnefødd',),
'barnefødde': ('barnefødd',),
'barneføddere': ('barnefødd',),
'barneføddest': ('barnefødd',),
'barneføddeste': ('barnefødd',),
'barnefødt': ('barnefødt',),
'barnefødte': ('barnefødt',),
'barnefødtere': ('barnefødt',),
'barnefødtest': ('barnefødt',),
'barnefødteste': ('barnefødt',),
'barnerik': ('barnerik',),
'barnerike': ('barnerik',),
'barnerikere': ('barnerik',),
'barnerikest': ('barnerik',),
'barnerikeste': ('barnerik',),
'barnerikt': ('barnerik',),
'barnesikker': ('barnesikker',),
'barnesikkert': ('barnesikker',),
'barnesikre': ('barnesikker',),
'barnesikrere': ('barnesikker',),
'barnesikrest': ('barnesikker',),
'barnesikreste': ('barnesikker',),
'barnevennlig': ('barnevennlig',),
'barnevennlige': ('barnevennlig',),
'barnevennligere': ('barnevennlig',),
'barnevennligst': ('barnevennlig',),
'barnevennligste': ('barnevennlig',),
'barnlaus': ('barnlaus',),
'barnlause': ('barnlaus',),
'barnlausere': ('barnlaus',),
'barnlausest': ('barnlaus',),
'barnlauseste': ('barnlaus',),
'barnlaust': ('barnlaus',),
'barnlig': ('barnlig',),
'barnlige': ('barnlig',),
'barnligere': ('barnlig',),
'barnligst': ('barnlig',),
'barnligste': ('barnlig',),
'barnløs': ('barnløs',),
'barnløse': ('barnløs',),
'barnløsere': ('barnløs',),
'barnløsest': ('barnløs',),
'barnløseste': ('barnløs',),
'barnløst': ('barnløs',),
'barnslig': ('barnslig',),
'barnslige': ('barnslig',),
'barnsligere': ('barnslig',),
'barnsligst': ('barnslig',),
'barnsligste': ('barnslig',),
'barokk': ('barokk',),
'barokke': ('barokk',),
'barokkere': ('barokk',),
'barokkest': ('barokk',),
'barokkeste': ('barokk',),
'barokt': ('barokk',),
'barometrisk': ('barometrisk',),
'barometriske': ('barometrisk',),
'barometriskere': ('barometrisk',),
'barometriskest': ('barometrisk',),
'barometriskeste': ('barometrisk',),
'barrikaderende': ('barrikadere',),
'barrikadert': ('barrikadere',),
'barrikaderte': ('barrikadere',),
'barsk': ('barsk',),
'barske': ('barsk',),
'barskere': ('barsk',),
'barskest': ('barsk',),
'barskeste': ('barsk',),
'barskt': ('barsk',),
'barska': ('barske',),
'barskede': ('barske',),
'barskende': ('barske',),
'barsket': ('barske',),
'barskete': ('barske',),
'basal': ('basal',),
'basale': ('basal',),
'basalere': ('basal',),
'basalest': ('basal',),
'basaleste': ('basal',),
'basalt': ('basal',),
'basaltisk': ('basaltisk',),
'basaltiske': ('basaltisk',),
'basaltiskere': ('basaltisk',),
'basaltiskest': ('basaltisk',),
'basaltiskeste': ('basaltisk',),
'basa': ('base',),
'basende': ('base',),
'bast': ('base',),
'baste': ('base',),
'baserende': ('basere',),
'basert': ('basere',),
'baserte': ('basere',),
'basisk': ('basisk',),
'basiske': ('basisk',),
'basiskere': ('basisk',),
'basiskest': ('basisk',),
'basiskeste': ('basisk',),
'baska': ('baske',),
'baskede': ('baske',),
'baskende': ('baske',),
'basket': ('baske',),
'baskete': ('baske',),
'baskisk': ('baskisk',),
'baskiske': ('baskisk',),
'baskiskere': ('baskisk',),
'baskiskest': ('baskisk',),
'baskiskeste': ('baskisk',),
'bastant': ('bastant',),
'bastante': ('bastant',),
'bastantere': ('bastant',),
'bastantest': ('bastant',),
'bastanteste': ('bastant',),
'basta': ('baste',),
'bastede': ('baste',),
'bastende': ('baste',),
'bastet': ('baste',),
'bastete': ('baste',),
'basunerende': ('basunere',),
'basunert': ('basunere',),
'basunerte': ('basunere',),
'batteridrevet': ('batteridrevet',),
'batteridrevne': ('batteridrevet',),
'batteridrevnere': ('batteridrevet',),
'batteridrevnest': ('batteridrevet',),
'batteridrevneste': ('batteridrevet',),
'bauta': ('baute',),
'bautede': ('baute',),
'bautende': ('baute',),
'bautet': ('baute',),
'bautete': ('baute',),
'bayersk': ('bayersk',),
'bayerske': ('bayersk',),
'bayerskere': ('bayersk',),
'bayerskest': ('bayersk',),
'bayerskeste': ('bayersk',),
'bedt': ('be',),
'bedte': ('be',),
'beende': ('be',),
'bearbeida': ('bearbeide',),
'bearbeidd': ('bearbeide',),
'bearbeidde': ('bearbeide',),
'bearbeidede': ('bearbeide',),
'bearbeidende': ('bearbeide',),
'bearbeidet': ('bearbeide',),
'bearbeidete': ('bearbeide',),
'bebodd': ('bebo',),
'bebodde': ('bebo',),
'beboende': ('bebo',),
'beboelig': ('beboelig',),
'beboelige': ('beboelig',),
'beboeligere': ('beboelig',),
'beboeligst': ('beboelig',),
'beboeligste': ('beboelig',),
'bebreida': ('bebreide',),
'bebreidede': ('bebreide',),
'bebreidende': ('bebreide',),
'bebreidet': ('bebreide',),
'bebreidete': ('bebreide',),
'bebreidende': ('bebreidende',),
'bebrilla': ('bebrilla',),
'bebrillede': ('bebrillet',),
'bebrillet': ('bebrillet',),
'bebrillete': ('bebrillet',),
'bebrilletere': ('bebrillet',),
'bebrilletest': ('bebrillet',),
'bebrilleteste': ('bebrillet',),
'bebuda': ('bebude',),
'bebudede': ('bebude',),
'bebudende': ('bebude',),
'bebudet': ('bebude',),
'bebudete': ('bebude',),
'bebygd': ('bebygge',),
'bebygde': ('bebygge',),
'bebygga': ('bebygge',),
'bebyggede': ('bebygge',),
'bebyggende': ('bebygge',),
'bebygget': ('bebygge',),
'bebyggete': ('bebygge',),
'bebyggelig': ('bebyggelig',),
'bebyggelige': ('bebyggelig',),
'bebyggeligere': ('bebyggelig',),
'bebyggeligst': ('bebyggelig',),
'bebyggeligste': ('bebyggelig',),
'bebyrda': ('bebyrde',),
'bebyrdede': ('bebyrde',),
'bebyrdende': ('bebyrde',),
'bebyrdet': ('bebyrde',),
'bebyrdete': ('bebyrde',),
'bedaga': ('bedaga',),
'bedaga': ('bedage',),
'bedagede': ('bedage',),
'bedagende': ('bedage',),
'bedaget': ('bedage',),
'bedagete': ('bedage',),
'bedagelig': ('bedagelig',),
'bedagelige': ('bedagelig',),
'bedageligere': ('bedagelig',),
'bedageligst': ('bedagelig',),
'bedageligste': ('bedagelig',),
'bedagede': ('bedaget',),
'bedaget': ('bedaget',),
'bedagete': ('bedaget',),
'bedagetere': ('bedaget',),
'bedagetest': ('bedaget',),
'bedageteste': ('bedaget',),
'bedende': ('bede',),
'bedt': ('bede',),
'bedte': ('bede',),
'bedekka': ('bedekke',),
'bedekkede': ('bedekke',),
'bedekkende': ('bedekke',),
'bedekket': ('bedekke',),
'bedekkete': ('bedekke',),
'bedekt': ('bedekke',),
'bedekte': ('bedekke',),
'bederva': ('bederva',),
'bedervelig': ('bedervelig',),
'bedervelige': ('bedervelig',),
'bederveligere': ('bedervelig',),
'bederveligst': ('bedervelig',),
'bederveligste': ('bedervelig',),
'bedervede': ('bedervet',),
'bedervet': ('bedervet',),
'bedervete': ('bedervet',),
'bedervetere': ('bedervet',),
'bedervetest': ('bedervet',),
'bederveteste': ('bedervet',),
'bedradd': ('bedra',),
'bedradde': ('bedra',),
'bedragende': ('bedra',),
'bedratt': ('bedra',),
'bedratte': ('bedra',),
'bedragerisk': ('bedragerisk',),
'bedrageriske': ('bedragerisk',),
'bedrageriskere': ('bedragerisk',),
'bedrageriskest': ('bedragerisk',),
'bedrageriskeste': ('bedragerisk',),
'bedragersk': ('bedragersk',),
'bedragerske': ('bedragersk',),
'bedragerskere': ('bedragersk',),
'bedragerskest': ('bedragersk',),
'bedragerskeste': ('bedragersk',),
'bedra': ('bedre',),
'bedrede': ('bedre',),
'bedrende': ('bedre',),
'bedret': ('bedre',),
'bedrete': ('bedre',),
'bedre': ('bedre',),
'bedrestilt': ('bedrestilt',),
'bedrestilte': ('bedrestilt',),
'bedrestiltere': ('bedrestilt',),
'bedrestiltest': ('bedrestilt',),
'bedrestilteste': ('bedrestilt',),
'bedrevitende': ('bedrevitende',),
'bedreven': ('bedrive',),
'bedrevet': ('bedrive',),
'bedrevne': ('bedrive',),
'bedrivende': ('bedrive',),
'bedrøva': ('bedrøve',),
'bedrøvede': ('bedrøve',),
'bedrøvende': ('bedrøve',),
'bedrøvet': ('bedrøve',),
'bedrøvete': ('bedrøve',),
'bedrøvelig': ('bedrøvelig',),
'bedrøvelige': ('bedrøvelig',),
'bedrøveligere': ('bedrøvelig',),
'bedrøveligst': ('bedrøvelig',),
'bedrøveligste': ('bedrøvelig',),
'bedugga': ('bedugga',),
'beduggede': ('bedugget',),
'bedugget': ('bedugget',),
'beduggete': ('bedugget',),
'beduggetere': ('bedugget',),
'beduggetest': ('bedugget',),
'beduggeteste': ('bedugget',),
'bedyra': ('bedyre',),
'bedyrede': ('bedyre',),
'bedyrende': ('bedyre',),
'bedyret': ('bedyre',),
'bedyrete': ('bedyre',),
'bedyrt': ('bedyre',),
'bedyrte': ('bedyre',),
'bedåra': ('bedåre',),
'bedårede': ('bedåre',),
'bedårende': ('bedåre',),
'bedåret': ('bedåre',),
'bedårete': ('bedåre',),
'bedårende': ('bedårende',),
'bedømmende': ('bedømme',),
'bedømt': ('bedømme',),
'bedømte': ('bedømme',),
'bedøva': ('bedøve',),
'bedøvd': ('bedøve',),
'bedøvde': ('bedøve',),
'bedøvede': ('bedøve',),
'bedøvende': ('bedøve',),
'bedøvet': ('bedøve',),
'bedøvete': ('bedøve',),
'beediga': ('beedige',),
'beedigede': ('beedige',),
'beedigende': ('beedige',),
'beediget': ('beedige',),
'beedigete': ('beedige',),
'befalende': ('befale',),
'befalt': ('befale',),
'befalte': ('befale',),
'befarende': ('befare',),
'befart': ('befare',),
'befarte': ('befare',),
'befaren': ('befaren',),
'befarent': ('befaren',),
'befarne': ('befaren',),
'befarnere': ('befaren',),
'befarnest': ('befaren',),
'befarneste': ('befaren',),
'befatta': ('befatte',),
'befattede': ('befatte',),
'befattende': ('befatte',),
'befattet': ('befatte',),
'befattete': ('befatte',),
'befengt': ('befengt',),
'befengte': ('befengt',),
'befengtere': ('befengt',),
'befengtest': ('befengt',),
'befengteste': ('befengt',),
'beferda': ('beferda',),
'beferdede': ('beferdet',),
'beferdet': ('beferdet',),
'beferdete': ('beferdet',),
'beferdetere': ('beferdet',),
'beferdetest': ('beferdet',),
'beferdeteste': ('beferdet',),
'befesta': ('befeste',),
'befestede': ('befeste',),
'befestende': ('befeste',),
'befestet': ('befeste',),
'befestete': ('befeste',),
'befinnende': ('befinne',),
'befunne': ('befinne',),
'befunnen': ('befinne',),
'befunnet': ('befinne',),
'befippa': ('befippa',),
'befippede': ('befippet',),
'befippet': ('befippet',),
'befippete': ('befippet',),
'befippetere': ('befippet',),
'befippetest': ('befippet',),
'befippeteste': ('befippet',),
'beflitta': ('beflitte',),
'beflittede': ('beflitte',),
'beflittende': ('beflitte',),
'beflittet': ('beflitte',),
'beflittete': ('beflitte',),
'befolka': ('befolke',),
'befolkede': ('befolke',),
'befolkende': ('befolke',),
'befolket': ('befolke',),
'befolkete': ('befolke',),
'befordra': ('befordre',),
'befordrede': ('befordre',),
'befordrende': ('befordre',),
'befordret': ('befordre',),
'befordrete': ('befordre',),
'befrakta': ('befrakte',),
'befraktede': ('befrakte',),
'befraktende': ('befrakte',),
'befraktet': ('befrakte',),
'befraktete': ('befrakte',),
'befridd': ('befri',),
'befridde': ('befri',),
'befriende': ('befri',),
'befriende': ('befriende',),
'befrukta': ('befrukte',),
'befruktede': ('befrukte',),
'befruktende': ('befrukte',),
'befruktet': ('befrukte',),
'befruktete': ('befrukte',),
'befruktningsdyktig': ('befruktningsdyktig',),
'befruktningsdyktige': ('befruktningsdyktig',),
'befruktningsdyktigere': ('befruktningsdyktig',),
'befruktningsdyktigst': ('befruktningsdyktig',),
'befruktningsdyktigste': ('befruktningsdyktig',),
'befruktningshindrende': ('befruktningshindrende',),
'befølende': ('beføle',),
'befølt': ('beføle',),
'befølte': ('beføle',),
'beføya': ('beføya',),
'beføyede': ('beføyet',),
'beføyet': ('beføyet',),
'beføyete': ('beføyet',),
'beføyetere': ('beføyet',),
'beføyetest': ('beføyet',),
'beføyeteste': ('beføyet',),
'begava': ('begava',),
'begavede': ('begavet',),
'begavet': ('begavet',),
'begavete': ('begavet',),
'begavetere': ('begavet',),
'begavetest': ('begavet',),
'begaveteste': ('begavet',),
'begeistra': ('begeistre',),
'begeistrede': ('begeistre',),
'begeistrende': ('begeistre',),
'begeistret': ('begeistre',),
'begeistrete': ('begeistre',),
'begiende': ('begi',),
'begitt': ('begi',),
'begitte': ('begi',),
'begivende': ('begi',),
'begivenhetslaus': ('begivenhetslaus',),
'begivenhetslause': ('begivenhetslaus',),
'begivenhetslausere': ('begivenhetslaus',),
'begivenhetslausest': ('begivenhetslaus',),
'begivenhetslauseste': ('begivenhetslaus',),
'begivenhetslaust': ('begivenhetslaus',),
'begivenhetsløs': ('begivenhetsløs',),
'begivenhetsløse': ('begivenhetsløs',),
'begivenhetsløsere': ('begivenhetsløs',),
'begivenhetsløsest': ('begivenhetsløs',),
'begivenhetsløseste': ('begivenhetsløs',),
'begivenhetsløst': ('begivenhetsløs',),
'begivenhetsrik': ('begivenhetsrik',),
'begivenhetsrike': ('begivenhetsrik',),
'begivenhetsrikere': ('begivenhetsrik',),
'begivenhetsrikest': ('begivenhetsrik',),
'begivenhetsrikeste': ('begivenhetsrik',),
'begivenhetsrikt': ('begivenhetsrik',),
'begjærende': ('begjære',),
'begjært': ('begjære',),
'begjærte': ('begjære',),
'begjærlig': ('begjærlig',),
'begjærlige': ('begjærlig',),
'begjærligere': ('begjærlig',),
'begjærligst': ('begjærlig',),
'begjærligste': ('begjærlig',),
'beglodd': ('beglo',),
'beglodde': ('beglo',),
'begloende': ('beglo',),
'begravd': ('begrave',),
'begravde': ('begrave',),
'begravede': ('begrave',),
'begravende': ('begrave',),
'begravet': ('begrave',),
'begravete': ('begrave',),
'begredelig': ('begredelig',),
'begredelige': ('begredelig',),
'begredeligere': ('begredelig',),
'begredeligst': ('begredelig',),
'begredeligste': ('begredelig',),
'begrensa': ('begrensa',),
'begrensa': ('begrense',),
'begrensede': ('begrense',),
'begrensende': ('begrense',),
'begrenset': ('begrense',),
'begrensete': ('begrense',),
'begrensede': ('begrenset',),
'begrenset': ('begrenset',),
'begrensete': ('begrenset',),
'begrensetere': ('begrenset',),
'begrensetest': ('begrenset',),
'begrenseteste': ('begrenset',),
'begrepsbestemmende': ('begrepsbestemme',),
'begrepsbestemt': ('begrepsbestemme',),
'begrepsbestemte': ('begrepsbestemme',),
'begrepsmessig': ('begrepsmessig',),
'begrepsmessige': ('begrepsmessig',),
'begrepsmessigere': ('begrepsmessig',),
'begrepsmessigst': ('begrepsmessig',),
'begrepsmessigste': ('begrepsmessig',),
'begrepen': ('begripe',),
'begrepet': ('begripe',),
'begrepne': ('begripe',),
'begripende': ('begripe',),
'begripelig': ('begripelig',),
'begripelige': ('begripelig',),
'begripeligere': ('begripelig',),
'begripeligst': ('begripelig',),
'begripeligste': ('begripelig',),
'begrodd': ('begrodd',),
'begrodde': ('begrodd',),
'begroddere': ('begrodd',),
'begroddest': ('begrodd',),
'begroddeste': ('begrodd',),
'begrunna': ('begrunne',),
'begrunnede': ('begrunne',),
'begrunnende': ('begrunne',),
'begrunnet': ('begrunne',),
'begrunnete': ('begrunne',),
'begunstiga': ('begunstige',),
'begunstigede': ('begunstige',),
'begunstigende': ('begunstige',),
'begunstiget': ('begunstige',),
'begunstigete': ('begunstige',),
'begynnende': ('begynne',),
'begynt': ('begynne',),
'begynte': ('begynne',),
'begående': ('begå',),
'begått': ('begå',),
'begåtte': ('begå',),
'behaga': ('behage',),
'behagede': ('behage',),
'behagende': ('behage',),
'behaget': ('behage',),
'behagete': ('behage',),
'behagelig': ('behagelig',),
'behagelige': ('behagelig',),
'behageligere': ('behagelig',),
'behageligst': ('behagelig',),
'behageligste': ('behagelig',),
'behandla': ('behandle',),
'behandlede': ('behandle',),
'behandlende': ('behandle',),
'behandlet': ('behandle',),
'behandlete': ('behandle',),
'behanska': ('behanska',),
'behanskede': ('behansket',),
'behansket': ('behansket',),
'behanskete': ('behansket',),
'behansketere': ('behansket',),
'behansketest': ('behansket',),
'behansketeste': ('behansket',),
'behefta': ('behefte',),
'beheftede': ('behefte',),
'beheftende': ('behefte',),
'beheftet': ('behefte',),
'beheftete': ('behefte',),
'behendig': ('behendig',),
'behendige': ('behendig',),
'behendigere': ('behendig',),
'behendigst': ('behendig',),
'behendigste': ('behendig',),
'behengt': ('behengt',),
'behengte': ('behengt',),
'behengtere': ('behengt',),
'behengtest': ('behengt',),
'behengteste': ('behengt',),
'beherska': ('beherska',),
'beherska': ('beherske',),
'beherskede': ('beherske',),
'beherskende': ('beherske',),
'behersket': ('beherske',),
'beherskete': ('beherske',),
'beherskede': ('behersket',),
'behersket': ('behersket',),
'beherskete': ('behersket',),
'behersketere': ('behersket',),
'behersketest': ('behersket',),
'behersketeste': ('behersket',),
'behjelpelig': ('behjelpelig',),
'behjelpelige': ('behjelpelig',),
'behjelpeligere': ('behjelpelig',),
'behjelpeligst': ('behjelpelig',),
'behjelpeligste': ('behjelpelig',),
'behjerta': ('behjerta',),
'behjertede': ('behjertet',),
'behjertet': ('behjertet',),
'behjertete': ('behjertet',),
'behjertetere': ('behjertet',),
'behjertetest': ('behjertet',),
'behjerteteste': ('behjertet',),
'beholdende': ('beholde',),
'beholdt': ('beholde',),
'beholdte': ('beholde',),
'behåra': ('behåra',),
'behårede': ('behåret',),
'behåret': ('behåret',),
'behårete': ('behåret',),
'behåretere': ('behåret',),
'behåretest': ('behåret',),
'behåreteste': ('behåret',),
'behørig': ('behørig',),
'behørige': ('behørig',),
'behørigere': ('behørig',),
'behørigst': ('behørig',),
'behørigste': ('behørig',),
'behøvd': ('behøve',),
'behøvde': ('behøve',),
'behøvende': ('behøve',),
'beige': ('beige',),
'beigere': ('beige',),
'beigest': ('beige',),
'beigeste': ('beige',),
'beila': ('beile',),
'beilede': ('beile',),
'beilende': ('beile',),
'beilet': ('beile',),
'beilete': ('beile',),
'beilt': ('beile',),
'beilte': ('beile',),
'bein': ('bein',),
'beine': ('bein',),
'beinere': ('bein',),
'beinest': ('bein',),
'beineste': ('bein',),
'beint': ('bein',),
'beina': ('beine',),
'beinede': ('beine',),
'beinende': ('beine',),
'beinet': ('beine',),
'beinete': ('beine',),
'beinet': ('beinet',),
'beinete': ('beinet',),
'beinetere': ('beinet',),
'beinetest': ('beinet',),
'beineteste': ('beinet',),
'beinete': ('beinete',),
'beinflydd': ('beinflyge',),
'beinflydde': ('beinflyge',),
'beinflygende': ('beinflyge',),
'beinfløyen': ('beinflyge',),
'beinfløyet': ('beinflyge',),
'beinfløyne': ('beinflyge',),
'beinhard': ('beinhard',),
'beinharde': ('beinhard',),
'beinhardere': ('beinhard',),
'beinhardest': ('beinhard',),
'beinhardeste': ('beinhard',),
'beinhardt': ('beinhard',),
'beinka': ('beinke',),
'beinkede': ('beinke',),
'beinkende': ('beinke',),
'beinket': ('beinke',),
'beinkete': ('beinke',),
'beinløs': ('beinløs',),
'beinløse': ('beinløs',),
'beinløsere': ('beinløs',),
'beinløsest': ('beinløs',),
'beinløseste': ('beinløs',),
'beinløst': ('beinløs',),
'beintfram': ('beintfram',),
'beintframme': ('beintfram',),
'beintframmere': ('beintfram',),
'beintframmest': ('beintfram',),
'beintframmeste': ('beintfram',),
'beintframt': ('beintfram',),
'beisa': ('beise',),
'beisede': ('beise',),
'beisende': ('beise',),
'beiset': ('beise',),
'beisete': ('beise',),
'beist': ('beise',),
'beiste': ('beise',),
'beisk': ('beisk',),
'beiske': ('beisk',),
'beiskere': ('beisk',),
'beiskest': ('beisk',),
'beiskeste': ('beisk',),
'beiskt': ('beisk',),
'beiskna': ('beiskne',),
'beisknede': ('beiskne',),
'beisknende': ('beiskne',),
'beisknet': ('beiskne',),
'beisknete': ('beiskne',),
'beita': ('beite',),
'beitede': ('beite',),
'beitende': ('beite',),
'beitet': ('beite',),
'beitete': ('beite',),
'beitt': ('beite',),
'beitte': ('beite',),
'bejaa': ('bejae',),
'bejaede': ('bejae',),
'bejaende': ('bejae',),
'bejaet': ('bejae',),
'bejaete': ('bejae',),
'beka': ('beke',),
'bekede': ('beke',),
'bekende': ('beke',),
'beket': ('beke',),
'bekete': ('beke',),
'bekt': ('beke',),
'bekte': ('beke',),
'bekjempa': ('bekjempe',),
'bekjempede': ('bekjempe',),
'bekjempende': ('bekjempe',),
'bekjempet': ('bekjempe',),
'bekjempete': ('bekjempe',),
'bekjennende': ('bekjenne',),
'bekjent': ('bekjenne',),
'bekjente': ('bekjenne',),
'bekjennelseslaus': ('bekjennelseslaus',),
'bekjennelseslause': ('bekjennelseslaus',),
'bekjennelseslausere': ('bekjennelseslaus',),
'bekjennelseslausest': ('bekjennelseslaus',),
'bekjennelseslauseste': ('bekjennelseslaus',),
'bekjennelseslaust': ('bekjennelseslaus',),
'bekjennelsesløs': ('bekjennelsesløs',),
'bekjennelsesløse': ('bekjennelsesløs',),
'bekjennelsesløsere': ('bekjennelsesløs',),
'bekjennelsesløsest': ('bekjennelsesløs',),
'bekjennelsesløseste': ('bekjennelsesløs',),
'bekjennelsesløst': ('bekjennelsesløs',),
'bekjent': ('bekjent',),
'bekjente': ('bekjent',),
'bekjentere': ('bekjent',),
'bekjentest': ('bekjent',),
'bekjenteste': ('bekjent',),
'bekjentgjort': ('bekjentgjøre',),
'bekjentgjorte': ('bekjentgjøre',),
'bekjentgjørende': ('bekjentgjøre',),
'beklaga': ('beklage',),
'beklagd': ('beklage',),
'beklagde': ('beklage',),
'beklagede': ('beklage',),
'beklagende': ('beklage',),
'beklaget': ('beklage',),
'beklagete': ('beklage',),
'beklagelig': ('beklagelig',),
'beklagelige': ('beklagelig',),
'beklageligere': ('beklagelig',),
'beklageligst': ('beklagelig',),
'beklageligste': ('beklagelig',),
'bekledd': ('bekle',),
'bekledde': ('bekle',),
'bekleende': ('bekle',),
'beklemmende': ('beklemmende',),
'beklemt': ('beklemt',),
'beklemte': ('beklemt',),
'beklemtere': ('beklemt',),
'beklemtest': ('beklemt',),
'beklemteste': ('beklemt',),
'beklippa': ('beklippe',),
'beklippede': ('beklippe',),
'beklippende': ('beklippe',),
'beklippet': ('beklippe',),
'beklippete': ('beklippe',),
'beklipt': ('beklippe',),
'beklipte': ('beklippe',),
'bekmørk': ('bekmørk',),
'bekmørke': ('bekmørk',),
'bekmørkere': ('bekmørk',),
'bekmørkest': ('bekmørk',),
'bekmørkeste': ('bekmørk',),
'bekmørkt': ('bekmørk',),
'bekommen': ('bekomme',),
'bekommende': ('bekomme',),
'bekommet': ('bekomme',),
'bekomne': ('bekomme',),
'bekosta': ('bekoste',),
'bekostede': ('bekoste',),
'bekostende': ('bekoste',),
'bekostet': ('bekoste',),
'bekostete': ('bekoste',),
'bekransa': ('bekranse',),
'bekransede': ('bekranse',),
'bekransende': ('bekranse',),
'bekranset': ('bekranse',),
'bekransete': ('bekranse',),
'bekrefta': ('bekrefte',),
'bekreftede': ('bekrefte',),
'bekreftende': ('bekrefte',),
'bekreftet': ('bekrefte',),
'bekreftete': ('bekrefte',),
'bekreftende': ('bekreftende',),
'beksla': ('beksle',),
'bekslede': ('beksle',),
'bekslende': ('beksle',),
'bekslet': ('beksle',),
'bekslete': ('beksle',),
'beksvart': ('beksvart',),
'beksvarte': ('beksvart',),
'beksvartere': ('beksvart',),
'beksvartest': ('beksvart',),
'beksvarteste': ('beksvart',),
'bekvem': ('bekvem',),
'bekvemme': ('bekvem',),
'bekvemmere': ('bekvem',),
'bekvemmest': ('bekvem',),
'bekvemmeste': ('bekvem',),
'bekvemt': ('bekvem',),
'bekvemma': ('bekvemme',),
'bekvemmede': ('bekvemme',),
'bekvemmende': ('bekvemme',),
'bekvemmet': ('bekvemme',),
'bekvemmete': ('bekvemme',),
'bekvemmelig': ('bekvemmelig',),
'bekvemmelige': ('bekvemmelig',),
'bekvemmeligere': ('bekvemmelig',),
'bekvemmeligst': ('bekvemmelig',),
'bekvemmeligste': ('bekvemmelig',),
'bekymra': ('bekymre',),
'bekymrede': ('bekymre',),
'bekymrende': ('bekymre',),
'bekymret': ('bekymre',),
'bekymrete': ('bekymre',),
'bekymringsfull': ('bekymringsfull',),
'bekymringsfulle': ('bekymringsfull',),
'bekymringsfullere': ('bekymringsfull',),
'bekymringsfullest': ('bekymringsfull',),
'bekymringsfulleste': ('bekymringsfull',),
'bekymringsfullt': ('bekymringsfull',),
'bekymringslaus': ('bekymringslaus',),
'bekymringslause': ('bekymringslaus',),
'bekymringslausere': ('bekymringslaus',),
'bekymringslausest': ('bekymringslaus',),
'bekymringslauseste': ('bekymringslaus',),
'bekymringslaust': ('bekymringslaus',),
'bekymringsløs': ('bekymringsløs',),
'bekymringsløse': ('bekymringsløs',),
'bekymringsløsere': ('bekymringsløs',),
'bekymringsløsest': ('bekymringsløs',),
'bekymringsløseste': ('bekymringsløs',),
'bekymringsløst': ('bekymringsløs',),
'belaga': ('belage',),
'belagd': ('belage',),
'belagde': ('belage',),
'belagede': ('belage',),
'belagende': ('belage',),
'belaget': ('belage',),
'belagete': ('belage',),
'belasta': ('belaste',),
'belastede': ('belaste',),
'belastende': ('belaste',),
'belastet': ('belaste',),
'belastete': ('belaste',),
'belagt': ('belegge',),
'belagte': ('belegge',),
'beleggende': ('belegge',),
'beleilig': ('beleilig',),
'beleilige': ('beleilig',),
'beleiligere': ('beleilig',),
'beleiligst': ('beleilig',),
'beleiligste': ('beleilig',),
'beleira': ('beleire',),
'beleirede': ('beleire',),
'beleirende': ('beleire',),
'beleiret': ('beleire',),
'beleirete': ('beleire',),
'belemra': ('belemre',),
'belemrede': ('belemre',),
'belemrende': ('belemre',),
'belemret': ('belemre',),
'belemrete': ('belemre',),
'belessa': ('belesse',),
'belessede': ('belesse',),
'belessende': ('belesse',),
'belesset': ('belesse',),
'belessete': ('belesse',),
'belest': ('belesse',),
'beleste': ('belesse',),
'belest': ('belest',),
'beleste': ('belest',),
'belestere': ('belest',),
'belestest': ('belest',),
'belesteste': ('belest',),
'beleven': ('beleven',),
'belevent': ('beleven',),
'belevne': ('beleven',),
'belevnere': ('beleven',),
'belevnest': ('beleven',),
'belevneste': ('beleven',),
'belgisk': ('belgisk',),
'belgiske': ('belgisk',),
'belgiskere': ('belgisk',),
'belgiskest': ('belgisk',),
'belgiskeste': ('belgisk',),
'belgmørk': ('belgmørk',),
'belgmørke': ('belgmørk',),
'belgmørkere': ('belgmørk',),
'belgmørkest': ('belgmørk',),
'belgmørkeste': ('belgmørk',),
'belgmørkt': ('belgmørk',),
'beliggende': ('beliggende',),
'beliva': ('beliva',),
'belivede': ('belivet',),
'belivet': ('belivet',),
'belivete': ('belivet',),
'belivetere': ('belivet',),
'belivetest': ('belivet',),
'beliveteste': ('belivet',),
'belizisk': ('belizisk',),
'beliziske': ('belizisk',),
'beliziskere': ('belizisk',),
'beliziskest': ('belizisk',),
'beliziskeste': ('belizisk',),
'belja': ('belje',),
'beljede': ('belje',),
'beljende': ('belje',),
'beljet': ('belje',),
'beljete': ('belje',),
'belja': ('belje',),
'beljede': ('belje',),
'beljende': ('belje',),
'beljet': ('belje',),
'beljete': ('belje',),
'belma': ('belme',),
'belmede': ('belme',),
'belmende': ('belme',),
'belmet': ('belme',),
'belmete': ('belme',),
'beltegående': ('beltegående',),
'belysende': ('belyse',),
'belyst': ('belyse',),
'belyste': ('belyse',),
'belånende': ('belåne',),
'belånt': ('belåne',),
'belånte': ('belåne',),
'belærende': ('belære',),
'belært': ('belære',),
'belærte': ('belære',),
'belærende': ('belære',),
'belært': ('belære',),
'belærte': ('belære',),
'belærende': ('belærende',),
'belønna': ('belønne',),
'belønnede': ('belønne',),
'belønnende': ('belønne',),
'belønnet': ('belønne',),
'belønnete': ('belønne',),
'belønt': ('belønne',),
'belønte': ('belønne',),
'beløpende': ('beløpe',),
'beløpet': ('beløpe',),
'beløpt': ('beløpe',),
'beløpte': ('beløpe',),
'bemanna': ('bemanne',),
'bemannede': ('bemanne',),
'bemannende': ('bemanne',),
'bemannet': ('bemanne',),
'bemannete': ('bemanne',),
'bemektiga': ('bemektige',),
'bemektigede': ('bemektige',),
'bemektigende': ('bemektige',),
'bemektiget': ('bemektige',),
'bemektigete': ('bemektige',),
'bemerka': ('bemerke',),
'bemerkede': ('bemerke',),
'bemerkende': ('bemerke',),
'bemerket': ('bemerke',),
'bemerkete': ('bemerke',),
'bemerkelsesverdig': ('bemerkelsesverdig',),
'bemerkelsesverdige': ('bemerkelsesverdig',),
'bemerkelsesverdigere': ('bemerkelsesverdig',),
'bemerkelsesverdigst': ('bemerkelsesverdig',),
'bemerkelsesverdigste': ('bemerkelsesverdig',),
'bemidla': ('bemidla',),
'bemidlede': ('bemidlet',),
'bemidlet': ('bemidlet',),
'bemidlete': ('bemidlet',),
'bemidletere': ('bemidlet',),
'bemidletest': ('bemidlet',),
'bemidleteste': ('bemidlet',),
'bemyndiga': ('bemyndige',),
'bemyndigede': ('bemyndige',),
'bemyndigende': ('bemyndige',),
'bemyndiget': ('bemyndige',),
'bemyndigete': ('bemyndige',),
'bemøya': ('bemøye',),
'bemøyd': ('bemøye',),
'bemøyde': ('bemøye',),
'bemøyede': ('bemøye',),
'bemøyende': ('bemøye',),
'bemøyet': ('bemøye',),
'bemøyete': ('bemøye',),
'ben': ('ben',),
'bene': ('ben',),
'benere': ('ben',),
'benest': ('ben',),
'beneste': ('ben',),
'bent': ('ben',),
'bendende': ('bende',),
'bendt': ('bende',),
'bendte': ('bende',),
'bena': ('bene',),
'benede': ('bene',),
'benende': ('bene',),
'benet': ('bene',),
'benete': ('bene',),
'benefisert': ('benefisert',),
'benefiserte': ('benefisert',),
'benefisertere': ('benefisert',),
'benefisertest': ('benefisert',),
'benefiserteste': ('benefisert',),
'benekta': ('benekte',),
'benektede': ('benekte',),
'benektende': ('benekte',),
'benektet': ('benekte',),
'benektete': ('benekte',),
'benektende': ('benektende',),
'benet': ('benet',),
'benete': ('benet',),
'benetere': ('benet',),
'benetest': ('benet',),
'beneteste': ('benet',),
'benete': ('benete',),
'benevnende': ('benevne',),
'benevnt': ('benevne',),
'benevnte': ('benevne',),
'benevnt': ('benevnt',),
'benevnte': ('benevnt',),
'benevntere': ('benevnt',),
'benevntest': ('benevnt',),
'benevnteste': ('benevnt',),
'bengalsk': ('bengalsk',),
'bengalske': ('bengalsk',),
'bengalskere': ('bengalsk',),
'bengalskest': ('bengalsk',),
'bengalskeste': ('bengalsk',),
'beninsk': ('beninsk',),
'beninske': ('beninsk',),
'beninskere': ('beninsk',),
'beninskest': ('beninsk',),
'beninskeste': ('beninsk',),
'benka': ('benke',),
'benkede': ('benke',),
'benkende': ('benke',),
'benket': ('benke',),
'benkete': ('benke',),
'benka': ('benke',),
'benkede': ('benke',),
'benkende': ('benke',),
'benket': ('benke',),
'benkete': ('benke',),
'benløs': ('benløs',),
'benløse': ('benløs',),
'benløsere': ('benløs',),
'benløsest': ('benløs',),
'benløseste': ('benløs',),
'benløst': ('benløs',),
'bensindrevet': ('bensindrevet',),
'bensindrevne': ('bensindrevet',),
'bensindrevnere': ('bensindrevet',),
'bensindrevnest': ('bensindrevet',),
'bensindrevneste': ('bensindrevet',),
'bentfram': ('bentfram',),
'bentframme': ('bentfram',),
'bentframmere': ('bentfram',),
'bentframmest': ('bentfram',),
'bentframmeste': ('bentfram',),
'bentframt': ('bentfram',),
'bentfrem': ('bentfrem',),
'bentfremme': ('bentfrem',),
'bentfremmere': ('bentfrem',),
'bentfremmest': ('bentfrem',),
'bentfremmeste': ('bentfrem',),
'bentfremt': ('bentfrem',),
'benytta': ('benytte',),
'benyttede': ('benytte',),
'benyttende': ('benytte',),
'benyttet': ('benytte',),
'benyttete': ('benytte',),
'benåda': ('benåde',),
'benådede': ('benåde',),
'benådende': ('benåde',),
'benådet': ('benåde',),
'benådete': ('benåde',),
'beordra': ('beordre',),
'beordrede': ('beordre',),
'beordrende': ('beordre',),
'beordret': ('beordre',),
'beordrete': ('beordre',),
'beplanta': ('beplante',),
'beplantede': ('beplante',),
'beplantende': ('beplante',),
'beplantet': ('beplante',),
'beplantete': ('beplante',),
'beramma': ('beramme',),
'berammede': ('beramme',),
'berammende': ('beramme',),
'berammet': ('beramme',),
'berammete': ('beramme',),
'berbisk': ('berbisk',),
'berbiske': ('berbisk',),
'berbiskere': ('berbisk',),
'berbiskest': ('berbisk',),
'berbiskeste': ('berbisk',),
'beredende': ('berede',),
'beredt': ('berede',),
'beredte': ('berede',),
'beredt': ('beredt',),
'beredte': ('beredt',),
'beredtere': ('beredt',),
'beredtest': ('beredt',),
'beredteste': ('beredt',),
'beredvillig': ('beredvillig',),
'beredvillige': ('beredvillig',),
'beredvilligere': ('beredvillig',),
'beredvilligst': ('beredvillig',),
'beredvilligste': ('beredvillig',),
'beregnbar': ('beregnbar',),
'beregnbare': ('beregnbar',),
'beregnbarere': ('beregnbar',),
'beregnbarest': ('beregnbar',),
'beregnbareste': ('beregnbar',),
'beregnbart': ('beregnbar',),
'beregna': ('beregne',),
'beregnede': ('beregne',),
'beregnende': ('beregne',),
'beregnet': ('beregne',),
'beregnete': ('beregne',),
'beregnelig': ('beregnelig',),
'beregnelige': ('beregnelig',),
'beregneligere': ('beregnelig',),
'beregneligst': ('beregnelig',),
'beregneligste': ('beregnelig',),
'beregnende': ('beregnende',),
'bereist': ('bereist',),
'bereiste': ('bereist',),
'bereistere': ('bereist',),
'bereistest': ('bereist',),
'bereisteste': ('bereist',),
'bereknbar': ('bereknbar',),
'bereknbare': ('bereknbar',),
'bereknbarere': ('bereknbar',),
'bereknbarest': ('bereknbar',),
'bereknbareste': ('bereknbar',),
'bereknbart': ('bereknbar',),
'berekna': ('berekne',),
'bereknede': ('berekne',),
'bereknende': ('berekne',),
'bereknet': ('berekne',),
'bereknete': ('berekne',),
'bereknelig': ('bereknelig',),
'bereknelige': ('bereknelig',),
'berekneligere': ('bereknelig',),
'berekneligst': ('bereknelig',),
'berekneligste': ('bereknelig',),
'bereknende': ('bereknende',),
'beretta': ('berette',),
'berettede': ('berette',),
'berettende': ('berette',),
'berettet': ('berette',),
'berettete': ('berette',),
'berettiga': ('berettige',),
'berettigede': ('berettige',),
'berettigende': ('berettige',),
'berettiget': ('berettige',),
'berettigete': ('berettige',),
'berga': ('berge',),
'bergede': ('berge',),
'bergende': ('berge',),
'berget': ('berge',),
'bergete': ('berge',),
'bergensk': ('bergensk',),
'bergenske': ('bergensk',),
'bergenskere': ('bergensk',),
'bergenskest': ('bergensk',),
'bergenskeste': ('bergensk',),
'bergtakende': ('bergta',),
'bergtatt': ('bergta',),
'bergtatte': ('bergta',),
'berika': ('berike',),
'berikede': ('berike',),
'berikende': ('berike',),
'beriket': ('berike',),
'berikete': ('berike',),
'beriktiga': ('beriktige',),
'beriktigede': ('beriktige',),
'beriktigende': ('beriktige',),
'beriktiget': ('beriktige',),
'beriktigete': ('beriktige',),
'berlinsk': ('berlinsk',),
'berlinske': ('berlinsk',),
'berlinskere': ('berlinsk',),
'berlinskest': ('berlinsk',),
'berlinskeste': ('berlinsk',),
'berodd': ('bero',),
'berodde': ('bero',),
'beroende': ('bero',),
'beroliga': ('berolige',),
'beroligede': ('berolige',),
'beroligende': ('berolige',),
'beroliget': ('berolige',),
'beroligete': ('berolige',),
'beroligende': ('beroligende',),
'berrsynt': ('berrsynt',),
'berrsynte': ('berrsynt',),
'berrsyntere': ('berrsynt',),
'berrsyntest': ('berrsynt',),
'berrsynteste': ('berrsynt',),
'berta': ('berte',),
'bertede': ('berte',),
'bertende': ('berte',),
'bertet': ('berte',),
'bertete': ('berte',),
'berusa': ('berusa',),
'berusa': ('beruse',),
'berusede': ('beruse',),
'berusende': ('beruse',),
'beruset': ('beruse',),
'berusete': ('beruse',),
'berust': ('beruse',),
'beruste': ('beruse',),
'berusede': ('beruset',),
'beruset': ('beruset',),
'berusete': ('beruset',),
'berusetere': ('beruset',),
'berusetest': ('beruset',),
'beruseteste': ('beruset',),
'berykta': ('berykta',),
'beryktede': ('beryktet',),
'beryktet': ('beryktet',),
'beryktete': ('beryktet',),
'beryktetere': ('beryktet',),
'beryktetest': ('beryktet',),
'berykteteste': ('beryktet',),
'berømma': ('berømme',),
'berømmede': ('berømme',),
'berømmende': ('berømme',),
'berømmet': ('berømme',),
'berømmete': ('berømme',),
'berømt': ('berømme',),
'berømte': ('berømme',),
'berømmelig': ('berømmelig',),
'berømmelige': ('berømmelig',),
'berømmeligere': ('berømmelig',),
'berømmeligst': ('berømmelig',),
'berømmeligste': ('berømmelig',),
'berømt': ('berømt',),
'berømte': ('berømt',),
'berømtere': ('berømt',),
'berømtest': ('berømt',),
'berømteste': ('berømt',),
'berørende': ('berøre',),
'berørt': ('berøre',),
'berørte': ('berøre',),
'berøva': ('berøve',),
'berøvd': ('berøve',),
'berøvde': ('berøve',),
'berøvede': ('berøve',),
'berøvende': ('berøve',),
'berøvet': ('berøve',),
'berøvete': ('berøve',),
'besatt': ('besatt',),
'besatte': ('besatt',),
'besattere': ('besatt',),
'besattest': ('besatt',),
'besatteste': ('besatt',),
'beseende': ('bese',),
'besett': ('bese',),
'besette': ('bese',),
'besegla': ('besegle',),
'beseglede': ('besegle',),
'beseglende': ('besegle',),
'beseglet': ('besegle',),
'beseglete': ('besegle',),
'beseira': ('beseire',),
'beseirede': ('beseire',),
'beseirende': ('beseire',),
'beseiret': ('beseire',),
'beseirete': ('beseire',),
'besatt': ('besette',),
'besatte': ('besette',),
'besettende': ('besette',),
'besifra': ('besifre',),
'besifrede': ('besifre',),
'besifrende': ('besifre',),
'besifret': ('besifre',),
'besifrete': ('besifre',),
'besikta': ('besikte',),
'besiktede': ('besikte',),
'besiktende': ('besikte',),
'besiktet': ('besikte',),
'besiktete': ('besikte',),
'besiktiga': ('besiktige',),
'besiktigede': ('besiktige',),
'besiktigende': ('besiktige',),
'besiktiget': ('besiktige',),
'besiktigete': ('besiktige',),
'besindig': ('besindig',),
'besindige': ('besindig',),
'besindigere': ('besindig',),
'besindigst': ('besindig',),
'besindigste': ('besindig',),
'besinna': ('besinne',),
'besinnede': ('besinne',),
'besinnende': ('besinne',),
'besinnet': ('besinne',),
'besinnete': ('besinne',),
'besitne': ('besitte',),
'besitten': ('besitte',),
'besittende': ('besitte',),
'besittet': ('besitte',),
'besjelende': ('besjele',),
'besjelt': ('besjele',),
'besjelte': ('besjele',),
'besk': ('besk',),
'beske': ('besk',),
'beskere': ('besk',),
'beskest': ('besk',),
'beskeste': ('besk',),
'beskt': ('besk',),
'beskadiga': ('beskadige',),
'beskadigede': ('beskadige',),
'beskadigende': ('beskadige',),
'beskadiget': ('beskadige',),
'beskadigete': ('beskadige',),
'beskaffen': ('beskaffen',),
'beskaffent': ('beskaffen',),
'beskafne': ('beskaffen',),
'beskafnere': ('beskaffen',),
'beskafnest': ('beskaffen',),
'beskafneste': ('beskaffen',),
'beskatta': ('beskatte',),
'beskattede': ('beskatte',),
'beskattende': ('beskatte',),
'beskattet': ('beskatte',),
'beskattete': ('beskatte',),
'beskikka': ('beskikke',),
'beskikkede': ('beskikke',),
'beskikkende': ('beskikke',),
'beskikket': ('beskikke',),
'beskikkete': ('beskikke',),
'beskjeden': ('beskjeden',),
'beskjedent': ('beskjeden',),
'beskjedne': ('beskjeden',),
'beskjednere': ('beskjeden',),
'beskjednest': ('beskjeden',),
'beskjedneste': ('beskjeden',),
'beskjeftiga': ('beskjeftige',),
'beskjeftigede': ('beskjeftige',),
'beskjeftigende': ('beskjeftige',),
'beskjeftiget': ('beskjeftige',),
'beskjeftigete': ('beskjeftige',),
'beskjemma': ('beskjemma',),
'beskjemmede': ('beskjemmet',),
'beskjemmet': ('beskjemmet',),
'beskjemmete': ('beskjemmet',),
'beskjemmetere': ('beskjemmet',),
'beskjemmetest': ('beskjemmet',),
'beskjemmeteste': ('beskjemmet',),
'beskjærende': ('beskjære',),
'beskåren': ('beskjære',),
'beskåret': ('beskjære',),
'beskårne': ('beskjære',),
'beskjærende': ('beskjære',),
'beskåren': ('beskjære',),
'beskåret': ('beskjære',),
'beskårne': ('beskjære',),
'beskna': ('beskne',),
'besknede': ('beskne',),
'besknende': ('beskne',),
'besknet': ('beskne',),
'besknete': ('beskne',),
'beskreven': ('beskrive',),
'beskrevet': ('beskrive',),
'beskrevne': ('beskrive',),
'beskrivende': ('beskrive',),
'beskua': ('beskue',),
'beskuede': ('beskue',),
'beskuende': ('beskue',),
'beskuet': ('beskue',),
'beskuete': ('beskue',),
'beskyldende': ('beskylde',),
'beskyldt': ('beskylde',),
'beskyldte': ('beskylde',),
'beskutt': ('beskyte',),
'beskutte': ('beskyte',),
'beskytende': ('beskyte',),
'beskytta': ('beskytte',),
'beskyttede': ('beskytte',),
'beskyttende': ('beskytte',),
'beskyttet': ('beskytte',),
'beskyttete': ('beskytte',),
'beskyttende': ('beskyttende',),
'beslaglagt': ('beslaglegge',),
'beslaglagte': ('beslaglegge',),
'beslagleggende': ('beslaglegge',),
'beslekta': ('beslekta',),
'beslektede': ('beslektet',),
'beslektet': ('beslektet',),
'beslektete': ('beslektet',),
'beslektetere': ('beslektet',),
'beslektetest': ('beslektet',),
'beslekteteste': ('beslektet',),
'beslutningsdyktig': ('beslutningsdyktig',),
'beslutningsdyktige': ('beslutningsdyktig',),
'beslutningsdyktigere': ('beslutningsdyktig',),
'beslutningsdyktigst': ('beslutningsdyktig',),
'beslutningsdyktigste': ('beslutningsdyktig',),
'beslutta': ('beslutte',),
'besluttede': ('beslutte',),
'besluttende': ('beslutte',),
'besluttet': ('beslutte',),
'besluttete': ('beslutte',),
'besluttsom': ('besluttsom',),
'besluttsomme': ('besluttsom',),
'besluttsommere': ('besluttsom',),
'besluttsomst': ('besluttsom',),
'besluttsomste': ('besluttsom',),
'besluttsomt': ('besluttsom',),
'beslående': ('beslå',),
'beslått': ('beslå',),
'beslåtte': ('beslå',),
'besmitta': ('besmitte',),
'besmittede': ('besmitte',),
'besmittende': ('besmitte',),
'besmittet': ('besmitte',),
'besmittete': ('besmitte',),
'besnakka': ('besnakke',),
'besnakkede': ('besnakke',),
'besnakkende': ('besnakke',),
'besnakket': ('besnakke',),
'besnakkete': ('besnakke',),
'besnæra': ('besnære',),
'besnærede': ('besnære',),
'besnærende': ('besnære',),
'besnæret': ('besnære',),
'besnærete': ('besnære',),
'besnært': ('besnære',),
'besnærte': ('besnære',),
'besnærende': ('besnærende',),
'bespisende': ('bespise',),
'bespist': ('bespise',),
'bespiste': ('bespise',),
'bespotta': ('bespotte',),
'bespottede': ('bespotte',),
'bespottende': ('bespotte',),
'bespottet': ('bespotte',),
'bespottete': ('bespotte',),
'bespottelig': ('bespottelig',),
'bespottelige': ('bespottelig',),
'bespotteligere': ('bespottelig',),
'bespotteligst': ('bespottelig',),
'bespotteligste': ('bespottelig',),
'bestandig': ('bestandig',),
'bestandige': ('bestandig',),
'bestandigere': ('bestandig',),
'bestandigst': ('bestandig',),
'bestandigste': ('bestandig',),
'besteborgerlig': ('besteborgerlig',),
'besteborgerlige': ('besteborgerlig',),
'besteborgerligere': ('besteborgerlig',),
'besteborgerligst': ('besteborgerlig',),
'besteborgerligste': ('besteborgerlig',),
'bestemmende': ('bestemme',),
'bestemt': ('bestemme',),
'bestemte': ('bestemme',),
'bestemt': ('bestemt',),
'bestemte': ('bestemt',),
'bestemtere': ('bestemt',),
'bestemtest': ('bestemt',),
'bestemteste': ('bestemt',),
'bestialsk': ('bestialsk',),
'bestialske': ('bestialsk',),
'bestialskere': ('bestialsk',),
'bestialskest': ('bestialsk',),
'bestialskeste': ('bestialsk',),
'bestegen': ('bestige',),
'besteget': ('bestige',),
'bestegne': ('bestige',),
'bestigende': ('bestige',),
'bestikkende': ('bestikke',),
'bestukken': ('bestikke',),
'bestukket': ('bestikke',),
'bestukne': ('bestikke',),
'bestikkelig': ('bestikkelig',),
'bestikkelige': ('bestikkelig',),
'bestikkeligere': ('bestikkelig',),
'bestikkeligst': ('bestikkelig',),
'bestikkeligste': ('bestikkelig',),
'bestillende': ('bestille',),
'bestilt': ('bestille',),
'bestilte': ('bestille',),
'bestjelende': ('bestjele',),
'bestjålen': ('bestjele',),
'bestjålet': ('bestjele',),
'bestjålne': ('bestjele',),
'bestorma': ('bestorme',),
'bestormede': ('bestorme',),
'bestormende': ('bestorme',),
'bestormet': ('bestorme',),
'bestormete': ('bestorme',),
'bestreba': ('bestrebe',),
'bestrebede': ('bestrebe',),
'bestrebende': ('bestrebe',),
'bestrebet': ('bestrebe',),
'bestrebete': ('bestrebe',),
'bestridd': ('bestri',),
'bestridde': ('bestri',),
'bestridt': ('bestri',),
'bestridte': ('bestri',),
'bestriende': ('bestri',),
'bestridd': ('bestride',),
'bestridde': ('bestride',),
'bestridende': ('bestride',),
'bestridt': ('bestride',),
'bestridte': ('bestride',),
'bestrykende': ('bestryke',),
'bestrøken': ('bestryke',),
'bestrøket': ('bestryke',),
'bestrøkne': ('bestryke',),
'bestrålende': ('bestråle',),
'bestrålt': ('bestråle',),
'bestrålte': ('bestråle',),
'bestykka': ('bestykke',),
'bestykkede': ('bestykke',),
'bestykkende': ('bestykke',),
'bestykket': ('bestykke',),
'bestykkete': ('bestykke',),
'bestyrende': ('bestyre',),
'bestyrt': ('bestyre',),
'bestyrte': ('bestyre',),
'bestyrka': ('bestyrke',),
'bestyrkede': ('bestyrke',),
'bestyrkende': ('bestyrke',),
'bestyrket': ('bestyrke',),
'bestyrkete': ('bestyrke',),
'bestyrta': ('bestyrta',),
'bestyrtede': ('bestyrtet',),
'bestyrtet': ('bestyrtet',),
'bestyrtete': ('bestyrtet',),
'bestyrtetere': ('bestyrtet',),
'bestyrtetest': ('bestyrtet',),
'bestyrteteste': ('bestyrtet',),
'bestående': ('bestå',),
'bestått': ('bestå',),
'beståtte': ('bestå',),
'bestøva': ('bestøve',),
'bestøvede': ('bestøve',),
'bestøvende': ('bestøve',),
'bestøvet': ('bestøve',),
'bestøvete': ('bestøve',),
'besudla': ('besudle',),
'besudlede': ('besudle',),
'besudlende': ('besudle',),
'besudlet': ('besudle',),
'besudlete': ('besudle',),
'besvangra': ('besvangre',),
'besvangrede': ('besvangre',),
'besvangrende': ('besvangre',),
'besvangret': ('besvangre',),
'besvangrete': ('besvangre',),
'besvara': ('besvare',),
'besvarende': ('besvare',),
'besvart': ('besvare',),
'besvarte': ('besvare',),
'besverga': ('besverge',),
'besvergede': ('besverge',),
'besvergende': ('besverge',),
'besverget': ('besverge',),
'besvergete': ('besverge',),
'besvoren': ('besverge',),
'besvoret': ('besverge',),
'besvorne': ('besverge',),
'besverja': ('besverje',),
'besverjede': ('besverje',),
'besverjende': ('besverje',),
'besverjet': ('besverje',),
'besverjete': ('besverje',),
'besvoren': ('besverje',),
'besvoret': ('besverje',),
'besvorne': ('besverje',),
'besvimende': ('besvime',),
'besvimt': ('besvime',),
'besvimte': ('besvime',),
'besvogra': ('besvogra',),
'besvogrede': ('besvogret',),
'besvogret': ('besvogret',),
'besvogrete': ('besvogret',),
'besvogretere': ('besvogret',),
'besvogretest': ('besvogret',),
'besvogreteste': ('besvogret',),
'besværa': ('besvære',),
'besværede': ('besvære',),
'besværende': ('besvære',),
'besværet': ('besvære',),
'besværete': ('besvære',),
'besvært': ('besvære',),
'besværte': ('besvære',),
'besværlig': ('besværlig',),
'besværlige': ('besværlig',),
'besværligere': ('besværlig',),
'besværligst': ('besværlig',),
'besværligste': ('besværlig',),
'besynderlig': ('besynderlig',),
'besynderlige': ('besynderlig',),
'besynderligere': ('besynderlig',),
'besynderligst': ('besynderlig',),
'besynderligste': ('besynderlig',),
'besungen': ('besynge',),
'besunget': ('besynge',),
'besungne': ('besynge',),
'besyngende': ('besynge',),
'besådd': ('besådd',),
'besådde': ('besådd',),
'besåddere': ('besådd',),
'besåddest': ('besådd',),
'besåddeste': ('besådd',),
'besøkende': ('besøke',),
'besøkt': ('besøke',),
'besøkte': ('besøke',),
'besørga': ('besørge',),
'besørgede': ('besørge',),
'besørgende': ('besørge',),
'besørget': ('besørge',),
'besørgete': ('besørge',),
'betakende': ('beta',),
'betatt': ('beta',),
'betatte': ('beta',),
'betagende': ('betagende',),
'betakende': ('betakende',),
'betakka': ('betakke',),
'betakkede': ('betakke',),
'betakkende': ('betakke',),
'betakket': ('betakke',),
'betakkete': ('betakke',),
'betalende': ('betale',),
'betalt': ('betale',),
'betalte': ('betale',),
'betalingsdyktig': ('betalingsdyktig',),
'betalingsdyktige': ('betalingsdyktig',),
'betalingsdyktigere': ('betalingsdyktig',),
'betalingsdyktigst': ('betalingsdyktig',),
'betalingsdyktigste': ('betalingsdyktig',),
'betatt': ('betatt',),
'betatte': ('betatt',),
'betattere': ('betatt',),
'betattest': ('betatt',),
'betatteste': ('betatt',),
'betedd': ('bete',),
'betedde': ('bete',),
'beteende': ('bete',),
'betegna': ('betegne',),
'betegnede': ('betegne',),
'betegnende': ('betegne',),
'betegnet': ('betegne',),
'betegnete': ('betegne',),
'betegnende': ('betegnende',),
'betenkende': ('betenke',),
'betenkt': ('betenke',),
'betenkte': ('betenke',),
'betenkelig': ('betenkelig',),
'betenkelige': ('betenkelig',),
'betenkeligere': ('betenkelig',),
'betenkeligst': ('betenkelig',),
'betenkeligste': ('betenkelig',),
'betenksom': ('betenksom',),
'betenksomme': ('betenksom',),
'betenksommere': ('betenksom',),
'betenksomst': ('betenksom',),
'betenksomste': ('betenksom',),
'betenksomt': ('betenksom',),
'betenkt': ('betenkt',),
'betenkte': ('betenkt',),
'betenktere': ('betenkt',),
'betenktest': ('betenkt',),
'betenkteste': ('betenkt',),
'betent': ('betent',),
'betente': ('betent',),
'betentere': ('betent',),
'betentest': ('betent',),
'betenteste': ('betent',),
'betimelig': ('betimelig',),
'betimelige': ('betimelig',),
'betimeligere': ('betimelig',),
'betimeligst': ('betimelig',),
'betimeligste': ('betimelig',),
'betinga': ('betinge',),
'betingede': ('betinge',),
'betingende': ('betinge',),
'betinget': ('betinge',),
'betingete': ('betinge',),
'betingelseslaus': ('betingelseslaus',),
'betingelseslause': ('betingelseslaus',),
'betingelseslausere': ('betingelseslaus',),
'betingelseslausest': ('betingelseslaus',),
'betingelseslauseste': ('betingelseslaus',),
'betingelseslaust': ('betingelseslaus',),
'betingelsesløs': ('betingelsesløs',),
'betingelsesløse': ('betingelsesløs',),
'betingelsesløsere': ('betingelsesløs',),
'betingelsesløsest': ('betingelsesløs',),
'betingelsesløseste': ('betingelsesløs',),
'betingelsesløst': ('betingelsesløs',),
'betjenende': ('betjene',),
'betjent': ('betjene',),
'betjente': ('betjene',),
'betla': ('betle',),
'betlede': ('betle',),
'betlende': ('betle',),
'betlet': ('betle',),
'betlete': ('betle',),
'betona': ('betone',),
'betonede': ('betone',),
'betonende': ('betone',),
'betonet': ('betone',),
'betonete': ('betone',),
'betont': ('betone',),
'betonte': ('betone',),
'betrakta': ('betrakte',),
'betraktede': ('betrakte',),
'betraktende': ('betrakte',),
'betraktet': ('betrakte',),
'betraktete': ('betrakte',),
'betraktelig': ('betraktelig',),
'betraktelige': ('betraktelig',),
'betrakteligere': ('betraktelig',),
'betrakteligst': ('betraktelig',),
'betrakteligste': ('betraktelig',),
'betredende': ('betre',),
'betrådt': ('betre',),
'betrådte': ('betre',),
'betredende': ('betrede',),
'betrådt': ('betrede',),
'betrådte': ('betrede',),
'betrengt': ('betrengt',),
'betrengte': ('betrengt',),
'betrengtere': ('betrengt',),
'betrengtest': ('betrengt',),
'betrengteste': ('betrengt',),
'betrodd': ('betro',),
'betrodde': ('betro',),
'betroende': ('betro',),
'betrodd': ('betrodd',),
'betrodde': ('betrodd',),
'betroddere': ('betrodd',),
'betroddest': ('betrodd',),
'betroddeste': ('betrodd',),
'betryggende': ('betryggende',),
'betutta': ('betutta',),
'betuttede': ('betuttet',),
'betuttet': ('betuttet',),
'betuttete': ('betuttet',),
'betuttetere': ('betuttet',),
'betuttetest': ('betuttet',),
'betutteteste': ('betuttet',),
'betvilende': ('betvile',),
'betvilt': ('betvile',),
'betvilte': ('betvile',),
'betvingende': ('betvinge',),
'betvungen': ('betvinge',),
'betvunget': ('betvinge',),
'betvungne': ('betvinge',),
'betydd': ('bety',),
'betydde': ('bety',),
'betyende': ('bety',),
'betydelig': ('betydelig',),
'betydelige': ('betydelig',),
'betydeligere': ('betydelig',),
'betydeligst': ('betydelig',),
'betydeligste': ('betydelig',),
'betydningsbærende': ('betydningsbærende',),
'betydningsfull': ('betydningsfull',),
'betydningsfulle': ('betydningsfull',),
'betydningsfullere': ('betydningsfull',),
'betydningsfullest': ('betydningsfull',),
'betydningsfulleste': ('betydningsfull',),
'betydningsfullt': ('betydningsfull',),
'betydningslaus': ('betydningslaus',),
'betydningslause': ('betydningslaus',),
'betydningslausere': ('betydningslaus',),
'betydningslausest': ('betydningslaus',),
'betydningslauseste': ('betydningslaus',),
'betydningslaust': ('betydningslaus',),
'betydningsløs': ('betydningsløs',),
'betydningsløse': ('betydningsløs',),
'betydningsløsere': ('betydningsløs',),
'betydningsløsest': ('betydningsløs',),
'betydningsløseste': ('betydningsløs',),
'betydningsløst': ('betydningsløs',),
'betydningsrik': ('betydningsrik',),
'betydningsrike': ('betydningsrik',),
'betydningsrikere': ('betydningsrik',),
'betydningsrikest': ('betydningsrik',),
'betydningsrikeste': ('betydningsrik',),
'betydningsrikt': ('betydningsrik',),
'beundra': ('beundre',),
'beundrede': ('beundre',),
'beundrende': ('beundre',),
'beundret': ('beundre',),
'beundrete': ('beundre',),
'beundringsverdig': ('beundringsverdig',),
'beundringsverdige': ('beundringsverdig',),
'beundringsverdigere': ('beundringsverdig',),
'beundringsverdigst': ('beundringsverdig',),
'beundringsverdigste': ('beundringsverdig',),
'bevandra': ('bevandra',),
'bevandrede': ('bevandret',),
'bevandret': ('bevandret',),
'bevandrete': ('bevandret',),
'bevandretere': ('bevandret',),
'bevandretest': ('bevandret',),
'bevandreteste': ('bevandret',),
'bevarende': ('bevare',),
'bevart': ('bevare',),
'bevarte': ('bevare',),
'bevaringsverdig': ('bevaringsverdig',),
'bevaringsverdige': ('bevaringsverdig',),
'bevaringsverdigere': ('bevaringsverdig',),
'bevaringsverdigst': ('bevaringsverdig',),
'bevaringsverdigste': ('bevaringsverdig',),
'bevart': ('bevart',),
'bevarte': ('bevart',),
'bevartere': ('bevart',),
'bevartest': ('bevart',),
'bevarteste': ('bevart',),
'beva': ('beve',),
'bevd': ('beve',),
'bevde': ('beve',),
'bevede': ('beve',),
'bevende': ('beve',),
'bevet': ('beve',),
'bevete': ('beve',),
'bevega': ('bevege',),
'bevegd': ('bevege',),
'bevegde': ('bevege',),
'bevegede': ('bevege',),
'bevegende': ('bevege',),
'beveget': ('bevege',),
'bevegete': ('bevege',),
'bevegelig': ('bevegelig',),
'bevegelige': ('bevegelig',),
'bevegeligere': ('bevegelig',),
'bevegeligst': ('bevegelig',),
'bevegeligste': ('bevegelig',),
'bevegelseshemma': ('bevegelseshemma',),
'bevegelseshemmede': ('bevegelseshemmet',),
'bevegelseshemmet': ('bevegelseshemmet',),
'bevegelseshemmete': ('bevegelseshemmet',),
'bevegelseshemmetere': ('bevegelseshemmet',),
'bevegelseshemmetest': ('bevegelseshemmet',),
'bevegelseshemmeteste': ('bevegelseshemmet',),
'bevegede': ('beveget',),
'beveget': ('beveget',),
'bevegete': ('beveget',),
'bevegetere': ('beveget',),
'bevegetest': ('beveget',),
'bevegeteste': ('beveget',),
'bevendt': ('bevendt',),
'bevendte': ('bevendt',),
'bevendtere': ('bevendt',),
'bevendtest': ('bevendt',),
'bevendteste': ('bevendt',),
'beverta': ('beverte',),
'bevertede': ('beverte',),
'bevertende': ('beverte',),
'bevertet': ('beverte',),
'bevertete': ('beverte',),
'bevilga': ('bevilge',),
'bevilgede': ('bevilge',),
'bevilgende': ('bevilge',),
'bevilget': ('bevilge',),
'bevilgete': ('bevilge',),
'bevinga': ('bevinga',),
'bevingede': ('bevinget',),
'bevinget': ('bevinget',),
'bevingete': ('bevinget',),
'bevingetere': ('bevinget',),
'bevingetest': ('bevinget',),
'bevingeteste': ('bevinget',),
'bevirka': ('bevirke',),
'bevirkede': ('bevirke',),
'bevirkende': ('bevirke',),
'bevirket': ('bevirke',),
'bevirkete': ('bevirke',),
'bevisende': ('bevise',),
'bevist': ('bevise',),
'beviste': ('bevise',),
'beviselig': ('beviselig',),
'beviselige': ('beviselig',),
'beviseligere': ('beviselig',),
'beviseligst': ('beviselig',),
'beviseligste': ('beviselig',),
'bevislig': ('bevislig',),
'bevislige': ('bevislig',),
'bevisligere': ('bevislig',),
'bevisligst': ('bevislig',),
'bevisligste': ('bevislig',),
'bevisst': ('bevisst',),
'bevisste': ('bevisst',),
'bevisstere': ('bevisst',),
'bevisstest': ('bevisst',),
'bevissteste': ('bevisst',),
'bevisstgjort': ('bevisstgjøre',),
'bevisstgjorte': ('bevisstgjøre',),
'bevisstgjørende': ('bevisstgjøre',),
'bevissthetsutvidende': ('bevissthetsutvidende',),
'bevisstlaus': ('bevisstlaus',),
'bevisstlause': ('bevisstlaus',),
'bevisstlausere': ('bevisstlaus',),
'bevisstlausest': ('bevisstlaus',),
'bevisstlauseste': ('bevisstlaus',),
'bevisstlaust': ('bevisstlaus',),
'bevisstløs': ('bevisstløs',),
'bevisstløse': ('bevisstløs',),
'bevisstløsere': ('bevisstløs',),
'bevisstløsest': ('bevisstløs',),
'bevisstløseste': ('bevisstløs',),
'bevisstløst': ('bevisstløs',),
'bevitna': ('bevitne',),
'bevitnede': ('bevitne',),
'bevitnende': ('bevitne',),
'bevitnet': ('bevitne',),
'bevitnete': ('bevitne',),
'bevokst': ('bevokst',),
'bevokste': ('bevokst',),
'bevokstere': ('bevokst',),
'bevokstest': ('bevokst',),
'bevoksteste': ('bevokst',),
'bevokta': ('bevokte',),
'bevoktede': ('bevokte',),
'bevoktende': ('bevokte',),
'bevoktet': ('bevokte',),
'bevoktete': ('bevokte',),
'bevra': ('bevre',),
'bevrede': ('bevre',),
'bevrende': ('bevre',),
'bevret': ('bevre',),
'bevrete': ('bevre',),
'bevæpna': ('bevæpne',),
'bevæpnede': ('bevæpne',),
'bevæpnende': ('bevæpne',),
'bevæpnet': ('bevæpne',),
'bevæpnete': ('bevæpne',),
'beånda': ('beånde',),
'beåndede': ('beånde',),
'beåndende': ('beånde',),
'beåndet': ('beånde',),
'beåndete': ('beånde',),
'beæra': ('beære',),
'beærede': ('beære',),
'beærende': ('beære',),
'beæret': ('beære',),
'beærete': ('beære',),
'beæra': ('beære',),
'beærede': ('beære',),
'beærende': ('beære',),
'beæret': ('beære',),
'beærete': ('beære',),
'bhutansk': ('bhutansk',),
'bhutanske': ('bhutansk',),
'bhutanskere': ('bhutansk',),
'bhutanskest': ('bhutansk',),
'bhutanskeste': ('bhutansk',),
'biafransk': ('biafransk',),
'biafranske': ('biafransk',),
'biafranskere': ('biafransk',),
'biafranskest': ('biafransk',),
'biafranskeste': ('biafransk',),
'bibeholdende': ('bibeholde',),
'bibeholdt': ('bibeholde',),
'bibeholdte': ('bibeholde',),
'bibelsk': ('bibelsk',),
'bibelske': ('bibelsk',),
'bibelskere': ('bibelsk',),
'bibelskest': ('bibelsk',),
'bibelskeste': ('bibelsk',),
'bibelsprengt': ('bibelsprengt',),
'bibelsprengte': ('bibelsprengt',),
'bibelsprengtere': ('bibelsprengt',),
'bibelsprengtest': ('bibelsprengt',),
'bibelsprengteste': ('bibelsprengt',),
'bibliofil': ('bibliofil',),
'bibliofile': ('bibliofil',),
'bibliofilere': ('bibliofil',),
'bibliofilest': ('bibliofil',),
'bibliofileste': ('bibliofil',),
'bibliofilt': ('bibliofil',),
'bibliografisk': ('bibliografisk',),
'bibliografiske': ('bibliografisk',),
'bibliografiskere': ('bibliografisk',),
'bibliografiskest': ('bibliografisk',),
'bibliografiskeste': ('bibliografisk',),
'bibragt': ('bibringe',),
'bibragte': ('bibringe',),
'bibrakt': ('bibringe',),
'bibrakte': ('bibringe',),
'bibringende': ('bibringe',),
'bidig': ('bidig',),
'bidige': ('bidig',),
'bidigere': ('bidig',),
'bidigst': ('bidig',),
'bidigste': ('bidig',),
'bidradd': ('bidra',),
'bidradde': ('bidra',),
'bidragende': ('bidra',),
'bidratt': ('bidra',),
'bidratte': ('bidra',),
'bia': ('bie',),
'bidd': ('bie',),
'bidde': ('bie',),
'biede': ('bie',),
'biende': ('bie',),
'biet': ('bie',),
'biete': ('bie',),
'biennal': ('biennal',),
'biennale': ('biennal',),
'biennalere': ('biennal',),
'biennalest': ('biennal',),
'biennaleste': ('biennal',),
'biennalt': ('biennal',),
'bifallende': ('bifalle',),
'bifalt': ('bifalle',),
'bifalte': ('bifalle',),
'biff': ('biff',),
'bifil': ('bifil',),
'bifile': ('bifil',),
'bifilere': ('bifil',),
'bifilest': ('bifil',),
'bifileste': ('bifil',),
'bifilt': ('bifil',),
'bifokal': ('bifokal',),
'bifokale': ('bifokal',),
'bifokalere': ('bifokal',),
'bifokalest': ('bifokal',),
'bifokaleste': ('bifokal',),
'bifokalt': ('bifokal',),
'bigott': ('bigott',),
'bigotte': ('bigott',),
'bigottere': ('bigott',),
'bigottest': ('bigott',),
'bigotteste': ('bigott',),
'bikka': ('bikke',),
'bikkede': ('bikke',),
'bikkende': ('bikke',),
'bikket': ('bikke',),
'bikkete': ('bikke',),
'bikkjekald': ('bikkjekald',),
'bikkjekalde': ('bikkjekald',),
'bikkjekaldere': ('bikkjekald',),
'bikkjekaldest': ('bikkjekald',),
'bikkjekaldeste': ('bikkjekald',),
'bikkjekaldt': ('bikkjekald',),
'bikonkav': ('bikonkav',),
'bikonkave': ('bikonkav',),
'bikonkavere': ('bikonkav',),
'bikonkavest': ('bikonkav',),
'bikonkaveste': ('bikonkav',),
'bikonkavt': ('bikonkav',),
'bikonveks': ('bikonveks',),
'bikonvekse': ('bikonveks',),
'bikonveksere': ('bikonveks',),
'bikonveksest': ('bikonveks',),
'bikonvekseste': ('bikonveks',),
'bikonvekst': ('bikonveks',),
'bikta': ('bikte',),
'biktede': ('bikte',),
'biktende': ('bikte',),
'biktet': ('bikte',),
'biktete': ('bikte',),
'bilabial': ('bilabial',),
'bilabiale': ('bilabial',),
'bilabialere': ('bilabial',),
'bilabialest': ('bilabial',),
'bilabialeste': ('bilabial',),
'bilabialt': ('bilabial',),
'bilateral': ('bilateral',),
'bilaterale': ('bilateral',),
'bilateralere': ('bilateral',),
'bilateralest': ('bilateral',),
'bilateraleste': ('bilateral',),
'bilateralt': ('bilateral',),
'bildende': ('bildende',),
'bilderik': ('bilderik',),
'bilderike': ('bilderik',),
'bilderikere': ('bilderik',),
'bilderikest': ('bilderik',),
'bilderikeste': ('bilderik',),
'bilderikt': ('bilderik',),
'bildeskjønn': ('bildeskjønn',),
'bildeskjønne': ('bildeskjønn',),
'bildeskjønnere': ('bildeskjønn',),
'bildeskjønnest': ('bildeskjønn',),
'bildeskjønneste': ('bildeskjønn',),
'bildeskjønt': ('bildeskjønn',),
'bilende': ('bile',),
'bilt': ('bile',),
'bilte': ('bile',),
'bilagt': ('bilegge',),
'bilagte': ('bilegge',),
'bileggende': ('bilegge',),
'bilingv': ('bilingv',),
'bilingve': ('bilingv',),
'bilingvere': ('bilingv',),
'bilingvest': ('bilingv',),
'bilingveste': ('bilingv',),
'bilingval': ('bilingval',),
'bilingvale': ('bilingval',),
'bilingvalere': ('bilingval',),
'bilingvalest': ('bilingval',),
'bilingvaleste': ('bilingval',),
'bilingvalt': ('bilingval',),
'billedlig': ('billedlig',),
'billedlige': ('billedlig',),
'billedligere': ('billedlig',),
'billedligst': ('billedlig',),
'billedligste': ('billedlig',),
'billedrik': ('billedrik',),
'billedrike': ('billedrik',),
'billedrikere': ('billedrik',),
'billedrikest': ('billedrik',),
'billedrikeste': ('billedrik',),
'billedrikt': ('billedrik',),
'billedskjønn': ('billedskjønn',),
'billedskjønne': ('billedskjønn',),
'billedskjønnere': ('billedskjønn',),
'billedskjønnest': ('billedskjønn',),
'billedskjønneste': ('billedskjønn',),
'billedskjønt': ('billedskjønn',),
'billetterende': ('billettere',),
'billettert': ('billettere',),
'billetterte': ('billettere',),
'billig': ('billig',),
'billige': ('billig',),
'billigere': ('billig',),
'billigst': ('billig',),
'billigste': ('billig',),
'billiga': ('billige',),
'billigede': ('billige',),
'billigende': ('billige',),
'billiget': ('billige',),
'billigete': ('billige',),
'billiondels': ('billiondels',),
'billionte': ('billionte',),
'bilsakkyndig': ('bilsakkyndig',),
'bilsakkyndige': ('bilsakkyndig',),
'bilsakkyndigere': ('bilsakkyndig',),
'bilsakkyndigst': ('bilsakkyndig',),
'bilsakkyndigste': ('bilsakkyndig',),
'bilsjuk': ('bilsjuk',),
'bilsjuke': ('bilsjuk',),
'bilsjukere': ('bilsjuk',),
'bilsjukest': ('bilsjuk',),
'bilsjukeste': ('bilsjuk',),
'bilsjukt': ('bilsjuk',),
'bilsyk': ('bilsyk',),
'bilsyke': ('bilsyk',),
'bilsykere': ('bilsyk',),
'bilsykest': ('bilsyk',),
'bilsykeste': ('bilsyk',),
'bilsykt': ('bilsyk',),
'bindende': ('binde',),
'bunden': ('binde',),
'bundet': ('binde',),
'bundne': ('binde',),
'bindegal': ('bindegal',),
'bindegale': ('bindegal',),
'bindegalere': ('bindegal',),
'bindegalest': ('bindegal',),
'bindegaleste': ('bindegal',),
'bindegalt': ('bindegal',),
'bindegalen': ('bindegalen',),
'bindegalent': ('bindegalen',),
'bindegalne': ('bindegalen',),
'bindegalnere': ('bindegalen',),
'bindegalnest': ('bindegalen',),
'bindegalneste': ('bindegalen',),
'bindsterk': ('bindsterk',),
'bindsterke': ('bindsterk',),
'bindsterkere': ('bindsterk',),
'bindsterkest': ('bindsterk',),
'bindsterkeste': ('bindsterk',),
'bindsterkt': ('bindsterk',),
'binokular': ('binokular',),
'binokulare': ('binokular',),
'binokularere': ('binokular',),
'binokularest': ('binokular',),
'binokulareste': ('binokular',),
'binokulart': ('binokular',),
'binokulær': ('binokulær',),
'binokulære': ('binokulær',),
'binokulærere': ('binokulær',),
'binokulærest': ('binokulær',),
'binokulæreste': ('binokulær',),
'binokulært': ('binokulær',),
'binomial': ('binomial',),
'binomiale': ('binomial',),
'binomialere': ('binomial',),
'binomialest': ('binomial',),
'binomialeste': ('binomial',),
'binomialt': ('binomial',),
'binær': ('binær',),
'binære': ('binær',),
'binærere': ('binær',),
'binærest': ('binær',),
'binæreste': ('binær',),
'binært': ('binær',),
'biodynamisk': ('biodynamisk',),
'biodynamiske': ('biodynamisk',),
'biodynamiskere': ('biodynamisk',),
'biodynamiskest': ('biodynamisk',),
'biodynamiskeste': ('biodynamisk',),
'biogeokjemisk': ('biogeokjemisk',),
'biogeokjemiske': ('biogeokjemisk',),
'biogeokjemiskere': ('biogeokjemisk',),
'biogeokjemiskest': ('biogeokjemisk',),
'biogeokjemiskeste': ('biogeokjemisk',),
'biografisk': ('biografisk',),
'biografiske': ('biografisk',),
'biografiskere': ('biografisk',),
'biografiskest': ('biografisk',),
'biografiskeste': ('biografisk',),
'biokjemisk': ('biokjemisk',),
'biokjemiske': ('biokjemisk',),
'biokjemiskere': ('biokjemisk',),
'biokjemiskest': ('biokjemisk',),
'biokjemiskeste': ('biokjemisk',),
'biologisk': ('biologisk',),
'biologiske': ('biologisk',),
'biologiskere': ('biologisk',),
'biologiskest': ('biologisk',),
'biologiskeste': ('biologisk',),
'biotisk': ('biotisk',),
'biotiske': ('biotisk',),
'biotiskere': ('biotisk',),
'biotiskest': ('biotisk',),
'biotiskeste': ('biotisk',),
'bisarr': ('bisarr',),
'bisarre': ('bisarr',),
'bisarrere': ('bisarr',),
'bisarrest': ('bisarr',),
'bisarreste': ('bisarr',),
'bisart': ('bisarr',),
'biseksuell': ('biseksuell',),
'biseksuelle': ('biseksuell',),
'biseksuellere': ('biseksuell',),
'biseksuellest': ('biseksuell',),
'biseksuelleste': ('biseksuell',),
'biseksuelt': ('biseksuell',),
'bisatt': ('bisette',),
'bisatte': ('bisette',),
'bisettende': ('bisette',),
'bisk': ('bisk',),
'biske': ('bisk',),
'biskere': ('bisk',),
'biskest': ('bisk',),
'biskeste': ('bisk',),
'biskt': ('bisk',),
'biskoppelig': ('biskoppelig',),
'biskoppelige': ('biskoppelig',),
'biskoppeligere': ('biskoppelig',),
'biskoppeligst': ('biskoppelig',),
'biskoppeligste': ('biskoppelig',),
'bister': ('bister',),
'bistert': ('bister',),
'bistre': ('bister',),
'bistrere': ('bister',),
'bistrest': ('bister',),
'bistreste': ('bister',),
'bistående': ('bistå',),
'bistått': ('bistå',),
'biståtte': ('bistå',),
'bitende': ('bite',),
'bitt': ('bite',),
'bitte': ('bite',),
'bitende': ('bitende',),
'bitre': ('bitter',),
'bitrere': ('bitter',),
'bitrest': ('bitter',),
'bitreste': ('bitter',),
'bitter': ('bitter',),
'bittert': ('bitter',),
'bitterste': ('bitterste',),
'bittersøt': ('bittersøt',),
'bittersøte': ('bittersøt',),
'bittersøtere': ('bittersøt',),
'bittersøtest': ('bittersøt',),
'bittersøteste': ('bittersøt',),
'bittersøtt': ('bittersøt',),
'bitumiøs': ('bitumiøs',),
'bitumiøse': ('bitumiøs',),
'bitumiøsere': ('bitumiøs',),
'bitumiøsest': ('bitumiøs',),
'bitumiøseste': ('bitumiøs',),
'bitumiøst': ('bitumiøs',),
'bivalent': ('bivalent',),
'bivalente': ('bivalent',),
'bivalentere': ('bivalent',),
'bivalentest': ('bivalent',),
'bivalenteste': ('bivalent',),
'bivuakkerende': ('bivuakkere',),
'bivuakkert': ('bivuakkere',),
'bivuakkerte': ('bivuakkere',),
'bivåna': ('bivåne',),
'bivånede': ('bivåne',),
'bivånende': ('bivåne',),
'bivånet': ('bivåne',),
'bivånete': ('bivåne',),
'bivånt': ('bivåne',),
'bivånte': ('bivåne',),
'bjeffa': ('bjeffe',),
'bjeffede': ('bjeffe',),
'bjeffende': ('bjeffe',),
'bjeffet': ('bjeffe',),
'bjeffete': ('bjeffe',),
'bladd': ('bla',),
'bladde': ('bla',),
'blaende': ('bla',),
'bladtynn': ('bladtynn',),
'bladtynne': ('bladtynn',),
'bladtynnere': ('bladtynn',),
'bladtynnest': ('bladtynn',),
'bladtynneste': ('bladtynn',),
'bladtynt': ('bladtynn',),
'blaffa': ('blaffe',),
'blaffede': ('blaffe',),
'blaffende': ('blaffe',),
'blaffet': ('blaffe',),
'blaffete': ('blaffe',),
'blafra': ('blafre',),
'blafrede': ('blafre',),
'blafrende': ('blafre',),
'blafret': ('blafre',),
'blafrete': ('blafre',),
'blakk': ('blakk',),
'blakke': ('blakk',),
'blakkere': ('blakk',),
'blakkest': ('blakk',),
'blakkeste': ('blakk',),
'blakt': ('blakk',),
'blakka': ('blakke',),
'blakkede': ('blakke',),
'blakkende': ('blakke',),
'blakket': ('blakke',),
'blakkete': ('blakke',),
'blakna': ('blakne',),
'blaknede': ('blakne',),
'blaknende': ('blakne',),
'blaknet': ('blakne',),
'blaknete': ('blakne',),
'blakra': ('blakre',),
'blakrede': ('blakre',),
'blakrende': ('blakre',),
'blakret': ('blakre',),
'blakrete': ('blakre',),
'blamerende': ('blamere',),
'blamert': ('blamere',),
'blamerte': ('blamere',),
'blanda': ('blande',),
'blandede': ('blande',),
'blandende': ('blande',),
'blandet': ('blande',),
'blandete': ('blande',),
'blank': ('blank',),
'blanke': ('blank',),
'blankere': ('blank',),
'blankest': ('blank',),
'blankeste': ('blank',),
'blankt': ('blank',),
'blanka': ('blanke',),
'blankede': ('blanke',),
'blankende': ('blanke',),
'blanket': ('blanke',),
'blankete': ('blanke',),
'blankpussa': ('blankpusse',),
'blankpussede': ('blankpusse',),
'blankpussende': ('blankpusse',),
'blankpusset': ('blankpusse',),
'blankpussete': ('blankpusse',),
'blankslitende': ('blankslite',),
'blankslitt': ('blankslite',),
'blankslitte': ('blankslite',),
'blankøyd': ('blankøyd',),
'blankøyde': ('blankøyd',),
'blankøydere': ('blankøyd',),
'blankøydest': ('blankøyd',),
'blankøydeste': ('blankøyd',),
'blasert': ('blasert',),
'blaserte': ('blasert',),
'blasertere': ('blasert',),
'blasertest': ('blasert',),
'blaserteste': ('blasert',),
'blasfemisk': ('blasfemisk',),
'blasfemiske': ('blasfemisk',),
'blasfemiskere': ('blasfemisk',),
'blasfemiskest': ('blasfemisk',),
'blasfemiskeste': ('blasfemisk',),
'blasonerende': ('blasonere',),
'blasonert': ('blasonere',),
'blasonerte': ('blasonere',),
'blass': ('blass',),
'blasse': ('blass',),
'blassere': ('blass',),
'blassest': ('blass',),
'blasseste': ('blass',),
'blast': ('blass',),
'blaut': ('blaut',),
'blaute': ('blaut',),
'blautere': ('blaut',),
'blautest': ('blaut',),
'blauteste': ('blaut',),
'blautt': ('blaut',),
'blautgjort': ('blautgjøre',),
'blautgjorte': ('blautgjøre',),
'blautgjørende': ('blautgjøre',),
'blauthjertede': ('blauthjertet',),
'blauthjertet': ('blauthjertet',),
'blauthjertete': ('blauthjertet',),
'blauthjertetere': ('blauthjertet',),
'blauthjertetest': ('blauthjertet',),
'blauthjerteteste': ('blauthjertet',),
'blautkokende': ('blautkoke',),
'blautkokt': ('blautkoke',),
'blautkokte': ('blautkoke',),
'blautlendt': ('blautlendt',),
'blautlendte': ('blautlendt',),
'blautlendtere': ('blautlendt',),
'blautlendtest': ('blautlendt',),
'blautlendteste': ('blautlendt',),
'bleigd': ('bleige',),
'bleigde': ('bleige',),
'bleigende': ('bleige',),
'bleik': ('bleik',),
'bleike': ('bleik',),
'bleikere': ('bleik',),
'bleikest': ('bleik',),
'bleikeste': ('bleik',),
'bleikt': ('bleik',),
'bleikblå': ('bleikblå',),
'bleikblåe': ('bleikblå',),
'bleikblåere': ('bleikblå',),
'bleikblåest': ('bleikblå',),
'bleikblåeste': ('bleikblå',),
'bleikblått': ('bleikblå',),
'bleikbrun': ('bleikbrun',),
'bleikbrune': ('bleikbrun',),
'bleikbrunere': ('bleikbrun',),
'bleikbrunest': ('bleikbrun',),
'bleikbruneste': ('bleikbrun',),
'bleikbrunt': ('bleikbrun',),
'bleika': ('bleike',),
'bleikede': ('bleike',),
'bleikende': ('bleike',),
'bleiket': ('bleike',),
'bleikete': ('bleike',),
'bleikt': ('bleike',),
'bleikte': ('bleike',),
'bleikfeit': ('bleikfeit',),
'bleikfeite': ('bleikfeit',),
'bleikfeitere': ('bleikfeit',),
'bleikfeitest': ('bleikfeit',),
'bleikfeiteste': ('bleikfeit',),
'bleikfeitt': ('bleikfeit',),
'bleikfett': ('bleikfeit',),
'bleikna': ('bleikne',),
'bleiknede': ('bleikne',),
'bleiknende': ('bleikne',),
'bleiknet': ('bleikne',),
'bleiknete': ('bleikne',),
'bleiknebba': ('bleiknebba',),
'bleiknebbede': ('bleiknebbet',),
'bleiknebbet': ('bleiknebbet',),
'bleiknebbete': ('bleiknebbet',),
'bleiknebbetere': ('bleiknebbet',),
'bleiknebbetest': ('bleiknebbet',),
'bleiknebbeteste': ('bleiknebbet',),
'blek': ('blek',),
'bleke': ('blek',),
'blekere': ('blek',),
'blekest': ('blek',),
'blekeste': ('blek',),
'blekt': ('blek',),
'blekblå': ('blekblå',),
'blekblåe': ('blekblå',),
'blekblåere': ('blekblå',),
'blekblåest': ('blekblå',),
'blekblåeste': ('blekblå',),
'blekblått': ('blekblå',),
'blekbrun': ('blekbrun',),
'blekbrune': ('blekbrun',),
'blekbrunere': ('blekbrun',),
'blekbrunest': ('blekbrun',),
'blekbruneste': ('blekbrun',),
'blekbrunt': ('blekbrun',),
'bleka': ('bleke',),
'blekede': ('bleke',),
'blekende': ('bleke',),
'bleket': ('bleke',),
'blekete': ('bleke',),
'blekt': ('bleke',),
'blekte': ('bleke',),
'blekfet': ('blekfet',),
'blekfete': ('blekfet',),
'blekfetere': ('blekfet',),
'blekfetest': ('blekfet',),
'blekfeteste': ('blekfet',),
'blekfett': ('blekfet',),
'blekka': ('blekke',),
'blekkede': ('blekke',),
'blekkende': ('blekke',),
'blekket': ('blekke',),
'blekkete': ('blekke',),
'blekkende': ('blekke',),
'blekt': ('blekke',),
'blekte': ('blekke',),
'blekket': ('blekket',),
'blekkete': ('blekket',),
'blekketere': ('blekket',),
'blekketest': ('blekket',),
'blekketeste': ('blekket',),
'blekkete': ('blekkete',),
'blekna': ('blekne',),
'bleknede': ('blekne',),
'bleknende': ('blekne',),
'bleknet': ('blekne',),
'bleknete': ('blekne',),
'blemmet': ('blemmet',),
'blemmete': ('blemmet',),
'blemmetere': ('blemmet',),
'blemmetest': ('blemmet',),
'blemmeteste': ('blemmet',),
'blemmete': ('blemmete',),
'blenda': ('blende',),
'blendede': ('blende',),
'blendende': ('blende',),
'blendet': ('blende',),
'blendete': ('blende',),
'blendende': ('blendende',),
'blivende': ('bli',),
'blitt': ('bli',),
'blitte': ('bli',),
'blivende': ('bli',),
'blid': ('blid',),
'blide': ('blid',),
'blidere': ('blid',),
'blidest': ('blid',),
'blideste': ('blid',),
'blidt': ('blid',),
'blidgjort': ('blidgjøre',),
'blidgjorte': ('blidgjøre',),
'blidgjørende': ('blidgjøre',),
'blidlåten': ('blidlåten',),
'blidlåtent': ('blidlåten',),
'blidlåtne': ('blidlåten',),
'blidlåtnere': ('blidlåten',),
'blidlåtnest': ('blidlåten',),
'blidlåtneste': ('blidlåten',),
'blikkstille': ('blikkstille',),
'blind': ('blind',),
'blinde': ('blind',),
'blindere': ('blind',),
'blindest': ('blind',),
'blindeste': ('blind',),
'blindt': ('blind',),
'blinda': ('blinde',),
'blindede': ('blinde',),
'blindende': ('blinde',),
'blindet': ('blinde',),
'blindete': ('blinde',),
'blingsa': ('blingse',),
'blingsede': ('blingse',),
'blingsende': ('blingse',),
'blingset': ('blingse',),
'blingsete': ('blingse',),
'blingset': ('blingset',),
'blingsete': ('blingset',),
'blingsetere': ('blingset',),
'blingsetest': ('blingset',),
'blingseteste': ('blingset',),
'blingsete': ('blingsete',),
'blinka': ('blinke',),
'blinkede': ('blinke',),
'blinkende': ('blinke',),
'blinket': ('blinke',),
'blinkete': ('blinke',),
'blinka': ('blinke',),
'blinkede': ('blinke',),
'blinkende': ('blinke',),
'blinket': ('blinke',),
'blinkete': ('blinke',),
'blitsa': ('blitse',),
'blitsede': ('blitse',),
'blitsende': ('blitse',),
'blitset': ('blitse',),
'blitsete': ('blitse',),
'blitt': ('blive',),
'blitte': ('blive',),
'blivende': ('blive',),
'blivende': ('blivende',),
'bloddryppende': ('bloddryppende',),
'blodet': ('blodet',),
'blodete': ('blodet',),
'blodetere': ('blodet',),
'blodetest': ('blodet',),
'blodeteste': ('blodet',),
'blodete': ('blodete',),
'blodfattig': ('blodfattig',),
'blodfattige': ('blodfattig',),
'blodfattigere': ('blodfattig',),
'blodfattigst': ('blodfattig',),
'blodfattigste': ('blodfattig',),
'blodfersk': ('blodfersk',),
'blodferske': ('blodfersk',),
'blodferskere': ('blodfersk',),
'blodferskest': ('blodfersk',),
'blodferskeste': ('blodfersk',),
'blodferskt': ('blodfersk',),
'blodfull': ('blodfull',),
'blodfulle': ('blodfull',),
'blodfullere': ('blodfull',),
'blodfullest': ('blodfull',),
'blodfulleste': ('blodfull',),
'blodfullt': ('blodfull',),
'blodig': ('blodig',),
'blodige': ('blodig',),
'blodigere': ('blodig',),
'blodigst': ('blodig',),
'blodigste': ('blodig',),
'blodrød': ('blodrød',),
'blodrøde': ('blodrød',),
'blodrødere': ('blodrød',),
'blodrødest': ('blodrød',),
'blodrødeste': ('blodrød',),
'blodrødt': ('blodrød',),
'blodskutt': ('blodskutt',),
'blodskutte': ('blodskutt',),
'blodskuttere': ('blodskutt',),
'blodskuttest': ('blodskutt',),
'blodskutteste': ('blodskutt',),
'blodsprengt': ('blodsprengt',),
'blodsprengte': ('blodsprengt',),
'blodsprengtere': ('blodsprengt',),
'blodsprengtest': ('blodsprengt',),
'blodsprengteste': ('blodsprengt',),
'blodstillende': ('blodstillende',),
'blodtørstig': ('blodtørstig',),
'blodtørstige': ('blodtørstig',),
'blodtørstigere': ('blodtørstig',),
'blodtørstigst': ('blodtørstig',),
'blodtørstigste': ('blodtørstig',),
'blodunderløpen': ('blodunderløpen',),
'blodunderløpent': ('blodunderløpen',),
'blodunderløpne': ('blodunderløpen',),
'blodunderløpnere': ('blodunderløpen',),
'blodunderløpnest': ('blodunderløpen',),
'blodunderløpneste': ('blodunderløpen',),
'blogga': ('blogge',),
'bloggede': ('blogge',),
'bloggende': ('blogge',),
'blogget': ('blogge',),
'bloggete': ('blogge',),
'blokka': ('blokke',),
'blokkede': ('blokke',),
'blokkende': ('blokke',),
'blokket': ('blokke',),
'blokkete': ('blokke',),
'blokkerende': ('blokkere',),
'blokkert': ('blokkere',),
'blokkerte': ('blokkere',),
'blomstra': ('blomstre',),
'blomstrede': ('blomstre',),
'blomstrende': ('blomstre',),
'blomstret': ('blomstre',),
'blomstrete': ('blomstre',),
'blomstrende': ('blomstrende',),
'blomstret': ('blomstret',),
'blomstrete': ('blomstret',),
'blomstretere': ('blomstret',),
'blomstretest': ('blomstret',),
'blomstreteste': ('blomstret',),
'blomstrete': ('blomstrete',),
'blond': ('blond',),
'blonde': ('blond',),
'blondere': ('blond',),
'blondest': ('blond',),
'blondeste': ('blond',),
'blondt': ('blond',),
'blota': ('blote',),
'blotede': ('blote',),
'blotende': ('blote',),
'blotet': ('blote',),
'blotete': ('blote',),
'blott': ('blott',),
'blotte': ('blott',),
'blottere': ('blott',),
'blottest': ('blott',),
'blotteste': ('blott',),
'blotta': ('blotte',),
'blottede': ('blotte',),
'blottende': ('blotte',),
'blottet': ('blotte',),
'blottete': ('blotte',),
'blottlagt': ('blottlegge',),
'blottlagte': ('blottlegge',),
'blottleggende': ('blottlegge',),
'blottstillende': ('blottstille',),
'blottstilt': ('blottstille',),
'blottstilte': ('blottstille',),
'bluferdig': ('bluferdig',),
'bluferdige': ('bluferdig',),
'bluferdigere': ('bluferdig',),
'bluferdigst': ('bluferdig',),
'bluferdigste': ('bluferdig',),
'blunda': ('blunde',),
'blundede': ('blunde',),
'blundende': ('blunde',),
'blundet': ('blunde',),
'blundete': ('blunde',),
'blunka': ('blunke',),
'blunkede': ('blunke',),
'blunkende': ('blunke',),
'blunket': ('blunke',),
'blunkete': ('blunke',),
'blussa': ('blusse',),
'blussede': ('blusse',),
'blussende': ('blusse',),
'blusset': ('blusse',),
'blussete': ('blusse',),
'blussende': ('blussende',),
'blyg': ('blyg',),
'blyge': ('blyg',),
'blygere': ('blyg',),
'blygest': ('blyg',),
'blygeste': ('blyg',),
'blygt': ('blyg',),
'blygrå': ('blygrå',),
'blygråe': ('blygrå',),
'blygråere': ('blygrå',),
'blygråest': ('blygrå',),
'blygråeste': ('blygrå',),
'blygrått': ('blygrå',),
'blyholdig': ('blyholdig',),
'blyholdige': ('blyholdig',),
'blyholdigere': ('blyholdig',),
'blyholdigst': ('blyholdig',),
'blyholdigste': ('blyholdig',),
'blytung': ('blytung',),
'blytunge': ('blytung',),
'blytungere': ('blytung',),
'blytungest': ('blytung',),
'blytungeste': ('blytung',),
'blytungt': ('blytung',),
'blytyngre': ('blytung',),
'blytyngst': ('blytung',),
'blytyngste': ('blytung',),
'blå': ('blå',),
'blåe': ('blå',),
'blåere': ('blå',),
'blåest': ('blå',),
'blåeste': ('blå',),
'blått': ('blå',),
'blåfiolett': ('blåfiolett',),
'blåfiolette': ('blåfiolett',),
'blåfiolettere': ('blåfiolett',),
'blåfiolettest': ('blåfiolett',),
'blåfioletteste': ('blåfiolett',),
'blåfrosne': ('blåfrossen',),
'blåfrosnere': ('blåfrossen',),
'blåfrosnest': ('blåfrossen',),
'blåfrosneste': ('blåfrossen',),
'blåfrossen': ('blåfrossen',),
'blåfrossent': ('blåfrossen',),
'blåfrosset': ('blåfrossen',),
'blåfrosne': ('blåfrosset',),
'blåfrosnere': ('blåfrosset',),
'blåfrosnest': ('blåfrosset',),
'blåfrosneste': ('blåfrosset',),
'blåfrosset': ('blåfrosset',),
'blågul': ('blågul',),
'blågule': ('blågul',),
'blågulere': ('blågul',),
'blågulest': ('blågul',),
'blåguleste': ('blågul',),
'blågult': ('blågul',),
'blåhard': ('blåhard',),
'blåharde': ('blåhard',),
'blåhardere': ('blåhard',),
'blåhardest': ('blåhard',),
'blåhardeste': ('blåhard',),
'blåhardt': ('blåhard',),
'blåholdende': ('blåholde',),
'blåholdt': ('blåholde',),
'blåholdte': ('blåholde',),
'blålig': ('blålig',),
'blålige': ('blålig',),
'blåligere': ('blålig',),
'blåligst': ('blålig',),
'blåligste': ('blålig',),
'blåna': ('blåne',),
'blånede': ('blåne',),
'blånende': ('blåne',),
'blånet': ('blåne',),
'blånete': ('blåne',),
'blånt': ('blåne',),
'blånte': ('blåne',),
'blånekta': ('blånekte',),
'blånektede': ('blånekte',),
'blånektende': ('blånekte',),
'blånektet': ('blånekte',),
'blånektete': ('blånekte',),
'blånøye': ('blånøye',),
'blåsende': ('blåse',),
'blåst': ('blåse',),
'blåste': ('blåse',),
'blåsur': ('blåsur',),
'blåsure': ('blåsur',),
'blåsurere': ('blåsur',),
'blåsurest': ('blåsur',),
'blåsureste': ('blåsur',),
'blåsurt': ('blåsur',),
'blåøyd': ('blåøyd',),
'blåøyde': ('blåøyd',),
'blåøydere': ('blåøyd',),
'blåøydest': ('blåøyd',),
'blåøydeste': ('blåøyd',),
'blæra': ('blære',),
'blærede': ('blære',),
'blærende': ('blære',),
'blæret': ('blære',),
'blærete': ('blære',),
'blæret': ('blæret',),
'blærete': ('blæret',),
'blæretere': ('blæret',),
'blæretest': ('blæret',),
'blæreteste': ('blæret',),
'blærete': ('blærete',),
'blødd': ('blø',),
'blødde': ('blø',),
'bløende': ('blø',),
'blødd': ('bløde',),
'blødde': ('bløde',),
'blødende': ('bløde',),
'bløffa': ('bløffe',),
'bløffede': ('bløffe',),
'bløffende': ('bløffe',),
'bløffet': ('bløffe',),
'bløffete': ('bløffe',),
'bløgga': ('bløgge',),
'bløggede': ('bløgge',),
'bløggende': ('bløgge',),
'bløgget': ('bløgge',),
'bløggete': ('bløgge',),
'bløt': ('bløt',),
'bløte': ('bløt',),
'bløtere': ('bløt',),
'bløtest': ('bløt',),
'bløteste': ('bløt',),
'bløtt': ('bløt',),
'bløtaktig': ('bløtaktig',),
'bløtaktige': ('bløtaktig',),
'bløtaktigere': ('bløtaktig',),
'bløtaktigst': ('bløtaktig',),
'bløtaktigste': ('bløtaktig',),
'bløtende': ('bløte',),
'bløtt': ('bløte',),
'bløtte': ('bløte',),
'bløtgjort': ('bløtgjøre',),
'bløtgjorte': ('bløtgjøre',),
'bløtgjørende': ('bløtgjøre',),
'bløthjerta': ('bløthjerta',),
'bløthjertede': ('bløthjertet',),
'bløthjertet': ('bløthjertet',),
'bløthjertete': ('bløthjertet',),
'bløthjertetere': ('bløthjertet',),
'bløthjertetest': ('bløthjertet',),
'bløthjerteteste': ('bløthjertet',),
'bløtkokende': ('bløtkoke',),
'bløtkokt': ('bløtkoke',),
'bløtkokte': ('bløtkoke',),
'bløtlagt': ('bløtlegge',),
'bløtlagte': ('bløtlegge',),
'bløtleggende': ('bløtlegge',),
'bløtt': ('bløyte',),
'bløtte': ('bløyte',),
'bløytende': ('bløyte',),
'bløytt': ('bløyte',),
'bløytte': ('bløyte',),
'bløytlagt': ('bløytlegge',),
'bløytlagte': ('bløytlegge',),
'bløytleggende': ('bløytlegge',),
'bodd': ('bo',),
'bodde': ('bo',),
'boende': ('bo',),
'bobla': ('boble',),
'boblede': ('boble',),
'boblende': ('boble',),
'boblet': ('boble',),
'boblete': ('boble',),
'bofast': ('bofast',),
'bofaste': ('bofast',),
'bofastere': ('bofast',),
'bofastest': ('bofast',),
'bofasteste': ('bofast',),
'boga': ('boge',),
'bogede': ('boge',),
'bogende': ('boge',),
'boget': ('boge',),
'bogete': ('boge',),
'bogeforma': ('bogeforma',),
'bogeformede': ('bogeformet',),
'bogeformet': ('bogeformet',),
'bogeformete': ('bogeformet',),
'bogeformetere': ('bogeformet',),
'bogeformetest': ('bogeformet',),
'bogeformeteste': ('bogeformet',),
'bogna': ('bogne',),
'bognede': ('bogne',),
'bognende': ('bogne',),
'bognet': ('bogne',),
'bognete': ('bogne',),
'boikotta': ('boikotte',),
'boikottede': ('boikotte',),
'boikottende': ('boikotte',),
'boikottet': ('boikotte',),
'boikottete': ('boikotte',),
'bokførende': ('bokføre',),
'bokført': ('bokføre',),
'bokførte': ('bokføre',),
'boklig': ('boklig',),
'boklige': ('boklig',),
'bokligere': ('boklig',),
'bokligst': ('boklig',),
'bokligste': ('boklig',),
'bokna': ('bokne',),
'boknede': ('bokne',),
'boknende': ('bokne',),
'boknet': ('bokne',),
'boknete': ('bokne',),
'boksa': ('bokse',),
'boksede': ('bokse',),
'boksende': ('bokse',),
'bokset': ('bokse',),
'boksete': ('bokse',),
'bokstavelig': ('bokstavelig',),
'bokstavelige': ('bokstavelig',),
'bokstaveligere': ('bokstavelig',),
'bokstaveligst': ('bokstavelig',),
'bokstaveligste': ('bokstavelig',),
'bokstaverende': ('bokstavere',),
'bokstavert': ('bokstavere',),
'bokstaverte': ('bokstavere',),
'bokstavrett': ('bokstavrett',),
'bokstavrette': ('bokstavrett',),
'bokstavrettere': ('bokstavrett',),
'bokstavrettest': ('bokstavrett',),
'bokstavretteste': ('bokstavrett',),
'bold': ('bold',),
'bolde': ('bold',),
'boldere': ('bold',),
'boldest': ('bold',),
'boldeste': ('bold',),
'boldt': ('bold',),
'bola': ('bole',),
'bolede': ('bole',),
'bolende': ('bole',),
'bolet': ('bole',),
'bolete': ('bole',),
'bolt': ('bole',),
'bolte': ('bole',),
'boligsøkende': ('boligsøkende',),
'boliviansk': ('boliviansk',),
'bolivianske': ('boliviansk',),
'bolivianskere': ('boliviansk',),
'bolivianskest': ('boliviansk',),
'bolivianskeste': ('boliviansk',),
'bolna': ('bolne',),
'bolnede': ('bolne',),
'bolnende': ('bolne',),
'bolnet': ('bolne',),
'bolnete': ('bolne',),
'bolta': ('bolte',),
'boltede': ('bolte',),
'boltende': ('bolte',),
'boltet': ('bolte',),
'boltete': ('bolte',),
'boltra': ('boltre',),
'boltrede': ('boltre',),
'boltrende': ('boltre',),
'boltret': ('boltre',),
'boltrete': ('boltre',),
'bombarderende': ('bombardere',),
'bombardert': ('bombardere',),
'bombarderte': ('bombardere',),
'bombastisk': ('bombastisk',),
'bombastiske': ('bombastisk',),
'bombastiskere': ('bombastisk',),
'bombastiskest': ('bombastisk',),
'bombastiskeste': ('bombastisk',),
'bomba': ('bombe',),
'bombede': ('bombe',),
'bombende': ('bombe',),
'bombet': ('bombe',),
'bombete': ('bombe',),
'bombesikker': ('bombesikker',),
'bombesikkert': ('bombesikker',),
'bombesikre': ('bombesikker',),
'bombesikrere': ('bombesikker',),
'bombesikrest': ('bombesikker',),
'bombesikreste': ('bombesikker',),
'bomfast': ('bomfast',),
'bomfaste': ('bomfast',),
'bomfastere': ('bomfast',),
'bomfastest': ('bomfast',),
'bomfasteste': ('bomfast',),
'bomma': ('bomme',),
'bommede': ('bomme',),
'bommende': ('bomme',),
'bommet': ('bomme',),
'bommete': ('bomme',),
'bomma': ('bomme',),
'bommede': ('bomme',),
'bommende': ('bomme',),
'bommet': ('bomme',),
'bommete': ('bomme',),
'bomma': ('bomme',),
'bommede': ('bomme',),
'bommende': ('bomme',),
'bommet': ('bomme',),
'bommete': ('bomme',),
'bomsterk': ('bomsterk',),
'bomsterke': ('bomsterk',),
'bomsterkere': ('bomsterk',),
'bomsterkest': ('bomsterk',),
'bomsterkeste': ('bomsterk',),
'bomsterkt': ('bomsterk',),
'bomstille': ('bomstille',),
'bondeblå': ('bondeblå',),
'bondeblåe': ('bondeblå',),
'bondeblåere': ('bondeblå',),
'bondeblåest': ('bondeblå',),
'bondeblåeste': ('bondeblå',),
'bondeblått': ('bondeblå',),
'bondsk': ('bondsk',),
'bondske': ('bondsk',),
'bondskere': ('bondsk',),
'bondskest': ('bondsk',),
'bondskeste': ('bondsk',),
'bona': ('bone',),
'bonede': ('bone',),
'bonende': ('bone',),
'bonet': ('bone',),
'bonete': ('bone',),
'bont': ('bone',),
'bonte': ('bone',),
'bonga': ('bonge',),
'bongede': ('bonge',),
'bongende': ('bonge',),
'bonget': ('bonge',),
'bongete': ('bonge',),
'boniterende': ('bonitere',),
'bonitert': ('bonitere',),
'boniterte': ('bonitere',),
'booka': ('booke',),
'bookede': ('booke',),
'bookende': ('booke',),
'booket': ('booke',),
'bookete': ('booke',),
'boolsk': ('boolsk',),
'boolske': ('boolsk',),
'boolskere': ('boolsk',),
'boolskest': ('boolsk',),
'boolskeste': ('boolsk',),
'borda': ('borde',),
'bordede': ('borde',),
'bordende': ('borde',),
'bordet': ('borde',),
'bordete': ('borde',),
'bordkledd': ('bordkle',),
'bordkledde': ('bordkle',),
'bordkleende': ('bordkle',),
'bora': ('bore',),
'borede': ('bore',),
'borende': ('bore',),
'boret': ('bore',),
'borete': ('bore',),
'boreal': ('boreal',),
'boreale': ('boreal',),
'borealere': ('boreal',),
'borealest': ('boreal',),
'borealeste': ('boreal',),
'borealt': ('boreal',),
'borga': ('borge',),
'borgede': ('borge',),
'borgende': ('borge',),
'borget': ('borge',),
'borgete': ('borge',),
'borgerlig': ('borgerlig',),
'borgerlige': ('borgerlig',),
'borgerligere': ('borgerlig',),
'borgerligst': ('borgerlig',),
'borgerligste': ('borgerlig',),
'borket': ('borket',),
'borkete': ('borket',),
'borketere': ('borket',),
'borketest': ('borket',),
'borketeste': ('borket',),
'borkete': ('borkete',),
'bornert': ('bornert',),
'bornerte': ('bornert',),
'bornertere': ('bornert',),
'bornertest': ('bornert',),
'bornerteste': ('bornert',),
'bortbestilt': ('bortbestilt',),
'bortbestilte': ('bortbestilt',),
'bortbestiltere': ('bortbestilt',),
'bortbestiltest': ('bortbestilt',),
'bortbestilteste': ('bortbestilt',),
'bortbygsla': ('bortbygsle',),
'bortbygslede': ('bortbygsle',),
'bortbygslende': ('bortbygsle',),
'bortbygslet': ('bortbygsle',),
'bortbygslete': ('bortbygsle',),
'borterst': ('borterst',),
'borterste': ('borterst',),
'bortest': ('bortest',),
'borteste': ('bortest',),
'bortfesta': ('bortfeste',),
'bortfestede': ('bortfeste',),
'bortfestende': ('bortfeste',),
'bortfestet': ('bortfeste',),
'bortfestete': ('bortfeste',),
'bortforklarende': ('bortforklare',),
'bortforklart': ('bortforklare',),
'bortforklarte': ('bortforklare',),
'bortfrakta': ('bortfrakte',),
'bortfraktede': ('bortfrakte',),
'bortfraktende': ('bortfrakte',),
'bortfraktet': ('bortfrakte',),
'bortfraktete': ('bortfrakte',),
'bortførende': ('bortføre',),
'bortført': ('bortføre',),
'bortførte': ('bortføre',),
'bortgangen': ('bortgangen',),
'bortgangent': ('bortgangen',),
'bortgangne': ('bortgangen',),
'bortgangnere': ('bortgangen',),
'bortgangnest': ('bortgangen',),
'bortgangneste': ('bortgangen',),
'bortgjemt': ('bortgjemt',),
'bortgjemte': ('bortgjemt',),
'bortgjemtere': ('bortgjemt',),
'bortgjemtest': ('bortgjemt',),
'bortgjemteste': ('bortgjemt',),
'bortgjømt': ('bortgjømt',),
'bortgjømte': ('bortgjømt',),
'bortgjømtere': ('bortgjømt',),
'bortgjømtest': ('bortgjømt',),
'bortgjømteste': ('bortgjømt',),
'bortglemt': ('bortglemt',),
'bortglemte': ('bortglemt',),
'bortglemtere': ('bortglemt',),
'bortglemtest': ('bortglemt',),
'bortglemteste': ('bortglemt',),
'bortglømt': ('bortglømt',),
'bortglømte': ('bortglømt',),
'bortglømtere': ('bortglømt',),
'bortglømtest': ('bortglømt',),
'bortglømteste': ('bortglømt',),
'bortkasta': ('bortkasta',),
'bortkastede': ('bortkastet',),
'bortkastet': ('bortkastet',),
'bortkastete': ('bortkastet',),
'bortkastetere': ('bortkastet',),
'bortkastetest': ('bortkastet',),
'bortkasteteste': ('bortkastet',),
'bortkommen': ('bortkommen',),
'bortkomment': ('bortkommen',),
'bortkomne': ('bortkommen',),
'bortkomnere': ('bortkommen',),
'bortkomnest': ('bortkommen',),
'bortkomneste': ('bortkommen',),
'bortkommen': ('bortkommen',),
'bortkommet': ('bortkommen',),
'bortkomne': ('bortkommen',),
'bortkomnere': ('bortkommen',),
'bortkomnest': ('bortkommen',),
'bortkomneste': ('bortkommen',),
'bortkommet': ('bortkommet',),
'bortkomne': ('bortkommet',),
'bortkomnere': ('bortkommet',),
'bortkomnest': ('bortkommet',),
'bortkomneste': ('bortkommet',),
'bortleda': ('bortlede',),
'bortledede': ('bortlede',),
'bortledende': ('bortlede',),
'bortledet': ('bortlede',),
'bortledete': ('bortlede',),
'bortleid': ('bortleid',),
'bortleide': ('bortleid',),
'bortleidere': ('bortleid',),
'bortleidest': ('bortleid',),
'bortleideste': ('bortleid',),
'bortløpen': ('bortløpen',),
'bortløpent': ('bortløpen',),
'bortløpet': ('bortløpen',),
'bortløpne': ('bortløpen',),
'bortløpnere': ('bortløpen',),
'bortløpnest': ('bortløpen',),
'bortløpneste': ('bortløpen',),
'bortløpte': ('bortløpen',),
'borterst': ('bortre',),
'borterste': ('bortre',),
'bortre': ('bortre',),
'bortreist': ('bortreist',),
'bortreiste': ('bortreist',),
'bortreistere': ('bortreist',),
'bortreistest': ('bortreist',),
'bortreisteste': ('bortreist',),
'bortseende': ('bortse',),
'bortsett': ('bortse',),
'bortsette': ('bortse',),
'bortsatt': ('bortsette',),
'bortsatte': ('bortsette',),
'bortsettende': ('bortsette',),
'bortskjemt': ('bortskjemt',),
'bortskjemte': ('bortskjemt',),
'bortskjemtere': ('bortskjemt',),
'bortskjemtest': ('bortskjemt',),
'bortskjemteste': ('bortskjemt',),
'bortødsla': ('bortødsle',),
'bortødslede': ('bortødsle',),
'bortødslende': ('bortødsle',),
'bortødslet': ('bortødsle',),
'bortødslete': ('bortødsle',),
'bosatt': ('bosatt',),
'bosatte': ('bosatt',),
'bosattere': ('bosatt',),
'bosattest': ('bosatt',),
'bosatteste': ('bosatt',),
'bosatt': ('bosette',),
'bosatte': ('bosette',),
'bosettende': ('bosette',),
'bosnisk': ('bosnisk',),
'bosniske': ('bosnisk',),
'bosniskere': ('bosnisk',),
'bosniskest': ('bosnisk',),
'bosniskeste': ('bosnisk',),
'botaniserende': ('botanisere',),
'botanisert': ('botanisere',),
'botaniserte': ('botanisere',),
'botanisk': ('botanisk',),
'botaniske': ('botanisk',),
'botaniskere': ('botanisk',),
'botaniskest': ('botanisk',),
'botaniskeste': ('botanisk',),
'botferdig': ('botferdig',),
'botferdige': ('botferdig',),
'botferdigere': ('botferdig',),
'botferdigst': ('botferdig',),
'botferdigste': ('botferdig',),
'botlagt': ('botlegge',),
'botlagte': ('botlegge',),
'botleggende': ('botlegge',),
'botna': ('botne',),
'botnede': ('botne',),
'botnende': ('botne',),
'botnet': ('botne',),
'botnete': ('botne',),
'botnfellende': ('botnfelle',),
'botnfelt': ('botnfelle',),
'botnfelte': ('botnfelle',),
'botnlaus': ('botnlaus',),
'botnlause': ('botnlaus',),
'botnlausere': ('botnlaus',),
'botnlausest': ('botnlaus',),
'botnlauseste': ('botnlaus',),
'botnlaust': ('botnlaus',),
'botnløs': ('botnløs',),
'botnløse': ('botnløs',),
'botnløsere': ('botnløs',),
'botnløsest': ('botnløs',),
'botnløseste': ('botnløs',),
'botnløst': ('botnløs',),
'botnskrapa': ('botnskrape',),
'botnskrapede': ('botnskrape',),
'botnskrapende': ('botnskrape',),
'botnskrapet': ('botnskrape',),
'botnskrapete': ('botnskrape',),
'botnskrapt': ('botnskrape',),
'botnskrapte': ('botnskrape',),
'botswansk': ('botswansk',),
'botswanske': ('botswansk',),
'botswanskere': ('botswansk',),
'botswanskest': ('botswansk',),
'botswanskeste': ('botswansk',),
'bowla': ('bowle',),
'bowlede': ('bowle',),
'bowlende': ('bowle',),
'bowlet': ('bowle',),
'bowlete': ('bowle',),
'bra': ('bra',),
'braka': ('brake',),
'brakede': ('brake',),
'brakende': ('brake',),
'braket': ('brake',),
'brakete': ('brake',),
'brakt': ('brake',),
'brakte': ('brake',),
'brakk': ('brakk',),
'brakke': ('brakk',),
'brakkere': ('brakk',),
'brakkest': ('brakk',),
'brakkeste': ('brakk',),
'brakt': ('brakk',),
'brakk': ('brakk',),
'brakke': ('brakk',),
'brakkere': ('brakk',),
'brakkest': ('brakk',),
'brakkeste': ('brakk',),
'brakt': ('brakk',),
'brakka': ('brakke',),
'brakkede': ('brakke',),
'brakkende': ('brakke',),
'brakket': ('brakke',),
'brakkete': ('brakke',),
'bramansk': ('bramansk',),
'bramanske': ('bramansk',),
'bramanskere': ('bramansk',),
'bramanskest': ('bramansk',),
'bramanskeste': ('bramansk',),
'bramfri': ('bramfri',),
'bramfrie': ('bramfri',),
'bramfriere': ('bramfri',),
'bramfriest': ('bramfri',),
'bramfrieste': ('bramfri',),
'bramfritt': ('bramfri',),
'bramfull': ('bramfull',),
'bramfulle': ('bramfull',),
'bramfullere': ('bramfull',),
'bramfullest': ('bramfull',),
'bramfulleste': ('bramfull',),
'bramfullt': ('bramfull',),
'bramma': ('bramme',),
'brammede': ('bramme',),
'brammende': ('bramme',),
'brammet': ('bramme',),
'brammete': ('bramme',),
'brannet': ('brannet',),
'brannete': ('brannet',),
'brannetere': ('brannet',),
'brannetest': ('brannet',),
'branneteste': ('brannet',),
'brannete': ('brannete',),
'brannfarlig': ('brannfarlig',),
'brannfarlige': ('brannfarlig',),
'brannfarligere': ('brannfarlig',),
'brannfarligst': ('brannfarlig',),
'brannfarligste': ('brannfarlig',),
'branngul': ('branngul',),
'branngule': ('branngul',),
'branngulere': ('branngul',),
'branngulest': ('branngul',),
'brannguleste': ('branngul',),
'branngult': ('branngul',),
'brannrød': ('brannrød',),
'brannrøde': ('brannrød',),
'brannrødere': ('brannrød',),
'brannrødest': ('brannrød',),
'brannrødeste': ('brannrød',),
'brannrødt': ('brannrød',),
'brannsikker': ('brannsikker',),
'brannsikkert': ('brannsikker',),
'brannsikre': ('brannsikker',),
'brannsikrere': ('brannsikker',),
'brannsikrest': ('brannsikker',),
'brannsikreste': ('brannsikker',),
'brasiliansk': ('brasiliansk',),
'brasilianske': ('brasiliansk',),
'brasilianskere': ('brasiliansk',),
'brasilianskest': ('brasiliansk',),
'brasilianskeste': ('brasiliansk',),
'braska': ('braske',),
'braskede': ('braske',),
'braskende': ('braske',),
'brasket': ('braske',),
'braskete': ('braske',),
'bratna': ('bratne',),
'bratnede': ('bratne',),
'bratnende': ('bratne',),
'bratnet': ('bratne',),
'bratnete': ('bratne',),
'bratt': ('bratt',),
'bratte': ('bratt',),
'brattere': ('bratt',),
'brattest': ('bratt',),
'bratteste': ('bratt',),
'brattlendt': ('brattlendt',),
'brattlendte': ('brattlendt',),
'brattlendtere': ('brattlendt',),
'brattlendtest': ('brattlendt',),
'brattlendteste': ('brattlendt',),
'brauta': ('braute',),
'brautede': ('braute',),
'brautende': ('braute',),
'brautet': ('braute',),
'brautete': ('braute',),
'brav': ('brav',),
'brave': ('brav',),
'bravere': ('brav',),
'bravest': ('brav',),
'braveste': ('brav',),
'bravt': ('brav',),
'braverende': ('bravere',),
'bravert': ('bravere',),
'braverte': ('bravere',),
'bred': ('bred',),
'brede': ('bred',),
'bredere': ('bred',),
'bredest': ('bred',),
'bredeste': ('bred',),
'bredt': ('bred',),
'bredakslede': ('bredakslet',),
'bredakslet': ('bredakslet',),
'bredakslete': ('bredakslet',),
'bredaksletere': ('bredakslet',),
'bredaksletest': ('bredakslet',),
'bredaksleteste': ('bredakslet',),
'breddfull': ('breddfull',),
'breddfulle': ('breddfull',),
'breddfullere': ('breddfull',),
'breddfullest': ('breddfull',),
'breddfulleste': ('breddfull',),
'breddfullt': ('breddfull',),
'bredkinna': ('bredkinna',),
'bredkinnede': ('bredkinnet',),
'bredkinnet': ('bredkinnet',),
'bredkinnete': ('bredkinnet',),
'bredkinnetere': ('bredkinnet',),
'bredkinnetest': ('bredkinnet',),
'bredkinneteste': ('bredkinnet',),
'bredkjefta': ('bredkjefta',),
'bredkjeftede': ('bredkjeftet',),
'bredkjeftet': ('bredkjeftet',),
'bredkjeftete': ('bredkjeftet',),
'bredkjeftetere': ('bredkjeftet',),
'bredkjeftetest': ('bredkjeftet',),
'bredkjefteteste': ('bredkjeftet',),
'bredpanna': ('bredpanna',),
'bredpannede': ('bredpannet',),
'bredpannet': ('bredpannet',),
'bredpannete': ('bredpannet',),
'bredpannetere': ('bredpannet',),
'bredpannetest': ('bredpannet',),
'bredpanneteste': ('bredpannet',),
'bredskuldra': ('bredskuldra',),
'bredskuldrede': ('bredskuldret',),
'bredskuldret': ('bredskuldret',),
'bredskuldrete': ('bredskuldret',),
'bredskuldretere': ('bredskuldret',),
'bredskuldretest': ('bredskuldret',),
'bredskuldreteste': ('bredskuldret',),
'bredskåren': ('bredskåren',),
'bredskårent': ('bredskåren',),
'bredskårne': ('bredskåren',),
'bredskårnere': ('bredskåren',),
'bredskårnest': ('bredskåren',),
'bredskårneste': ('bredskåren',),
'bredspora': ('bredspora',),
'bredsporede': ('bredsporet',),
'bredsporet': ('bredsporet',),
'bredsporete': ('bredsporet',),
'bredsporetere': ('bredsporet',),
'bredsporetest': ('bredsporet',),
'bredsporeteste': ('bredsporet',),
'bredvokst': ('bredvokst',),
'bredvokste': ('bredvokst',),
'bredvokstere': ('bredvokst',),
'bredvokstest': ('bredvokst',),
'bredvoksteste': ('bredvokst',),
'bregrøn': ('bregrøn',),
'bregrøne': ('bregrøn',),
'bregrønere': ('bregrøn',),
'bregrønest': ('bregrøn',),
'bregrøneste': ('bregrøn',),
'bregrønt': ('bregrøn',),
'bregrønn': ('bregrønn',),
'bregrønne': ('bregrønn',),
'bregrønnere': ('bregrønn',),
'bregrønnest': ('bregrønn',),
'bregrønneste': ('bregrønn',),
'bregrønt': ('bregrønn',),
'brei': ('brei',),
'breie': ('brei',),
'breiere': ('brei',),
'breiest': ('brei',),
'breieste': ('brei',),
'breit': ('brei',),
'breitt': ('brei',),
'breiakslede': ('breiakslet',),
'breiakslet': ('breiakslet',),
'breiakslete': ('breiakslet',),
'breiaksletere': ('breiakslet',),
'breiaksletest': ('breiakslet',),
'breiaksleteste': ('breiakslet',),
'breia': ('breie',),
'breid': ('breie',),
'breidd': ('breie',),
'breidde': ('breie',),
'breide': ('breie',),
'breiede': ('breie',),
'breiende': ('breie',),
'breiet': ('breie',),
'breiete': ('breie',),
'breia': ('breie',),
'breid': ('breie',),
'breidd': ('breie',),
'breidde': ('breie',),
'breide': ('breie',),
'breiede': ('breie',),
'breiende': ('breie',),
'breiet': ('breie',),
'breiete': ('breie',),
'breikinna': ('breikinna',),
'breikinnede': ('breikinnet',),
'breikinnet': ('breikinnet',),
'breikinnete': ('breikinnet',),
'breikinnetere': ('breikinnet',),
'breikinnetest': ('breikinnet',),
'breikinneteste': ('breikinnet',),
'breikjefta': ('breikjefta',),
'breikjeftede': ('breikjeftet',),
'breikjeftet': ('breikjeftet',),
'breikjeftete': ('breikjeftet',),
'breikjeftetere': ('breikjeftet',),
'breikjeftetest': ('breikjeftet',),
'breikjefteteste': ('breikjeftet',),
'breipanna': ('breipanna',),
'breipannede': ('breipannet',),
'breipannet': ('breipannet',),
'breipannete': ('breipannet',),
'breipannetere': ('breipannet',),
'breipannetest': ('breipannet',),
'breipanneteste': ('breipannet',),
'breiskuldra': ('breiskuldra',),
'breiskuldrede': ('breiskuldret',),
'breiskuldret': ('breiskuldret',),
'breiskuldrete': ('breiskuldret',),
'breiskuldretere': ('breiskuldret',),
'breiskuldretest': ('breiskuldret',),
'breiskuldreteste': ('breiskuldret',),
'breiskåren': ('breiskåren',),
'breiskårent': ('breiskåren',),
'breiskårne': ('breiskåren',),
'breiskårnere': ('breiskåren',),
'breiskårnest': ('breiskåren',),
'breiskårneste': ('breiskåren',),
'breispora': ('breispora',),
'breisporede': ('breisporet',),
'breisporet': ('breisporet',),
'breisporete': ('breisporet',),
'breisporetere': ('breisporet',),
'breisporetest': ('breisporet',),
'breisporeteste': ('breisporet',),
'breivokst': ('breivokst',),
'breivokste': ('breivokst',),
'breivokstere': ('breivokst',),
'breivokstest': ('breivokst',),
'breivoksteste': ('breivokst',),
'breka': ('breke',),
'brekede': ('breke',),
'brekende': ('breke',),
'breket': ('breke',),
'brekete': ('breke',),
'brekt': ('breke',),
'brekte': ('breke',),
'brekka': ('brekke',),
'brekkede': ('brekke',),
'brekkende': ('brekke',),
'brekket': ('brekke',),
'brekkete': ('brekke',),
'brekt': ('brekke',),
'brekte': ('brekke',),
'brekkende': ('brekke',),
'brukken': ('brekke',),
'brukket': ('brekke',),
'brukne': ('brekke',),
'bremma': ('bremme',),
'bremmede': ('bremme',),
'bremmende': ('bremme',),
'bremmet': ('bremme',),
'bremmete': ('bremme',),
'bremsa': ('bremse',),
'bremsede': ('bremse',),
'bremsende': ('bremse',),
'bremset': ('bremse',),
'bremsete': ('bremse',),
'brennaktuell': ('brennaktuell',),
'brennaktuelle': ('brennaktuell',),
'brennaktuellere': ('brennaktuell',),
'brennaktuellest': ('brennaktuell',),
'brennaktuelleste': ('brennaktuell',),
'brennaktuelt': ('brennaktuell',),
'brennbar': ('brennbar',),
'brennbare': ('brennbar',),
'brennbarere': ('brennbar',),
'brennbarest': ('brennbar',),
'brennbareste': ('brennbar',),
'brennbart': ('brennbar',),
'brennemerka': ('brennemerke',),
'brennemerkede': ('brennemerke',),
'brennemerkende': ('brennemerke',),
'brennemerket': ('brennemerke',),
'brennemerkete': ('brennemerke',),
'brennhet': ('brennhet',),
'brennhete': ('brennhet',),
'brennhetere': ('brennhet',),
'brennhetest': ('brennhet',),
'brennheteste': ('brennhet',),
'brennhett': ('brennhet',),
'brennrød': ('brennrød',),
'brennrøde': ('brennrød',),
'brennrødere': ('brennrød',),
'brennrødest': ('brennrød',),
'brennrødeste': ('brennrød',),
'brennrødt': ('brennrød',),
'brennsikker': ('brennsikker',),
'brennsikkert': ('brennsikker',),
'brennsikre': ('brennsikker',),
'brennsikrere': ('brennsikker',),
'brennsikrest': ('brennsikker',),
'brennsikreste': ('brennsikker',),
'brennsnar': ('brennsnar',),
'brennsnare': ('brennsnar',),
'brennsnarere': ('brennsnar',),
'brennsnarest': ('brennsnar',),
'brennsnareste': ('brennsnar',),
'brennsnart': ('brennsnar',),
'breserende': ('bresere',),
'bresert': ('bresere',),
'breserte': ('bresere',),
'bresta': ('breste',),
'brestede': ('breste',),
'brestende': ('breste',),
'brestet': ('breste',),
'brestete': ('breste',),
'bresten': ('breste',),
'brestende': ('breste',),
'brestet': ('breste',),
'brestne': ('breste',),
'bresten': ('breste',),
'brestende': ('breste',),
'brestet': ('breste',),
'brestne': ('breste',),
'bretagnsk': ('bretagnsk',),
'bretagnske': ('bretagnsk',),
'bretagnskere': ('bretagnsk',),
'bretagnskest': ('bretagnsk',),
'bretagnskeste': ('bretagnsk',),
'bretonsk': ('bretonsk',),
'bretonske': ('bretonsk',),
'bretonskere': ('bretonsk',),
'bretonskest': ('bretonsk',),
'bretonskeste': ('bretonsk',),
'bretta': ('brette',),
'brettede': ('brette',),
'brettende': ('brette',),
'brettet': ('brette',),
'brettete': ('brette',),
'brettsegla': ('brettsegle',),
'brettseglede': ('brettsegle',),
'brettseglende': ('brettsegle',),
'brettseglet': ('brettsegle',),
'brettseglete': ('brettsegle',),
'brettseilende': ('brettseile',),
'brettseilt': ('brettseile',),
'brettseilte': ('brettseile',),
'brevveksla': ('brevveksle',),
'brevvekslede': ('brevveksle',),
'brevvekslende': ('brevveksle',),
'brevvekslet': ('brevveksle',),
'brevvekslete': ('brevveksle',),
'brifa': ('brife',),
'brifede': ('brife',),
'brifende': ('brife',),
'brifet': ('brife',),
'brifete': ('brife',),
'briketterende': ('brikettere',),
'brikettert': ('brikettere',),
'briketterte': ('brikettere',),
'briljant': ('briljant',),
'briljante': ('briljant',),
'briljantere': ('briljant',),
'briljantest': ('briljant',),
'briljanteste': ('briljant',),
'briljerende': ('briljere',),
'briljert': ('briljere',),
'briljerte': ('briljere',),
'brillefin': ('brillefin',),
'brillefine': ('brillefin',),
'brillefinere': ('brillefin',),
'brillefinest': ('brillefin',),
'brillefineste': ('brillefin',),
'brillefint': ('brillefin',),
'bragt': ('bringe',),
'bragte': ('bringe',),
'brakt': ('bringe',),
'brakte': ('bringe',),
'bringende': ('bringe',),
'bringebred': ('bringebred',),
'bringebrede': ('bringebred',),
'bringebredere': ('bringebred',),
'bringebredest': ('bringebred',),
'bringebredeste': ('bringebred',),
'bringebredt': ('bringebred',),
'bringebrei': ('bringebrei',),
'bringebreie': ('bringebrei',),
'bringebreiere': ('bringebrei',),
'bringebreiest': ('bringebrei',),
'bringebreieste': ('bringebrei',),
'bringebreit': ('bringebrei',),
'bringebreitt': ('bringebrei',),
'brisant': ('brisant',),
'brisante': ('brisant',),
'brisantere': ('brisant',),
'brisantest': ('brisant',),
'brisanteste': ('brisant',),
'brisende': ('brise',),
'brist': ('brise',),
'briste': ('brise',),
'brisen': ('brisen',),
'brisent': ('brisen',),
'brisne': ('brisen',),
'brisnere': ('brisen',),
'brisnest': ('brisen',),
'brisneste': ('brisen',),
'briska': ('briske',),
'briskede': ('briske',),
'briskende': ('briske',),
'brisket': ('briske',),
'briskete': ('briske',),
'bristen': ('briste',),
'bristende': ('briste',),
'bristet': ('briste',),
'bristne': ('briste',),
'brusten': ('briste',),
'brustet': ('briste',),
'brustne': ('briste',),
'bristen': ('briste',),
'bristende': ('briste',),
'bristet': ('briste',),
'bristne': ('briste',),
'brusten': ('briste',),
'brustet': ('briste',),
'brustne': ('briste',),
'bristeferdig': ('bristeferdig',),
'bristeferdige': ('bristeferdig',),
'bristeferdigere': ('bristeferdig',),
'bristeferdigst': ('bristeferdig',),
'bristeferdigste': ('bristeferdig',),
'bristfeldig': ('bristfeldig',),
'bristfeldige': ('bristfeldig',),
'bristfeldigere': ('bristfeldig',),
'bristfeldigst': ('bristfeldig',),
'bristfeldigste': ('bristfeldig',),
'britannisk': ('britannisk',),
'britanniske': ('britannisk',),
'britanniskere': ('britannisk',),
'britanniskest': ('britannisk',),
'britanniskeste': ('britannisk',),
'britisk': ('britisk',),
'britiske': ('britisk',),
'britiskere': ('britisk',),
'britiskest': ('britisk',),
'britiskeste': ('britisk',),
'brittonsk': ('brittonsk',),
'brittonske': ('brittonsk',),
'brittonskere': ('brittonsk',),
'brittonskest': ('brittonsk',),
'brittonskeste': ('brittonsk',),
'brodda': ('brodde',),
'broddede': ('brodde',),
'broddende': ('brodde',),
'broddet': ('brodde',),
'broddete': ('brodde',),
'brodden': ('brodden',),
'broddent': ('brodden',),
'brodne': ('brodden',),
'brodnere': ('brodden',),
'brodnest': ('brodden',),
'brodneste': ('brodden',),
'broderende': ('brodere',),
'brodert': ('brodere',),
'broderte': ('brodere',),
'broderlig': ('broderlig',),
'broderlige': ('broderlig',),
'broderligere': ('broderlig',),
'broderligst': ('broderlig',),
'broderligste': ('broderlig',),
'broket': ('broket',),
'brokete': ('broket',),
'broketere': ('broket',),
'broketest': ('broket',),
'broketeste': ('broket',),
'brokete': ('brokete',),
'brokksjuk': ('brokksjuk',),
'brokksjuke': ('brokksjuk',),
'brokksjukere': ('brokksjuk',),
'brokksjukest': ('brokksjuk',),
'brokksjukeste': ('brokksjuk',),
'brokksjukt': ('brokksjuk',),
'brokksyk': ('brokksyk',),
'brokksyke': ('brokksyk',),
'brokksykere': ('brokksyk',),
'brokksykest': ('brokksyk',),
'brokksykeste': ('brokksyk',),
'brokksykt': ('brokksyk',),
'brolagt': ('brolegge',),
'brolagte': ('brolegge',),
'broleggende': ('brolegge',),
'bronkial': ('bronkial',),
'bronkiale': ('bronkial',),
'bronkialere': ('bronkial',),
'bronkialest': ('bronkial',),
'bronkialeste': ('bronkial',),
'bronkialt': ('bronkial',),
'bronkittisk': ('bronkittisk',),
'bronkittiske': ('bronkittisk',),
'bronkittiskere': ('bronkittisk',),
'bronkittiskest': ('bronkittisk',),
'bronkittiskeste': ('bronkittisk',),
'bronsa': ('bronse',),
'bronsede': ('bronse',),
'bronsende': ('bronse',),
'bronset': ('bronse',),
'bronsete': ('bronse',),
'bronsebrun': ('bronsebrun',),
'bronsebrune': ('bronsebrun',),
'bronsebrunere': ('bronsebrun',),
'bronsebrunest': ('bronsebrun',),
'bronsebruneste': ('bronsebrun',),
'bronsebrunt': ('bronsebrun',),
'bronserende': ('bronsere',),
'bronsert': ('bronsere',),
'bronserte': ('bronsere',),
'brosjerende': ('brosjere',),
'brosjert': ('brosjere',),
'brosjerte': ('brosjere',),
'brotna': ('brotne',),
'brotnede': ('brotne',),
'brotnende': ('brotne',),
'brotnet': ('brotne',),
'brotnete': ('brotne',),
'brotsja': ('brotsje',),
'brotsjede': ('brotsje',),
'brotsjende': ('brotsje',),
'brotsjet': ('brotsje',),
'brotsjete': ('brotsje',),
'brottfast': ('brottfast',),
'brottfaste': ('brottfast',),
'brottfastere': ('brottfast',),
'brottfastest': ('brottfast',),
'brottfasteste': ('brottfast',),
'brudden': ('brudden',),
'bruddent': ('brudden',),
'brudne': ('brudden',),
'brudnere': ('brudden',),
'brudnest': ('brudden',),
'brudneste': ('brudden',),
'bruddfast': ('bruddfast',),
'bruddfaste': ('bruddfast',),
'bruddfastere': ('bruddfast',),
'bruddfastest': ('bruddfast',),
'bruddfasteste': ('bruddfast',),
'brukbar': ('brukbar',),
'brukbare': ('brukbar',),
'brukbarere': ('brukbar',),
'brukbarest': ('brukbar',),
'brukbareste': ('brukbar',),
'brukbart': ('brukbar',),
'brukende': ('bruke',),
'brukt': ('bruke',),
'brukte': ('bruke',),
'brukelig': ('brukelig',),
'brukelige': ('brukelig',),
'brukeligere': ('brukelig',),
'brukeligst': ('brukelig',),
'brukeligste': ('brukelig',),
'brukervennlig': ('brukervennlig',),
'brukervennlige': ('brukervennlig',),
'brukervennligere': ('brukervennlig',),
'brukervennligst': ('brukervennlig',),
'brukervennligste': ('brukervennlig',),
'brukken': ('brukken',),
'brukket': ('brukken',),
'brukne': ('brukken',),
'bruknere': ('brukken',),
'bruknest': ('brukken',),
'brukneste': ('brukken',),
'brukket': ('brukket',),
'brukne': ('brukket',),
'bruknere': ('brukket',),
'bruknest': ('brukket',),
'brukneste': ('brukket',),
'brukt': ('brukt',),
'brukte': ('brukt',),
'bruktere': ('brukt',),
'bruktest': ('brukt',),
'brukteste': ('brukt',),
'brulagt': ('brulegge',),
'brulagte': ('brulegge',),
'bruleggende': ('brulegge',),
'brumla': ('brumle',),
'brumlede': ('brumle',),
'brumlende': ('brumle',),
'brumlet': ('brumle',),
'brumlete': ('brumle',),
'brumma': ('brumme',),
'brummede': ('brumme',),
'brummende': ('brumme',),
'brummet': ('brumme',),
'brummete': ('brumme',),
'brun': ('brun',),
'brune': ('brun',),
'brunere': ('brun',),
'brunest': ('brun',),
'bruneste': ('brun',),
'brunt': ('brun',),
'brunbarka': ('brunbarka',),
'brunbarkede': ('brunbarket',),
'brunbarket': ('brunbarket',),
'brunbarkete': ('brunbarket',),
'brunbarketere': ('brunbarket',),
'brunbarketest': ('brunbarket',),
'brunbarketeste': ('brunbarket',),
'bruna': ('brune',),
'brunede': ('brune',),
'brunende': ('brune',),
'brunet': ('brune',),
'brunete': ('brune',),
'brunt': ('brune',),
'brunte': ('brune',),
'bruneisk': ('bruneisk',),
'bruneiske': ('bruneisk',),
'bruneiskere': ('bruneisk',),
'bruneiskest': ('bruneisk',),
'bruneiskeste': ('bruneisk',),
'brunlig': ('brunlig',),
'brunlige': ('brunlig',),
'brunligere': ('brunlig',),
'brunligst': ('brunlig',),
'brunligste': ('brunlig',),
'brunsteikende': ('brunsteike',),
'brunsteikt': ('brunsteike',),
'brunsteikte': ('brunsteike',),
'brunstekende': ('brunsteke',),
'brunstekt': ('brunsteke',),
'brunstekte': ('brunsteke',),
'brunstig': ('brunstig',),
'brunstige': ('brunstig',),
'brunstigere': ('brunstig',),
'brunstigst': ('brunstig',),
'brunstigste': ('brunstig',),
'brunøyd': ('brunøyd',),
'brunøyde': ('brunøyd',),
'brunøydere': ('brunøyd',),
'brunøydest': ('brunøyd',),
'brunøydeste': ('brunøyd',),
'brusende': ('bruse',),
'brust': ('bruse',),
'bruste': ('bruse',),
'brusten': ('brusten',),
'brustent': ('brusten',),
'brustne': ('brusten',),
'brustnere': ('brusten',),
'brustnest': ('brusten',),
'brustneste': ('brusten',),
'brutal': ('brutal',),
'brutale': ('brutal',),
'brutalere': ('brutal',),
'brutalest': ('brutal',),
'brutaleste': ('brutal',),
'brutalt': ('brutal',),
'brutaliserende': ('brutalisere',),
'brutalisert': ('brutalisere',),
'brutaliserte': ('brutalisere',),
'brydd': ('bry',),
'brydde': ('bry',),
'bryende': ('bry',),
'brydd': ('brydd',),
'brydde': ('brydd',),
'bryddere': ('brydd',),
'bryddest': ('brydd',),
'bryddeste': ('brydd',),
'brydda': ('brydde',),
'bryddede': ('brydde',),
'bryddende': ('brydde',),
'bryddet': ('brydde',),
'bryddete': ('brydde',),
'brygd': ('brygge',),
'brygde': ('brygge',),
'brygga': ('brygge',),
'bryggede': ('brygge',),
'bryggende': ('brygge',),
'brygget': ('brygge',),
'bryggete': ('brygge',),
'brynende': ('bryne',),
'brynt': ('bryne',),
'brynte': ('bryne',),
'bryologisk': ('bryologisk',),
'bryologiske': ('bryologisk',),
'bryologiskere': ('bryologisk',),
'bryologiskest': ('bryologisk',),
'bryologiskeste': ('bryologisk',),
'brysk': ('brysk',),
'bryske': ('brysk',),
'bryskere': ('brysk',),
'bryskest': ('brysk',),
'bryskeste': ('brysk',),
'bryskt': ('brysk',),
'bryska': ('bryske',),
'bryskede': ('bryske',),
'bryskende': ('bryske',),
'brysket': ('bryske',),
'bryskete': ('bryske',),
'brysom': ('brysom',),
'brysomme': ('brysom',),
'brysommere': ('brysom',),
'brysomst': ('brysom',),
'brysomste': ('brysom',),
'brysomt': ('brysom',),
'brysta': ('bryste',),
'brystede': ('bryste',),
'brystende': ('bryste',),
'brystet': ('bryste',),
'brystete': ('bryste',),
'brytbar': ('brytbar',),
'brytbare': ('brytbar',),
'brytbarere': ('brytbar',),
'brytbarest': ('brytbar',),
'brytbareste': ('brytbar',),
'brytbart': ('brytbar',),
'brutt': ('bryte',),
'brutte': ('bryte',),
'brytende': ('bryte',),
'brå': ('brå',),
'bråe': ('brå',),
'bråere': ('brå',),
'bråest': ('brå',),
'bråeste': ('brå',),
'brått': ('brå',),
'bråbremsa': ('bråbremse',),
'bråbremsede': ('bråbremse',),
'bråbremsende': ('bråbremse',),
'bråbremset': ('bråbremse',),
'bråbremsete': ('bråbremse',),
'brådjup': ('brådjup',),
'brådjupe': ('brådjup',),
'brådjupere': ('brådjup',),
'brådjupest': ('brådjup',),
'brådjupeste': ('brådjup',),
'brådjupt': ('brådjup',),
'brådyp': ('brådyp',),
'brådype': ('brådyp',),
'brådypere': ('brådyp',),
'brådypest': ('brådyp',),
'brådypeste': ('brådyp',),
'brådypt': ('brådyp',),
'bråka': ('bråke',),
'bråkede': ('bråke',),
'bråkende': ('bråke',),
'bråket': ('bråke',),
'bråkete': ('bråke',),
'bråkt': ('bråke',),
'bråkte': ('bråke',),
'bråka': ('bråke',),
'bråkede': ('bråke',),
'bråkende': ('bråke',),
'bråket': ('bråke',),
'bråkete': ('bråke',),
'bråkt': ('bråke',),
'bråkte': ('bråke',),
'bråket': ('bråket',),
'bråkete': ('bråket',),
'bråketere': ('bråket',),
'bråketest': ('bråket',),
'bråketeste': ('bråket',),
'bråkete': ('bråkete',),
'bråkjekk': ('bråkjekk',),
'bråkjekke': ('bråkjekk',),
'bråkjekkere': ('bråkjekk',),
'bråkjekkest': ('bråkjekk',),
'bråkjekkeste': ('bråkjekk',),
'bråkjekt': ('bråkjekk',),
'bråmoden': ('bråmoden',),
'bråmodent': ('bråmoden',),
'bråmodne': ('bråmoden',),
'bråmodnere': ('bråmoden',),
'bråmodnest': ('bråmoden',),
'bråmodneste': ('bråmoden',),
'bråna': ('bråne',),
'brånede': ('bråne',),
'brånende': ('bråne',),
'brånet': ('bråne',),
'brånete': ('bråne',),
'brånt': ('bråne',),
'brånte': ('bråne',),
'bråsinna': ('bråsinna',),
'bråsint': ('bråsint',),
'bråsinte': ('bråsint',),
'bråsintere': ('bråsint',),
'bråsintest': ('bråsint',),
'bråsinteste': ('bråsint',),
'bråvakker': ('bråvakker',),
'bråvakkert': ('bråvakker',),
'bråvakre': ('bråvakker',),
'bråvakrere': ('bråvakker',),
'bråvakrest': ('bråvakker',),
'bråvakreste': ('bråvakker',),
'brødefull': ('brødefull',),
'brødefulle': ('brødefull',),
'brødefullere': ('brødefull',),
'brødefullest': ('brødefull',),
'brødefulleste': ('brødefull',),
'brødefullt': ('brødefull',),
'brødfødd': ('brødfø',),
'brødfødde': ('brødfø',),
'brødføende': ('brødfø',),
'brødlaus': ('brødlaus',),
'brødlause': ('brødlaus',),
'brødlausere': ('brødlaus',),
'brødlausest': ('brødlaus',),
'brødlauseste': ('brødlaus',),
'brødlaust': ('brødlaus',),
'brødløs': ('brødløs',),
'brødløse': ('brødløs',),
'brødløsere': ('brødløs',),
'brødløsest': ('brødløs',),
'brødløseste': ('brødløs',),
'brødløst': ('brødløs',),
'brølende': ('brøle',),
'brølt': ('brøle',),
'brølte': ('brøle',),
'brøstfeldig': ('brøstfeldig',),
'brøstfeldige': ('brøstfeldig',),
'brøstfeldigere': ('brøstfeldig',),
'brøstfeldigst': ('brøstfeldig',),
'brøstfeldigste': ('brøstfeldig',),
'brøstholden': ('brøstholden',),
'brøstholdent': ('brøstholden',),
'brøstholdne': ('brøstholden',),
'brøstholdnere': ('brøstholden',),
'brøstholdnest': ('brøstholden',),
'brøstholdneste': ('brøstholden',),
'brøyta': ('brøyte',),
'brøytede': ('brøyte',),
'brøytende': ('brøyte',),
'brøytet': ('brøyte',),
'brøytete': ('brøyte',),
'brøytt': ('brøyte',),
'brøytte': ('brøyte',),
'budd': ('bu',),
'budde': ('bu',),
'buende': ('bu',),
'budd': ('bu',),
'budde': ('bu',),
'buende': ('bu',),
'bua': ('bua',),
'buddhistisk': ('buddhistisk',),
'buddhistiske': ('buddhistisk',),
'buddhistiskere': ('buddhistisk',),
'buddhistiskest': ('buddhistisk',),
'buddhistiskeste': ('buddhistisk',),
'buden': ('buden',),
'budent': ('buden',),
'budne': ('buden',),
'budnere': ('buden',),
'budnest': ('buden',),
'budneste': ('buden',),
'budsendende': ('budsende',),
'budsendt': ('budsende',),
'budsendte': ('budsende',),
'budsjetterende': ('budsjettere',),
'budsjettert': ('budsjettere',),
'budsjetterte': ('budsjettere',),
'bua': ('bue',),
'buede': ('bue',),
'buende': ('bue',),
'buet': ('bue',),
'buete': ('bue',),
'bueforma': ('bueforma',),
'bueformede': ('bueformet',),
'bueformet': ('bueformet',),
'bueformete': ('bueformet',),
'bueformetere': ('bueformet',),
'bueformetest': ('bueformet',),
'bueformeteste': ('bueformet',),
'buede': ('buet',),
'buet': ('buet',),
'buete': ('buet',),
'buetere': ('buet',),
'buetest': ('buet',),
'bueteste': ('buet',),
'bufast': ('bufast',),
'bufaste': ('bufast',),
'bufastere': ('bufast',),
'bufastest': ('bufast',),
'bufasteste': ('bufast',),
'bugna': ('bugne',),
'bugnede': ('bugne',),
'bugnende': ('bugne',),
'bugnet': ('bugne',),
'bugnete': ('bugne',),
'bukka': ('bukke',),
'bukkede': ('bukke',),
'bukkende': ('bukke',),
'bukket': ('bukke',),
'bukkete': ('bukke',),
'bukka': ('bukke',),
'bukkede': ('bukke',),
'bukkende': ('bukke',),
'bukket': ('bukke',),
'bukkete': ('bukke',),
'buklanda': ('buklande',),
'buklandede': ('buklande',),
'buklandende': ('buklande',),
'buklandet': ('buklande',),
'buklandete': ('buklande',),
'buklet': ('buklet',),
'buklete': ('buklet',),
'bukletere': ('buklet',),
'bukletest': ('buklet',),
'bukleteste': ('buklet',),
'buklete': ('buklete',),
'bukolisk': ('bukolisk',),
'bukoliske': ('bukolisk',),
'bukoliskere': ('bukolisk',),
'bukoliskest': ('bukolisk',),
'bukoliskeste': ('bukolisk',),
'bukserende': ('buksere',),
'buksert': ('buksere',),
'bukserte': ('buksere',),
'bukta': ('bukte',),
'buktede': ('bukte',),
'buktende': ('bukte',),
'buktet': ('bukte',),
'buktete': ('bukte',),
'buktet': ('buktet',),
'buktete': ('buktet',),
'buktetere': ('buktet',),
'buktetest': ('buktet',),
'bukteteste': ('buktet',),
'buktete': ('buktete',),
'buldra': ('buldre',),
'buldrede': ('buldre',),
'buldrende': ('buldre',),
'buldret': ('buldre',),
'buldrete': ('buldre',),
'bula': ('bule',),
'bulede': ('bule',),
'bulende': ('bule',),
'bulet': ('bule',),
'bulete': ('bule',),
'bult': ('bule',),
'bulte': ('bule',),
'bulet': ('bulet',),
'bulete': ('bulet',),
'buletere': ('bulet',),
'buletest': ('bulet',),
'buleteste': ('bulet',),
'bulete': ('bulete',),
'bulgarsk': ('bulgarsk',),
'bulgarske': ('bulgarsk',),
'bulgarskere': ('bulgarsk',),
'bulgarskest': ('bulgarsk',),
'bulgarskeste': ('bulgarsk',),
'bulka': ('bulke',),
'bulkede': ('bulke',),
'bulkende': ('bulke',),
'bulket': ('bulke',),
'bulkete': ('bulke',),
'bulket': ('bulket',),
'bulkete': ('bulket',),
'bulketere': ('bulket',),
'bulketest': ('bulket',),
'bulketeste': ('bulket',),
'bulkete': ('bulkete',),
'bulna': ('bulne',),
'bulnede': ('bulne',),
'bulnende': ('bulne',),
'bulnet': ('bulne',),
'bulnete': ('bulne',),
'bumsa': ('bumse',),
'bumsede': ('bumse',),
'bumsende': ('bumse',),
'bumset': ('bumse',),
'bumsete': ('bumse',),
'bumset': ('bumset',),
'bumsete': ('bumset',),
'bumsetere': ('bumset',),
'bumsetest': ('bumset',),
'bumseteste': ('bumset',),
'bumsete': ('bumsete',),
'bunadkledd': ('bunadkledd',),
'bunadkledde': ('bunadkledd',),
'bunadkleddere': ('bunadkledd',),
'bunadkleddest': ('bunadkledd',),
'bunadkleddeste': ('bunadkledd',),
'bunadskledd': ('bunadskledd',),
'bunadskledde': ('bunadskledd',),
'bunadskleddere': ('bunadskledd',),
'bunadskleddest': ('bunadskledd',),
'bunadskleddeste': ('bunadskledd',),
'bunden': ('bunden',),
'bundet': ('bunden',),
'bundne': ('bunden',),
'bundnere': ('bunden',),
'bundnest': ('bunden',),
'bundneste': ('bunden',),
'bundet': ('bundet',),
'bundne': ('bundet',),
'bundnere': ('bundet',),
'bundnest': ('bundet',),
'bundneste': ('bundet',),
'bundsforvandt': ('bundsforvandt',),
'bundsforvandte': ('bundsforvandt',),
'bundsforvandtere': ('bundsforvandt',),
'bundsforvandtest': ('bundsforvandt',),
'bundsforvandteste': ('bundsforvandt',),
'bunka': ('bunke',),
'bunkede': ('bunke',),
'bunkende': ('bunke',),
'bunket': ('bunke',),
'bunkete': ('bunke',),
'bunkra': ('bunkre',),
'bunkrede': ('bunkre',),
'bunkrende': ('bunkre',),
'bunkret': ('bunkre',),
'bunkrete': ('bunkre',),
'bunnfalsk': ('bunnfalsk',),
'bunnfalske': ('bunnfalsk',),
'bunnfalskere': ('bunnfalsk',),
'bunnfalskest': ('bunnfalsk',),
'bunnfalskeste': ('bunnfalsk',),
'bunnfalskt': ('bunnfalsk',),
'bunnfellende': ('bunnfelle',),
'bunnfelt': ('bunnfelle',),
'bunnfelte': ('bunnfelle',),
'bunnhederlig': ('bunnhederlig',),
'bunnhederlige': ('bunnhederlig',),
'bunnhederligere': ('bunnhederlig',),
'bunnhederligst': ('bunnhederlig',),
'bunnhederligste': ('bunnhederlig',),
'bunnlaus': ('bunnlaus',),
'bunnlause': ('bunnlaus',),
'bunnlausere': ('bunnlaus',),
'bunnlausest': ('bunnlaus',),
'bunnlauseste': ('bunnlaus',),
'bunnlaust': ('bunnlaus',),
'bunnløs': ('bunnløs',),
'bunnløse': ('bunnløs',),
'bunnløsere': ('bunnløs',),
'bunnløsest': ('bunnløs',),
'bunnløseste': ('bunnløs',),
'bunnløst': ('bunnløs',),
'bunnskrapa': ('bunnskrape',),
'bunnskrapede': ('bunnskrape',),
'bunnskrapende': ('bunnskrape',),
'bunnskrapet': ('bunnskrape',),
'bunnskrapete': ('bunnskrape',),
'bunnskrapt': ('bunnskrape',),
'bunnskrapte': ('bunnskrape',),
'bunnsolid': ('bunnsolid',),
'bunnsolide': ('bunnsolid',),
'bunnsolidere': ('bunnsolid',),
'bunnsolidest': ('bunnsolid',),
'bunnsolideste': ('bunnsolid',),
'bunta': ('bunte',),
'buntede': ('bunte',),
'buntende': ('bunte',),
'buntet': ('bunte',),
'buntete': ('bunte',),
'bura': ('bure',),
'burede': ('bure',),
'burende': ('bure',),
'buret': ('bure',),
'burete': ('bure',),
'burt': ('bure',),
'burte': ('bure',),
'bura': ('bure',),
'burede': ('bure',),
'burende': ('bure',),
'buret': ('bure',),
'burete': ('bure',),
'burt': ('bure',),
'burte': ('bure',),
'burgunderrød': ('burgunderrød',),
'burgunderrøde': ('burgunderrød',),
'burgunderrødere': ('burgunderrød',),
'burgunderrødest': ('burgunderrød',),
'burgunderrødeste': ('burgunderrød',),
'burgunderrødt': ('burgunderrød',),
'burgundisk': ('burgundisk',),
'burgundiske': ('burgundisk',),
'burgundiskere': ('burgundisk',),
'burgundiskest': ('burgundisk',),
'burgundiskeste': ('burgundisk',),
'burjatisk': ('burjatisk',),
'burjatiske': ('burjatisk',),
'burjatiskere': ('burjatisk',),
'burjatiskest': ('burjatisk',),
'burjatiskeste': ('burjatisk',),
'burkinsk': ('burkinsk',),
'burkinske': ('burkinsk',),
'burkinskere': ('burkinsk',),
'burkinskest': ('burkinsk',),
'burkinskeste': ('burkinsk',),
'burlesk': ('burlesk',),
'burleske': ('burlesk',),
'burleskere': ('burlesk',),
'burleskest': ('burlesk',),
'burleskeste': ('burlesk',),
'burmansk': ('burmansk',),
'burmanske': ('burmansk',),
'burmanskere': ('burmansk',),
'burmanskest': ('burmansk',),
'burmanskeste': ('burmansk',),
'bursjikos': ('bursjikos',),
'bursjikose': ('bursjikos',),
'bursjikosere': ('bursjikos',),
'bursjikosest': ('bursjikos',),
'bursjikoseste': ('bursjikos',),
'burundisk': ('burundisk',),
'burundiske': ('burundisk',),
'burundiskere': ('burundisk',),
'burundiskest': ('burundisk',),
'burundiskeste': ('burundisk',),
'busatt': ('busatt',),
'busatte': ('busatt',),
'busattere': ('busatt',),
'busattest': ('busatt',),
'busatteste': ('busatt',),
'busa': ('buse',),
'busede': ('buse',),
'busende': ('buse',),
'buset': ('buse',),
'busete': ('buse',),
'bust': ('buse',),
'buste': ('buse',),
'busatt': ('busette',),
'busatte': ('busette',),
'busettende': ('busette',),
'buska': ('buske',),
'buskede': ('buske',),
'buskende': ('buske',),
'busket': ('buske',),
'buskete': ('buske',),
'busket': ('busket',),
'buskete': ('busket',),
'busketere': ('busket',),
'busketest': ('busket',),
'busketeste': ('busket',),
'buskete': ('buskete',),
'bussa': ('busse',),
'bussede': ('busse',),
'bussende': ('busse',),
'busset': ('busse',),
'bussete': ('busse',),
'busta': ('buste',),
'bustede': ('buste',),
'bustende': ('buste',),
'bustet': ('buste',),
'bustete': ('buste',),
'bustet': ('bustet',),
'bustete': ('bustet',),
'bustetere': ('bustet',),
'bustetest': ('bustet',),
'busteteste': ('bustet',),
'bustete': ('bustete',),
'butt': ('butt',),
'butte': ('butt',),
'buttere': ('butt',),
'buttest': ('butt',),
'butteste': ('butt',),
'butta': ('butte',),
'buttede': ('butte',),
'buttende': ('butte',),
'buttet': ('butte',),
'buttete': ('butte',),
'buttet': ('buttet',),
'buttete': ('buttet',),
'buttetere': ('buttet',),
'buttetest': ('buttet',),
'butteteste': ('buttet',),
'buttete': ('buttete',),
'budt': ('by',),
'budte': ('by',),
'bydd': ('by',),
'bydde': ('by',),
'byende': ('by',),
'budt': ('by',),
'budte': ('by',),
'bydd': ('by',),
'bydde': ('by',),
'byende': ('by',),
'budt': ('byde',),
'budte': ('byde',),
'bydd': ('byde',),
'bydde': ('byde',),
'bydende': ('byde',),
'bydende': ('bydende',),
'byet': ('byet',),
'byete': ('byet',),
'byetere': ('byet',),
'byetest': ('byet',),
'byeteste': ('byet',),
'byet': ('byet',),
'byete': ('byet',),
'byetere': ('byet',),
'byetest': ('byet',),
'byeteste': ('byet',),
'byete': ('byete',),
'byete': ('byete',),
'byget': ('byget',),
'bygete': ('byget',),
'bygetere': ('byget',),
'bygetest': ('byget',),
'bygeteste': ('byget',),
'byget': ('byget',),
'bygete': ('byget',),
'bygetere': ('byget',),
'bygetest': ('byget',),
'bygeteste': ('byget',),
'bygete': ('bygete',),
'bygete': ('bygete',),
'bygd': ('bygge',),
'bygde': ('bygge',),
'bygga': ('bygge',),
'byggede': ('bygge',),
'byggende': ('bygge',),
'bygget': ('bygge',),
'byggete': ('bygge',),
'byggeklar': ('byggeklar',),
'byggeklare': ('byggeklar',),
'byggeklarere': ('byggeklar',),
'byggeklarest': ('byggeklar',),
'byggeklareste': ('byggeklar',),
'byggeklart': ('byggeklar',),
'bygsla': ('bygsle',),
'bygslede': ('bygsle',),
'bygslende': ('bygsle',),
'bygslet': ('bygsle',),
'bygslete': ('bygsle',),
'byksende': ('bykse',),
'bykst': ('bykse',),
'bykste': ('bykse',),
'bylta': ('bylte',),
'byltede': ('bylte',),
'byltende': ('bylte',),
'byltet': ('bylte',),
'byltete': ('bylte',),
'bymessig': ('bymessig',),
'bymessige': ('bymessig',),
'bymessigere': ('bymessig',),
'bymessigst': ('bymessig',),
'bymessigste': ('bymessig',),
'byrdefull': ('byrdefull',),
'byrdefulle': ('byrdefull',),
'byrdefullere': ('byrdefull',),
'byrdefullest': ('byrdefull',),
'byrdefulleste': ('byrdefull',),
'byrdefullt': ('byrdefull',),
'byrg': ('byrg',),
'byrge': ('byrg',),
'byrgere': ('byrg',),
'byrgest': ('byrg',),
'byrgeste': ('byrg',),
'byrgt': ('byrg',),
'byråkratiserende': ('byråkratisere',),
'byråkratisert': ('byråkratisere',),
'byråkratiserte': ('byråkratisere',),
'byråkratisk': ('byråkratisk',),
'byråkratiske': ('byråkratisk',),
'byråkratiskere': ('byråkratisk',),
'byråkratiskest': ('byråkratisk',),
'byråkratiskeste': ('byråkratisk',),
'bysantinsk': ('bysantinsk',),
'bysantinske': ('bysantinsk',),
'bysantinskere': ('bysantinsk',),
'bysantinskest': ('bysantinsk',),
'bysantinskeste': ('bysantinsk',),
'byssa': ('bysse',),
'byssede': ('bysse',),
'byssende': ('bysse',),
'bysset': ('bysse',),
'byssete': ('bysse',),
'bytta': ('bytte',),
'byttede': ('bytte',),
'byttende': ('bytte',),
'byttet': ('bytte',),
'byttete': ('bytte',),
'byttelånende': ('byttelåne',),
'byttelånt': ('byttelåne',),
'byttelånte': ('byttelåne',),
'båndlagt': ('båndlegge',),
'båndlagte': ('båndlegge',),
'båndleggende': ('båndlegge',),
'båra': ('båre',),
'bårede': ('båre',),
'bårende': ('båre',),
'båret': ('båre',),
'bårete': ('båre',),
'båtvant': ('båtvant',),
'båtvante': ('båtvant',),
'båtvantere': ('båtvant',),
'båtvantest': ('båtvant',),
'båtvanteste': ('båtvant',),
'bærbar': ('bærbar',),
'bærbare': ('bærbar',),
'bærbarere': ('bærbar',),
'bærbarest': ('bærbar',),
'bærbareste': ('bærbar',),
'bærbart': ('bærbar',),
'bærekraftig': ('bærekraftig',),
'bærekraftige': ('bærekraftig',),
'bærekraftigere': ('bærekraftig',),
'bærekraftigst': ('bærekraftig',),
'bærekraftigste': ('bærekraftig',),
'bæsja': ('bæsje',),
'bæsjede': ('bæsje',),
'bæsjende': ('bæsje',),
'bæsjet': ('bæsje',),
'bæsjete': ('bæsje',),
'bøhmisk': ('bøhmisk',),
'bøhmiske': ('bøhmisk',),
'bøhmiskere': ('bøhmisk',),
'bøhmiskest': ('bøhmisk',),
'bøhmiskeste': ('bøhmisk',),
'bølga': ('bølge',),
'bølgede': ('bølge',),
'bølgende': ('bølge',),
'bølget': ('bølge',),
'bølgete': ('bølge',),
'bølgja': ('bølgje',),
'bølgjede': ('bølgje',),
'bølgjende': ('bølgje',),
'bølgjet': ('bølgje',),
'bølgjete': ('bølgje',),
'bøllet': ('bøllet',),
'bøllete': ('bøllet',),
'bølletere': ('bøllet',),
'bølletest': ('bøllet',),
'bølleteste': ('bøllet',),
'bøllete': ('bøllete',),
'bønnfallende': ('bønnfalle',),
'bønnfalt': ('bønnfalle',),
'bønnfalte': ('bønnfalle',),
'bønnhørende': ('bønnhøre',),
'bønnhørt': ('bønnhøre',),
'bønnhørte': ('bønnhøre',),
'bønnlig': ('bønnlig',),
'bønnlige': ('bønnlig',),
'bønnligere': ('bønnlig',),
'bønnligst': ('bønnlig',),
'bønnligste': ('bønnlig',),
'børsa': ('børse',),
'børsede': ('børse',),
'børsende': ('børse',),
'børset': ('børse',),
'børsete': ('børse',),
'børsnoterende': ('børsnotere',),
'børsnotert': ('børsnotere',),
'børsnoterte': ('børsnotere',),
'børsta': ('børste',),
'børstede': ('børste',),
'børstende': ('børste',),
'børstet': ('børste',),
'børstete': ('børste',),
'børsten': ('børsten',),
'børstent': ('børsten',),
'børstne': ('børsten',),
'børstnere': ('børsten',),
'børstnest': ('børsten',),
'børstneste': ('børsten',),
'bøs': ('bøs',),
'bøse': ('bøs',),
'bøsere': ('bøs',),
'bøsest': ('bøs',),
'bøseste': ('bøs',),
'bøst': ('bøs',),
'bøtende': ('bøte',),
'bøtt': ('bøte',),
'bøtte': ('bøte',),
'bøtelagt': ('bøtelegge',),
'bøtelagte': ('bøtelegge',),
'bøteleggende': ('bøtelegge',),
'bøya': ('bøye',),
'bøyd': ('bøye',),
'bøyde': ('bøye',),
'bøyede': ('bøye',),
'bøyende': ('bøye',),
'bøyet': ('bøye',),
'bøyete': ('bøye',),
'bøyefast': ('bøyefast',),
'bøyefaste': ('bøyefast',),
'bøyefastere': ('bøyefast',),
'bøyefastest': ('bøyefast',),
'bøyefasteste': ('bøyefast',),
'bøyelig': ('bøyelig',),
'bøyelige': ('bøyelig',),
'bøyeligere': ('bøyelig',),
'bøyeligst': ('bøyelig',),
'bøyeligste': ('bøyelig',),
'bøyet': ('bøyet',),
'bøyete': ('bøyet',),
'bøyetere': ('bøyet',),
'bøyetest': ('bøyet',),
'bøyeteste': ('bøyet',),
'bøyet': ('bøyet',),
'bøyete': ('bøyet',),
'bøyetere': ('bøyet',),
'bøyetest': ('bøyet',),
'bøyeteste': ('bøyet',),
'bøyete': ('bøyete',),
'bøyete': ('bøyete',),
'californisk': ('californisk',),
'californiske': ('californisk',),
'californiskere': ('californisk',),
'californiskest': ('californisk',),
'californiskeste': ('californisk',),
'campa': ('campe',),
'campede': ('campe',),
'campende': ('campe',),
'campet': ('campe',),
'campete': ('campe',),
'canadisk': ('canadisk',),
'canadiske': ('canadisk',),
'canadiskere': ('canadisk',),
'canadiskest': ('canadisk',),
'canadiskeste': ('canadisk',),
'cash': ('cash',),
'casha': ('cashe',),
'cashede': ('cashe',),
'cashende': ('cashe',),
'cashet': ('cashe',),
'cashete': ('cashe',),
'celeber': ('celeber',),
'celebert': ('celeber',),
'celebre': ('celeber',),
'celebrere': ('celeber',),
'celebrest': ('celeber',),
'celebreste': ('celeber',),
'celebrerende': ('celebrere',),
'celebrert': ('celebrere',),
'celebrerte': ('celebrere',),
'celest': ('celest',),
'celeste': ('celest',),
'celestere': ('celest',),
'celestest': ('celest',),
'celesteste': ('celest',),
'cellular': ('cellular',),
'cellulare': ('cellular',),
'cellularere': ('cellular',),
'cellularest': ('cellular',),
'cellulareste': ('cellular',),
'cellulart': ('cellular',),
'cellulær': ('cellulær',),
'cellulære': ('cellulær',),
'cellulærere': ('cellulær',),
'cellulærest': ('cellulær',),
'cellulæreste': ('cellulær',),
'cellulært': ('cellulær',),
'cendre': ('cendre',),
'cerebral': ('cerebral',),
'cerebrale': ('cerebral',),
'cerebralere': ('cerebral',),
'cerebralest': ('cerebral',),
'cerebraleste': ('cerebral',),
'cerebralt': ('cerebral',),
'cerebral parese-ramma': ('cerebral parese-ramma',),
'cerebral parese-rammede': ('cerebral parese-rammet',),
'cerebral parese-rammet': ('cerebral parese-rammet',),
'cerebral parese-rammete': ('cerebral parese-rammet',),
'cerebral parese-rammetere': ('cerebral parese-rammet',),
'cerebral parese-rammetest': ('cerebral parese-rammet',),
'cerebral parese-rammeteste': ('cerebral parese-rammet',),
'ceylonsk': ('ceylonsk',),
'ceylonske': ('ceylonsk',),
'ceylonskere': ('ceylonsk',),
'ceylonskest': ('ceylonsk',),
'ceylonskeste': ('ceylonsk',),
'changeant': ('changeant',),
'changerende': ('changere',),
'changert': ('changere',),
'changerte': ('changere',),
'chartra': ('chartre',),
'chartrede': ('chartre',),
'chartrende': ('chartre',),
'chartret': ('chartre',),
'chartrete': ('chartre',),
'chevaleresk': ('chevaleresk',),
'chevalereske': ('chevaleresk',),
'chevalereskere': ('chevaleresk',),
'chevalereskest': ('chevaleresk',),
'chevalereskeste': ('chevaleresk',),
'chevroterende': ('chevrotere',),
'chevrotert': ('chevrotere',),
'chevroterte': ('chevrotere',),
'chic': ('chic',),
'chice': ('chic',),
'chicere': ('chic',),
'chicest': ('chic',),
'chiceste': ('chic',),
'chict': ('chic',),
'chiffrerende': ('chiffrere',),
'chiffrert': ('chiffrere',),
'chiffrerte': ('chiffrere',),
'chilensk': ('chilensk',),
'chilenske': ('chilensk',),
'chilenskere': ('chilensk',),
'chilenskest': ('chilensk',),
'chilenskeste': ('chilensk',),
'choka': ('choke',),
'chokede': ('choke',),
'chokende': ('choke',),
'choket': ('choke',),
'chokete': ('choke',),
'cirkumpolar': ('cirkumpolar',),
'cirkumpolare': ('cirkumpolar',),
'cirkumpolarere': ('cirkumpolar',),
'cirkumpolarest': ('cirkumpolar',),
'cirkumpolareste': ('cirkumpolar',),
'cirkumpolart': ('cirkumpolar',),
'cirkumpolær': ('cirkumpolær',),
'cirkumpolære': ('cirkumpolær',),
'cirkumpolærere': ('cirkumpolær',),
'cirkumpolærest': ('cirkumpolær',),
'cirkumpolæreste': ('cirkumpolær',),
'cirkumpolært': ('cirkumpolær',),
'cisalpinsk': ('cisalpinsk',),
'cisalpinske': ('cisalpinsk',),
'cisalpinskere': ('cisalpinsk',),
'cisalpinskest': ('cisalpinsk',),
'cisalpinskeste': ('cisalpinsk',),
'clairvoyant': ('clairvoyant',),
'clairvoyante': ('clairvoyant',),
'clairvoyantere': ('clairvoyant',),
'clairvoyantest': ('clairvoyant',),
'clairvoyanteste': ('clairvoyant',),
'clincha': ('clinche',),
'clinchede': ('clinche',),
'clinchende': ('clinche',),
'clinchet': ('clinche',),
'clinchete': ('clinche',),
'clutcha': ('clutche',),
'clutchede': ('clutche',),
'clutchende': ('clutche',),
'clutchet': ('clutche',),
'clutchete': ('clutche',),
'colombiansk': ('colombiansk',),
'colombianske': ('colombiansk',),
'colombianskere': ('colombiansk',),
'colombianskest': ('colombiansk',),
'colombianskeste': ('colombiansk',),
'comme il faut': ('comme il faut',),
'corny': ('corny',),
'corsicansk': ('corsicansk',),
'corsicanske': ('corsicansk',),
'corsicanskere': ('corsicansk',),
'corsicanskest': ('corsicansk',),
'corsicanskeste': ('corsicansk',),
'costaricansk': ('costaricansk',),
'costaricanske': ('costaricansk',),
'costaricanskere': ('costaricansk',),
'costaricanskest': ('costaricansk',),
'costaricanskeste': ('costaricansk',),
'crazy': ('crazy',),
'cruisa': ('cruise',),
'cruisede': ('cruise',),
'cruisende': ('cruise',),
'cruiset': ('cruise',),
'cruisete': ('cruise',),
'cubansk': ('cubansk',),
'cubanske': ('cubansk',),
'cubanskere': ('cubansk',),
'cubanskest': ('cubansk',),
'cubanskeste': ('cubansk',),
'cyanidiserende': ('cyanidisere',),
'cyanidisert': ('cyanidisere',),
'cyanidiserte': ('cyanidisere',),
'cyklamen': ('cyklamen',),
'cystisk': ('cystisk',),
'cystiske': ('cystisk',),
'cystiskere': ('cystisk',),
'cystiskest': ('cystisk',),
'cystiskeste': ('cystisk',),
'cytologisk': ('cytologisk',),
'cytologiske': ('cytologisk',),
'cytologiskere': ('cytologisk',),
'cytologiskest': ('cytologisk',),
'cytologiskeste': ('cytologisk',),
'cæsarisk': ('cæsarisk',),
'cæsariske': ('cæsarisk',),
'cæsariskere': ('cæsarisk',),
'cæsariskest': ('cæsarisk',),
'cæsariskeste': ('cæsarisk',),
'cøliakisk': ('cøliakisk',),
'cøliakiske': ('cøliakisk',),
'cøliakiskere': ('cøliakisk',),
'cøliakiskest': ('cøliakisk',),
'cøliakiskeste': ('cøliakisk',),
'dabba': ('dabbe',),
'dabbede': ('dabbe',),
'dabbende': ('dabbe',),
'dabbet': ('dabbe',),
'dabbete': ('dabbe',),
'dadaistisk': ('dadaistisk',),
'dadaistiske': ('dadaistisk',),
'dadaistiskere': ('dadaistisk',),
'dadaistiskest': ('dadaistisk',),
'dadaistiskeste': ('dadaistisk',),
'daddellaus': ('daddellaus',),
'daddellause': ('daddellaus',),
'daddellausere': ('daddellaus',),
'daddellausest': ('daddellaus',),
'daddellauseste': ('daddellaus',),
'daddellaust': ('daddellaus',),
'daddelløs': ('daddelløs',),
'daddelløse': ('daddelløs',),
'daddelløsere': ('daddelløs',),
'daddelløsest': ('daddelløs',),
'daddelløseste': ('daddelløs',),
'daddelløst': ('daddelløs',),
'daddelverdig': ('daddelverdig',),
'daddelverdige': ('daddelverdig',),
'daddelverdigere': ('daddelverdig',),
'daddelverdigst': ('daddelverdig',),
'daddelverdigste': ('daddelverdig',),
'dadla': ('dadle',),
'dadlede': ('dadle',),
'dadlende': ('dadle',),
'dadlet': ('dadle',),
'dadlete': ('dadle',),
'daff': ('daff',),
'daffe': ('daff',),
'daffere': ('daff',),
'daffest': ('daff',),
'daffeste': ('daff',),
'daft': ('daff',),
'daffa': ('daffe',),
'daffede': ('daffe',),
'daffende': ('daffe',),
'daffet': ('daffe',),
'daffete': ('daffe',),
'dagdrømmende': ('dagdrømme',),
'dagdrømt': ('dagdrømme',),
'dagdrømte': ('dagdrømme',),
'daga': ('dage',),
'dagede': ('dage',),
'dagende': ('dage',),
'daget': ('dage',),
'dagete': ('dage',),
'daghavende': ('daghavende',),
'dagjeldende': ('dagjeldende',),
'daglig': ('daglig',),
'daglige': ('daglig',),
'dagligere': ('daglig',),
'dagligst': ('daglig',),
'dagligste': ('daglig',),
'dagligdags': ('dagligdags',),
'dagligdagse': ('dagligdags',),
'dagligdagsere': ('dagligdags',),
'dagligdagsest': ('dagligdags',),
'dagligdagseste': ('dagligdags',),
'dagsaktuell': ('dagsaktuell',),
'dagsaktuelle': ('dagsaktuell',),
'dagsaktuellere': ('dagsaktuell',),
'dagsaktuellest': ('dagsaktuell',),
'dagsaktuelleste': ('dagsaktuell',),
'dagsaktuelt': ('dagsaktuell',),
'dagsens': ('dagsens',),
'dagvill': ('dagvill',),
'dagville': ('dagvill',),
'dagvillere': ('dagvill',),
'dagvillest': ('dagvill',),
'dagvilleste': ('dagvill',),
'dagvilt': ('dagvill',),
'dagviss': ('dagviss',),
'dagvisse': ('dagviss',),
'dagvissere': ('dagviss',),
'dagvissest': ('dagviss',),
'dagvisseste': ('dagviss',),
'dagvisst': ('dagviss',),
'daktylisk': ('daktylisk',),
'daktyliske': ('daktylisk',),
'daktyliskere': ('daktylisk',),
'daktyliskest': ('daktylisk',),
'daktyliskeste': ('daktylisk',),
'dalende': ('dale',),
'dalt': ('dale',),
'dalte': ('dale',),
'dalet': ('dalet',),
'dalete': ('dalet',),
'daletere': ('dalet',),
'daletest': ('dalet',),
'daleteste': ('dalet',),
'dalete': ('dalete',),
'dalevende': ('dalevende',),
'dalka': ('dalke',),
'dalkede': ('dalke',),
'dalkende': ('dalke',),
'dalket': ('dalke',),
'dalkete': ('dalke',),
'dalmatisk': ('dalmatisk',),
'dalmatiske': ('dalmatisk',),
'dalmatiskere': ('dalmatisk',),
'dalmatiskest': ('dalmatisk',),
'dalmatiskeste': ('dalmatisk',),
'dalta': ('dalte',),
'daltede': ('dalte',),
'daltende': ('dalte',),
'daltet': ('dalte',),
'daltete': ('dalte',),
'damascerende': ('damascere',),
'damascert': ('damascere',),
'damascerte': ('damascere',),
'dampdrevet': ('dampdrevet',),
'dampdrevne': ('dampdrevet',),
'dampdrevnere': ('dampdrevet',),
'dampdrevnest': ('dampdrevet',),
'dampdrevneste': ('dampdrevet',),
'dampa': ('dampe',),
'dampede': ('dampe',),
'dampende': ('dampe',),
'dampet': ('dampe',),
'dampete': ('dampe',),
'dampkokende': ('dampkoke',),
'dampkokt': ('dampkoke',),
'dampkokte': ('dampkoke',),
'danderende': ('dandere',),
'dandert': ('dandere',),
'danderte': ('dandere',),
'dangla': ('dangle',),
'danglede': ('dangle',),
'danglende': ('dangle',),
'danglet': ('dangle',),
'danglete': ('dangle',),
'danka': ('danke',),
'dankede': ('danke',),
'dankende': ('danke',),
'danket': ('danke',),
'dankete': ('danke',),
'danna': ('danna',),
'danna': ('danne',),
'dannede': ('danne',),
'dannende': ('danne',),
'dannet': ('danne',),
'dannete': ('danne',),
'dannede': ('dannet',),
'dannet': ('dannet',),
'dannete': ('dannet',),
'dannetere': ('dannet',),
'dannetest': ('dannet',),
'danneteste': ('dannet',),
'dansa': ('danse',),
'dansede': ('danse',),
'dansende': ('danse',),
'danset': ('danse',),
'dansete': ('danse',),
'dansegal': ('dansegal',),
'dansegale': ('dansegal',),
'dansegalere': ('dansegal',),
'dansegalest': ('dansegal',),
'dansegaleste': ('dansegal',),
'dansegalt': ('dansegal',),
'dansk': ('dansk',),
'danske': ('dansk',),
'danskere': ('dansk',),
'danskest': ('dansk',),
'danskeste': ('dansk',),
'dansk-norsk': ('dansk-norsk',),
'dansk-norske': ('dansk-norsk',),
'dansk-norskere': ('dansk-norsk',),
'dansk-norskest': ('dansk-norsk',),
'dansk-norskeste': ('dansk-norsk',),
'danska': ('danske',),
'danskede': ('danske',),
'danskende': ('danske',),
'dansket': ('danske',),
'danskete': ('danske',),
'darra': ('darre',),
'darrede': ('darre',),
'darrende': ('darre',),
'darret': ('darre',),
'darrete': ('darre',),
'daska': ('daske',),
'daskede': ('daske',),
'daskende': ('daske',),
'dasket': ('daske',),
'daskete': ('daske',),
'databehandla': ('databehandle',),
'databehandlede': ('databehandle',),
'databehandlende': ('databehandle',),
'databehandlet': ('databehandle',),
'databehandlete': ('databehandle',),
'dataførende': ('dataføre',),
'dataført': ('dataføre',),
'dataførte': ('dataføre',),
'datagrafisk': ('datagrafisk',),
'datagrafiske': ('datagrafisk',),
'datagrafiskere': ('datagrafisk',),
'datagrafiskest': ('datagrafisk',),
'datagrafiskeste': ('datagrafisk',),
'datamaskinassistert': ('datamaskinassistert',),
'datamaskinassisterte': ('datamaskinassistert',),
'datamaskinassistertere': ('datamaskinassistert',),
'datamaskinassistertest': ('datamaskinassistert',),
'datamaskinassisterteste': ('datamaskinassistert',),
'datamaskinell': ('datamaskinell',),
'datamaskinelle': ('datamaskinell',),
'datamaskinellere': ('datamaskinell',),
'datamaskinellest': ('datamaskinell',),
'datamaskinelleste': ('datamaskinell',),
'datamaskinelt': ('datamaskinell',),
'datastyrende': ('datastyre',),
'datastyrt': ('datastyre',),
'datastyrte': ('datastyre',),
'daterende': ('datere',),
'datert': ('datere',),
'daterte': ('datere',),
'datidig': ('datidig',),
'datidige': ('datidig',),
'datidigere': ('datidig',),
'datidigst': ('datidig',),
'datidigste': ('datidig',),
'datostempla': ('datostemple',),
'datostemplede': ('datostemple',),
'datostemplende': ('datostemple',),
'datostemplet': ('datostemple',),
'datostemplete': ('datostemple',),
'dau': ('dau',),
'daue': ('dau',),
'dauere': ('dau',),
'dauest': ('dau',),
'daueste': ('dau',),
'daut': ('dau',),
'daubakt': ('daubakt',),
'daubakte': ('daubakt',),
'daubaktere': ('daubakt',),
'daubaktest': ('daubakt',),
'daubakteste': ('daubakt',),
'daud': ('daud',),
'daude': ('daud',),
'daudere': ('daud',),
'daudest': ('daud',),
'daudeste': ('daud',),
'daudt': ('daud',),
'daudbleik': ('daudbleik',),
'daudbleike': ('daudbleik',),
'daudbleikere': ('daudbleik',),
'daudbleikest': ('daudbleik',),
'daudbleikeste': ('daudbleik',),
'daudbleikt': ('daudbleik',),
'daudblek': ('daudblek',),
'daudbleke': ('daudblek',),
'daudblekere': ('daudblek',),
'daudblekest': ('daudblek',),
'daudblekeste': ('daudblek',),
'daudblekt': ('daudblek',),
'daudbrent': ('daudbrent',),
'daudbrente': ('daudbrent',),
'daudbrentere': ('daudbrent',),
'daudbrentest': ('daudbrent',),
'daudbrenteste': ('daudbrent',),
'dauddrukken': ('dauddrukken',),
'dauddrukkent': ('dauddrukken',),
'dauddrukne': ('dauddrukken',),
'dauddruknere': ('dauddrukken',),
'dauddruknest': ('dauddrukken',),
'dauddrukneste': ('dauddrukken',),
'dauda': ('daude',),
'daudede': ('daude',),
'daudende': ('daude',),
'daudet': ('daude',),
'daudete': ('daude',),
'daudfødd': ('daudfødd',),
'daudfødde': ('daudfødd',),
'daudføddere': ('daudfødd',),
'daudføddest': ('daudfødd',),
'daudføddeste': ('daudfødd',),
'daudfødt': ('daudfødt',),
'daudfødte': ('daudfødt',),
'daudfødtere': ('daudfødt',),
'daudfødtest': ('daudfødt',),
'daudfødteste': ('daudfødt',),
'daugjødsla': ('daugjødsle',),
'daugjødslede': ('daugjødsle',),
'daugjødslende': ('daugjødsle',),
'daugjødslet': ('daugjødsle',),
'daugjødslete': ('daugjødsle',),
'dauhogd': ('dauhogge',),
'dauhogde': ('dauhogge',),
'dauhoggede': ('dauhogge',),
'dauhoggende': ('dauhogge',),
'dauhogget': ('dauhogge',),
'dauhoggete': ('dauhogge',),
'dauhugd': ('dauhugge',),
'dauhugde': ('dauhugge',),
'dauhugga': ('dauhugge',),
'dauhuggede': ('dauhugge',),
'dauhuggende': ('dauhugge',),
'dauhugget': ('dauhugge',),
'dauhuggete': ('dauhugge',),
'daukjørende': ('daukjøre',),
'daukjørt': ('daukjøre',),
'daukjørte': ('daukjøre',),
'dausteikt': ('dausteikt',),
'dausteikte': ('dausteikt',),
'dausteiktere': ('dausteikt',),
'dausteiktest': ('dausteikt',),
'dausteikteste': ('dausteikt',),
'daustekt': ('daustekt',),
'daustekte': ('daustekt',),
'daustektere': ('daustekt',),
'daustektest': ('daustekt',),
'daustekteste': ('daustekt',),
'daværende': ('daværende',),
'debatterende': ('debattere',),
'debattert': ('debattere',),
'debatterte': ('debattere',),
'debil': ('debil',),
'debile': ('debil',),
'debilere': ('debil',),
'debilest': ('debil',),
'debileste': ('debil',),
'debilt': ('debil',),
'debiterende': ('debitere',),
'debitert': ('debitere',),
'debiterte': ('debitere',),
'debuterende': ('debutere',),
'debutert': ('debutere',),
'debuterte': ('debutere',),
'dechiffrerende': ('dechiffrere',),
'dechiffrert': ('dechiffrere',),
'dechiffrerte': ('dechiffrere',),
'dediserende': ('dedisere',),
'dedisert': ('dedisere',),
'dediserte': ('dedisere',),
'deduktiv': ('deduktiv',),
'deduktive': ('deduktiv',),
'deduktivere': ('deduktiv',),
'deduktivest': ('deduktiv',),
'deduktiveste': ('deduktiv',),
'deduktivt': ('deduktiv',),
'deduserende': ('dedusere',),
'dedusert': ('dedusere',),
'deduserte': ('dedusere',),
'defaitistisk': ('defaitistisk',),
'defaitistiske': ('defaitistisk',),
'defaitistiskere': ('defaitistisk',),
'defaitistiskest': ('defaitistisk',),
'defaitistiskeste': ('defaitistisk',),
'defekt': ('defekt',),
'defekte': ('defekt',),
'defektere': ('defekt',),
'defektest': ('defekt',),
'defekteste': ('defekt',),
'defensiv': ('defensiv',),
'defensive': ('defensiv',),
'defensivere': ('defensiv',),
'defensivest': ('defensiv',),
'defensiveste': ('defensiv',),
'defensivt': ('defensiv',),
'defilerende': ('defilere',),
'defilert': ('defilere',),
'defilerte': ('defilere',),
'definerbar': ('definerbar',),
'definerbare': ('definerbar',),
'definerbarere': ('definerbar',),
'definerbarest': ('definerbar',),
'definerbareste': ('definerbar',),
'definerbart': ('definerbar',),
'definerende': ('definere',),
'definert': ('definere',),
'definerte': ('definere',),
'definisjonsmessig': ('definisjonsmessig',),
'definisjonsmessige': ('definisjonsmessig',),
'definisjonsmessigere': ('definisjonsmessig',),
'definisjonsmessigst': ('definisjonsmessig',),
'definisjonsmessigste': ('definisjonsmessig',),
'definitiv': ('definitiv',),
'definitive': ('definitiv',),
'definitivere': ('definitiv',),
'definitivest': ('definitiv',),
'definitiveste': ('definitiv',),
'definitivt': ('definitiv',),
'definitorisk': ('definitorisk',),
'definitoriske': ('definitorisk',),
'definitoriskere': ('definitorisk',),
'definitoriskest': ('definitorisk',),
'definitoriskeste': ('definitorisk',),
'deflaterende': ('deflatere',),
'deflatert': ('deflatere',),
'deflaterte': ('deflatere',),
'deflatorisk': ('deflatorisk',),
'deflatoriske': ('deflatorisk',),
'deflatoriskere': ('deflatorisk',),
'deflatoriskest': ('deflatorisk',),
'deflatoriskeste': ('deflatorisk',),
'deflorerende': ('deflorere',),
'deflorert': ('deflorere',),
'deflorerte': ('deflorere',),
'deform': ('deform',),
'deforme': ('deform',),
'deformere': ('deform',),
'deformest': ('deform',),
'deformeste': ('deform',),
'deformt': ('deform',),
'deformerende': ('deformere',),
'deformert': ('deformere',),
'deformerte': ('deformere',),
'degenererende': ('degenerere',),
'degenerert': ('degenerere',),
'degenererte': ('degenerere',),
'degenerert': ('degenerert',),
'degenererte': ('degenerert',),
'degenerertere': ('degenerert',),
'degenerertest': ('degenerert',),
'degenererteste': ('degenerert',),
'degga': ('degge',),
'deggede': ('degge',),
'deggende': ('degge',),
'degget': ('degge',),
'deggete': ('degge',),
'degraderende': ('degradere',),
'degradert': ('degradere',),
'degraderte': ('degradere',),
'degressiv': ('degressiv',),
'degressive': ('degressiv',),
'degressivere': ('degressiv',),
'degressivest': ('degressiv',),
'degressiveste': ('degressiv',),
'degressivt': ('degressiv',),
'dehydrerende': ('dehydrere',),
'dehydrert': ('dehydrere',),
'dehydrerte': ('dehydrere',),
'deiget': ('deiget',),
'deigete': ('deiget',),
'deigetere': ('deiget',),
'deigetest': ('deiget',),
'deigeteste': ('deiget',),
'deigete': ('deigete',),
'deiktisk': ('deiktisk',),
'deiktiske': ('deiktisk',),
'deiktiskere': ('deiktisk',),
'deiktiskest': ('deiktisk',),
'deiktiskeste': ('deiktisk',),
'deilig': ('deilig',),
'deilige': ('deilig',),
'deiligere': ('deilig',),
'deiligst': ('deilig',),
'deiligste': ('deilig',),
'deisa': ('deise',),
'deisede': ('deise',),
'deisende': ('deise',),
'deiset': ('deise',),
'deisete': ('deise',),
'deist': ('deise',),
'deiste': ('deise',),
'deistisk': ('deistisk',),
'deistiske': ('deistisk',),
'deistiskere': ('deistisk',),
'deistiskest': ('deistisk',),
'deistiskeste': ('deistisk',),
'dekadent': ('dekadent',),
'dekadente': ('dekadent',),
'dekadentere': ('dekadent',),
'dekadentest': ('dekadent',),
'dekadenteste': ('dekadent',),
'dekadisk': ('dekadisk',),
'dekadiske': ('dekadisk',),
'dekadiskere': ('dekadisk',),
'dekadiskest': ('dekadisk',),
'dekadiskeste': ('dekadisk',),
'dekanterende': ('dekantere',),
'dekantert': ('dekantere',),
'dekanterte': ('dekantere',),
'dekaterende': ('dekatere',),
'dekatert': ('dekatere',),
'dekaterte': ('dekatere',),
'dekka': ('dekke',),
'dekkede': ('dekke',),
'dekkende': ('dekke',),
'dekket': ('dekke',),
'dekkete': ('dekke',),
'dekt': ('dekke',),
'dekte': ('dekke',),
'dekkende': ('dekkende',),
'dekkfrøa': ('dekkfrøa',),
'dekkfrøede': ('dekkfrøet',),
'dekkfrøet': ('dekkfrøet',),
'dekkfrøete': ('dekkfrøet',),
'dekkfrøetere': ('dekkfrøet',),
'dekkfrøetest': ('dekkfrøet',),
'dekkfrøeteste': ('dekkfrøet',),
'deklamerende': ('deklamere',),
'deklamert': ('deklamere',),
'deklamerte': ('deklamere',),
'deklaratorisk': ('deklaratorisk',),
'deklaratoriske': ('deklaratorisk',),
'deklaratoriskere': ('deklaratorisk',),
'deklaratoriskest': ('deklaratorisk',),
'deklaratoriskeste': ('deklaratorisk',),
'deklarerende': ('deklarere',),
'deklarert': ('deklarere',),
'deklarerte': ('deklarere',),
'deklasserende': ('deklassere',),
'deklassert': ('deklassere',),
'deklasserte': ('deklassere',),
'deklinabel': ('deklinabel',),
'deklinabelt': ('deklinabel',),
'deklinable': ('deklinabel',),
'deklinablere': ('deklinabel',),
'deklinablest': ('deklinabel',),
'deklinableste': ('deklinabel',),
'deklinerende': ('deklinere',),
'deklinert': ('deklinere',),
'deklinerte': ('deklinere',),
'dekningslaus': ('dekningslaus',),
'dekningslause': ('dekningslaus',),
'dekningslausere': ('dekningslaus',),
'dekningslausest': ('dekningslaus',),
'dekningslauseste': ('dekningslaus',),
'dekningslaust': ('dekningslaus',),
'dekningsløs': ('dekningsløs',),
'dekningsløse': ('dekningsløs',),
'dekningsløsere': ('dekningsløs',),
'dekningsløsest': ('dekningsløs',),
'dekningsløseste': ('dekningsløs',),
'dekningsløst': ('dekningsløs',),
'dekoda': ('dekode',),
'dekodede': ('dekode',),
'dekodende': ('dekode',),
'dekodet': ('dekode',),
'dekodete': ('dekode',),
'dekolletert': ('dekolletert',),
'dekolleterte': ('dekolletert',),
'dekolletertere': ('dekolletert',),
'dekolletertest': ('dekolletert',),
'dekolleterteste': ('dekolletert',),
'dekomponerende': ('dekomponere',),
'dekomponert': ('dekomponere',),
'dekomponerte': ('dekomponere',),
'dekorativ': ('dekorativ',),
'dekorative': ('dekorativ',),
'dekorativere': ('dekorativ',),
'dekorativest': ('dekorativ',),
'dekorativeste': ('dekorativ',),
'dekorativt': ('dekorativ',),
'dekorerende': ('dekorere',),
'dekorert': ('dekorere',),
'dekorerte': ('dekorere',),
'dekorterende': ('dekortere',),
'dekortert': ('dekortere',),
'dekorterte': ('dekortere',),
'dekreterende': ('dekretere',),
'dekretert': ('dekretere',),
'dekreterte': ('dekretere',),
'dekuperende': ('dekupere',),
'dekupert': ('dekupere',),
'dekuperte': ('dekupere',),
'delabialiserende': ('delabialisere',),
'delabialisert': ('delabialisere',),
'delabialiserte': ('delabialisere',),
'delaktig': ('delaktig',),
'delaktige': ('delaktig',),
'delaktigere': ('delaktig',),
'delaktigst': ('delaktig',),
'delaktigste': ('delaktig',),
'delende': ('dele',),
'delt': ('dele',),
'delte': ('dele',),
'delegerende': ('delegere',),
'delegert': ('delegere',),
'delegerte': ('delegere',),
'delegert': ('delegert',),
'delegerte': ('delegert',),
'delegertere': ('delegert',),
'delegertest': ('delegert',),
'delegerteste': ('delegert',),
'delelig': ('delelig',),
'delelige': ('delelig',),
'deleligere': ('delelig',),
'deleligst': ('delelig',),
'deleligste': ('delelig',),
'delerende': ('delere',),
'delert': ('delere',),
'delerte': ('delere',),
'delikat': ('delikat',),
'delikate': ('delikat',),
'delikatere': ('delikat',),
'delikatest': ('delikat',),
'delikateste': ('delikat',),
'delikaterende': ('delikatere',),
'delikatert': ('delikatere',),
'delikaterte': ('delikatere',),
'delirant': ('delirant',),
'delirante': ('delirant',),
'delirantere': ('delirant',),
'delirantest': ('delirant',),
'deliranteste': ('delirant',),
'delirerende': ('delirere',),
'delirert': ('delirere',),
'delirerte': ('delirere',),
'delja': ('delje',),
'deljede': ('delje',),
'deljende': ('delje',),
'deljet': ('delje',),
'deljete': ('delje',),
'deltakende': ('delta',),
'deltatt': ('delta',),
'deltatte': ('delta',),
'deltaforma': ('deltaforma',),
'deltaformede': ('deltaformet',),
'deltaformet': ('deltaformet',),
'deltaformete': ('deltaformet',),
'deltaformetere': ('deltaformet',),
'deltaformetest': ('deltaformet',),
'deltaformeteste': ('deltaformet',),
'deltagende': ('deltagende',),
'deltakende': ('deltakende',),
'deltidsansatt': ('deltidsansatt',),
'deltidsansatte': ('deltidsansatt',),
'deltidsansattere': ('deltidsansatt',),
'deltidsansattest': ('deltidsansatt',),
'deltidsansatteste': ('deltidsansatt',),
'demagogisk': ('demagogisk',),
'demagogiske': ('demagogisk',),
'demagogiskere': ('demagogisk',),
'demagogiskest': ('demagogisk',),
'demagogiskeste': ('demagogisk',),
'demaskerende': ('demaskere',),
'demaskert': ('demaskere',),
'demaskerte': ('demaskere',),
'dementerende': ('dementere',),
'dementert': ('dementere',),
'dementerte': ('dementere',),
'demi-sec': ('demi-sec',),
'demilitariserende': ('demilitarisere',),
'demilitarisert': ('demilitarisere',),
'demilitariserte': ('demilitarisere',),
'demisjonerende': ('demisjonere',),
'demisjonert': ('demisjonere',),
'demisjonerte': ('demisjonere',),
'demma': ('demme',),
'demmede': ('demme',),
'demmende': ('demme',),
'demmet': ('demme',),
'demmete': ('demme',),
'demt': ('demme',),
'demte': ('demme',),
'demobiliserende': ('demobilisere',),
'demobilisert': ('demobilisere',),
'demobiliserte': ('demobilisere',),
'demografisk': ('demografisk',),
'demografiske': ('demografisk',),
'demografiskere': ('demografisk',),
'demografiskest': ('demografisk',),
'demografiskeste': ('demografisk',),
'demokratiserende': ('demokratisere',),
'demokratisert': ('demokratisere',),
'demokratiserte': ('demokratisere',),
'demokratisk': ('demokratisk',),
'demokratiske': ('demokratisk',),
'demokratiskere': ('demokratisk',),
'demokratiskest': ('demokratisk',),
'demokratiskeste': ('demokratisk',),
'demolerende': ('demolere',),
'demolert': ('demolere',),
'demolerte': ('demolere',),
'demonisk': ('demonisk',),
'demoniske': ('demonisk',),
'demoniskere': ('demonisk',),
'demoniskest': ('demonisk',),
'demoniskeste': ('demonisk',),
'demonstrativ': ('demonstrativ',),
'demonstrative': ('demonstrativ',),
'demonstrativere': ('demonstrativ',),
'demonstrativest': ('demonstrativ',),
'demonstrativeste': ('demonstrativ',),
'demonstrativt': ('demonstrativ',),
'demonstrerende': ('demonstrere',),
'demonstrert': ('demonstrere',),
'demonstrerte': ('demonstrere',),
'demonterende': ('demontere',),
'demontert': ('demontere',),
'demonterte': ('demontere',),
'demoraliserende': ('demoralisere',),
'demoralisert': ('demoralisere',),
'demoraliserte': ('demoralisere',),
'dempa': ('dempe',),
'dempede': ('dempe',),
'dempende': ('dempe',),
'dempet': ('dempe',),
'dempete': ('dempe',),
'demra': ('demre',),
'demrede': ('demre',),
'demrende': ('demre',),
'demret': ('demre',),
'demrete': ('demre',),
'den slags': ('den slags',),
'denasjonaliserende': ('denasjonalisere',),
'denasjonalisert': ('denasjonalisere',),
'denasjonaliserte': ('denasjonalisere',),
'denaturaliserende': ('denaturalisere',),
'denaturalisert': ('denaturalisere',),
'denaturaliserte': ('denaturalisere',),
'denaturerende': ('denaturere',),
'denaturert': ('denaturere',),
'denaturerte': ('denaturere',),
'dengende': ('denge',),
'dengt': ('denge',),
'dengte': ('denge',),
'dennesidig': ('dennesidig',),
'dennesidige': ('dennesidig',),
'dennesidigere': ('dennesidig',),
'dennesidigst': ('dennesidig',),
'dennesidigste': ('dennesidig',),
'denominativ': ('denominativ',),
'denominative': ('denominativ',),
'denominativere': ('denominativ',),
'denominativest': ('denominativ',),
'denominativeste': ('denominativ',),
'denominativt': ('denominativ',),
'denotativ': ('denotativ',),
'denotative': ('denotativ',),
'denotativere': ('denotativ',),
'denotativest': ('denotativ',),
'denotativeste': ('denotativ',),
'denotativt': ('denotativ',),
'denoterende': ('denotere',),
'denotert': ('denotere',),
'denoterte': ('denotere',),
'dental': ('dental',),
'dentale': ('dental',),
'dentalere': ('dental',),
'dentalest': ('dental',),
'dentaleste': ('dental',),
'dentalt': ('dental',),
'denuderende': ('denudere',),
'denudert': ('denudere',),
'denuderte': ('denudere',),
'deoksiderende': ('deoksidere',),
'deoksidert': ('deoksidere',),
'deoksiderte': ('deoksidere',),
'departemental': ('departemental',),
'departementale': ('departemental',),
'departementalere': ('departemental',),
'departementalest': ('departemental',),
'departementaleste': ('departemental',),
'departementalt': ('departemental',),
'deponent': ('deponent',),
'deponente': ('deponent',),
'deponentere': ('deponent',),
'deponentest': ('deponent',),
'deponenteste': ('deponent',),
'deponerende': ('deponere',),
'deponert': ('deponere',),
'deponerte': ('deponere',),
'deporterende': ('deportere',),
'deportert': ('deportere',),
'deporterte': ('deportere',),
'deppa': ('deppa',),
'deppa': ('deppe',),
'deppede': ('deppe',),
'deppende': ('deppe',),
'deppet': ('deppe',),
'deppete': ('deppe',),
'depraverende': ('depravere',),
'depravert': ('depravere',),
'depraverte': ('depravere',),
'depressiv': ('depressiv',),
'depressive': ('depressiv',),
'depressivere': ('depressiv',),
'depressivest': ('depressiv',),
'depressiveste': ('depressiv',),
'depressivt': ('depressiv',),
'deprimerende': ('deprimere',),
'deprimert': ('deprimere',),
'deprimerte': ('deprimere',),
'deprimert': ('deprimert',),
'deprimerte': ('deprimert',),
'deprimertere': ('deprimert',),
'deprimertest': ('deprimert',),
'deprimerteste': ('deprimert',),
'deprivatiserende': ('deprivatisere',),
'deprivatisert': ('deprivatisere',),
'deprivatiserte': ('deprivatisere',),
'deputert': ('deputert',),
'deputerte': ('deputert',),
'deputertere': ('deputert',),
'deputertest': ('deputert',),
'deputerteste': ('deputert',),
'derangerende': ('derangere',),
'derangert': ('derangere',),
'derangerte': ('derangere',),
'derangert': ('derangert',),
'derangerte': ('derangert',),
'derangertere': ('derangert',),
'derangertest': ('derangert',),
'derangerteste': ('derangert',),
'derelinkverende': ('derelinkvere',),
'derelinkvert': ('derelinkvere',),
'derelinkverte': ('derelinkvere',),
'deriverbar': ('deriverbar',),
'deriverbare': ('deriverbar',),
'deriverbarere': ('deriverbar',),
'deriverbarest': ('deriverbar',),
'deriverbareste': ('deriverbar',),
'deriverbart': ('deriverbar',),
'deriverende': ('derivere',),
'derivert': ('derivere',),
'deriverte': ('derivere',),
'derværende': ('derværende',),
'desarmerende': ('desarmere',),
'desarmert': ('desarmere',),
'desarmerte': ('desarmere',),
'desavuerende': ('desavuere',),
'desavuert': ('desavuere',),
'desavuerte': ('desavuere',),
'desentraliserende': ('desentralisere',),
'desentralisert': ('desentralisere',),
'desentraliserte': ('desentralisere',),
'deserterende': ('desertere',),
'desertert': ('desertere',),
'deserterte': ('desertere',),
'desiderende': ('desidere',),
'desidert': ('desidere',),
'desiderte': ('desidere',),
'desidert': ('desidert',),
'desiderte': ('desidert',),
'desidertere': ('desidert',),
'desidertest': ('desidert',),
'desiderteste': ('desidert',),
'designa': ('designe',),
'designede': ('designe',),
'designende': ('designe',),
'designet': ('designe',),
'designete': ('designe',),
'desillusjonerende': ('desillusjonere',),
'desillusjonert': ('desillusjonere',),
'desillusjonerte': ('desillusjonere',),
'desillusjonert': ('desillusjonert',),
'desillusjonerte': ('desillusjonert',),
'desillusjonertere': ('desillusjonert',),
'desillusjonertest': ('desillusjonert',),
'desillusjonerteste': ('desillusjonert',),
'desimerende': ('desimere',),
'desimert': ('desimere',),
'desimerte': ('desimere',),
'desinfiserende': ('desinfisere',),
'desinfisert': ('desinfisere',),
'desinfiserte': ('desinfisere',),
'desinformerende': ('desinformere',),
'desinformert': ('desinformere',),
'desinformerte': ('desinformere',),
'desintegrerende': ('desintegrere',),
'desintegrert': ('desintegrere',),
'desintegrerte': ('desintegrere',),
'deskriptiv': ('deskriptiv',),
'deskriptive': ('deskriptiv',),
'deskriptivere': ('deskriptiv',),
'deskriptivest': ('deskriptiv',),
'deskriptiveste': ('deskriptiv',),
'deskriptivt': ('deskriptiv',),
'desoksiderende': ('desoksidere',),
'desoksidert': ('desoksidere',),
'desoksiderte': ('desoksidere',),
'desorganiserende': ('desorganisere',),
'desorganisert': ('desorganisere',),
'desorganiserte': ('desorganisere',),
'desorienterende': ('desorientere',),
'desorientert': ('desorientere',),
'desorienterte': ('desorientere',),
'desorientert': ('desorientert',),
'desorienterte': ('desorientert',),
'desorientertere': ('desorientert',),
'desorientertest': ('desorientert',),
'desorienterteste': ('desorientert',),
'desperat': ('desperat',),
'desperate': ('desperat',),
'desperatere': ('desperat',),
'desperatest': ('desperat',),
'desperateste': ('desperat',),
'despotisk': ('despotisk',),
'despotiske': ('despotisk',),
'despotiskere': ('despotisk',),
'despotiskest': ('despotisk',),
'despotiskeste': ('despotisk',),
'desslike': ('desslike',),
'destillerende': ('destillere',),
'destillert': ('destillere',),
'destillerte': ('destillere',),
'destruerende': ('destruere',),
'destruert': ('destruere',),
'destruerte': ('destruere',),
'destruktiv': ('destruktiv',),
'destruktive': ('destruktiv',),
'destruktivere': ('destruktiv',),
'destruktivest': ('destruktiv',),
'destruktiveste': ('destruktiv',),
'destruktivt': ('destruktiv',),
'detaljbehandla': ('detaljbehandle',),
'detaljbehandlede': ('detaljbehandle',),
'detaljbehandlende': ('detaljbehandle',),
'detaljbehandlet': ('detaljbehandle',),
'detaljbehandlete': ('detaljbehandle',),
'detaljerende': ('detaljere',),
'detaljert': ('detaljere',),
'detaljerte': ('detaljere',),
'detaljert': ('detaljert',),
'detaljerte': ('detaljert',),
'detaljertere': ('detaljert',),
'detaljertest': ('detaljert',),
'detaljerteste': ('detaljert',),
'detaljrik': ('detaljrik',),
'detaljrike': ('detaljrik',),
'detaljrikere': ('detaljrik',),
'detaljrikest': ('detaljrik',),
'detaljrikeste': ('detaljrik',),
'detaljrikt': ('detaljrik',),
'detasjerende': ('detasjere',),
'detasjert': ('detasjere',),
'detasjerte': ('detasjere',),
'detasjerende': ('detasjere',),
'detasjert': ('detasjere',),
'detasjerte': ('detasjere',),
'determinativ': ('determinativ',),
'determinative': ('determinativ',),
'determinativere': ('determinativ',),
'determinativest': ('determinativ',),
'determinativeste': ('determinativ',),
'determinativt': ('determinativ',),
'determinerende': ('determinere',),
'determinert': ('determinere',),
'determinerte': ('determinere',),
'deterministisk': ('deterministisk',),
'deterministiske': ('deterministisk',),
'deterministiskere': ('deterministisk',),
'deterministiskest': ('deterministisk',),
'deterministiskeste': ('deterministisk',),
'detonerende': ('detonere',),
'detonert': ('detonere',),
'detonerte': ('detonere',),
'detonerende': ('detonere',),
'detonert': ('detonere',),
'detonerte': ('detonere',),
'detroniserende': ('detronisere',),
'detronisert': ('detronisere',),
'detroniserte': ('detronisere',),
'detne': ('dette',),
'detten': ('dette',),
'dettende': ('dette',),
'dettet': ('dette',),
'devaluerende': ('devaluere',),
'devaluert': ('devaluere',),
'devaluerte': ('devaluere',),
'devierende': ('deviere',),
'deviert': ('deviere',),
'devierte': ('deviere',),
'devot': ('devot',),
'diabetisk': ('diabetisk',),
'diabetiske': ('diabetisk',),
'diabetiskere': ('diabetisk',),
'diabetiskest': ('diabetisk',),
'diabetiskeste': ('diabetisk',),
'diabolsk': ('diabolsk',),
'diabolske': ('diabolsk',),
'diabolskere': ('diabolsk',),
'diabolskest': ('diabolsk',),
'diabolskeste': ('diabolsk',),
'diagnostiserende': ('diagnostisere',),
'diagnostisert': ('diagnostisere',),
'diagnostiserte': ('diagnostisere',),
'diagnostisk': ('diagnostisk',),
'diagnostiske': ('diagnostisk',),
'diagnostiskere': ('diagnostisk',),
'diagnostiskest': ('diagnostisk',),
'diagnostiskeste': ('diagnostisk',),
'diagonal': ('diagonal',),
'diagonale': ('diagonal',),
'diagonalere': ('diagonal',),
'diagonalest': ('diagonal',),
'diagonaleste': ('diagonal',),
'diagonalt': ('diagonal',),
'diagonalvevd': ('diagonalvevd',),
'diagonalvevde': ('diagonalvevd',),
'diagonalvevdere': ('diagonalvevd',),
'diagonalvevdest': ('diagonalvevd',),
'diagonalvevdeste': ('diagonalvevd',),
'diakonal': ('diakonal',),
'diakonale': ('diakonal',),
'diakonalere': ('diakonal',),
'diakonalest': ('diakonal',),
'diakonaleste': ('diakonal',),
'diakonalt': ('diakonal',),
'diakritisk': ('diakritisk',),
'diakritiske': ('diakritisk',),
'diakritiskere': ('diakritisk',),
'diakritiskest': ('diakritisk',),
'diakritiskeste': ('diakritisk',),
'diakron': ('diakron',),
'diakrone': ('diakron',),
'diakronere': ('diakron',),
'diakronest': ('diakron',),
'diakroneste': ('diakron',),
'diakront': ('diakron',),
'diakronisk': ('diakronisk',),
'diakroniske': ('diakronisk',),
'diakroniskere': ('diakronisk',),
'diakroniskest': ('diakronisk',),
'diakroniskeste': ('diakronisk',),
'dialektal': ('dialektal',),
'dialektale': ('dialektal',),
'dialektalere': ('dialektal',),
'dialektalest': ('dialektal',),
'dialektaleste': ('dialektal',),
'dialektalt': ('dialektal',),
'dialektfarga': ('dialektfarga',),
'dialektfargede': ('dialektfarget',),
'dialektfarget': ('dialektfarget',),
'dialektfargete': ('dialektfarget',),
'dialektfargetere': ('dialektfarget',),
'dialektfargetest': ('dialektfarget',),
'dialektfargeteste': ('dialektfarget',),
'dialektisk': ('dialektisk',),
'dialektiske': ('dialektisk',),
'dialektiskere': ('dialektisk',),
'dialektiskest': ('dialektisk',),
'dialektiskeste': ('dialektisk',),
'dialyserende': ('dialysere',),
'dialysert': ('dialysere',),
'dialyserte': ('dialysere',),
'diametral': ('diametral',),
'diametrale': ('diametral',),
'diametralere': ('diametral',),
'diametralest': ('diametral',),
'diametraleste': ('diametral',),
'diametralt': ('diametral',),
'diatonisk': ('diatonisk',),
'diatoniske': ('diatonisk',),
'diatoniskere': ('diatonisk',),
'diatoniskest': ('diatonisk',),
'diatoniskeste': ('diatonisk',),
'didaktisk': ('didaktisk',),
'didaktiske': ('didaktisk',),
'didaktiskere': ('didaktisk',),
'didaktiskest': ('didaktisk',),
'didaktiskeste': ('didaktisk',),
'dia': ('die',),
'diede': ('die',),
'diende': ('die',),
'diet': ('die',),
'diete': ('die',),
'dieseldrevet': ('dieseldrevet',),
'dieseldrevne': ('dieseldrevet',),
'dieseldrevnere': ('dieseldrevet',),
'dieseldrevnest': ('dieseldrevet',),
'dieseldrevneste': ('dieseldrevet',),
'differensierende': ('differensiere',),
'differensiert': ('differensiere',),
'differensierte': ('differensiere',),
'differerende': ('differere',),
'differert': ('differere',),
'differerte': ('differere',),
'diffunderende': ('diffundere',),
'diffundert': ('diffundere',),
'diffunderte': ('diffundere',),
'diffus': ('diffus',),
'diffuse': ('diffus',),
'diffusere': ('diffus',),
'diffusest': ('diffus',),
'diffuseste': ('diffus',),
'diffust': ('diffus',),
'difterisk': ('difterisk',),
'difteriske': ('difterisk',),
'difteriskere': ('difterisk',),
'difteriskest': ('difterisk',),
'difteriskeste': ('difterisk',),
'difterittisk': ('difterittisk',),
'difterittiske': ('difterittisk',),
'difterittiskere': ('difterittisk',),
'difterittiskest': ('difterittisk',),
'difterittiskeste': ('difterittisk',),
'diftongerende': ('diftongere',),
'diftongert': ('diftongere',),
'diftongerte': ('diftongere',),
'diger': ('diger',),
'digert': ('diger',),
'digre': ('diger',),
'digrere': ('diger',),
'digrest': ('diger',),
'digreste': ('diger',),
'digga': ('digge',),
'diggede': ('digge',),
'diggende': ('digge',),
'digget': ('digge',),
'diggete': ('digge',),
'digital': ('digital',),
'digitale': ('digital',),
'digitalere': ('digital',),
'digitalest': ('digital',),
'digitaleste': ('digital',),
'digitalt': ('digital',),
'digitaliserende': ('digitalisere',),
'digitalisert': ('digitalisere',),
'digitaliserte': ('digitalisere',),
'dikka': ('dikke',),
'dikkede': ('dikke',),
'dikkende': ('dikke',),
'dikket': ('dikke',),
'dikkete': ('dikke',),
'dikka': ('dikke',),
'dikkede': ('dikke',),
'dikkende': ('dikke',),
'dikket': ('dikke',),
'dikkete': ('dikke',),
'diktatorisk': ('diktatorisk',),
'diktatoriske': ('diktatorisk',),
'diktatoriskere': ('diktatorisk',),
'diktatoriskest': ('diktatorisk',),
'diktatoriskeste': ('diktatorisk',),
'dikta': ('dikte',),
'diktede': ('dikte',),
'diktende': ('dikte',),
'diktet': ('dikte',),
'diktete': ('dikte',),
'dikterende': ('diktere',),
'diktert': ('diktere',),
'dikterte': ('diktere',),
'dikterisk': ('dikterisk',),
'dikteriske': ('dikterisk',),
'dikteriskere': ('dikterisk',),
'dikteriskest': ('dikterisk',),
'dikteriskeste': ('dikterisk',),
'dilettantisk': ('dilettantisk',),
'dilettantiske': ('dilettantisk',),
'dilettantiskere': ('dilettantisk',),
'dilettantiskest': ('dilettantisk',),
'dilettantiskeste': ('dilettantisk',),
'dilettantmessig': ('dilettantmessig',),
'dilettantmessige': ('dilettantmessig',),
'dilettantmessigere': ('dilettantmessig',),
'dilettantmessigst': ('dilettantmessig',),
'dilettantmessigste': ('dilettantmessig',),
'dilla': ('dille',),
'dillede': ('dille',),
'dillende': ('dille',),
'dillet': ('dille',),
'dillete': ('dille',),
'dillet': ('dillet',),
'dillete': ('dillet',),
'dilletere': ('dillet',),
'dilletest': ('dillet',),
'dilleteste': ('dillet',),
'dillete': ('dillete',),
'dilta': ('dilte',),
'diltede': ('dilte',),
'diltende': ('dilte',),
'diltet': ('dilte',),
'diltete': ('dilte',),
'diluvial': ('diluvial',),
'diluviale': ('diluvial',),
'diluvialere': ('diluvial',),
'diluvialest': ('diluvial',),
'diluvialeste': ('diluvial',),
'diluvialt': ('diluvial',),
'diluviansk': ('diluviansk',),
'diluvianske': ('diluviansk',),
'diluvianskere': ('diluviansk',),
'diluvianskest': ('diluviansk',),
'diluvianskeste': ('diluviansk',),
'dim': ('dim',),
'dimme': ('dim',),
'dimmere': ('dim',),
'dimmest': ('dim',),
'dimmeste': ('dim',),
'dimt': ('dim',),
'dimensjonal': ('dimensjonal',),
'dimensjonale': ('dimensjonal',),
'dimensjonalere': ('dimensjonal',),
'dimensjonalest': ('dimensjonal',),
'dimensjonaleste': ('dimensjonal',),
'dimensjonalt': ('dimensjonal',),
'dimensjonerende': ('dimensjonere',),
'dimensjonert': ('dimensjonere',),
'dimensjonerte': ('dimensjonere',),
'diminutiv': ('diminutiv',),
'diminutive': ('diminutiv',),
'diminutivere': ('diminutiv',),
'diminutivest': ('diminutiv',),
'diminutiveste': ('diminutiv',),
'diminutivt': ('diminutiv',),
'dimitterende': ('dimittere',),
'dimittert': ('dimittere',),
'dimitterte': ('dimittere',),
'dimma': ('dimme',),
'dimmede': ('dimme',),
'dimmende': ('dimme',),
'dimmet': ('dimme',),
'dimmete': ('dimme',),
'dimma': ('dimme',),
'dimmede': ('dimme',),
'dimmende': ('dimme',),
'dimmet': ('dimme',),
'dimmete': ('dimme',),
'dimmende': ('dimme',),
'dimt': ('dimme',),
'dimte': ('dimme',),
'dimorf': ('dimorf',),
'dimorfe': ('dimorf',),
'dimorfere': ('dimorf',),
'dimorfest': ('dimorf',),
'dimorfeste': ('dimorf',),
'dimorft': ('dimorf',),
'dinerende': ('dinere',),
'dinert': ('dinere',),
'dinerte': ('dinere',),
'dingla': ('dingle',),
'dinglede': ('dingle',),
'dinglende': ('dingle',),
'dinglet': ('dingle',),
'dinglete': ('dingle',),
'dionysisk': ('dionysisk',),
'dionysiske': ('dionysisk',),
'dionysiskere': ('dionysisk',),
'dionysiskest': ('dionysisk',),
'dionysiskeste': ('dionysisk',),
'diploid': ('diploid',),
'diploide': ('diploid',),
'diploidere': ('diploid',),
'diploidest': ('diploid',),
'diploideste': ('diploid',),
'diplomatarisk': ('diplomatarisk',),
'diplomatariske': ('diplomatarisk',),
'diplomatariskere': ('diplomatarisk',),
'diplomatariskest': ('diplomatarisk',),
'diplomatariskeste': ('diplomatarisk',),
'diplomatisk': ('diplomatisk',),
'diplomatiske': ('diplomatisk',),
'diplomatiskere': ('diplomatisk',),
'diplomatiskest': ('diplomatisk',),
'diplomatiskeste': ('diplomatisk',),
'direkte': ('direkte',),
'direktekobla': ('direktekobla',),
'direktekoblede': ('direktekoblet',),
'direktekoblet': ('direktekoblet',),
'direktekoblete': ('direktekoblet',),
'direktekobletere': ('direktekoblet',),
'direktekobletest': ('direktekoblet',),
'direktekobleteste': ('direktekoblet',),
'direktekopla': ('direktekopla',),
'direktekoplede': ('direktekoplet',),
'direktekoplet': ('direktekoplet',),
'direktekoplete': ('direktekoplet',),
'direktekopletere': ('direktekoplet',),
'direktekopletest': ('direktekoplet',),
'direktekopleteste': ('direktekoplet',),
'direktiv': ('direktiv',),
'direktive': ('direktiv',),
'direktivere': ('direktiv',),
'direktivest': ('direktiv',),
'direktiveste': ('direktiv',),
'direktivt': ('direktiv',),
'dirigerende': ('dirigere',),
'dirigert': ('dirigere',),
'dirigerte': ('dirigere',),
'dirka': ('dirke',),
'dirkede': ('dirke',),
'dirkende': ('dirke',),
'dirket': ('dirke',),
'dirkete': ('dirke',),
'dirkefri': ('dirkefri',),
'dirkefrie': ('dirkefri',),
'dirkefriere': ('dirkefri',),
'dirkefriest': ('dirkefri',),
'dirkefrieste': ('dirkefri',),
'dirkefritt': ('dirkefri',),
'dirra': ('dirre',),
'dirrede': ('dirre',),
'dirrende': ('dirre',),
'dirret': ('dirre',),
'dirrete': ('dirre',),
'diset': ('diset',),
'disete': ('diset',),
'disetere': ('diset',),
'disetest': ('diset',),
'diseteste': ('diset',),
'disete': ('disete',),
'disharmonisk': ('disharmonisk',),
'disharmoniske': ('disharmonisk',),
'disharmoniskere': ('disharmonisk',),
'disharmoniskest': ('disharmonisk',),
'disharmoniskeste': ('disharmonisk',),
'disig': ('disig',),
'disige': ('disig',),
'disigere': ('disig',),
'disigst': ('disig',),
'disigste': ('disig',),
'disiplinerende': ('disiplinere',),
'disiplinert': ('disiplinere',),
'disiplinerte': ('disiplinere',),
'disiplinær': ('disiplinær',),
'disiplinære': ('disiplinær',),
'disiplinærere': ('disiplinær',),
'disiplinærest': ('disiplinær',),
'disiplinæreste': ('disiplinær',),
'disiplinært': ('disiplinær',),
'disjunktiv': ('disjunktiv',),
'disjunktive': ('disjunktiv',),
'disjunktivere': ('disjunktiv',),
'disjunktivest': ('disjunktiv',),
'disjunktiveste': ('disjunktiv',),
'disjunktivt': ('disjunktiv',),
'diska': ('diske',),
'diskede': ('diske',),
'diskende': ('diske',),
'disket': ('diske',),
'diskete': ('diske',),
'diska': ('diske',),
'diskede': ('diske',),
'diskende': ('diske',),
'disket': ('diske',),
'diskete': ('diske',),
'diskonterende': ('diskontere',),
'diskontert': ('diskontere',),
'diskonterte': ('diskontere',),
'diskontinuerlig': ('diskontinuerlig',),
'diskontinuerlige': ('diskontinuerlig',),
'diskontinuerligere': ('diskontinuerlig',),
'diskontinuerligst': ('diskontinuerlig',),
'diskontinuerligste': ('diskontinuerlig',),
'diskré': ('diskré',),
'diskrée': ('diskré',),
'diskréere': ('diskré',),
'diskréest': ('diskré',),
'diskréeste': ('diskré',),
'diskrediterende': ('diskreditere',),
'diskreditert': ('diskreditere',),
'diskrediterte': ('diskreditere',),
'diskret': ('diskret',),
'diskrete': ('diskret',),
'diskretere': ('diskret',),
'diskretest': ('diskret',),
'diskreteste': ('diskret',),
'diskriminerende': ('diskriminere',),
'diskriminert': ('diskriminere',),
'diskriminerte': ('diskriminere',),
'diskursiv': ('diskursiv',),
'diskursive': ('diskursiv',),
'diskursivere': ('diskursiv',),
'diskursivest': ('diskursiv',),
'diskursiveste': ('diskursiv',),
'diskursivt': ('diskursiv',),
'diskutabel': ('diskutabel',),
'diskutabelt': ('diskutabel',),
'diskutable': ('diskutabel',),
'diskutablere': ('diskutabel',),
'diskutablest': ('diskutabel',),
'diskutableste': ('diskutabel',),
'diskuterende': ('diskutere',),
'diskutert': ('diskutere',),
'diskuterte': ('diskutere',),
'diskvalifiserende': ('diskvalifisere',),
'diskvalifisert': ('diskvalifisere',),
'diskvalifiserte': ('diskvalifisere',),
'dispasjerende': ('dispasjere',),
'dispasjert': ('dispasjere',),
'dispasjerte': ('dispasjere',),
'dispenserende': ('dispensere',),
'dispensert': ('dispensere',),
'dispenserte': ('dispensere',),
'disponerende': ('disponere',),
'disponert': ('disponere',),
'disponerte': ('disponere',),
'disponibel': ('disponibel',),
'disponibelt': ('disponibel',),
'disponible': ('disponibel',),
'disponiblere': ('disponibel',),
'disponiblest': ('disponibel',),
'disponibleste': ('disponibel',),
'disputerende': ('disputere',),
'disputert': ('disputere',),
'disputerte': ('disputere',),
'dissa': ('disse',),
'dissede': ('disse',),
'dissende': ('disse',),
'disset': ('disse',),
'dissete': ('disse',),
'dissekerende': ('dissekere',),
'dissekert': ('dissekere',),
'dissekerte': ('dissekere',),
'dissenterende': ('dissentere',),
'dissentert': ('dissentere',),
'dissenterte': ('dissentere',),
'dissimilerende': ('dissimilere',),
'dissimilert': ('dissimilere',),
'dissimilerte': ('dissimilere',),
'dissonerende': ('dissonere',),
'dissonert': ('dissonere',),
'dissonerte': ('dissonere',),
'dissosierende': ('dissosiere',),
'dissosiert': ('dissosiere',),
'dissosierte': ('dissosiere',),
'distanserende': ('distansere',),
'distansert': ('distansere',),
'distanserte': ('distansere',),
'distingverende': ('distingvere',),
'distingvert': ('distingvere',),
'distingverte': ('distingvere',),
'distingvert': ('distingvert',),
'distingverte': ('distingvert',),
'distingvertere': ('distingvert',),
'distingvertest': ('distingvert',),
'distingverteste': ('distingvert',),
'distinkt': ('distinkt',),
'distinkte': ('distinkt',),
'distinktere': ('distinkt',),
'distinktest': ('distinkt',),
'distinkteste': ('distinkt',),
'distinktiv': ('distinktiv',),
'distinktive': ('distinktiv',),
'distinktivere': ('distinktiv',),
'distinktivest': ('distinktiv',),
'distinktiveste': ('distinktiv',),
'distinktivt': ('distinktiv',),
'distré': ('distré',),
'distrée': ('distré',),
'distréere': ('distré',),
'distréest': ('distré',),
'distréeste': ('distré',),
'distraherende': ('distrahere',),
'distrahert': ('distrahere',),
'distraherte': ('distrahere',),
'distribuerende': ('distribuere',),
'distribuert': ('distribuere',),
'distribuerte': ('distribuere',),
'distributiv': ('distributiv',),
'distributive': ('distributiv',),
'distributivere': ('distributiv',),
'distributivest': ('distributiv',),
'distributiveste': ('distributiv',),
'distributivt': ('distributiv',),
'divergent': ('divergent',),
'divergente': ('divergent',),
'divergentere': ('divergent',),
'divergentest': ('divergent',),
'divergenteste': ('divergent',),
'divergerende': ('divergere',),
'divergert': ('divergere',),
'divergerte': ('divergere',),
'diverse': ('diverse',),
'diverterende': ('divertere',),
'divertert': ('divertere',),
'diverterte': ('divertere',),
'dividerende': ('dividere',),
'dividert': ('dividere',),
'dividerte': ('dividere',),
'diøcisk': ('diøcisk',),
'diøciske': ('diøcisk',),
'diøciskere': ('diøcisk',),
'diøciskest': ('diøcisk',),
'diøciskeste': ('diøcisk',),
'djerv': ('djerv',),
'djerve': ('djerv',),
'djervere': ('djerv',),
'djervest': ('djerv',),
'djerveste': ('djerv',),
'djervt': ('djerv',),
'djevelsk': ('djevelsk',),
'djevelske': ('djevelsk',),
'djevelskere': ('djevelsk',),
'djevelskest': ('djevelsk',),
'djevelskeste': ('djevelsk',),
'djevla': ('djevla',),
'djevlebesatt': ('djevlebesatt',),
'djevlebesatte': ('djevlebesatt',),
'djevlebesattere': ('djevlebesatt',),
'djevlebesattest': ('djevlebesatt',),
'djevlebesatteste': ('djevlebesatt',),
'djevlig': ('djevlig',),
'djevlige': ('djevlig',),
'djevligere': ('djevlig',),
'djevligst': ('djevlig',),
'djevligste': ('djevlig',),
'djiboutisk': ('djiboutisk',),
'djiboutiske': ('djiboutisk',),
'djiboutiskere': ('djiboutisk',),
'djiboutiskest': ('djiboutisk',),
'djiboutiskeste': ('djiboutisk',),
'djup': ('djup',),
'djupe': ('djup',),
'djupere': ('djup',),
'djupest': ('djup',),
'djupeste': ('djup',),
'djupt': ('djup',),
'djupblå': ('djupblå',),
'djupblåe': ('djupblå',),
'djupblåere': ('djupblå',),
'djupblåest': ('djupblå',),
'djupblåeste': ('djupblå',),
'djupblått': ('djupblå',),
'djuperegående': ('djuperegående',),
'djupereliggende': ('djupereliggende',),
'djupetsa': ('djupetse',),
'djupetsede': ('djupetse',),
'djupetsende': ('djupetse',),
'djupetset': ('djupetse',),
'djupetsete': ('djupetse',),
'djupfrysende': ('djupfryse',),
'djupfryst': ('djupfryse',),
'djupfryste': ('djupfryse',),
'djupfølt': ('djupfølt',),
'djupfølte': ('djupfølt',),
'djupføltere': ('djupfølt',),
'djupføltest': ('djupfølt',),
'djupfølteste': ('djupfølt',),
'djuplendt': ('djuplendt',),
'djuplendte': ('djuplendt',),
'djuplendtere': ('djuplendt',),
'djuplendtest': ('djuplendt',),
'djuplendteste': ('djuplendt',),
'djupna': ('djupne',),
'djupnede': ('djupne',),
'djupnende': ('djupne',),
'djupnet': ('djupne',),
'djupnete': ('djupne',),
'djuprød': ('djuprød',),
'djuprøde': ('djuprød',),
'djuprødere': ('djuprød',),
'djuprødest': ('djuprød',),
'djuprødeste': ('djuprød',),
'djuprødt': ('djuprød',),
'djupsindig': ('djupsindig',),
'djupsindige': ('djupsindig',),
'djupsindigere': ('djupsindig',),
'djupsindigst': ('djupsindig',),
'djupsindigste': ('djupsindig',),
'djuptfølt': ('djuptfølt',),
'djuptfølte': ('djuptfølt',),
'djuptføltere': ('djuptfølt',),
'djuptføltest': ('djuptfølt',),
'djuptfølteste': ('djuptfølt',),
'djuptgripende': ('djuptgripende',),
'djuptgående': ('djuptgående',),
'djuptloddende': ('djuptloddende',),
'djupttenkende': ('djupttenkende',),
'dobbel': ('dobbel',),
'dobbelt': ('dobbel',),
'doble': ('dobbel',),
'doblere': ('dobbel',),
'doblest': ('dobbel',),
'dobleste': ('dobbel',),
'dobbelt': ('dobbelt',),
'dobbelte': ('dobbelt',),
'dobbeltere': ('dobbelt',),
'dobbeltest': ('dobbelt',),
'dobbelteste': ('dobbelt',),
'dobbeltarbeidende': ('dobbeltarbeidende',),
'dobbeltbotna': ('dobbeltbotna',),
'dobbeltbotnede': ('dobbeltbotnet',),
'dobbeltbotnet': ('dobbeltbotnet',),
'dobbeltbotnete': ('dobbeltbotnet',),
'dobbeltbotnetere': ('dobbeltbotnet',),
'dobbeltbotnetest': ('dobbeltbotnet',),
'dobbeltbotneteste': ('dobbeltbotnet',),
'dobbeltbunna': ('dobbeltbunna',),
'dobbeltbunnede': ('dobbeltbunnet',),
'dobbeltbunnet': ('dobbeltbunnet',),
'dobbeltbunnete': ('dobbeltbunnet',),
'dobbeltbunnetere': ('dobbeltbunnet',),
'dobbeltbunnetest': ('dobbeltbunnet',),
'dobbeltbunneteste': ('dobbeltbunnet',),
'dobbeltknappa': ('dobbeltknappa',),
'dobbeltknappede': ('dobbeltknappet',),
'dobbeltknappet': ('dobbeltknappet',),
'dobbeltknappete': ('dobbeltknappet',),
'dobbeltknappetere': ('dobbeltknappet',),
'dobbeltknappetest': ('dobbeltknappet',),
'dobbeltknappeteste': ('dobbeltknappet',),
'dobbeltrensa': ('dobbeltrensa',),
'dobbeltrensede': ('dobbeltrenset',),
'dobbeltrenset': ('dobbeltrenset',),
'dobbeltrensete': ('dobbeltrenset',),
'dobbeltrensetere': ('dobbeltrenset',),
'dobbeltrensetest': ('dobbeltrenset',),
'dobbeltrenseteste': ('dobbeltrenset',),
'dobbeltsidig': ('dobbeltsidig',),
'dobbeltsidige': ('dobbeltsidig',),
'dobbeltsidigere': ('dobbeltsidig',),
'dobbeltsidigst': ('dobbeltsidig',),
'dobbeltsidigste': ('dobbeltsidig',),
'dobbeltspora': ('dobbeltspora',),
'dobbeltsporede': ('dobbeltsporet',),
'dobbeltsporet': ('dobbeltsporet',),
'dobbeltsporete': ('dobbeltsporet',),
'dobbeltsporetere': ('dobbeltsporet',),
'dobbeltsporetest': ('dobbeltsporet',),
'dobbeltsporeteste': ('dobbeltsporet',),
'dobla': ('doble',),
'doblede': ('doble',),
'doblende': ('doble',),
'doblet': ('doble',),
'doblete': ('doble',),
'dogga': ('dogge',),
'doggede': ('dogge',),
'doggende': ('dogge',),
'dogget': ('dogge',),
'doggete': ('dogge',),
'dogga': ('dogge',),
'doggede': ('dogge',),
'doggende': ('dogge',),
'dogget': ('dogge',),
'doggete': ('dogge',),
'dogget': ('dogget',),
'doggete': ('dogget',),
'doggetere': ('dogget',),
'doggetest': ('dogget',),
'doggeteste': ('dogget',),
'doggete': ('doggete',),
'doggfri': ('doggfri',),
'doggfrie': ('doggfri',),
'doggfriere': ('doggfri',),
'doggfriest': ('doggfri',),
'doggfrieste': ('doggfri',),
'doggfritt': ('doggfri',),
'doggfrisk': ('doggfrisk',),
'doggfriske': ('doggfrisk',),
'doggfriskere': ('doggfrisk',),
'doggfriskest': ('doggfrisk',),
'doggfriskeste': ('doggfrisk',),
'doggfriskt': ('doggfrisk',),
'doggvåt': ('doggvåt',),
'doggvåte': ('doggvåt',),
'doggvåtere': ('doggvåt',),
'doggvåtest': ('doggvåt',),
'doggvåteste': ('doggvåt',),
'doggvått': ('doggvåt',),
'dogmatisk': ('dogmatisk',),
'dogmatiske': ('dogmatisk',),
'dogmatiskere': ('dogmatisk',),
'dogmatiskest': ('dogmatisk',),
'dogmatiskeste': ('dogmatisk',),
'dokka': ('dokke',),
'dokkede': ('dokke',),
'dokkende': ('dokke',),
'dokket': ('dokke',),
'dokkete': ('dokke',),
'dokkeaktig': ('dokkeaktig',),
'dokkeaktige': ('dokkeaktig',),
'dokkeaktigere': ('dokkeaktig',),
'dokkeaktigst': ('dokkeaktig',),
'dokkeaktigste': ('dokkeaktig',),
'dokksatt': ('dokksette',),
'dokksatte': ('dokksette',),
'dokksettende': ('dokksette',),
'doktorerende': ('doktorere',),
'doktorert': ('doktorere',),
'doktorerte': ('doktorere',),
'doktrinær': ('doktrinær',),
'doktrinære': ('doktrinær',),
'doktrinærere': ('doktrinær',),
'doktrinærest': ('doktrinær',),
'doktrinæreste': ('doktrinær',),
'doktrinært': ('doktrinær',),
'dokumentarisk': ('dokumentarisk',),
'dokumentariske': ('dokumentarisk',),
'dokumentariskere': ('dokumentarisk',),
'dokumentariskest': ('dokumentarisk',),
'dokumentariskeste': ('dokumentarisk',),
'dokumenterende': ('dokumentere',),
'dokumentert': ('dokumentere',),
'dokumenterte': ('dokumentere',),
'dolka': ('dolke',),
'dolkede': ('dolke',),
'dolkende': ('dolke',),
'dolket': ('dolke',),
'dolkete': ('dolke',),
'domfellende': ('domfelle',),
'domfelt': ('domfelle',),
'domfelte': ('domfelle',),
'dominant': ('dominant',),
'dominante': ('dominant',),
'dominantere': ('dominant',),
'dominantest': ('dominant',),
'dominanteste': ('dominant',),
'dominerende': ('dominere',),
'dominert': ('dominere',),
'dominerte': ('dominere',),
'dominerende': ('dominerende',),
'dominikansk': ('dominikansk',),
'dominikanske': ('dominikansk',),
'dominikanskere': ('dominikansk',),
'dominikanskest': ('dominikansk',),
'dominikanskeste': ('dominikansk',),
'dominikisk': ('dominikisk',),
'dominikiske': ('dominikisk',),
'dominikiskere': ('dominikisk',),
'dominikiskest': ('dominikisk',),
'dominikiskeste': ('dominikisk',),
'domisilierende': ('domisiliere',),
'domisiliert': ('domisiliere',),
'domisilierte': ('domisiliere',),
'donerende': ('donere',),
'donert': ('donere',),
'donerte': ('donere',),
'dopa': ('dope',),
'dopede': ('dope',),
'dopende': ('dope',),
'dopet': ('dope',),
'dopete': ('dope',),
'dora': ('dore',),
'dorede': ('dore',),
'dorende': ('dore',),
'doret': ('dore',),
'dorete': ('dore',),
'dort': ('dore',),
'dorte': ('dore',),
'dorga': ('dorge',),
'dorgede': ('dorge',),
'dorgende': ('dorge',),
'dorget': ('dorge',),
'dorgete': ('dorge',),
'dorisk': ('dorisk',),
'doriske': ('dorisk',),
'doriskere': ('dorisk',),
'doriskest': ('dorisk',),
'doriskeste': ('dorisk',),
'dorma': ('dorme',),
'dormede': ('dorme',),
'dormende': ('dorme',),
'dormet': ('dorme',),
'dormete': ('dorme',),
'dorsal': ('dorsal',),
'dorsale': ('dorsal',),
'dorsalere': ('dorsal',),
'dorsalest': ('dorsal',),
'dorsaleste': ('dorsal',),
'dorsalt': ('dorsal',),
'dorsk': ('dorsk',),
'dorske': ('dorsk',),
'dorskere': ('dorsk',),
'dorskest': ('dorsk',),
'dorskeste': ('dorsk',),
'dorskt': ('dorsk',),
'doserende': ('dosere',),
'dosert': ('dosere',),
'doserte': ('dosere',),
'doserende': ('dosere',),
'dosert': ('dosere',),
'doserte': ('dosere',),
'dosserende': ('dossere',),
'dossert': ('dossere',),
'dosserte': ('dossere',),
'doterende': ('dotere',),
'dotert': ('dotere',),
'doterte': ('dotere',),
'dottet': ('dottet',),
'dottete': ('dottet',),
'dottetere': ('dottet',),
'dottetest': ('dottet',),
'dotteteste': ('dottet',),
'dottete': ('dottete',),
'dov': ('dov',),
'dove': ('dov',),
'dovere': ('dov',),
'dovest': ('dov',),
'doveste': ('dov',),
'dovt': ('dov',),
'doven': ('doven',),
'dovent': ('doven',),
'dovne': ('doven',),
'dovnere': ('doven',),
'dovnest': ('doven',),
'dovneste': ('doven',),
'dovna': ('dovne',),
'dovnede': ('dovne',),
'dovnende': ('dovne',),
'dovnet': ('dovne',),
'dovnete': ('dovne',),
'dradd': ('dra',),
'dradde': ('dra',),
'dragende': ('dra',),
'dratt': ('dra',),
'dratte': ('dra',),
'drabelig': ('drabelig',),
'drabelige': ('drabelig',),
'drabeligere': ('drabelig',),
'drabeligst': ('drabelig',),
'drabeligste': ('drabelig',),
'dradd': ('drage',),
'dradde': ('drage',),
'dragende': ('drage',),
'dratt': ('drage',),
'dratte': ('drage',),
'dradd': ('drage',),
'dradde': ('drage',),
'dragende': ('drage',),
'dratt': ('drage',),
'dratte': ('drage',),
'dragen': ('dragen',),
'draget': ('dragen',),
'dragne': ('dragen',),
'dragnere': ('dragen',),
'dragnest': ('dragen',),
'dragneste': ('dragen',),
'dragende': ('dragende',),
'dragsa': ('dragse',),
'dragsede': ('dragse',),
'dragsende': ('dragse',),
'dragset': ('dragse',),
'dragsete': ('dragse',),
'drakonisk': ('drakonisk',),
'drakoniske': ('drakonisk',),
'drakoniskere': ('drakonisk',),
'drakoniskest': ('drakonisk',),
'drakoniskeste': ('drakonisk',),
'dramatiserende': ('dramatisere',),
'dramatisert': ('dramatisere',),
'dramatiserte': ('dramatisere',),
'dramatisk': ('dramatisk',),
'dramatiske': ('dramatisk',),
'dramatiskere': ('dramatisk',),
'dramatiskest': ('dramatisk',),
'dramatiskeste': ('dramatisk',),
'dramaturgisk': ('dramaturgisk',),
'dramaturgiske': ('dramaturgisk',),
'dramaturgiskere': ('dramaturgisk',),
'dramaturgiskest': ('dramaturgisk',),
'dramaturgiskeste': ('dramaturgisk',),
'draperende': ('drapere',),
'drapert': ('drapere',),
'draperte': ('drapere',),
'drapsmistenkt': ('drapsmistenkt',),
'drapsmistenkte': ('drapsmistenkt',),
'drapsmistenktere': ('drapsmistenkt',),
'drapsmistenktest': ('drapsmistenkt',),
'drapsmistenkteste': ('drapsmistenkt',),
'drasjerende': ('drasjere',),
'drasjert': ('drasjere',),
'drasjerte': ('drasjere',),
'drassa': ('drasse',),
'drassede': ('drasse',),
'drassende': ('drasse',),
'drasset': ('drasse',),
'drassete': ('drasse',),
'drastisk': ('drastisk',),
'drastiske': ('drastisk',),
'drastiskere': ('drastisk',),
'drastiskest': ('drastisk',),
'drastiskeste': ('drastisk',),
'dratta': ('dratte',),
'drattede': ('dratte',),
'drattende': ('dratte',),
'drattet': ('dratte',),
'drattete': ('dratte',),
'draugbleik': ('draugbleik',),
'draugbleike': ('draugbleik',),
'draugbleikere': ('draugbleik',),
'draugbleikest': ('draugbleik',),
'draugbleikeste': ('draugbleik',),
'draugbleikt': ('draugbleik',),
'draugblek': ('draugblek',),
'draugbleke': ('draugblek',),
'draugblekere': ('draugblek',),
'draugblekest': ('draugblek',),
'draugblekeste': ('draugblek',),
'draugblekt': ('draugblek',),
'dravidisk': ('dravidisk',),
'dravidiske': ('dravidisk',),
'dravidiskere': ('dravidisk',),
'dravidiskest': ('dravidisk',),
'dravidiskeste': ('dravidisk',),
'dregga': ('dregge',),
'dreggede': ('dregge',),
'dreggende': ('dregge',),
'dregget': ('dregge',),
'dreggete': ('dregge',),
'dreibar': ('dreibar',),
'dreibare': ('dreibar',),
'dreibarere': ('dreibar',),
'dreibarest': ('dreibar',),
'dreibareste': ('dreibar',),
'dreibart': ('dreibar',),
'dreia': ('dreie',),
'dreid': ('dreie',),
'dreidd': ('dreie',),
'dreidde': ('dreie',),
'dreide': ('dreie',),
'dreiede': ('dreie',),
'dreiende': ('dreie',),
'dreiet': ('dreie',),
'dreiete': ('dreie',),
'dreielig': ('dreielig',),
'dreielige': ('dreielig',),
'dreieligere': ('dreielig',),
'dreieligst': ('dreielig',),
'dreieligste': ('dreielig',),
'dreisende': ('dreise',),
'dreist': ('dreise',),
'dreiste': ('dreise',),
'drektig': ('drektig',),
'drektige': ('drektig',),
'drektigere': ('drektig',),
'drektigst': ('drektig',),
'drektigste': ('drektig',),
'drenende': ('drene',),
'drent': ('drene',),
'drente': ('drene',),
'drenerende': ('drenere',),
'drenert': ('drenere',),
'drenerte': ('drenere',),
'drepende': ('drepe',),
'drept': ('drepe',),
'drepte': ('drepe',),
'drepende': ('drepende',),
'dressa': ('dresse',),
'dressede': ('dresse',),
'dressende': ('dresse',),
'dresset': ('dresse',),
'dressete': ('dresse',),
'dresserende': ('dressere',),
'dressert': ('dressere',),
'dresserte': ('dressere',),
'dretta': ('drette',),
'drettede': ('drette',),
'drettende': ('drette',),
'drettet': ('drette',),
'drettete': ('drette',),
'dreven': ('dreven',),
'drevent': ('dreven',),
'drevne': ('dreven',),
'drevnere': ('dreven',),
'drevnest': ('dreven',),
'drevneste': ('dreven',),
'driblete': ('drible',),
'dribla': ('drible',),
'driblede': ('drible',),
'driblende': ('drible',),
'driblet': ('drible',),
'drifta': ('drifte',),
'driftede': ('drifte',),
'driftende': ('drifte',),
'driftet': ('drifte',),
'driftete': ('drifte',),
'driftig': ('driftig',),
'driftige': ('driftig',),
'driftigere': ('driftig',),
'driftigst': ('driftig',),
'driftigste': ('driftig',),
'driftsmessig': ('driftsmessig',),
'driftsmessige': ('driftsmessig',),
'driftsmessigere': ('driftsmessig',),
'driftsmessigst': ('driftsmessig',),
'driftsmessigste': ('driftsmessig',),
'driftssikker': ('driftssikker',),
'driftssikkert': ('driftssikker',),
'driftssikre': ('driftssikker',),
'driftssikrere': ('driftssikker',),
'driftssikrest': ('driftssikker',),
'driftssikreste': ('driftssikker',),
'drikkende': ('drikke',),
'drukken': ('drikke',),
'drukket': ('drikke',),
'drukne': ('drikke',),
'drikkelig': ('drikkelig',),
'drikkelige': ('drikkelig',),
'drikkeligere': ('drikkelig',),
'drikkeligst': ('drikkelig',),
'drikkeligste': ('drikkelig',),
'drikkfeldig': ('drikkfeldig',),
'drikkfeldige': ('drikkfeldig',),
'drikkfeldigere': ('drikkfeldig',),
'drikkfeldigst': ('drikkfeldig',),
'drikkfeldigste': ('drikkfeldig',),
'drilla': ('drille',),
'drillede': ('drille',),
'drillende': ('drille',),
'drillet': ('drille',),
'drillete': ('drille',),
'drilla': ('drille',),
'drillede': ('drille',),
'drillende': ('drille',),
'drillet': ('drille',),
'drillete': ('drille',),
'drilt': ('drille',),
'drilte': ('drille',),
'drilla': ('drille',),
'drillede': ('drille',),
'drillende': ('drille',),
'drillet': ('drille',),
'drillete': ('drille',),
'drilt': ('drille',),
'drilte': ('drille',),
'drilla': ('drille',),
'drillede': ('drille',),
'drillende': ('drille',),
'drillet': ('drille',),
'drillete': ('drille',),
'drilt': ('drille',),
'drilte': ('drille',),
'drista': ('driste',),
'dristede': ('driste',),
'dristende': ('driste',),
'dristet': ('driste',),
'dristete': ('driste',),
'dristig': ('dristig',),
'dristige': ('dristig',),
'dristigere': ('dristig',),
'dristigst': ('dristig',),
'dristigste': ('dristig',),
'driten': ('drite',),
'dritende': ('drite',),
'dritet': ('drite',),
'dritne': ('drite',),
'dritt': ('drite',),
'dritte': ('drite',),
'drittlei': ('drittlei',),
'drittleie': ('drittlei',),
'drittleiere': ('drittlei',),
'drittleiest': ('drittlei',),
'drittleieste': ('drittlei',),
'drittleit': ('drittlei',),
'dreven': ('drive',),
'drevet': ('drive',),
'drevne': ('drive',),
'drivende': ('drive',),
'drivende': ('drivende',),
'drivendes': ('drivendes',),
'drivhvit': ('drivhvit',),
'drivhvite': ('drivhvit',),
'drivhvitere': ('drivhvit',),
'drivhvitest': ('drivhvit',),
'drivhviteste': ('drivhvit',),
'drivhvitt': ('drivhvit',),
'drivkvit': ('drivkvit',),
'drivkvite': ('drivkvit',),
'drivkvitere': ('drivkvit',),
'drivkvitest': ('drivkvit',),
'drivkviteste': ('drivkvit',),
'drivkvitt': ('drivkvit',),
'drivverdig': ('drivverdig',),
'drivverdige': ('drivverdig',),
'drivverdigere': ('drivverdig',),
'drivverdigst': ('drivverdig',),
'drivverdigste': ('drivverdig',),
'drivvåt': ('drivvåt',),
'drivvåte': ('drivvåt',),
'drivvåtere': ('drivvåt',),
'drivvåtest': ('drivvåt',),
'drivvåteste': ('drivvåt',),
'drivvått': ('drivvåt',),
'drodla': ('drodle',),
'drodlede': ('drodle',),
'drodlende': ('drodle',),
'drodlet': ('drodle',),
'drodlete': ('drodle',),
'droplet': ('droplet',),
'droplete': ('droplet',),
'dropletere': ('droplet',),
'dropletest': ('droplet',),
'dropleteste': ('droplet',),
'droplete': ('droplete',),
'droppa': ('droppe',),
'droppede': ('droppe',),
'droppende': ('droppe',),
'droppet': ('droppe',),
'droppete': ('droppe',),
'drukken': ('drukken',),
'drukkent': ('drukken',),
'drukne': ('drukken',),
'druknere': ('drukken',),
'druknest': ('drukken',),
'drukneste': ('drukken',),
'drukna': ('drukne',),
'druknede': ('drukne',),
'druknende': ('drukne',),
'druknet': ('drukne',),
'druknete': ('drukne',),
'drusisk': ('drusisk',),
'drusiske': ('drusisk',),
'drusiskere': ('drusisk',),
'drusiskest': ('drusisk',),
'drusiskeste': ('drusisk',),
'dry': ('dry',),
'dryg': ('dryg',),
'dryge': ('dryg',),
'drygere': ('dryg',),
'drygest': ('dryg',),
'drygeste': ('dryg',),
'drygt': ('dryg',),
'drygd': ('dryge',),
'drygde': ('dryge',),
'drygende': ('dryge',),
'dryppa': ('dryppe',),
'dryppede': ('dryppe',),
'dryppende': ('dryppe',),
'dryppet': ('dryppe',),
'dryppete': ('dryppe',),
'drypt': ('dryppe',),
'drypte': ('dryppe',),
'dryppefri': ('dryppefri',),
'dryppefrie': ('dryppefri',),
'dryppefriere': ('dryppefri',),
'dryppefriest': ('dryppefri',),
'dryppefrieste': ('dryppefri',),
'dryppefritt': ('dryppefri',),
'dryppfri': ('dryppfri',),
'dryppfrie': ('dryppfri',),
'dryppfriere': ('dryppfri',),
'dryppfriest': ('dryppfri',),
'dryppfrieste': ('dryppfri',),
'dryppfritt': ('dryppfri',),
'drypptørka': ('drypptørke',),
'drypptørkede': ('drypptørke',),
'drypptørkende': ('drypptørke',),
'drypptørket': ('drypptørke',),
'drypptørkete': ('drypptørke',),
'drypptørra': ('drypptørre',),
'drypptørrede': ('drypptørre',),
'drypptørrende': ('drypptørre',),
'drypptørret': ('drypptørre',),
'drypptørrete': ('drypptørre',),
'dryppvåt': ('dryppvåt',),
'dryppvåte': ('dryppvåt',),
'dryppvåtere': ('dryppvåt',),
'dryppvåtest': ('dryppvåt',),
'dryppvåteste': ('dryppvåt',),
'dryppvått': ('dryppvåt',),
'dryssa': ('drysse',),
'dryssede': ('drysse',),
'dryssende': ('drysse',),
'drysset': ('drysse',),
'dryssete': ('drysse',),
'dryst': ('drysse',),
'dryste': ('drysse',),
'dråpeforma': ('dråpeforma',),
'dråpeformede': ('dråpeformet',),
'dråpeformet': ('dråpeformet',),
'dråpeformete': ('dråpeformet',),
'dråpeformetere': ('dråpeformet',),
'dråpeformetest': ('dråpeformet',),
'dråpeformeteste': ('dråpeformet',),
'drøfta': ('drøfte',),
'drøftede': ('drøfte',),
'drøftende': ('drøfte',),
'drøftet': ('drøfte',),
'drøftete': ('drøfte',),
'drømmende': ('drømme',),
'drømt': ('drømme',),
'drømte': ('drømme',),
'drømmende': ('drømmende',),
'drønna': ('drønne',),
'drønnede': ('drønne',),
'drønnende': ('drønne',),
'drønnet': ('drønne',),
'drønnete': ('drønne',),
'drønt': ('drønne',),
'drønte': ('drønne',),
'drøsende': ('drøse',),
'drøst': ('drøse',),
'drøste': ('drøse',),
'drøvtygd': ('drøvtygge',),
'drøvtygde': ('drøvtygge',),
'drøvtyggede': ('drøvtygge',),
'drøvtyggende': ('drøvtygge',),
'drøvtygget': ('drøvtygge',),
'drøvtyggete': ('drøvtygge',),
'drøy': ('drøy',),
'drøye': ('drøy',),
'drøyere': ('drøy',),
'drøyest': ('drøy',),
'drøyeste': ('drøy',),
'drøyt': ('drøy',),
'drøyd': ('drøye',),
'drøyde': ('drøye',),
'drøyende': ('drøye',),
'dualistisk': ('dualistisk',),
'dualistiske': ('dualistisk',),
'dualistiskere': ('dualistisk',),
'dualistiskest': ('dualistisk',),
'dualistiskeste': ('dualistisk',),
'dubba': ('dubbe',),
'dubbede': ('dubbe',),
'dubbende': ('dubbe',),
'dubbet': ('dubbe',),
'dubbete': ('dubbe',),
'dubba': ('dubbe',),
'dubbede': ('dubbe',),
'dubbende': ('dubbe',),
'dubbet': ('dubbe',),
'dubbete': ('dubbe',),
'dubiøs': ('dubiøs',),
'dubiøse': ('dubiøs',),
'dubiøsere': ('dubiøs',),
'dubiøsest': ('dubiøs',),
'dubiøseste': ('dubiøs',),
'dubiøst': ('dubiøs',),
'dublerende': ('dublere',),
'dublert': ('dublere',),
'dublerte': ('dublere',),
'dueblå': ('dueblå',),
'dueblåe': ('dueblå',),
'dueblåere': ('dueblå',),
'dueblåest': ('dueblå',),
'dueblåeste': ('dueblå',),
'dueblått': ('dueblå',),
'duellerende': ('duellere',),
'duellert': ('duellere',),
'duellerte': ('duellere',),
'dufta': ('dufte',),
'duftede': ('dufte',),
'duftende': ('dufte',),
'duftet': ('dufte',),
'duftete': ('dufte',),
'dugd': ('duge',),
'dugde': ('duge',),
'dugende': ('duge',),
'dugelig': ('dugelig',),
'dugelige': ('dugelig',),
'dugeligere': ('dugelig',),
'dugeligst': ('dugelig',),
'dugeligste': ('dugelig',),
'dugga': ('dugge',),
'duggede': ('dugge',),
'duggende': ('dugge',),
'dugget': ('dugge',),
'duggete': ('dugge',),
'dugget': ('dugget',),
'duggete': ('dugget',),
'duggetere': ('dugget',),
'duggetest': ('dugget',),
'duggeteste': ('dugget',),
'duggete': ('duggete',),
'duggfri': ('duggfri',),
'duggfrie': ('duggfri',),
'duggfriere': ('duggfri',),
'duggfriest': ('duggfri',),
'duggfrieste': ('duggfri',),
'duggfritt': ('duggfri',),
'duggfrisk': ('duggfrisk',),
'duggfriske': ('duggfrisk',),
'duggfriskere': ('duggfrisk',),
'duggfriskest': ('duggfrisk',),
'duggfriskeste': ('duggfrisk',),
'duggfriskt': ('duggfrisk',),
'duggvåt': ('duggvåt',),
'duggvåte': ('duggvåt',),
'duggvåtere': ('duggvåt',),
'duggvåtest': ('duggvåt',),
'duggvåteste': ('duggvåt',),
'duggvått': ('duggvåt',),
'duka': ('duke',),
'dukede': ('duke',),
'dukende': ('duke',),
'duket': ('duke',),
'dukete': ('duke',),
'dukka': ('dukke',),
'dukkede': ('dukke',),
'dukkende': ('dukke',),
'dukket': ('dukke',),
'dukkete': ('dukke',),
'dukkeaktig': ('dukkeaktig',),
'dukkeaktige': ('dukkeaktig',),
'dukkeaktigere': ('dukkeaktig',),
'dukkeaktigst': ('dukkeaktig',),
'dukkeaktigste': ('dukkeaktig',),
'dukknakka': ('dukknakka',),
'dukknakkede': ('dukknakket',),
'dukknakket': ('dukknakket',),
'dukknakkete': ('dukknakket',),
'dukknakketere': ('dukknakket',),
'dukknakketest': ('dukknakket',),
'dukknakketeste': ('dukknakket',),
'dulgt': ('dulgt',),
'dulgte': ('dulgt',),
'dulgtere': ('dulgt',),
'dulgtest': ('dulgt',),
'dulgteste': ('dulgt',),
'dulla': ('dulle',),
'dullede': ('dulle',),
'dullende': ('dulle',),
'dullet': ('dulle',),
'dullete': ('dulle',),
'dulma': ('dulme',),
'dulmede': ('dulme',),
'dulmende': ('dulme',),
'dulmet': ('dulme',),
'dulmete': ('dulme',),
'dulta': ('dulte',),
'dultede': ('dulte',),
'dultende': ('dulte',),
'dultet': ('dulte',),
'dultete': ('dulte',),
'dum': ('dum',),
'dumme': ('dum',),
'dummere': ('dum',),
'dummest': ('dum',),
'dummeste': ('dum',),
'dumt': ('dum',),
'dumdristig': ('dumdristig',),
'dumdristige': ('dumdristig',),
'dumdristigere': ('dumdristig',),
'dumdristigst': ('dumdristig',),
'dumdristigste': ('dumdristig',),
'dumma': ('dumme',),
'dummede': ('dumme',),
'dummende': ('dumme',),
'dummet': ('dumme',),
'dummete': ('dumme',),
'dump': ('dump',),
'dumpe': ('dump',),
'dumpere': ('dump',),
'dumpest': ('dump',),
'dumpeste': ('dump',),
'dumpt': ('dump',),
'dumpa': ('dumpe',),
'dumpede': ('dumpe',),
'dumpende': ('dumpe',),
'dumpet': ('dumpe',),
'dumpete': ('dumpe',),
'dumpa': ('dumpe',),
'dumpede': ('dumpe',),
'dumpende': ('dumpe',),
'dumpet': ('dumpe',),
'dumpete': ('dumpe',),
'dumpet': ('dumpet',),
'dumpete': ('dumpet',),
'dumpetere': ('dumpet',),
'dumpetest': ('dumpet',),
'dumpeteste': ('dumpet',),
'dumpete': ('dumpete',),
'dumsnill': ('dumsnill',),
'dumsnille': ('dumsnill',),
'dumsnillere': ('dumsnill',),
'dumsnillest': ('dumsnill',),
'dumsnilleste': ('dumsnill',),
'dumsnilt': ('dumsnill',),
'dumstolt': ('dumstolt',),
'dumstolte': ('dumstolt',),
'dumstoltere': ('dumstolt',),
'dumstoltest': ('dumstolt',),
'dumstolteste': ('dumstolt',),
'dunbløt': ('dunbløt',),
'dunbløte': ('dunbløt',),
'dunbløtere': ('dunbløt',),
'dunbløtest': ('dunbløt',),
'dunbløteste': ('dunbløt',),
'dunbløtt': ('dunbløt',),
'dundra': ('dundre',),
'dundrede': ('dundre',),
'dundrende': ('dundre',),
'dundret': ('dundre',),
'dundrete': ('dundre',),
'dundrende': ('dundrende',),
'dunet': ('dunet',),
'dunete': ('dunet',),
'dunetere': ('dunet',),
'dunetest': ('dunet',),
'duneteste': ('dunet',),
'dunete': ('dunete',),
'dunga': ('dunge',),
'dungede': ('dunge',),
'dungende': ('dunge',),
'dunget': ('dunge',),
'dungete': ('dunge',),
'dunhåra': ('dunhåra',),
'dunhårede': ('dunhåret',),
'dunhåret': ('dunhåret',),
'dunhårete': ('dunhåret',),
'dunhåretere': ('dunhåret',),
'dunhåretest': ('dunhåret',),
'dunhåreteste': ('dunhåret',),
'dunka': ('dunke',),
'dunkede': ('dunke',),
'dunkende': ('dunke',),
'dunket': ('dunke',),
'dunkete': ('dunke',),
'dunkel': ('dunkel',),
'dunkelt': ('dunkel',),
'dunkle': ('dunkel',),
'dunklere': ('dunkel',),
'dunklest': ('dunkel',),
'dunkleste': ('dunkel',),
'dunkledd': ('dunkledd',),
'dunkledde': ('dunkledd',),
'dunkleddere': ('dunkledd',),
'dunkleddest': ('dunkledd',),
'dunkleddeste': ('dunkledd',),
'dunlett': ('dunlett',),
'dunlette': ('dunlett',),
'dunlettere': ('dunlett',),
'dunlettest': ('dunlett',),
'dunletteste': ('dunlett',),
'dunsta': ('dunste',),
'dunstede': ('dunste',),
'dunstende': ('dunste',),
'dunstet': ('dunste',),
'dunstete': ('dunste',),
'duperende': ('dupere',),
'dupert': ('dupere',),
'duperte': ('dupere',),
'dupliserende': ('duplisere',),
'duplisert': ('duplisere',),
'dupliserte': ('duplisere',),
'duppa': ('duppe',),
'duppede': ('duppe',),
'duppende': ('duppe',),
'duppet': ('duppe',),
'duppete': ('duppe',),
'durabel': ('durabel',),
'durabelt': ('durabel',),
'durable': ('durabel',),
'durablere': ('durabel',),
'durablest': ('durabel',),
'durableste': ('durabel',),
'durabelig': ('durabelig',),
'durabelige': ('durabelig',),
'durabeligere': ('durabelig',),
'durabeligst': ('durabelig',),
'durabeligste': ('durabelig',),
'durativ': ('durativ',),
'durative': ('durativ',),
'durativere': ('durativ',),
'durativest': ('durativ',),
'durativeste': ('durativ',),
'durativt': ('durativ',),
'dura': ('dure',),
'durede': ('dure',),
'durende': ('dure',),
'duret': ('dure',),
'durete': ('dure',),
'durt': ('dure',),
'durte': ('dure',),
'durkdreven': ('durkdreven',),
'durkdrevent': ('durkdreven',),
'durkdrevne': ('durkdreven',),
'durkdrevnere': ('durkdreven',),
'durkdrevnest': ('durkdreven',),
'durkdrevneste': ('durkdreven',),
'durksydd': ('durksy',),
'durksydde': ('durksy',),
'durksyende': ('durksy',),
'dus': ('dus',),
'duse': ('dus',),
'dusere': ('dus',),
'dusest': ('dus',),
'duseste': ('dus',),
'dust': ('dus',),
'dusende': ('duse',),
'dust': ('duse',),
'duste': ('duse',),
'dusende': ('duse',),
'dust': ('duse',),
'duste': ('duse',),
'dusement': ('dusement',),
'dusemente': ('dusement',),
'dusementere': ('dusement',),
'dusementest': ('dusement',),
'dusementeste': ('dusement',),
'dusja': ('dusje',),
'dusjede': ('dusje',),
'dusjende': ('dusje',),
'dusjet': ('dusje',),
'dusjete': ('dusje',),
'duskregna': ('duskregne',),
'duskregnede': ('duskregne',),
'duskregnende': ('duskregne',),
'duskregnet': ('duskregne',),
'duskregnete': ('duskregne',),
'duskregnt': ('duskregne',),
'duskregnte': ('duskregne',),
'dustet': ('dustet',),
'dustete': ('dustet',),
'dustetere': ('dustet',),
'dustetest': ('dustet',),
'dusteteste': ('dustet',),
'dustete': ('dustete',),
'dutta': ('dutte',),
'duttede': ('dutte',),
'duttende': ('dutte',),
'duttet': ('dutte',),
'duttete': ('dutte',),
'dutta': ('dutte',),
'duttede': ('dutte',),
'duttende': ('dutte',),
'duttet': ('dutte',),
'duttete': ('dutte',),
'duva': ('duve',),
'duvd': ('duve',),
'duvde': ('duve',),
'duvede': ('duve',),
'duvende': ('duve',),
'duvet': ('duve',),
'duvete': ('duve',),
'dvask': ('dvask',),
'dvaske': ('dvask',),
'dvaskere': ('dvask',),
'dvaskest': ('dvask',),
'dvaskeste': ('dvask',),
'dvaskt': ('dvask',),
'dvelende': ('dvele',),
'dvelt': ('dvele',),
'dvelte': ('dvele',),
'dydd': ('dy',),
'dydde': ('dy',),
'dyende': ('dy',),
'dyadisk': ('dyadisk',),
'dyadiske': ('dyadisk',),
'dyadiskere': ('dyadisk',),
'dyadiskest': ('dyadisk',),
'dyadiskeste': ('dyadisk',),
'dydig': ('dydig',),
'dydige': ('dydig',),
'dydigere': ('dydig',),
'dydigst': ('dydig',),
'dydigste': ('dydig',),
'dydsirede': ('dydsiret',),
'dydsiret': ('dydsiret',),
'dydsirete': ('dydsiret',),
'dydsiretere': ('dydsiret',),
'dydsiretest': ('dydsiret',),
'dydsireteste': ('dydsiret',),
'dykka': ('dykke',),
'dykkede': ('dykke',),
'dykkende': ('dykke',),
'dykket': ('dykke',),
'dykkete': ('dykke',),
'dyktig': ('dyktig',),
'dyktige': ('dyktig',),
'dyktigere': ('dyktig',),
'dyktigst': ('dyktig',),
'dyktigste': ('dyktig',),
'dyktiggjort': ('dyktiggjøre',),
'dyktiggjorte': ('dyktiggjøre',),
'dyktiggjørende': ('dyktiggjøre',),
'dynamisk': ('dynamisk',),
'dynamiske': ('dynamisk',),
'dynamiskere': ('dynamisk',),
'dynamiskest': ('dynamisk',),
'dynamiskeste': ('dynamisk',),
'dynastisk': ('dynastisk',),
'dynastiske': ('dynastisk',),
'dynastiskere': ('dynastisk',),
'dynastiskest': ('dynastisk',),
'dynastiskeste': ('dynastisk',),
'dynga': ('dynge',),
'dyngede': ('dynge',),
'dyngende': ('dynge',),
'dynget': ('dynge',),
'dyngete': ('dynge',),
'dynka': ('dynke',),
'dynkede': ('dynke',),
'dynkende': ('dynke',),
'dynket': ('dynke',),
'dynkete': ('dynke',),
'dyp': ('dyp',),
'dype': ('dyp',),
'dypere': ('dyp',),
'dypest': ('dyp',),
'dypeste': ('dyp',),
'dypt': ('dyp',),
'dypblå': ('dypblå',),
'dypblåe': ('dypblå',),
'dypblåere': ('dypblå',),
'dypblåest': ('dypblå',),
'dypblåeste': ('dypblå',),
'dypblått': ('dypblå',),
'dyperegående': ('dyperegående',),
'dypereliggende': ('dypereliggende',),
'dypetsa': ('dypetse',),
'dypetsede': ('dypetse',),
'dypetsende': ('dypetse',),
'dypetset': ('dypetse',),
'dypetsete': ('dypetse',),
'dypfrysende': ('dypfryse',),
'dypfryst': ('dypfryse',),
'dypfryste': ('dypfryse',),
'dyppa': ('dyppe',),
'dyppede': ('dyppe',),
'dyppende': ('dyppe',),
'dyppet': ('dyppe',),
'dyppete': ('dyppe',),
'dyprød': ('dyprød',),
'dyprøde': ('dyprød',),
'dyprødere': ('dyprød',),
'dyprødest': ('dyprød',),
'dyprødeste': ('dyprød',),
'dyprødt': ('dyprød',),
'dypsindig': ('dypsindig',),
'dypsindige': ('dypsindig',),
'dypsindigere': ('dypsindig',),
'dypsindigst': ('dypsindig',),
'dypsindigste': ('dypsindig',),
'dyptfølt': ('dyptfølt',),
'dyptfølte': ('dyptfølt',),
'dyptføltere': ('dyptfølt',),
'dyptføltest': ('dyptfølt',),
'dyptfølteste': ('dyptfølt',),
'dyptgripende': ('dyptgripende',),
'dyptgående': ('dyptgående',),
'dyptloddende': ('dyptloddende',),
'dypttenkende': ('dypttenkende',),
'dyr': ('dyr',),
'dyre': ('dyr',),
'dyrere': ('dyr',),
'dyrest': ('dyr',),
'dyreste': ('dyr',),
'dyrt': ('dyr',),
'dyrebar': ('dyrebar',),
'dyrebare': ('dyrebar',),
'dyrebarere': ('dyrebar',),
'dyrebarest': ('dyrebar',),
'dyrebareste': ('dyrebar',),
'dyrebart': ('dyrebar',),
'dyrebedre': ('dyregod',),
'dyrebest': ('dyregod',),
'dyrebeste': ('dyregod',),
'dyregod': ('dyregod',),
'dyregode': ('dyregod',),
'dyregodt': ('dyregod',),
'dyrekjøpt': ('dyrekjøpt',),
'dyrekjøpte': ('dyrekjøpt',),
'dyrekjøptere': ('dyrekjøpt',),
'dyrekjøptest': ('dyrekjøpt',),
'dyrekjøpteste': ('dyrekjøpt',),
'dyrisk': ('dyrisk',),
'dyriske': ('dyrisk',),
'dyriskere': ('dyrisk',),
'dyriskest': ('dyrisk',),
'dyriskeste': ('dyrisk',),
'dyrkbar': ('dyrkbar',),
'dyrkbare': ('dyrkbar',),
'dyrkbarere': ('dyrkbar',),
'dyrkbarest': ('dyrkbar',),
'dyrkbareste': ('dyrkbar',),
'dyrkbart': ('dyrkbar',),
'dyrka': ('dyrke',),
'dyrkede': ('dyrke',),
'dyrkende': ('dyrke',),
'dyrket': ('dyrke',),
'dyrkete': ('dyrke',),
'dysfunksjonell': ('dysfunksjonell',),
'dysfunksjonelle': ('dysfunksjonell',),
'dysfunksjonellere': ('dysfunksjonell',),
'dysfunksjonellest': ('dysfunksjonell',),
'dysfunksjonelleste': ('dysfunksjonell',),
'dysfunksjonelt': ('dysfunksjonell',),
'dyssa': ('dysse',),
'dyssede': ('dysse',),
'dyssende': ('dysse',),
'dysset': ('dysse',),
'dyssete': ('dysse',),
'dyster': ('dyster',),
'dystert': ('dyster',),
'dystre': ('dyster',),
'dystrere': ('dyster',),
'dystrest': ('dyster',),
'dystreste': ('dyster',),
'dytta': ('dytte',),
'dyttede': ('dytte',),
'dyttende': ('dytte',),
'dyttet': ('dytte',),
'dyttete': ('dytte',),
'dytta': ('dytte',),
'dyttede': ('dytte',),
'dyttende': ('dytte',),
'dyttet': ('dytte',),
'dyttete': ('dytte',),
'dyvåt': ('dyvåt',),
'dyvåte': ('dyvåt',),
'dyvåtere': ('dyvåt',),
'dyvåtest': ('dyvåt',),
'dyvåteste': ('dyvåt',),
'dyvått': ('dyvåt',),
'dådlaus': ('dådlaus',),
'dådlause': ('dådlaus',),
'dådlausere': ('dådlaus',),
'dådlausest': ('dådlaus',),
'dådlauseste': ('dådlaus',),
'dådlaust': ('dådlaus',),
'dådløs': ('dådløs',),
'dådløse': ('dådløs',),
'dådløsere': ('dådløs',),
'dådløsest': ('dådløs',),
'dådløseste': ('dådløs',),
'dådløst': ('dådløs',),
'dådrik': ('dådrik',),
'dådrike': ('dådrik',),
'dådrikere': ('dådrik',),
'dådrikest': ('dådrik',),
'dådrikeste': ('dådrik',),
'dådrikt': ('dådrik',),
'dåna': ('dåne',),
'dånede': ('dåne',),
'dånende': ('dåne',),
'dånet': ('dåne',),
'dånete': ('dåne',),
'dånt': ('dåne',),
'dånte': ('dåne',),
'dåneferdig': ('dåneferdig',),
'dåneferdige': ('dåneferdig',),
'dåneferdigere': ('dåneferdig',),
'dåneferdigst': ('dåneferdig',),
'dåneferdigste': ('dåneferdig',),
'dåraktig': ('dåraktig',),
'dåraktige': ('dåraktig',),
'dåraktigere': ('dåraktig',),
'dåraktigst': ('dåraktig',),
'dåraktigste': ('dåraktig',),
'dåra': ('dåre',),
'dårede': ('dåre',),
'dårende': ('dåre',),
'dåret': ('dåre',),
'dårete': ('dåre',),
'dårlig': ('dårlig',),
'dårlige': ('dårlig',),
'dårligere': ('dårlig',),
'dårligst': ('dårlig',),
'dårligste': ('dårlig',),
'dåset': ('dåset',),
'dåsete': ('dåset',),
'dåsetere': ('dåset',),
'dåsetest': ('dåset',),
'dåseteste': ('dåset',),
'dåsete': ('dåsete',),
'dødd': ('dø',),
'dødde': ('dø',),
'døende': ('dø',),
'død': ('død',),
'døde': ('død',),
'dødere': ('død',),
'dødest': ('død',),
'dødeste': ('død',),
'dødt': ('død',),
'dødbleik': ('dødbleik',),
'dødbleike': ('dødbleik',),
'dødbleikere': ('dødbleik',),
'dødbleikest': ('dødbleik',),
'dødbleikeste': ('dødbleik',),
'dødbleikt': ('dødbleik',),
'dødblek': ('dødblek',),
'dødbleke': ('dødblek',),
'dødblekere': ('dødblek',),
'dødblekest': ('dødblek',),
'dødblekeste': ('dødblek',),
'dødblekt': ('dødblek',),
'dødbrent': ('dødbrent',),
'dødbrente': ('dødbrent',),
'dødbrentere': ('dødbrent',),
'dødbrentest': ('dødbrent',),
'dødbrenteste': ('dødbrent',),
'dødbringende': ('dødbringende',),
'døddrukken': ('døddrukken',),
'døddrukkent': ('døddrukken',),
'døddrukne': ('døddrukken',),
'døddruknere': ('døddrukken',),
'døddruknest': ('døddrukken',),
'døddrukneste': ('døddrukken',),
'døda': ('døde',),
'dødede': ('døde',),
'dødende': ('døde',),
'dødet': ('døde',),
'dødete': ('døde',),
'dødelig': ('dødelig',),
'dødelige': ('dødelig',),
'dødeligere': ('dødelig',),
'dødeligst': ('dødelig',),
'dødeligste': ('dødelig',),
'dødfødd': ('dødfødd',),
'dødfødde': ('dødfødd',),
'dødføddere': ('dødfødd',),
'dødføddest': ('dødfødd',),
'dødføddeste': ('dødfødd',),
'dødfødt': ('dødfødt',),
'dødfødte': ('dødfødt',),
'dødfødtere': ('dødfødt',),
'dødfødtest': ('dødfødt',),
'dødfødteste': ('dødfødt',),
'dødsdømt': ('dødsdømt',),
'dødsdømte': ('dødsdømt',),
'dødsdømtere': ('dødsdømt',),
'dødsdømtest': ('dødsdømt',),
'dødsdømteste': ('dødsdømt',),
'dødsens': ('dødsens',),
'dødslei': ('dødslei',),
'dødsleie': ('dødslei',),
'dødsleiere': ('dødslei',),
'dødsleiest': ('dødslei',),
'dødsleieste': ('dødslei',),
'dødsleit': ('dødslei',),
'dødsleitt': ('dødslei',),
'dødsmerka': ('dødsmerka',),
'dødsmerkede': ('dødsmerket',),
'dødsmerket': ('dødsmerket',),
'dødsmerkete': ('dødsmerket',),
'dødsmerketere': ('dødsmerket',),
'dødsmerketest': ('dødsmerket',),
'dødsmerketeste': ('dødsmerket',),
'dødssjuk': ('dødssjuk',),
'dødssjuke': ('dødssjuk',),
'dødssjukere': ('dødssjuk',),
'dødssjukest': ('dødssjuk',),
'dødssjukeste': ('dødssjuk',),
'dødssjukt': ('dødssjuk',),
'dødssyk': ('dødssyk',),
'dødssyke': ('dødssyk',),
'dødssykere': ('dødssyk',),
'dødssykest': ('dødssyk',),
'dødssykeste': ('dødssyk',),
'dødssykt': ('dødssyk',),
'dødstrett': ('dødstrett',),
'dødstrette': ('dødstrett',),
'dødstrettere': ('dødstrett',),
'dødstrettest': ('dødstrett',),
'dødstretteste': ('dødstrett',),
'dødstrøtt': ('dødstrøtt',),
'dødstrøtte': ('dødstrøtt',),
'dødstrøttere': ('dødstrøtt',),
'dødstrøttest': ('dødstrøtt',),
'dødstrøtteste': ('dødstrøtt',),
'døgervill': ('døgervill',),
'døgerville': ('døgervill',),
'døgervillere': ('døgervill',),
'døgervillest': ('døgervill',),
'døgervilleste': ('døgervill',),
'døgervilt': ('døgervill',),
'døgneldre': ('døgngammel',),
'døgneldst': ('døgngammel',),
'døgneldste': ('døgngammel',),
'døgngamle': ('døgngammel',),
'døgngammel': ('døgngammel',),
'døgngammelt': ('døgngammel',),
'døgnkontinuerlig': ('døgnkontinuerlig',),
'døgnkontinuerlige': ('døgnkontinuerlig',),
'døgnkontinuerligere': ('døgnkontinuerlig',),
'døgnkontinuerligst': ('døgnkontinuerlig',),
'døgnkontinuerligste': ('døgnkontinuerlig',),
'døgnvill': ('døgnvill',),
'døgnville': ('døgnvill',),
'døgnvillere': ('døgnvill',),
'døgnvillest': ('døgnvill',),
'døgnvilleste': ('døgnvill',),
'døgnvilt': ('døgnvill',),
'døgnåpen': ('døgnåpen',),
'døgnåpent': ('døgnåpen',),
'døgnåpne': ('døgnåpen',),
'døgnåpnere': ('døgnåpen',),
'døgnåpnest': ('døgnåpen',),
'døgnåpneste': ('døgnåpen',),
'dulgt': ('dølge',),
'dulgte': ('dølge',),
'dølgende': ('dølge',),
'dølsk': ('dølsk',),
'dølske': ('dølsk',),
'dølskere': ('dølsk',),
'dølskest': ('dølsk',),
'dølskeste': ('dølsk',),
'dømmende': ('dømme',),
'dømt': ('dømme',),
'dømte': ('dømme',),
'dømmesjuk': ('dømmesjuk',),
'dømmesjuke': ('dømmesjuk',),
'dømmesjukere': ('dømmesjuk',),
'dømmesjukest': ('dømmesjuk',),
'dømmesjukeste': ('dømmesjuk',),
'dømmesjukt': ('dømmesjuk',),
'dømmesyk': ('dømmesyk',),
'dømmesyke': ('dømmesyk',),
'dømmesykere': ('dømmesyk',),
'dømmesykest': ('dømmesyk',),
'dømmesykeste': ('dømmesyk',),
'dømmesykt': ('dømmesyk',),
'dønna': ('dønne',),
'dønnede': ('dønne',),
'dønnende': ('dønne',),
'dønnet': ('dønne',),
'dønnete': ('dønne',),
'dønt': ('dønne',),
'dønte': ('dønne',),
'døpende': ('døpe',),
'døpt': ('døpe',),
'døpte': ('døpe',),
'døsa': ('døse',),
'døsede': ('døse',),
'døsende': ('døse',),
'døset': ('døse',),
'døsete': ('døse',),
'døst': ('døse',),
'døste': ('døse',),
'døsen': ('døsen',),
'døsent': ('døsen',),
'døsne': ('døsen',),
'døsnere': ('døsen',),
'døsnest': ('døsen',),
'døsneste': ('døsen',),
'døsig': ('døsig',),
'døsige': ('døsig',),
'døsigere': ('døsig',),
'døsigst': ('døsig',),
'døsigste': ('døsig',),
'døv': ('døv',),
'døve': ('døv',),
'døvere': ('døv',),
'døvest': ('døv',),
'døveste': ('døv',),
'døvt': ('døv',),
'døvblind': ('døvblind',),
'døvblinde': ('døvblind',),
'døvblindere': ('døvblind',),
'døvblindest': ('døvblind',),
'døvblindeste': ('døvblind',),
'døvblindt': ('døvblind',),
'døvfødd': ('døvfødd',),
'døvfødde': ('døvfødd',),
'døvføddere': ('døvfødd',),
'døvføddest': ('døvfødd',),
'døvføddeste': ('døvfødd',),
'døvfødt': ('døvfødt',),
'døvfødte': ('døvfødt',),
'døvfødtere': ('døvfødt',),
'døvfødtest': ('døvfødt',),
'døvfødteste': ('døvfødt',),
'døvhørt': ('døvhørt',),
'døvhørte': ('døvhørt',),
'døvhørtere': ('døvhørt',),
'døvhørtest': ('døvhørt',),
'døvhørteste': ('døvhørt',),
'døvstum': ('døvstum',),
'døvstumme': ('døvstum',),
'døvstummere': ('døvstum',),
'døvstummest': ('døvstum',),
'døvstummeste': ('døvstum',),
'døvstumt': ('døvstum',),
'døya': ('døye',),
'døyd': ('døye',),
'døyde': ('døye',),
'døyede': ('døye',),
'døyende': ('døye',),
'døyet': ('døye',),
'døyete': ('døye',),
'døyva': ('døyve',),
'døyvd': ('døyve',),
'døyvde': ('døyve',),
'døyvede': ('døyve',),
'døyvende': ('døyve',),
'døyvet': ('døyve',),
'døyvete': ('døyve',),
'ebba': ('ebbe',),
'ebbede': ('ebbe',),
'ebbende': ('ebbe',),
'ebbet': ('ebbe',),
'ebbete': ('ebbe',),
'ecru': ('ecru',),
'ecuadoriansk': ('ecuadoriansk',),
'ecuadorianske': ('ecuadoriansk',),
'ecuadorianskere': ('ecuadoriansk',),
'ecuadorianskest': ('ecuadoriansk',),
'ecuadorianskeste': ('ecuadoriansk',),
'edafisk': ('edafisk',),
'edafiske': ('edafisk',),
'edafiskere': ('edafisk',),
'edafiskest': ('edafisk',),
'edafiskeste': ('edafisk',),
'eddiksur': ('eddiksur',),
'eddiksure': ('eddiksur',),
'eddiksurere': ('eddiksur',),
'eddiksurest': ('eddiksur',),
'eddiksureste': ('eddiksur',),
'eddiksurt': ('eddiksur',),
'edel': ('edel',),
'edelt': ('edel',),
'edle': ('edel',),
'edlere': ('edel',),
'edlest': ('edel',),
'edleste': ('edel',),
'edelig': ('edelig',),
'edelige': ('edelig',),
'edeligere': ('edelig',),
'edeligst': ('edelig',),
'edeligste': ('edelig',),
'edelmodig': ('edelmodig',),
'edelmodige': ('edelmodig',),
'edelmodigere': ('edelmodig',),
'edelmodigst': ('edelmodig',),
'edelmodigste': ('edelmodig',),
'edfesta': ('edfeste',),
'edfestede': ('edfeste',),
'edfestende': ('edfeste',),
'edfestet': ('edfeste',),
'edfestete': ('edfeste',),
'edru': ('edru',),
'edrue': ('edru',),
'edruere': ('edru',),
'edruest': ('edru',),
'edrueste': ('edru',),
'edruelig': ('edruelig',),
'edruelige': ('edruelig',),
'edrueligere': ('edruelig',),
'edrueligst': ('edruelig',),
'edrueligste': ('edruelig',),
'edsvoren': ('edsvoren',),
'edsvorent': ('edsvoren',),
'edsvorne': ('edsvoren',),
'edsvornere': ('edsvoren',),
'edsvornest': ('edsvoren',),
'edsvorneste': ('edsvoren',),
'efemer': ('efemer',),
'efemere': ('efemer',),
'efemerere': ('efemer',),
'efemerest': ('efemer',),
'efemereste': ('efemer',),
'efemert': ('efemer',),
'effektfull': ('effektfull',),
'effektfulle': ('effektfull',),
'effektfullere': ('effektfull',),
'effektfullest': ('effektfull',),
'effektfulleste': ('effektfull',),
'effektfullt': ('effektfull',),
'effektiv': ('effektiv',),
'effektive': ('effektiv',),
'effektivere': ('effektiv',),
'effektivest': ('effektiv',),
'effektiveste': ('effektiv',),
'effektivt': ('effektiv',),
'effektiviserende': ('effektivisere',),
'effektivisert': ('effektivisere',),
'effektiviserte': ('effektivisere',),
'effektuerende': ('effektuere',),
'effektuert': ('effektuere',),
'effektuerte': ('effektuere',),
'egal': ('egal',),
'egale': ('egal',),
'egalere': ('egal',),
'egalest': ('egal',),
'egaleste': ('egal',),
'egalt': ('egal',),
'egaliserende': ('egalisere',),
'egalisert': ('egalisere',),
'egaliserte': ('egalisere',),
'egalitær': ('egalitær',),
'egalitære': ('egalitær',),
'egalitærere': ('egalitær',),
'egalitærest': ('egalitær',),
'egalitæreste': ('egalitær',),
'egalitært': ('egalitær',),
'egdsk': ('egdsk',),
'egdske': ('egdsk',),
'egdskere': ('egdsk',),
'egdskest': ('egdsk',),
'egdskeste': ('egdsk',),
'egeisk': ('egeisk',),
'egeiske': ('egeisk',),
'egeiskere': ('egeisk',),
'egeiskest': ('egeisk',),
'egeiskeste': ('egeisk',),
'egen': ('egen',),
'egent': ('egen',),
'egne': ('egen',),
'egnere': ('egen',),
'egnest': ('egen',),
'egneste': ('egen',),
'egenarta': ('egenarta',),
'egenartede': ('egenartet',),
'egenartet': ('egenartet',),
'egenartete': ('egenartet',),
'egenartetere': ('egenartet',),
'egenartetest': ('egenartet',),
'egenarteteste': ('egenartet',),
'egenhendig': ('egenhendig',),
'egenhendige': ('egenhendig',),
'egenhendigere': ('egenhendig',),
'egenhendigst': ('egenhendig',),
'egenhendigste': ('egenhendig',),
'egenkjærlig': ('egenkjærlig',),
'egenkjærlige': ('egenkjærlig',),
'egenkjærligere': ('egenkjærlig',),
'egenkjærligst': ('egenkjærlig',),
'egenkjærligste': ('egenkjærlig',),
'egenmektig': ('egenmektig',),
'egenmektige': ('egenmektig',),
'egenmektigere': ('egenmektig',),
'egenmektigst': ('egenmektig',),
'egenmektigste': ('egenmektig',),
'egenprodusert': ('egenprodusert',),
'egenproduserte': ('egenprodusert',),
'egenprodusertere': ('egenprodusert',),
'egenprodusertest': ('egenprodusert',),
'egenproduserteste': ('egenprodusert',),
'egenrettferdig': ('egenrettferdig',),
'egenrettferdige': ('egenrettferdig',),
'egenrettferdigere': ('egenrettferdig',),
'egenrettferdigst': ('egenrettferdig',),
'egenrettferdigste': ('egenrettferdig',),
'egenrådig': ('egenrådig',),
'egenrådige': ('egenrådig',),
'egenrådigere': ('egenrådig',),
'egenrådigst': ('egenrådig',),
'egenrådigste': ('egenrådig',),
'egensikker': ('egensikker',),
'egensikkert': ('egensikker',),
'egensikre': ('egensikker',),
'egensikrere': ('egensikker',),
'egensikrest': ('egensikker',),
'egensikreste': ('egensikker',),
'egensindig': ('egensindig',),
'egensindige': ('egensindig',),
'egensindigere': ('egensindig',),
'egensindigst': ('egensindig',),
'egensindigste': ('egensindig',),
'egentlig': ('egentlig',),
'egentlige': ('egentlig',),
'egentligere': ('egentlig',),
'egentligst': ('egentlig',),
'egentligste': ('egentlig',),
'egga': ('egge',),
'eggede': ('egge',),
'eggende': ('egge',),
'egget': ('egge',),
'eggete': ('egge',),
'eggeforma': ('eggeforma',),
'eggeformede': ('eggeformet',),
'eggeformet': ('eggeformet',),
'eggeformete': ('eggeformet',),
'eggeformetere': ('eggeformet',),
'eggeformetest': ('eggeformet',),
'eggeformeteste': ('eggeformet',),
'eggeskalfarga': ('eggeskalfarga',),
'eggeskalfargede': ('eggeskalfarget',),
'eggeskalfarget': ('eggeskalfarget',),
'eggeskalfargete': ('eggeskalfarget',),
'eggeskalfargetere': ('eggeskalfarget',),
'eggeskalfargetest': ('eggeskalfarget',),
'eggeskalfargeteste': ('eggeskalfarget',),
'eggeskallfarga': ('eggeskallfarga',),
'eggeskallfargede': ('eggeskallfarget',),
'eggeskallfarget': ('eggeskallfarget',),
'eggeskallfargete': ('eggeskallfarget',),
'eggeskallfargetere': ('eggeskallfarget',),
'eggeskallfargetest': ('eggeskallfarget',),
'eggeskallfargeteste': ('eggeskallfarget',),
'eggforma': ('eggforma',),
'eggformede': ('eggformet',),
'eggformet': ('eggformet',),
'eggformete': ('eggformet',),
'eggformetere': ('eggformet',),
'eggformetest': ('eggformet',),
'eggformeteste': ('eggformet',),
'egla': ('egle',),
'eglede': ('egle',),
'eglende': ('egle',),
'eglet': ('egle',),
'eglete': ('egle',),
'eglet': ('eglet',),
'eglete': ('eglet',),
'egletere': ('eglet',),
'egletest': ('eglet',),
'egleteste': ('eglet',),
'eglete': ('eglete',),
'egna': ('egna',),
'egna': ('egne',),
'egnede': ('egne',),
'egnende': ('egne',),
'egnet': ('egne',),
'egnete': ('egne',),
'egna': ('egne',),
'egnede': ('egne',),
'egnende': ('egne',),
'egnet': ('egne',),
'egnete': ('egne',),
'egnt': ('egne',),
'egnte': ('egne',),
'egnede': ('egnet',),
'egnet': ('egnet',),
'egnete': ('egnet',),
'egnetere': ('egnet',),
'egnetest': ('egnet',),
'egneteste': ('egnet',),
'egoistisk': ('egoistisk',),
'egoistiske': ('egoistisk',),
'egoistiskere': ('egoistisk',),
'egoistiskest': ('egoistisk',),
'egoistiskeste': ('egoistisk',),
'egosentrisk': ('egosentrisk',),
'egosentriske': ('egosentrisk',),
'egosentriskere': ('egosentrisk',),
'egosentriskest': ('egosentrisk',),
'egosentriskeste': ('egosentrisk',),
'egyptisk': ('egyptisk',),
'egyptiske': ('egyptisk',),
'egyptiskere': ('egyptisk',),
'egyptiskest': ('egyptisk',),
'egyptiskeste': ('egyptisk',),
'eid': ('eie',),
'eide': ('eie',),
'eiede': ('eie',),
'eiende': ('eie',),
'eiet': ('eie',),
'eiete': ('eie',),
'ått': ('eie',),
'åtte': ('eie',),
'eiebedre': ('eiegod',),
'eiebest': ('eiegod',),
'eiebeste': ('eiegod',),
'eiegod': ('eiegod',),
'eiegode': ('eiegod',),
'eiegodt': ('eiegod',),
'eiendommelig': ('eiendommelig',),
'eiendommelige': ('eiendommelig',),
'eiendommeligere': ('eiendommelig',),
'eiendommeligst': ('eiendommelig',),
'eiendommeligste': ('eiendommelig',),
'eiendomslaus': ('eiendomslaus',),
'eiendomslause': ('eiendomslaus',),
'eiendomslausere': ('eiendomslaus',),
'eiendomslausest': ('eiendomslaus',),
'eiendomslauseste': ('eiendomslaus',),
'eiendomslaust': ('eiendomslaus',),
'eiendomsløs': ('eiendomsløs',),
'eiendomsløse': ('eiendomsløs',),
'eiendomsløsere': ('eiendomsløs',),
'eiendomsløsest': ('eiendomsløs',),
'eiendomsløseste': ('eiendomsløs',),
'eiendomsløst': ('eiendomsløs',),
'eiesnill': ('eiesnill',),
'eiesnille': ('eiesnill',),
'eiesnillere': ('eiesnill',),
'eiesnillest': ('eiesnill',),
'eiesnilleste': ('eiesnill',),
'eiesnilt': ('eiesnill',),
'eigenarta': ('eigenarta',),
'eigenartede': ('eigenartet',),
'eigenartet': ('eigenartet',),
'eigenartete': ('eigenartet',),
'eigenartetere': ('eigenartet',),
'eigenartetest': ('eigenartet',),
'eigenarteteste': ('eigenartet',),
'eigenhendig': ('eigenhendig',),
'eigenhendige': ('eigenhendig',),
'eigenhendigere': ('eigenhendig',),
'eigenhendigst': ('eigenhendig',),
'eigenhendigste': ('eigenhendig',),
'eigenkjærlig': ('eigenkjærlig',),
'eigenkjærlige': ('eigenkjærlig',),
'eigenkjærligere': ('eigenkjærlig',),
'eigenkjærligst': ('eigenkjærlig',),
'eigenkjærligste': ('eigenkjærlig',),
'eigenmektig': ('eigenmektig',),
'eigenmektige': ('eigenmektig',),
'eigenmektigere': ('eigenmektig',),
'eigenmektigst': ('eigenmektig',),
'eigenmektigste': ('eigenmektig',),
'eigenprodusert': ('eigenprodusert',),
'eigenproduserte': ('eigenprodusert',),
'eigenprodusertere': ('eigenprodusert',),
'eigenprodusertest': ('eigenprodusert',),
'eigenproduserteste': ('eigenprodusert',),
'eigenrettferdig': ('eigenrettferdig',),
'eigenrettferdige': ('eigenrettferdig',),
'eigenrettferdigere': ('eigenrettferdig',),
'eigenrettferdigst': ('eigenrettferdig',),
'eigenrettferdigste': ('eigenrettferdig',),
'eigenrådig': ('eigenrådig',),
'eigenrådige': ('eigenrådig',),
'eigenrådigere': ('eigenrådig',),
'eigenrådigst': ('eigenrådig',),
'eigenrådigste': ('eigenrådig',),
'eigensikker': ('eigensikker',),
'eigensikkert': ('eigensikker',),
'eigensikre': ('eigensikker',),
'eigensikrere': ('eigensikker',),
'eigensikrest': ('eigensikker',),
'eigensikreste': ('eigensikker',),
'eigensindig': ('eigensindig',),
'eigensindige': ('eigensindig',),
'eigensindigere': ('eigensindig',),
'eigensindigst': ('eigensindig',),
'eigensindigste': ('eigensindig',),
'eima': ('eime',),
'eimede': ('eime',),
'eimende': ('eime',),
'eimet': ('eime',),
'eimete': ('eime',),
'einslig': ('einslig',),
'einslige': ('einslig',),
'einsligere': ('einslig',),
'einsligst': ('einslig',),
'einsligste': ('einslig',),
'einsligstilt': ('einsligstilt',),
'einsligstilte': ('einsligstilt',),
'einsligstiltere': ('einsligstilt',),
'einsligstiltest': ('einsligstilt',),
'einsligstilteste': ('einsligstilt',),
'eira': ('eire',),
'eirede': ('eire',),
'eirende': ('eire',),
'eiret': ('eire',),
'eirete': ('eire',),
'eiret': ('eiret',),
'eirete': ('eiret',),
'eiretere': ('eiret',),
'eiretest': ('eiret',),
'eireteste': ('eiret',),
'eirete': ('eirete',),
'eirgrøn': ('eirgrøn',),
'eirgrøne': ('eirgrøn',),
'eirgrønere': ('eirgrøn',),
'eirgrønest': ('eirgrøn',),
'eirgrøneste': ('eirgrøn',),
'eirgrønt': ('eirgrøn',),
'eirgrønn': ('eirgrønn',),
'eirgrønne': ('eirgrønn',),
'eirgrønnere': ('eirgrønn',),
'eirgrønnest': ('eirgrønn',),
'eirgrønneste': ('eirgrønn',),
'eirgrønt': ('eirgrønn',),
'ejakulerende': ('ejakulere',),
'ejakulert': ('ejakulere',),
'ejakulerte': ('ejakulere',),
'ekkel': ('ekkel',),
'ekkelt': ('ekkel',),
'ekle': ('ekkel',),
'eklere': ('ekkel',),
'eklest': ('ekkel',),
'ekleste': ('ekkel',),
'eklatant': ('eklatant',),
'eklatante': ('eklatant',),
'eklatantere': ('eklatant',),
'eklatantest': ('eklatant',),
'eklatanteste': ('eklatant',),
'eklektisk': ('eklektisk',),
'eklektiske': ('eklektisk',),
'eklektiskere': ('eklektisk',),
'eklektiskest': ('eklektisk',),
'eklektiskeste': ('eklektisk',),
'eksakt': ('eksakt',),
'eksakte': ('eksakt',),
'eksaktere': ('eksakt',),
'eksaktest': ('eksakt',),
'eksakteste': ('eksakt',),
'eksaltert': ('eksaltert',),
'eksalterte': ('eksaltert',),
'eksaltertere': ('eksaltert',),
'eksaltertest': ('eksaltert',),
'eksalterteste': ('eksaltert',),
'eksamensberettiga': ('eksamensberettiga',),
'eksamensberettigede': ('eksamensberettiget',),
'eksamensberettiget': ('eksamensberettiget',),
'eksamensberettigete': ('eksamensberettiget',),
'eksamensberettigetere': ('eksamensberettiget',),
'eksamensberettigetest': ('eksamensberettiget',),
'eksamensberettigeteste': ('eksamensberettiget',),
'eksamensfri': ('eksamensfri',),
'eksamensfrie': ('eksamensfri',),
'eksamensfriere': ('eksamensfri',),
'eksamensfriest': ('eksamensfri',),
'eksamensfrieste': ('eksamensfri',),
'eksamensfritt': ('eksamensfri',),
'eksamensretta': ('eksamensretta',),
'eksamensrettede': ('eksamensrettet',),
'eksamensrettet': ('eksamensrettet',),
'eksamensrettete': ('eksamensrettet',),
'eksamensrettetere': ('eksamensrettet',),
'eksamensrettetest': ('eksamensrettet',),
'eksamensretteteste': ('eksamensrettet',),
'eksaminatorisk': ('eksaminatorisk',),
'eksaminatoriske': ('eksaminatorisk',),
'eksaminatoriskere': ('eksaminatorisk',),
'eksaminatoriskest': ('eksaminatorisk',),
'eksaminatoriskeste': ('eksaminatorisk',),
'eksaminerende': ('eksaminere',),
'eksaminert': ('eksaminere',),
'eksaminerte': ('eksaminere',),
'eksegerende': ('eksegere',),
'eksegert': ('eksegere',),
'eksegerte': ('eksegere',),
'eksegetisk': ('eksegetisk',),
'eksegetiske': ('eksegetisk',),
'eksegetiskere': ('eksegetisk',),
'eksegetiskest': ('eksegetisk',),
'eksegetiskeste': ('eksegetisk',),
'eksekutiv': ('eksekutiv',),
'eksekutive': ('eksekutiv',),
'eksekutivere': ('eksekutiv',),
'eksekutivest': ('eksekutiv',),
'eksekutiveste': ('eksekutiv',),
'eksekutivt': ('eksekutiv',),
'eksekverende': ('eksekvere',),
'eksekvert': ('eksekvere',),
'eksekverte': ('eksekvere',),
'eksellent': ('eksellent',),
'eksellente': ('eksellent',),
'eksellentere': ('eksellent',),
'eksellentest': ('eksellent',),
'eksellenteste': ('eksellent',),
'eksellerende': ('eksellere',),
'eksellert': ('eksellere',),
'eksellerte': ('eksellere',),
'eksemplarisk': ('eksemplarisk',),
'eksemplariske': ('eksemplarisk',),
'eksemplariskere': ('eksemplarisk',),
'eksemplariskest': ('eksemplarisk',),
'eksemplariskeste': ('eksemplarisk',),
'eksemplifiserende': ('eksemplifisere',),
'eksemplifisert': ('eksemplifisere',),
'eksemplifiserte': ('eksemplifisere',),
'eksentrisk': ('eksentrisk',),
'eksentriske': ('eksentrisk',),
'eksentriskere': ('eksentrisk',),
'eksentriskest': ('eksentrisk',),
'eksentriskeste': ('eksentrisk',),
'eksepsjonell': ('eksepsjonell',),
'eksepsjonelle': ('eksepsjonell',),
'eksepsjonellere': ('eksepsjonell',),
'eksepsjonellest': ('eksepsjonell',),
'eksepsjonelleste': ('eksepsjonell',),
'eksepsjonelt': ('eksepsjonell',),
'ekserperende': ('ekserpere',),
'ekserpert': ('ekserpere',),
'ekserperte': ('ekserpere',),
'ekserserende': ('eksersere',),
'eksersert': ('eksersere',),
'ekserserte': ('eksersere',),
'ekshalerende': ('ekshalere',),
'ekshalert': ('ekshalere',),
'ekshalerte': ('ekshalere',),
'ekshibisjonistisk': ('ekshibisjonistisk',),
'ekshibisjonistiske': ('ekshibisjonistisk',),
'ekshibisjonistiskere': ('ekshibisjonistisk',),
'ekshibisjonistiskest': ('ekshibisjonistisk',),
'ekshibisjonistiskeste': ('ekshibisjonistisk',),
'eksistensialistisk': ('eksistensialistisk',),
'eksistensialistiske': ('eksistensialistisk',),
'eksistensialistiskere': ('eksistensialistisk',),
'eksistensialistiskest': ('eksistensialistisk',),
'eksistensialistiskeste': ('eksistensialistisk',),
'eksistensiell': ('eksistensiell',),
'eksistensielle': ('eksistensiell',),
'eksistensiellere': ('eksistensiell',),
'eksistensiellest': ('eksistensiell',),
'eksistensielleste': ('eksistensiell',),
'eksistensielt': ('eksistensiell',),
'eksisterende': ('eksistere',),
'eksistert': ('eksistere',),
'eksisterte': ('eksistere',),
'eksklamerende': ('eksklamere',),
'eksklamert': ('eksklamere',),
'eksklamerte': ('eksklamere',),
'ekskluderende': ('ekskludere',),
'ekskludert': ('ekskludere',),
'ekskluderte': ('ekskludere',),
'eksklusiv': ('eksklusiv',),
'eksklusive': ('eksklusiv',),
'eksklusivere': ('eksklusiv',),
'eksklusivest': ('eksklusiv',),
'eksklusiveste': ('eksklusiv',),
'eksklusivt': ('eksklusiv',),
'ekskommuniserende': ('ekskommunisere',),
'ekskommunisert': ('ekskommunisere',),
'ekskommuniserte': ('ekskommunisere',),
'eksogen': ('eksogen',),
'eksogene': ('eksogen',),
'eksogenere': ('eksogen',),
'eksogenest': ('eksogen',),
'eksogeneste': ('eksogen',),
'eksogent': ('eksogen',),
'eksokrin': ('eksokrin',),
'eksokrine': ('eksokrin',),
'eksokrinere': ('eksokrin',),
'eksokrinest': ('eksokrin',),
'eksokrineste': ('eksokrin',),
'eksokrint': ('eksokrin',),
'eksosforgifta': ('eksosforgifta',),
'eksosforgiftede': ('eksosforgiftet',),
'eksosforgiftet': ('eksosforgiftet',),
'eksosforgiftete': ('eksosforgiftet',),
'eksosforgiftetere': ('eksosforgiftet',),
'eksosforgiftetest': ('eksosforgiftet',),
'eksosforgifteteste': ('eksosforgiftet',),
'eksoterisk': ('eksoterisk',),
'eksoteriske': ('eksoterisk',),
'eksoteriskere': ('eksoterisk',),
'eksoteriskest': ('eksoterisk',),
'eksoteriskeste': ('eksoterisk',),
'eksoterm': ('eksoterm',),
'eksoterme': ('eksoterm',),
'eksotermere': ('eksoterm',),
'eksotermest': ('eksoterm',),
'eksotermeste': ('eksoterm',),
'eksotermt': ('eksoterm',),
'eksotisk': ('eksotisk',),
'eksotiske': ('eksotisk',),
'eksotiskere': ('eksotisk',),
'eksotiskest': ('eksotisk',),
'eksotiskeste': ('eksotisk',),
'ekspanderende': ('ekspandere',),
'ekspandert': ('ekspandere',),
'ekspanderte': ('ekspandere',),
'ekspansiv': ('ekspansiv',),
'ekspansive': ('ekspansiv',),
'ekspansivere': ('ekspansiv',),
'ekspansivest': ('ekspansiv',),
'ekspansiveste': ('ekspansiv',),
'ekspansivt': ('ekspansiv',),
'ekspatrierende': ('ekspatriere',),
'ekspatriert': ('ekspatriere',),
'ekspatrierte': ('ekspatriere',),
'ekspederende': ('ekspedere',),
'ekspedert': ('ekspedere',),
'ekspederte': ('ekspedere',),
'ekspeditt': ('ekspeditt',),
'ekspeditte': ('ekspeditt',),
'ekspedittere': ('ekspeditt',),
'ekspedittest': ('ekspeditt',),
'ekspeditteste': ('ekspeditt',),
'eksperimentell': ('eksperimentell',),
'eksperimentelle': ('eksperimentell',),
'eksperimentellere': ('eksperimentell',),
'eksperimentellest': ('eksperimentell',),
'eksperimentelleste': ('eksperimentell',),
'eksperimentelt': ('eksperimentell',),
'eksperimenterende': ('eksperimentere',),
'eksperimentert': ('eksperimentere',),
'eksperimenterte': ('eksperimentere',),
'ekspiratorisk': ('ekspiratorisk',),
'ekspiratoriske': ('ekspiratorisk',),
'ekspiratoriskere': ('ekspiratorisk',),
'ekspiratoriskest': ('ekspiratorisk',),
'ekspiratoriskeste': ('ekspiratorisk',),
'ekspirerende': ('ekspirere',),
'ekspirert': ('ekspirere',),
'ekspirerte': ('ekspirere',),
'eksplisitt': ('eksplisitt',),
'eksplisitte': ('eksplisitt',),
'eksplisittere': ('eksplisitt',),
'eksplisittest': ('eksplisitt',),
'eksplisitteste': ('eksplisitt',),
'eksplisitterende': ('eksplisittere',),
'eksplisittert': ('eksplisittere',),
'eksplisitterte': ('eksplisittere',),
'eksploaterende': ('eksploatere',),
'eksploatert': ('eksploatere',),
'eksploaterte': ('eksploatere',),
'eksploderende': ('eksplodere',),
'eksplodert': ('eksplodere',),
'eksploderte': ('eksplodere',),
'eksplosiv': ('eksplosiv',),
'eksplosive': ('eksplosiv',),
'eksplosivere': ('eksplosiv',),
'eksplosivest': ('eksplosiv',),
'eksplosiveste': ('eksplosiv',),
'eksplosivt': ('eksplosiv',),
'eksplosjonsarta': ('eksplosjonsarta',),
'eksplosjonsartede': ('eksplosjonsartet',),
'eksplosjonsartet': ('eksplosjonsartet',),
'eksplosjonsartete': ('eksplosjonsartet',),
'eksplosjonsartetere': ('eksplosjonsartet',),
'eksplosjonsartetest': ('eksplosjonsartet',),
'eksplosjonsarteteste': ('eksplosjonsartet',),
'eksplosjonsfarlig': ('eksplosjonsfarlig',),
'eksplosjonsfarlige': ('eksplosjonsfarlig',),
'eksplosjonsfarligere': ('eksplosjonsfarlig',),
'eksplosjonsfarligst': ('eksplosjonsfarlig',),
'eksplosjonsfarligste': ('eksplosjonsfarlig',),
'eksplosjonssikker': ('eksplosjonssikker',),
'eksplosjonssikkert': ('eksplosjonssikker',),
'eksplosjonssikre': ('eksplosjonssikker',),
'eksplosjonssikrere': ('eksplosjonssikker',),
'eksplosjonssikrest': ('eksplosjonssikker',),
'eksplosjonssikreste': ('eksplosjonssikker',),
'eksplosjonstett': ('eksplosjonstett',),
'eksplosjonstette': ('eksplosjonstett',),
'eksplosjonstettere': ('eksplosjonstett',),
'eksplosjonstettest': ('eksplosjonstett',),
'eksplosjonstetteste': ('eksplosjonstett',),
'eksponerende': ('eksponere',),
'eksponert': ('eksponere',),
'eksponerte': ('eksponere',),
'eksporterende': ('eksportere',),
'eksportert': ('eksportere',),
'eksporterte': ('eksportere',),
'eksportfremmende': ('eksportfremmende',),
'eksportregulerende': ('eksportregulerende',),
'ekspresjonistisk': ('ekspresjonistisk',),
'ekspresjonistiske': ('ekspresjonistisk',),
'ekspresjonistiskere': ('ekspresjonistisk',),
'ekspresjonistiskest': ('ekspresjonistisk',),
'ekspresjonistiskeste': ('ekspresjonistisk',),
'ekspressiv': ('ekspressiv',),
'ekspressive': ('ekspressiv',),
'ekspressivere': ('ekspressiv',),
'ekspressivest': ('ekspressiv',),
'ekspressiveste': ('ekspressiv',),
'ekspressivt': ('ekspressiv',),
'eksproprierende': ('ekspropriere',),
'ekspropriert': ('ekspropriere',),
'eksproprierte': ('ekspropriere',),
'ekstatisk': ('ekstatisk',),
'ekstatiske': ('ekstatisk',),
'ekstatiskere': ('ekstatisk',),
'ekstatiskest': ('ekstatisk',),
'ekstatiskeste': ('ekstatisk',),
'ekstemporal': ('ekstemporal',),
'ekstemporale': ('ekstemporal',),
'ekstemporalere': ('ekstemporal',),
'ekstemporalest': ('ekstemporal',),
'ekstemporaleste': ('ekstemporal',),
'ekstemporalt': ('ekstemporal',),
'ekstemporerende': ('ekstemporere',),
'ekstemporert': ('ekstemporere',),
'ekstemporerte': ('ekstemporere',),
'ekstensiv': ('ekstensiv',),
'ekstensive': ('ekstensiv',),
'ekstensivere': ('ekstensiv',),
'ekstensivest': ('ekstensiv',),
'ekstensiveste': ('ekstensiv',),
'ekstensivt': ('ekstensiv',),
'ekstensiverende': ('ekstensivere',),
'ekstensivert': ('ekstensivere',),
'ekstensiverte': ('ekstensivere',),
'ekstern': ('ekstern',),
'eksterne': ('ekstern',),
'eksternere': ('ekstern',),
'eksternest': ('ekstern',),
'eksterneste': ('ekstern',),
'eksternt': ('ekstern',),
'eksterritorial': ('eksterritorial',),
'eksterritoriale': ('eksterritorial',),
'eksterritorialere': ('eksterritorial',),
'eksterritorialest': ('eksterritorial',),
'eksterritorialeste': ('eksterritorial',),
'eksterritorialt': ('eksterritorial',),
'ekstra': ('ekstra',),
'ekstraherende': ('ekstrahere',),
'ekstrahert': ('ekstrahere',),
'ekstraherte': ('ekstrahere',),
'ekstraordinær': ('ekstraordinær',),
'ekstraordinære': ('ekstraordinær',),
'ekstraordinærere': ('ekstraordinær',),
'ekstraordinærest': ('ekstraordinær',),
'ekstraordinæreste': ('ekstraordinær',),
'ekstraordinært': ('ekstraordinær',),
'ekstrapolerende': ('ekstrapolere',),
'ekstrapolert': ('ekstrapolere',),
'ekstrapolerte': ('ekstrapolere',),
'ekstrauterin': ('ekstrauterin',),
'ekstrauterine': ('ekstrauterin',),
'ekstrauterinere': ('ekstrauterin',),
'ekstrauterinest': ('ekstrauterin',),
'ekstrauterineste': ('ekstrauterin',),
'ekstrauterint': ('ekstrauterin',),
'ekstravagant': ('ekstravagant',),
'ekstravagante': ('ekstravagant',),
'ekstravagantere': ('ekstravagant',),
'ekstravagantest': ('ekstravagant',),
'ekstravaganteste': ('ekstravagant',),
'ekstrem': ('ekstrem',),
'ekstreme': ('ekstrem',),
'ekstremere': ('ekstrem',),
'ekstremest': ('ekstrem',),
'ekstremeste': ('ekstrem',),
'ekstremt': ('ekstrem',),
'ekstremistisk': ('ekstremistisk',),
'ekstremistiske': ('ekstremistisk',),
'ekstremistiskere': ('ekstremistisk',),
'ekstremistiskest': ('ekstremistisk',),
'ekstremistiskeste': ('ekstremistisk',),
'ekstrovert': ('ekstrovert',),
'ekstroverte': ('ekstrovert',),
'ekstrovertere': ('ekstrovert',),
'ekstrovertest': ('ekstrovert',),
'ekstroverteste': ('ekstrovert',),
'ekta': ('ekte',),
'ektede': ('ekte',),
'ektende': ('ekte',),
'ektet': ('ekte',),
'ektete': ('ekte',),
'ekte': ('ekte',),
'ekteskapelig': ('ekteskapelig',),
'ekteskapelige': ('ekteskapelig',),
'ekteskapeligere': ('ekteskapelig',),
'ekteskapeligst': ('ekteskapelig',),
'ekteskapeligste': ('ekteskapelig',),
'ektevia': ('ektevie',),
'ektevidd': ('ektevie',),
'ektevidde': ('ektevie',),
'ekteviede': ('ektevie',),
'ekteviende': ('ektevie',),
'ekteviet': ('ektevie',),
'ekteviete': ('ektevie',),
'ektevigd': ('ektevie',),
'ektevigde': ('ektevie',),
'ekvatorial': ('ekvatorial',),
'ekvatoriale': ('ekvatorial',),
'ekvatorialere': ('ekvatorial',),
'ekvatorialest': ('ekvatorial',),
'ekvatorialeste': ('ekvatorial',),
'ekvatorialt': ('ekvatorial',),
'ekvatorialguineansk': ('ekvatorialguineansk',),
'ekvatorialguineanske': ('ekvatorialguineansk',),
'ekvatorialguineanskere': ('ekvatorialguineansk',),
'ekvatorialguineanskest': ('ekvatorialguineansk',),
'ekvatorialguineanskeste': ('ekvatorialguineansk',),
'ekvilibristisk': ('ekvilibristisk',),
'ekvilibristiske': ('ekvilibristisk',),
'ekvilibristiskere': ('ekvilibristisk',),
'ekvilibristiskest': ('ekvilibristisk',),
'ekvilibristiskeste': ('ekvilibristisk',),
'ekviperende': ('ekvipere',),
'ekvipert': ('ekvipere',),
'ekviperte': ('ekvipere',),
'ekvivalent': ('ekvivalent',),
'ekvivalente': ('ekvivalent',),
'ekvivalentere': ('ekvivalent',),
'ekvivalentest': ('ekvivalent',),
'ekvivalenteste': ('ekvivalent',),
'ekvivalerende': ('ekvivalere',),
'ekvivalert': ('ekvivalere',),
'ekvivalerte': ('ekvivalere',),
'elastisk': ('elastisk',),
'elastiske': ('elastisk',),
'elastiskere': ('elastisk',),
'elastiskest': ('elastisk',),
'elastiskeste': ('elastisk',),
'elda': ('elde',),
'eldede': ('elde',),
'eldende': ('elde',),
'eldet': ('elde',),
'eldete': ('elde',),
'elda': ('elde',),
'eldede': ('elde',),
'eldende': ('elde',),
'eldet': ('elde',),
'eldete': ('elde',),
'elda': ('elde',),
'eldede': ('elde',),
'eldende': ('elde',),
'eldet': ('elde',),
'eldete': ('elde',),
'eldfast': ('eldfast',),
'eldfaste': ('eldfast',),
'eldfastere': ('eldfast',),
'eldfastest': ('eldfast',),
'eldfasteste': ('eldfast',),
'eldfast': ('eldfast',),
'eldfaste': ('eldfast',),
'eldfastere': ('eldfast',),
'eldfastest': ('eldfast',),
'eldfasteste': ('eldfast',),
'eldfull': ('eldfull',),
'eldfulle': ('eldfull',),
'eldfullere': ('eldfull',),
'eldfullest': ('eldfull',),
'eldfulleste': ('eldfull',),
'eldfullt': ('eldfull',),
'eldfull': ('eldfull',),
'eldfulle': ('eldfull',),
'eldfullere': ('eldfull',),
'eldfullest': ('eldfull',),
'eldfulleste': ('eldfull',),
'eldfullt': ('eldfull',),
'eldeldre': ('eldgammel',),
'eldeldst': ('eldgammel',),
'eldeldste': ('eldgammel',),
'eldgamle': ('eldgammel',),
'eldgammel': ('eldgammel',),
'eldgammelt': ('eldgammel',),
'eldhuga': ('eldhuga',),
'eldre': ('eldre',),
'eldrød': ('eldrød',),
'eldrøde': ('eldrød',),
'eldrødere': ('eldrød',),
'eldrødest': ('eldrød',),
'eldrødeste': ('eldrød',),
'eldrødt': ('eldrød',),
'eldrød': ('eldrød',),
'eldrøde': ('eldrød',),
'eldrødere': ('eldrød',),
'eldrødest': ('eldrød',),
'eldrødeste': ('eldrød',),
'eldrødt': ('eldrød',),
'eldrød': ('eldrød',),
'eldrøde': ('eldrød',),
'eldrødere': ('eldrød',),
'eldrødest': ('eldrød',),
'eldrødeste': ('eldrød',),
'eldrødt': ('eldrød',),
'eldsfarlig': ('eldsfarlig',),
'eldsfarlige': ('eldsfarlig',),
'eldsfarligere': ('eldsfarlig',),
'eldsfarligst': ('eldsfarlig',),
'eldsfarligste': ('eldsfarlig',),
'eldsfarlig': ('eldsfarlig',),
'eldsfarlige': ('eldsfarlig',),
'eldsfarligere': ('eldsfarlig',),
'eldsfarligst': ('eldsfarlig',),
'eldsfarligste': ('eldsfarlig',),
'eldsikker': ('eldsikker',),
'eldsikkert': ('eldsikker',),
'eldsikre': ('eldsikker',),
'eldsikrere': ('eldsikker',),
'eldsikrest': ('eldsikker',),
'eldsikreste': ('eldsikker',),
'eldsikker': ('eldsikker',),
'eldsikkert': ('eldsikker',),
'eldsikre': ('eldsikker',),
'eldsikrere': ('eldsikker',),
'eldsikrest': ('eldsikker',),
'eldsikreste': ('eldsikker',),
'eldsprutende': ('eldsprutende',),
'eldsprutende': ('eldsprutende',),
'elegant': ('elegant',),
'elegante': ('elegant',),
'elegantere': ('elegant',),
'elegantest': ('elegant',),
'eleganteste': ('elegant',),
'elegisk': ('elegisk',),
'elegiske': ('elegisk',),
'elegiskere': ('elegisk',),
'elegiskest': ('elegisk',),
'elegiskeste': ('elegisk',),
'elektiv': ('elektiv',),
'elektive': ('elektiv',),
'elektivere': ('elektiv',),
'elektivest': ('elektiv',),
'elektiveste': ('elektiv',),
'elektivt': ('elektiv',),
'elektoral': ('elektoral',),
'elektorale': ('elektoral',),
'elektoralere': ('elektoral',),
'elektoralest': ('elektoral',),
'elektoraleste': ('elektoral',),
'elektoralt': ('elektoral',),
'elektrifiserende': ('elektrifisere',),
'elektrifisert': ('elektrifisere',),
'elektrifiserte': ('elektrifisere',),
'elektriserende': ('elektrisere',),
'elektrisert': ('elektrisere',),
'elektriserte': ('elektrisere',),
'elektrisk': ('elektrisk',),
'elektriske': ('elektrisk',),
'elektriskere': ('elektrisk',),
'elektriskest': ('elektrisk',),
'elektriskeste': ('elektrisk',),
'elektrokjemisk': ('elektrokjemisk',),
'elektrokjemiske': ('elektrokjemisk',),
'elektrokjemiskere': ('elektrokjemisk',),
'elektrokjemiskest': ('elektrokjemisk',),
'elektrokjemiskeste': ('elektrokjemisk',),
'elektrolytisk': ('elektrolytisk',),
'elektrolytiske': ('elektrolytisk',),
'elektrolytiskere': ('elektrolytisk',),
'elektrolytiskest': ('elektrolytisk',),
'elektrolytiskeste': ('elektrolytisk',),
'elektromagnetisk': ('elektromagnetisk',),
'elektromagnetiske': ('elektromagnetisk',),
'elektromagnetiskere': ('elektromagnetisk',),
'elektromagnetiskest': ('elektromagnetisk',),
'elektromagnetiskeste': ('elektromagnetisk',),
'elektrometallurgisk': ('elektrometallurgisk',),
'elektrometallurgiske': ('elektrometallurgisk',),
'elektrometallurgiskere': ('elektrometallurgisk',),
'elektrometallurgiskest': ('elektrometallurgisk',),
'elektrometallurgiskeste': ('elektrometallurgisk',),
'elektronisk': ('elektronisk',),
'elektroniske': ('elektronisk',),
'elektroniskere': ('elektronisk',),
'elektroniskest': ('elektronisk',),
'elektroniskeste': ('elektronisk',),
'elementær': ('elementær',),
'elementære': ('elementær',),
'elementærere': ('elementær',),
'elementærest': ('elementær',),
'elementæreste': ('elementær',),
'elementært': ('elementær',),
'elendig': ('elendig',),
'elendige': ('elendig',),
'elendigere': ('elendig',),
'elendigst': ('elendig',),
'elendigste': ('elendig',),
'eleverende': ('elevere',),
'elevert': ('elevere',),
'eleverte': ('elevere',),
'elevert': ('elevert',),
'eleverte': ('elevert',),
'elevertere': ('elevert',),
'elevertest': ('elevert',),
'eleverteste': ('elevert',),
'elgsblakk': ('elgsblakk',),
'elgsblakke': ('elgsblakk',),
'elgsblakkere': ('elgsblakk',),
'elgsblakkest': ('elgsblakk',),
'elgsblakkeste': ('elgsblakk',),
'elgsblakt': ('elgsblakk',),
'elgsgrå': ('elgsgrå',),
'elgsgråe': ('elgsgrå',),
'elgsgråere': ('elgsgrå',),
'elgsgråest': ('elgsgrå',),
'elgsgråeste': ('elgsgrå',),
'elgsgrått': ('elgsgrå',),
'eligerende': ('eligere',),
'eligert': ('eligere',),
'eligerte': ('eligere',),
'eliminerende': ('eliminere',),
'eliminert': ('eliminere',),
'eliminerte': ('eliminere',),
'ella': ('elle',),
'ellede': ('elle',),
'ellende': ('elle',),
'ellet': ('elle',),
'ellete': ('elle',),
'elleveårig': ('elleveårig',),
'elleveårige': ('elleveårig',),
'elleveårigere': ('elleveårig',),
'elleveårigst': ('elleveårig',),
'elleveårigste': ('elleveårig',),
'elleveårs': ('elleveårs',),
'ellevill': ('ellevill',),
'elleville': ('ellevill',),
'ellevillere': ('ellevill',),
'ellevillest': ('ellevill',),
'ellevilleste': ('ellevill',),
'ellevilt': ('ellevill',),
'ellevte': ('ellevte',),
'ellipseforma': ('ellipseforma',),
'ellipseformede': ('ellipseformet',),
'ellipseformet': ('ellipseformet',),
'ellipseformete': ('ellipseformet',),
'ellipseformetere': ('ellipseformet',),
'ellipseformetest': ('ellipseformet',),
'ellipseformeteste': ('ellipseformet',),
'elliptisk': ('elliptisk',),
'elliptiske': ('elliptisk',),
'elliptiskere': ('elliptisk',),
'elliptiskest': ('elliptisk',),
'elliptiskeste': ('elliptisk',),
'elokserende': ('eloksere',),
'eloksert': ('eloksere',),
'elokserte': ('eloksere',),
'elska': ('elske',),
'elskede': ('elske',),
'elskende': ('elske',),
'elsket': ('elske',),
'elskete': ('elske',),
'elskelig': ('elskelig',),
'elskelige': ('elskelig',),
'elskeligere': ('elskelig',),
'elskeligst': ('elskelig',),
'elskeligste': ('elskelig',),
'elskovsfull': ('elskovsfull',),
'elskovsfulle': ('elskovsfull',),
'elskovsfullere': ('elskovsfull',),
'elskovsfullest': ('elskovsfull',),
'elskovsfulleste': ('elskovsfull',),
'elskovsfullt': ('elskovsfull',),
'elskverdig': ('elskverdig',),
'elskverdige': ('elskverdig',),
'elskverdigere': ('elskverdig',),
'elskverdigst': ('elskverdig',),
'elskverdigste': ('elskverdig',),
'elta': ('elte',),
'eltede': ('elte',),
'eltende': ('elte',),
'eltet': ('elte',),
'eltete': ('elte',),
'eluderende': ('eludere',),
'eludert': ('eludere',),
'eluderte': ('eludere',),
'elyseisk': ('elyseisk',),
'elyseiske': ('elyseisk',),
'elyseiskere': ('elyseisk',),
'elyseiskest': ('elyseisk',),
'elyseiskeste': ('elyseisk',),
'elysisk': ('elysisk',),
'elysiske': ('elysisk',),
'elysiskere': ('elysisk',),
'elysiskest': ('elysisk',),
'elysiskeste': ('elysisk',),
'elzevirsk': ('elzevirsk',),
'elzevirske': ('elzevirsk',),
'elzevirskere': ('elzevirsk',),
'elzevirskest': ('elzevirsk',),
'elzevirskeste': ('elzevirsk',),
'emaljerende': ('emaljere',),
'emaljert': ('emaljere',),
'emaljerte': ('emaljere',),
'emansiperende': ('emansipere',),
'emansipert': ('emansipere',),
'emansiperte': ('emansipere',),
'emansipert': ('emansipert',),
'emansiperte': ('emansipert',),
'emansipertere': ('emansipert',),
'emansipertest': ('emansipert',),
'emansiperteste': ('emansipert',),
'emballerende': ('emballere',),
'emballert': ('emballere',),
'emballerte': ('emballere',),
'embarkerende': ('embarkere',),
'embarkert': ('embarkere',),
'embarkerte': ('embarkere',),
'emeriti': ('emeritus',),
'emeritus': ('emeritus',),
'emfatisk': ('emfatisk',),
'emfatiske': ('emfatisk',),
'emfatiskere': ('emfatisk',),
'emfatiskest': ('emfatisk',),
'emfatiskeste': ('emfatisk',),
'emigrerende': ('emigrere',),
'emigrert': ('emigrere',),
'emigrerte': ('emigrere',),
'eminent': ('eminent',),
'eminente': ('eminent',),
'eminentere': ('eminent',),
'eminentest': ('eminent',),
'eminenteste': ('eminent',),
'emitterende': ('emittere',),
'emittert': ('emittere',),
'emitterte': ('emittere',),
'emmen': ('emmen',),
'emment': ('emmen',),
'emne': ('emmen',),
'emnere': ('emmen',),
'emnest': ('emmen',),
'emneste': ('emmen',),
'emna': ('emne',),
'emnede': ('emne',),
'emnende': ('emne',),
'emnet': ('emne',),
'emnete': ('emne',),
'emnelig': ('emnelig',),
'emnelige': ('emnelig',),
'emneligere': ('emnelig',),
'emneligst': ('emnelig',),
'emneligste': ('emnelig',),
'emosjonell': ('emosjonell',),
'emosjonelle': ('emosjonell',),
'emosjonellere': ('emosjonell',),
'emosjonellest': ('emosjonell',),
'emosjonelleste': ('emosjonell',),
'emosjonelt': ('emosjonell',),
'emotiv': ('emotiv',),
'emotive': ('emotiv',),
'emotivere': ('emotiv',),
'emotivest': ('emotiv',),
'emotiveste': ('emotiv',),
'emotivt': ('emotiv',),
'empirisk': ('empirisk',),
'empiriske': ('empirisk',),
'empiriskere': ('empirisk',),
'empiriskest': ('empirisk',),
'empiriskeste': ('empirisk',),
'employerende': ('employere',),
'employert': ('employere',),
'employerte': ('employere',),
'emulgerende': ('emulgere',),
'emulgert': ('emulgere',),
'emulgerte': ('emulgere',),
'en vogue': ('en vogue',),
'enarma': ('enarma',),
'enarmede': ('enarmet',),
'enarmet': ('enarmet',),
'enarmete': ('enarmet',),
'enarmetere': ('enarmet',),
'enarmetest': ('enarmet',),
'enarmeteste': ('enarmet',),
'enatomig': ('enatomig',),
'enatomige': ('enatomig',),
'enatomigere': ('enatomig',),
'enatomigst': ('enatomig',),
'enatomigste': ('enatomig',),
'enbo': ('enbo',),
'enbu': ('enbu',),
'enbåren': ('enbåren',),
'enbårent': ('enbåren',),
'enbårne': ('enbåren',),
'enbårnere': ('enbåren',),
'enbårnest': ('enbåren',),
'enbårneste': ('enbåren',),
'encella': ('encella',),
'encellede': ('encellet',),
'encellet': ('encellet',),
'encellete': ('encellet',),
'encelletere': ('encellet',),
'encelletest': ('encellet',),
'encelleteste': ('encellet',),
'encyklisk': ('encyklisk',),
'encykliske': ('encyklisk',),
'encykliskere': ('encyklisk',),
'encykliskest': ('encyklisk',),
'encykliskeste': ('encyklisk',),
'encyklopedisk': ('encyklopedisk',),
'encyklopediske': ('encyklopedisk',),
'encyklopediskere': ('encyklopedisk',),
'encyklopediskest': ('encyklopedisk',),
'encyklopediskeste': ('encyklopedisk',),
'endende': ('ende',),
'endt': ('ende',),
'endte': ('ende',),
'endefram': ('endefram',),
'endeframme': ('endefram',),
'endeframmere': ('endefram',),
'endeframmest': ('endefram',),
'endeframmeste': ('endefram',),
'endeframt': ('endefram',),
'endefrem': ('endefrem',),
'endefremme': ('endefrem',),
'endefremmere': ('endefrem',),
'endefremmest': ('endefrem',),
'endefremmeste': ('endefrem',),
'endefremt': ('endefrem',),
'endegyldig': ('endegyldig',),
'endegyldige': ('endegyldig',),
'endegyldigere': ('endegyldig',),
'endegyldigst': ('endegyldig',),
'endegyldigste': ('endegyldig',),
'endelaus': ('endelaus',),
'endelause': ('endelaus',),
'endelausere': ('endelaus',),
'endelausest': ('endelaus',),
'endelauseste': ('endelaus',),
'endelaust': ('endelaus',),
'endelig': ('endelig',),
'endelige': ('endelig',),
'endeligere': ('endelig',),
'endeligst': ('endelig',),
'endeligste': ('endelig',),
'endeløs': ('endeløs',),
'endeløse': ('endeløs',),
'endeløsere': ('endeløs',),
'endeløsest': ('endeløs',),
'endeløseste': ('endeløs',),
'endeløst': ('endeløs',),
'endemisk': ('endemisk',),
'endemiske': ('endemisk',),
'endemiskere': ('endemisk',),
'endemiskest': ('endemisk',),
'endemiskeste': ('endemisk',),
'endetil': ('endetil',),
'endevendende': ('endevende',),
'endevendt': ('endevende',),
'endevendte': ('endevende',),
'endimensjonal': ('endimensjonal',),
'endimensjonale': ('endimensjonal',),
'endimensjonalere': ('endimensjonal',),
'endimensjonalest': ('endimensjonal',),
'endimensjonaleste': ('endimensjonal',),
'endimensjonalt': ('endimensjonal',),
'endogen': ('endogen',),
'endogene': ('endogen',),
'endogenere': ('endogen',),
'endogenest': ('endogen',),
'endogeneste': ('endogen',),
'endogent': ('endogen',),
'endokrin': ('endokrin',),
'endokrine': ('endokrin',),
'endokrinere': ('endokrin',),
'endokrinest': ('endokrin',),
'endokrineste': ('endokrin',),
'endokrint': ('endokrin',),
'endosserende': ('endossere',),
'endossert': ('endossere',),
'endosserte': ('endossere',),
'endoterm': ('endoterm',),
'endoterme': ('endoterm',),
'endotermere': ('endoterm',),
'endotermest': ('endoterm',),
'endotermeste': ('endoterm',),
'endotermt': ('endoterm',),
'endra': ('endre',),
'endrede': ('endre',),
'endrende': ('endre',),
'endret': ('endre',),
'endrete': ('endre',),
'enende': ('ene',),
'ent': ('ene',),
'ente': ('ene',),
'eneberettiga': ('eneberettiga',),
'eneberettigede': ('eneberettiget',),
'eneberettiget': ('eneberettiget',),
'eneberettigete': ('eneberettiget',),
'eneberettigetere': ('eneberettiget',),
'eneberettigetest': ('eneberettiget',),
'eneberettigeteste': ('eneberettiget',),
'eneherskende': ('eneherskende',),
'energetisk': ('energetisk',),
'energetiske': ('energetisk',),
'energetiskere': ('energetisk',),
'energetiskest': ('energetisk',),
'energetiskeste': ('energetisk',),
'energisk': ('energisk',),
'energiske': ('energisk',),
'energiskere': ('energisk',),
'energiskest': ('energisk',),
'energiskeste': ('energisk',),
'enerverende': ('enervere',),
'enervert': ('enervere',),
'enerverte': ('enervere',),
'enerverende': ('enerverende',),
'enerådende': ('enerådende',),
'enerådig': ('enerådig',),
'enerådige': ('enerådig',),
'enerådigere': ('enerådig',),
'enerådigst': ('enerådig',),
'enerådigste': ('enerådig',),
'enestående': ('enestående',),
'enetasjes': ('enetasjes',),
'eneveldig': ('eneveldig',),
'eneveldige': ('eneveldig',),
'eneveldigere': ('eneveldig',),
'eneveldigst': ('eneveldig',),
'eneveldigste': ('eneveldig',),
'enfasa': ('enfasa',),
'enfasede': ('enfaset',),
'enfaset': ('enfaset',),
'enfasete': ('enfaset',),
'enfasetere': ('enfaset',),
'enfasetest': ('enfaset',),
'enfaseteste': ('enfaset',),
'enfoldig': ('enfoldig',),
'enfoldige': ('enfoldig',),
'enfoldigere': ('enfoldig',),
'enfoldigst': ('enfoldig',),
'enfoldigste': ('enfoldig',),
'enfrøblada': ('enfrøblada',),
'enfrøbladede': ('enfrøbladet',),
'enfrøbladet': ('enfrøbladet',),
'enfrøbladete': ('enfrøbladet',),
'enfrøbladetere': ('enfrøbladet',),
'enfrøbladetest': ('enfrøbladet',),
'enfrøbladeteste': ('enfrøbladet',),
'eng': ('eng',),
'enge': ('eng',),
'engere': ('eng',),
'engest': ('eng',),
'engeste': ('eng',),
'engt': ('eng',),
'engangs': ('engangs',),
'engasjerende': ('engasjere',),
'engasjert': ('engasjere',),
'engasjerte': ('engasjere',),
'engelsk': ('engelsk',),
'engelske': ('engelsk',),
'engelskere': ('engelsk',),
'engelskest': ('engelsk',),
'engelskeste': ('engelsk',),
'engelsk-norsk': ('engelsk-norsk',),
'engelsk-norske': ('engelsk-norsk',),
'engelsk-norskere': ('engelsk-norsk',),
'engelsk-norskest': ('engelsk-norsk',),
'engelsk-norskeste': ('engelsk-norsk',),
'engelskspråklig': ('engelskspråklig',),
'engelskspråklige': ('engelskspråklig',),
'engelskspråkligere': ('engelskspråklig',),
'engelskspråkligst': ('engelskspråklig',),
'engelskspråkligste': ('engelskspråklig',),
'engelsktalende': ('engelsktalende',),
'engleaktig': ('engleaktig',),
'engleaktige': ('engleaktig',),
'engleaktigere': ('engleaktig',),
'engleaktigst': ('engleaktig',),
'engleaktigste': ('engleaktig',),
'engsta': ('engste',),
'engstede': ('engste',),
'engstende': ('engste',),
'engstet': ('engste',),
'engstete': ('engste',),
'engstelig': ('engstelig',),
'engstelige': ('engstelig',),
'engsteligere': ('engstelig',),
'engsteligst': ('engstelig',),
'engsteligste': ('engstelig',),
'enhetlig': ('enhetlig',),
'enhetlige': ('enhetlig',),
'enhetligere': ('enhetlig',),
'enhetligst': ('enhetlig',),
'enhetligste': ('enhetlig',),
'enhånds': ('enhånds',),
'enig': ('enig',),
'enige': ('enig',),
'enigere': ('enig',),
'enigst': ('enig',),
'enigste': ('enig',),
'enigmatisk': ('enigmatisk',),
'enigmatiske': ('enigmatisk',),
'enigmatiskere': ('enigmatisk',),
'enigmatiskest': ('enigmatisk',),
'enigmatiskeste': ('enigmatisk',),
'enkel': ('enkel',),
'enkelt': ('enkel',),
'enkle': ('enkel',),
'enklere': ('enkel',),
'enklest': ('enkel',),
'enkleste': ('enkel',),
'enkelt': ('enkelt',),
'enkelte': ('enkelt',),
'enkeltere': ('enkelt',),
'enkeltest': ('enkelt',),
'enkelteste': ('enkelt',),
'enkeltknappa': ('enkeltknappa',),
'enkeltknappede': ('enkeltknappet',),
'enkeltknappet': ('enkeltknappet',),
'enkeltknappete': ('enkeltknappet',),
'enkeltknappetere': ('enkeltknappet',),
'enkeltknappetest': ('enkeltknappet',),
'enkeltknappeteste': ('enkeltknappet',),
'enkeltløpa': ('enkeltløpa',),
'enkeltløpede': ('enkeltløpet',),
'enkeltløpet': ('enkeltløpet',),
'enkeltløpete': ('enkeltløpet',),
'enkeltløpetere': ('enkeltløpet',),
'enkeltløpetest': ('enkeltløpet',),
'enkeltløpeteste': ('enkeltløpet',),
'enkeltspent': ('enkeltspent',),
'enkeltspente': ('enkeltspent',),
'enkeltspentere': ('enkeltspent',),
'enkeltspentest': ('enkeltspent',),
'enkeltspenteste': ('enkeltspent',),
'enkeltspora': ('enkeltspora',),
'enkeltsporede': ('enkeltsporet',),
'enkeltsporet': ('enkeltsporet',),
'enkeltsporete': ('enkeltsporet',),
'enkeltsporetere': ('enkeltsporet',),
'enkeltsporetest': ('enkeltsporet',),
'enkeltsporeteste': ('enkeltsporet',),
'enkeltstående': ('enkeltstående',),
'enkjønna': ('enkjønna',),
'enkjønnede': ('enkjønnet',),
'enkjønnet': ('enkjønnet',),
'enkjønnete': ('enkjønnet',),
'enkjønnetere': ('enkjønnet',),
'enkjønnetest': ('enkjønnet',),
'enkjønneteste': ('enkjønnet',),
'enklitisk': ('enklitisk',),
'enklitiske': ('enklitisk',),
'enklitiskere': ('enklitisk',),
'enklitiskest': ('enklitisk',),
'enklitiskeste': ('enklitisk',),
'enmanns': ('enmanns',),
'enmannsbetjent': ('enmannsbetjent',),
'enmannsbetjente': ('enmannsbetjent',),
'enmannsbetjentere': ('enmannsbetjent',),
'enmannsbetjentest': ('enmannsbetjent',),
'enmannsbetjenteste': ('enmannsbetjent',),
'enmotors': ('enmotors',),
'enorm': ('enorm',),
'enorme': ('enorm',),
'enormere': ('enorm',),
'enormest': ('enorm',),
'enormeste': ('enorm',),
'enormt': ('enorm',),
'enpukla': ('enpukla',),
'enpuklede': ('enpuklet',),
'enpuklet': ('enpuklet',),
'enpuklete': ('enpuklet',),
'enpukletere': ('enpuklet',),
'enpukletest': ('enpuklet',),
'enpukleteste': ('enpuklet',),
'ens': ('ens',),
'ensarta': ('ensarta',),
'ensartede': ('ensartet',),
'ensartet': ('ensartet',),
'ensartete': ('ensartet',),
'ensartetere': ('ensartet',),
'ensartetest': ('ensartet',),
'ensarteteste': ('ensartet',),
'ensbetydende': ('ensbetydende',),
'ensa': ('ense',),
'ensede': ('ense',),
'ensende': ('ense',),
'enset': ('ense',),
'ensete': ('ense',),
'enst': ('ense',),
'enste': ('ense',),
'ensfarga': ('ensfarga',),
'ensfargede': ('ensfarget',),
'ensfarget': ('ensfarget',),
'ensfargete': ('ensfarget',),
'ensfargetere': ('ensfarget',),
'ensfargetest': ('ensfarget',),
'ensfargeteste': ('ensfarget',),
'ensforma': ('ensforma',),
'ensformede': ('ensformet',),
'ensformet': ('ensformet',),
'ensformete': ('ensformet',),
'ensformetere': ('ensformet',),
'ensformetest': ('ensformet',),
'ensformeteste': ('ensformet',),
'ensformig': ('ensformig',),
'ensformige': ('ensformig',),
'ensformigere': ('ensformig',),
'ensformigst': ('ensformig',),
'ensformigste': ('ensformig',),
'ensidig': ('ensidig',),
'ensidige': ('ensidig',),
'ensidigere': ('ensidig',),
'ensidigst': ('ensidig',),
'ensidigste': ('ensidig',),
'ensifra': ('ensifra',),
'ensifrede': ('ensifret',),
'ensifret': ('ensifret',),
'ensifrete': ('ensifret',),
'ensifretere': ('ensifret',),
'ensifretest': ('ensifret',),
'ensifreteste': ('ensifret',),
'ensilerende': ('ensilere',),
'ensilert': ('ensilere',),
'ensilerte': ('ensilere',),
'enskafta': ('enskafta',),
'enskaftede': ('enskaftet',),
'enskaftet': ('enskaftet',),
'enskaftete': ('enskaftet',),
'enskaftetere': ('enskaftet',),
'enskaftetest': ('enskaftet',),
'enskafteteste': ('enskaftet',),
'enskjærs': ('enskjærs',),
'enslig': ('enslig',),
'enslige': ('enslig',),
'ensligere': ('enslig',),
'ensligst': ('enslig',),
'ensligste': ('enslig',),
'ensligstilt': ('ensligstilt',),
'ensligstilte': ('ensligstilt',),
'ensligstiltere': ('ensligstilt',),
'ensligstiltest': ('ensligstilt',),
'ensligstilteste': ('ensligstilt',),
'enslydende': ('enslydende',),
'ensom': ('ensom',),
'ensomme': ('ensom',),
'ensommere': ('ensom',),
'ensomst': ('ensom',),
'ensomste': ('ensom',),
'ensomt': ('ensom',),
'enspora': ('enspora',),
'ensporede': ('ensporet',),
'ensporet': ('ensporet',),
'ensporete': ('ensporet',),
'ensporetere': ('ensporet',),
'ensporetest': ('ensporet',),
'ensporeteste': ('ensporet',),
'enspråklig': ('enspråklig',),
'enspråklige': ('enspråklig',),
'enspråkligere': ('enspråklig',),
'enspråkligst': ('enspråklig',),
'enspråkligste': ('enspråklig',),
'ensretta': ('ensrette',),
'ensrettede': ('ensrette',),
'ensrettende': ('ensrette',),
'ensrettet': ('ensrette',),
'ensrettete': ('ensrette',),
'enstava': ('enstava',),
'enstavede': ('enstavet',),
'enstavet': ('enstavet',),
'enstavete': ('enstavet',),
'enstavetere': ('enstavet',),
'enstavetest': ('enstavet',),
'enstaveteste': ('enstavet',),
'enstemmig': ('enstemmig',),
'enstemmige': ('enstemmig',),
'enstemmigere': ('enstemmig',),
'enstemmigst': ('enstemmig',),
'enstemmigste': ('enstemmig',),
'enstonig': ('enstonig',),
'enstonige': ('enstonig',),
'enstonigere': ('enstonig',),
'enstonigst': ('enstonig',),
'enstonigste': ('enstonig',),
'enstrøken': ('enstrøken',),
'enstrøket': ('enstrøken',),
'enstrøkne': ('enstrøken',),
'enstrøknere': ('enstrøken',),
'enstrøknest': ('enstrøken',),
'enstrøkneste': ('enstrøken',),
'enstrøket': ('enstrøket',),
'enstrøkne': ('enstrøket',),
'enstrøknere': ('enstrøket',),
'enstrøknest': ('enstrøket',),
'enstrøkneste': ('enstrøket',),
'enstydig': ('enstydig',),
'enstydige': ('enstydig',),
'enstydigere': ('enstydig',),
'enstydigst': ('enstydig',),
'enstydigste': ('enstydig',),
'ente': ('ente',),
'entoms': ('entoms',),
'entra': ('entre',),
'entrede': ('entre',),
'entrende': ('entre',),
'entret': ('entre',),
'entrete': ('entre',),
'entreprenant': ('entreprenant',),
'entreprenante': ('entreprenant',),
'entreprenantere': ('entreprenant',),
'entreprenantest': ('entreprenant',),
'entreprenanteste': ('entreprenant',),
'entusiastisk': ('entusiastisk',),
'entusiastiske': ('entusiastisk',),
'entusiastiskere': ('entusiastisk',),
'entusiastiskest': ('entusiastisk',),
'entusiastiskeste': ('entusiastisk',),
'entydig': ('entydig',),
'entydige': ('entydig',),
'entydigere': ('entydig',),
'entydigst': ('entydig',),
'entydigste': ('entydig',),
'envegsregulerende': ('envegsregulere',),
'envegsregulert': ('envegsregulere',),
'envegsregulerte': ('envegsregulere',),
'enveisregulerende': ('enveisregulere',),
'enveisregulert': ('enveisregulere',),
'enveisregulerte': ('enveisregulere',),
'enverdig': ('enverdig',),
'enverdige': ('enverdig',),
'enverdigere': ('enverdig',),
'enverdigst': ('enverdig',),
'enverdigste': ('enverdig',),
'envis': ('envis',),
'envise': ('envis',),
'envisere': ('envis',),
'envisest': ('envis',),
'enviseste': ('envis',),
'envist': ('envis',),
'enzymatisk': ('enzymatisk',),
'enzymatiske': ('enzymatisk',),
'enzymatiskere': ('enzymatisk',),
'enzymatiskest': ('enzymatisk',),
'enzymatiskeste': ('enzymatisk',),
'enøres': ('enøres',),
'enøyd': ('enøyd',),
'enøyde': ('enøyd',),
'enøydere': ('enøyd',),
'enøydest': ('enøyd',),
'enøydeste': ('enøyd',),
'epidemisk': ('epidemisk',),
'epidemiske': ('epidemisk',),
'epidemiskere': ('epidemisk',),
'epidemiskest': ('epidemisk',),
'epidemiskeste': ('epidemisk',),
'epidural': ('epidural',),
'epidurale': ('epidural',),
'epiduralere': ('epidural',),
'epiduralest': ('epidural',),
'epiduraleste': ('epidural',),
'epiduralt': ('epidural',),
'epikureisk': ('epikureisk',),
'epikureiske': ('epikureisk',),
'epikureiskere': ('epikureisk',),
'epikureiskest': ('epikureisk',),
'epikureiskeste': ('epikureisk',),
'epileptisk': ('epileptisk',),
'epileptiske': ('epileptisk',),
'epileptiskere': ('epileptisk',),
'epileptiskest': ('epileptisk',),
'epileptiskeste': ('epileptisk',),
'episk': ('episk',),
'episke': ('episk',),
'episkere': ('episk',),
'episkest': ('episk',),
'episkeste': ('episk',),
'episkopal': ('episkopal',),
'episkopale': ('episkopal',),
'episkopalere': ('episkopal',),
'episkopalest': ('episkopal',),
'episkopaleste': ('episkopal',),
'episkopalt': ('episkopal',),
'episodisk': ('episodisk',),
'episodiske': ('episodisk',),
'episodiskere': ('episodisk',),
'episodiskest': ('episodisk',),
'episodiskeste': ('episodisk',),
'epistemisk': ('epistemisk',),
'epistemiske': ('epistemisk',),
'epistemiskere': ('epistemisk',),
'epistemiskest': ('epistemisk',),
'epistemiskeste': ('epistemisk',),
'epistemologisk': ('epistemologisk',),
'epistemologiske': ('epistemologisk',),
'epistemologiskere': ('epistemologisk',),
'epistemologiskest': ('epistemologisk',),
'epistemologiskeste': ('epistemologisk',),
'epokegjørende': ('epokegjørende',),
'erfarende': ('erfare',),
'erfart': ('erfare',),
'erfarte': ('erfare',),
'erfaren': ('erfaren',),
'erfarent': ('erfaren',),
'erfarne': ('erfaren',),
'erfarnere': ('erfaren',),
'erfarnest': ('erfaren',),
'erfarneste': ('erfaren',),
'erfaringsmessig': ('erfaringsmessig',),
'erfaringsmessige': ('erfaringsmessig',),
'erfaringsmessigere': ('erfaringsmessig',),
'erfaringsmessigst': ('erfaringsmessig',),
'erfaringsmessigste': ('erfaringsmessig',),
'ergerlig': ('ergerlig',),
'ergerlige': ('ergerlig',),
'ergerligere': ('ergerlig',),
'ergerligst': ('ergerlig',),
'ergerligste': ('ergerlig',),
'ergra': ('ergre',),
'ergrede': ('ergre',),
'ergrende': ('ergre',),
'ergret': ('ergre',),
'ergrete': ('ergre',),
'erholdende': ('erholde',),
'erholdt': ('erholde',),
'erholdte': ('erholde',),
'erigerende': ('erigere',),
'erigert': ('erigere',),
'erigerte': ('erigere',),
'erindra': ('erindre',),
'erindrede': ('erindre',),
'erindrende': ('erindre',),
'erindret': ('erindre',),
'erindrete': ('erindre',),
'eritreisk': ('eritreisk',),
'eritreiske': ('eritreisk',),
'eritreiskere': ('eritreisk',),
'eritreiskest': ('eritreisk',),
'eritreiskeste': ('eritreisk',),
'erkekonservativ': ('erkekonservativ',),
'erkekonservative': ('erkekonservativ',),
'erkekonservativere': ('erkekonservativ',),
'erkekonservativest': ('erkekonservativ',),
'erkekonservativeste': ('erkekonservativ',),
'erkekonservativt': ('erkekonservativ',),
'erkjennende': ('erkjenne',),
'erkjent': ('erkjenne',),
'erkjente': ('erkjenne',),
'erklærende': ('erklære',),
'erklært': ('erklære',),
'erklærte': ('erklære',),
'erklært': ('erklært',),
'erklærte': ('erklært',),
'erklærtere': ('erklært',),
'erklærtest': ('erklært',),
'erklærteste': ('erklært',),
'erlagt': ('erlegge',),
'erlagte': ('erlegge',),
'erleggende': ('erlegge',),
'ernærende': ('ernære',),
'ernært': ('ernære',),
'ernærte': ('ernære',),
'erobra': ('erobre',),
'erobrede': ('erobre',),
'erobrende': ('erobre',),
'erobret': ('erobre',),
'erobrete': ('erobre',),
'eroderende': ('erodere',),
'erodert': ('erodere',),
'eroderte': ('erodere',),
'erogen': ('erogen',),
'erogene': ('erogen',),
'erogenere': ('erogen',),
'erogenest': ('erogen',),
'erogeneste': ('erogen',),
'erogent': ('erogen',),
'erotiserende': ('erotisere',),
'erotisert': ('erotisere',),
'erotiserte': ('erotisere',),
'erotisk': ('erotisk',),
'erotiske': ('erotisk',),
'erotiskere': ('erotisk',),
'erotiskest': ('erotisk',),
'erotiskeste': ('erotisk',),
'erotoman': ('erotoman',),
'erotomane': ('erotoman',),
'erotomanere': ('erotoman',),
'erotomanest': ('erotoman',),
'erotomaneste': ('erotoman',),
'erotomant': ('erotoman',),
'erstatta': ('erstatte',),
'erstattede': ('erstatte',),
'erstattende': ('erstatte',),
'erstattet': ('erstatte',),
'erstattete': ('erstatte',),
'erstattelig': ('erstattelig',),
'erstattelige': ('erstattelig',),
'erstatteligere': ('erstattelig',),
'erstatteligst': ('erstattelig',),
'erstatteligste': ('erstattelig',),
'erta': ('erte',),
'ertede': ('erte',),
'ertende': ('erte',),
'ertet': ('erte',),
'ertete': ('erte',),
'erteblomstra': ('erteblomstra',),
'erteblomstrede': ('erteblomstret',),
'erteblomstret': ('erteblomstret',),
'erteblomstrete': ('erteblomstret',),
'erteblomstretere': ('erteblomstret',),
'erteblomstretest': ('erteblomstret',),
'erteblomstreteste': ('erteblomstret',),
'erten': ('erten',),
'ertent': ('erten',),
'ertne': ('erten',),
'ertnere': ('erten',),
'ertnest': ('erten',),
'ertneste': ('erten',),
'ertet': ('ertet',),
'ertete': ('ertet',),
'ertetere': ('ertet',),
'ertetest': ('ertet',),
'erteteste': ('ertet',),
'ertete': ('ertete',),
'eruptiv': ('eruptiv',),
'eruptive': ('eruptiv',),
'eruptivere': ('eruptiv',),
'eruptivest': ('eruptiv',),
'eruptiveste': ('eruptiv',),
'eruptivt': ('eruptiv',),
'erverva': ('erverve',),
'ervervede': ('erverve',),
'ervervende': ('erverve',),
'ervervet': ('erverve',),
'ervervete': ('erverve',),
'ervervsdyktig': ('ervervsdyktig',),
'ervervsdyktige': ('ervervsdyktig',),
'ervervsdyktigere': ('ervervsdyktig',),
'ervervsdyktigst': ('ervervsdyktig',),
'ervervsdyktigste': ('ervervsdyktig',),
'ervervslaus': ('ervervslaus',),
'ervervslause': ('ervervslaus',),
'ervervslausere': ('ervervslaus',),
'ervervslausest': ('ervervslaus',),
'ervervslauseste': ('ervervslaus',),
'ervervslaust': ('ervervslaus',),
'ervervsløs': ('ervervsløs',),
'ervervsløse': ('ervervsløs',),
'ervervsløsere': ('ervervsløs',),
'ervervsløsest': ('ervervsløs',),
'ervervsløseste': ('ervervsløs',),
'ervervsløst': ('ervervsløs',),
'ervervsmessig': ('ervervsmessig',),
'ervervsmessige': ('ervervsmessig',),
'ervervsmessigere': ('ervervsmessig',),
'ervervsmessigst': ('ervervsmessig',),
'ervervsmessigste': ('ervervsmessig',),
'esende': ('ese',),
'est': ('ese',),
'este': ('ese',),
'eskalerende': ('eskalere',),
'eskalert': ('eskalere',),
'eskalerte': ('eskalere',),
'eskamoterende': ('eskamotere',),
'eskamotert': ('eskamotere',),
'eskamoterte': ('eskamotere',),
'eskaperende': ('eskapere',),
'eskapert': ('eskapere',),
'eskaperte': ('eskapere',),
'eskapistisk': ('eskapistisk',),
'eskapistiske': ('eskapistisk',),
'eskapistiskere': ('eskapistisk',),
'eskapistiskest': ('eskapistisk',),
'eskapistiskeste': ('eskapistisk',),
'eskatologisk': ('eskatologisk',),
'eskatologiske': ('eskatologisk',),
'eskatologiskere': ('eskatologisk',),
'eskatologiskest': ('eskatologisk',),
'eskatologiskeste': ('eskatologisk',),
'eska': ('eske',),
'eskede': ('eske',),
'eskende': ('eske',),
'esket': ('eske',),
'eskete': ('eske',),
'eskimoisk': ('eskimoisk',),
'eskimoiske': ('eskimoisk',),
'eskimoiskere': ('eskimoisk',),
'eskimoiskest': ('eskimoisk',),
'eskimoiskeste': ('eskimoisk',),
'eskimoisk-aleutisk': ('eskimoisk-aleutisk',),
'eskimoisk-aleutiske': ('eskimoisk-aleutisk',),
'eskimoisk-aleutiskere': ('eskimoisk-aleutisk',),
'eskimoisk-aleutiskest': ('eskimoisk-aleutisk',),
'eskimoisk-aleutiskeste': ('eskimoisk-aleutisk',),
'eskorterende': ('eskortere',),
'eskortert': ('eskortere',),
'eskorterte': ('eskortere',),
'esla': ('esle',),
'eslede': ('esle',),
'eslende': ('esle',),
'eslet': ('esle',),
'eslete': ('esle',),
'esoterisk': ('esoterisk',),
'esoteriske': ('esoterisk',),
'esoteriskere': ('esoterisk',),
'esoteriskest': ('esoterisk',),
'esoteriskeste': ('esoterisk',),
'essensiell': ('essensiell',),
'essensielle': ('essensiell',),
'essensiellere': ('essensiell',),
'essensiellest': ('essensiell',),
'essensielleste': ('essensiell',),
'essensielt': ('essensiell',),
'estetiserende': ('estetisere',),
'estetisert': ('estetisere',),
'estetiserte': ('estetisere',),
'estetisk': ('estetisk',),
'estetiske': ('estetisk',),
'estetiskere': ('estetisk',),
'estetiskest': ('estetisk',),
'estetiskeste': ('estetisk',),
'estimerende': ('estimere',),
'estimert': ('estimere',),
'estimerte': ('estimere',),
'estisk': ('estisk',),
'estiske': ('estisk',),
'estiskere': ('estisk',),
'estiskest': ('estisk',),
'estiskeste': ('estisk',),
'estlandsk': ('estlandsk',),
'estlandske': ('estlandsk',),
'estlandskere': ('estlandsk',),
'estlandskest': ('estlandsk',),
'estlandskeste': ('estlandsk',),
'etablerende': ('etablere',),
'etablert': ('etablere',),
'etablerte': ('etablere',),
'etablert': ('etablert',),
'etablerte': ('etablert',),
'etablertere': ('etablert',),
'etablertest': ('etablert',),
'etablerteste': ('etablert',),
'etende': ('ete',),
'ett': ('ete',),
'ette': ('ete',),
'eterisk': ('eterisk',),
'eteriske': ('eterisk',),
'eteriskere': ('eterisk',),
'eteriskest': ('eterisk',),
'eteriskeste': ('eterisk',),
'etiketterende': ('etikettere',),
'etikettert': ('etikettere',),
'etiketterte': ('etikettere',),
'etiopisk': ('etiopisk',),
'etiopiske': ('etiopisk',),
'etiopiskere': ('etiopisk',),
'etiopiskest': ('etiopisk',),
'etiopiskeste': ('etiopisk',),
'etisk': ('etisk',),
'etiske': ('etisk',),
'etiskere': ('etisk',),
'etiskest': ('etisk',),
'etiskeste': ('etisk',),
'etla': ('etle',),
'etlede': ('etle',),
'etlende': ('etle',),
'etlet': ('etle',),
'etlete': ('etle',),
'etnisk': ('etnisk',),
'etniske': ('etnisk',),
'etniskere': ('etnisk',),
'etniskest': ('etnisk',),
'etniskeste': ('etnisk',),
'etnografisk': ('etnografisk',),
'etnografiske': ('etnografisk',),
'etnografiskere': ('etnografisk',),
'etnografiskest': ('etnografisk',),
'etnografiskeste': ('etnografisk',),
'etnologisk': ('etnologisk',),
'etnologiske': ('etnologisk',),
'etnologiskere': ('etnologisk',),
'etnologiskest': ('etnologisk',),
'etnologiskeste': ('etnologisk',),
'etnosentrisk': ('etnosentrisk',),
'etnosentriske': ('etnosentrisk',),
'etnosentriskere': ('etnosentrisk',),
'etnosentriskest': ('etnosentrisk',),
'etnosentriskeste': ('etnosentrisk',),
'etologisk': ('etologisk',),
'etologiske': ('etologisk',),
'etologiskere': ('etologisk',),
'etologiskest': ('etologisk',),
'etologiskeste': ('etologisk',),
'etrurisk': ('etrurisk',),
'etruriske': ('etrurisk',),
'etruriskere': ('etrurisk',),
'etruriskest': ('etrurisk',),
'etruriskeste': ('etrurisk',),
'etruskisk': ('etruskisk',),
'etruskiske': ('etruskisk',),
'etruskiskere': ('etruskisk',),
'etruskiskest': ('etruskisk',),
'etruskiskeste': ('etruskisk',),
'etsa': ('etse',),
'etsede': ('etse',),
'etsende': ('etse',),
'etset': ('etse',),
'etsete': ('etse',),
'etteranmeldende': ('etteranmelde',),
'etteranmeldt': ('etteranmelde',),
'etteranmeldte': ('etteranmelde',),
'etterapa': ('etterape',),
'etterapede': ('etterape',),
'etterapende': ('etterape',),
'etterapet': ('etterape',),
'etterapete': ('etterape',),
'etterapt': ('etterape',),
'etterapte': ('etterape',),
'etterbehandla': ('etterbehandle',),
'etterbehandlede': ('etterbehandle',),
'etterbehandlende': ('etterbehandle',),
'etterbehandlet': ('etterbehandle',),
'etterbehandlete': ('etterbehandle',),
'etterbetalende': ('etterbetale',),
'etterbetalt': ('etterbetale',),
'etterbetalte': ('etterbetale',),
'etterforska': ('etterforske',),
'etterforskede': ('etterforske',),
'etterforskende': ('etterforske',),
'etterforsket': ('etterforske',),
'etterforskete': ('etterforske',),
'etterfyllende': ('etterfylle',),
'etterfylt': ('etterfylle',),
'etterfylte': ('etterfylle',),
'ettergiende': ('ettergi',),
'ettergitt': ('ettergi',),
'ettergitte': ('ettergi',),
'ettergivende': ('ettergi',),
'ettergiven': ('ettergiven',),
'ettergivent': ('ettergiven',),
'ettergivne': ('ettergiven',),
'ettergivnere': ('ettergiven',),
'ettergivnest': ('ettergiven',),
'ettergivneste': ('ettergiven',),
'ettergivende': ('ettergivende',),
'ettergjort': ('ettergjøre',),
'ettergjorte': ('ettergjøre',),
'ettergjørende': ('ettergjøre',),
'ettergymnasial': ('ettergymnasial',),
'ettergymnasiale': ('ettergymnasial',),
'ettergymnasialere': ('ettergymnasial',),
'ettergymnasialest': ('ettergymnasial',),
'ettergymnasialeste': ('ettergymnasial',),
'ettergymnasialt': ('ettergymnasial',),
'etterhengt': ('etterhengt',),
'etterhengte': ('etterhengt',),
'etterhengtere': ('etterhengt',),
'etterhengtest': ('etterhengt',),
'etterhengteste': ('etterhengt',),
'etterisolerende': ('etterisolere',),
'etterisolert': ('etterisolere',),
'etterisolerte': ('etterisolere',),
'etterklok': ('etterklok',),
'etterkloke': ('etterklok',),
'etterklokere': ('etterklok',),
'etterklokest': ('etterklok',),
'etterklokeste': ('etterklok',),
'etterklokt': ('etterklok',),
'etterlatende': ('etterlate',),
'etterlatt': ('etterlate',),
'etterlatte': ('etterlate',),
'etterlengta': ('etterlengta',),
'etterlengtede': ('etterlengtet',),
'etterlengtet': ('etterlengtet',),
'etterlengtete': ('etterlengtet',),
'etterlengtetere': ('etterlengtet',),
'etterlengtetest': ('etterlengtet',),
'etterlengteteste': ('etterlengtet',),
'etterlevd': ('etterleve',),
'etterlevde': ('etterleve',),
'etterlevende': ('etterleve',),
'etterlevende': ('etterlevende',),
'etterligna': ('etterligne',),
'etterlignede': ('etterligne',),
'etterlignende': ('etterligne',),
'etterlignet': ('etterligne',),
'etterlignete': ('etterligne',),
'etterlikna': ('etterlikne',),
'etterliknede': ('etterlikne',),
'etterliknende': ('etterlikne',),
'etterliknet': ('etterlikne',),
'etterliknete': ('etterlikne',),
'etterlysende': ('etterlyse',),
'etterlyst': ('etterlyse',),
'etterlyste': ('etterlyse',),
'etterplapra': ('etterplapre',),
'etterplaprede': ('etterplapre',),
'etterplaprende': ('etterplapre',),
'etterplapret': ('etterplapre',),
'etterplaprete': ('etterplapre',),
'etterprøvd': ('etterprøve',),
'etterprøvde': ('etterprøve',),
'etterprøvende': ('etterprøve',),
'etterpåklok': ('etterpåklok',),
'etterpåkloke': ('etterpåklok',),
'etterpåklokere': ('etterpåklok',),
'etterpåklokest': ('etterpåklok',),
'etterpåklokeste': ('etterpåklok',),
'etterpåklokt': ('etterpåklok',),
'etterrettelig': ('etterrettelig',),
'etterrettelige': ('etterrettelig',),
'etterretteligere': ('etterrettelig',),
'etterretteligst': ('etterrettelig',),
'etterretteligste': ('etterrettelig',),
'etterseende': ('etterse',),
'ettersett': ('etterse',),
'ettersette': ('etterse',),
'ettersendende': ('ettersende',),
'ettersendt': ('ettersende',),
'ettersendte': ('ettersende',),
'ettersittende': ('ettersittende',),
'etterslokka': ('etterslokke',),
'etterslokkede': ('etterslokke',),
'etterslokkende': ('etterslokke',),
'etterslokket': ('etterslokke',),
'etterslokkete': ('etterslokke',),
'etterslokt': ('etterslokke',),
'etterslokte': ('etterslokke',),
'etterslukka': ('etterslukke',),
'etterslukkede': ('etterslukke',),
'etterslukkende': ('etterslukke',),
'etterslukket': ('etterslukke',),
'etterslukkete': ('etterslukke',),
'etterslukt': ('etterslukke',),
'etterslukte': ('etterslukke',),
'etterspora': ('etterspore',),
'ettersporede': ('etterspore',),
'ettersporende': ('etterspore',),
'ettersporet': ('etterspore',),
'ettersporete': ('etterspore',),
'ettersport': ('etterspore',),
'ettersporte': ('etterspore',),
'etterspurt': ('etterspurt',),
'etterspurte': ('etterspurt',),
'etterspurtere': ('etterspurt',),
'etterspurtest': ('etterspurt',),
'etterspurteste': ('etterspurt',),
'etterstreba': ('etterstrebe',),
'etterstrebede': ('etterstrebe',),
'etterstrebende': ('etterstrebe',),
'etterstrebet': ('etterstrebe',),
'etterstrebete': ('etterstrebe',),
'ettersynkroniserende': ('ettersynkronisere',),
'ettersynkronisert': ('ettersynkronisere',),
'ettersynkroniserte': ('ettersynkronisere',),
'ettersøkende': ('ettersøke',),
'ettersøkt': ('ettersøke',),
'ettersøkte': ('ettersøke',),
'ettertenksom': ('ettertenksom',),
'ettertenksomme': ('ettertenksom',),
'ettertenksommere': ('ettertenksom',),
'ettertenksomst': ('ettertenksom',),
'ettertenksomste': ('ettertenksom',),
'ettertenksomt': ('ettertenksom',),
'ettertrakta': ('ettertrakta',),
'ettertrakta': ('ettertrakte',),
'ettertraktede': ('ettertrakte',),
'ettertraktende': ('ettertrakte',),
'ettertraktet': ('ettertrakte',),
'ettertraktete': ('ettertrakte',),
'ettertraktelsesverdig': ('ettertraktelsesverdig',),
'ettertraktelsesverdige': ('ettertraktelsesverdig',),
'ettertraktelsesverdigere': ('ettertraktelsesverdig',),
'ettertraktelsesverdigst': ('ettertraktelsesverdig',),
'ettertraktelsesverdigste': ('ettertraktelsesverdig',),
'ettertraktede': ('ettertraktet',),
'ettertraktet': ('ettertraktet',),
'ettertraktete': ('ettertraktet',),
'ettertraktetere': ('ettertraktet',),
'ettertraktetest': ('ettertraktet',),
'ettertrakteteste': ('ettertraktet',),
'ettertrykkelig': ('ettertrykkelig',),
'ettertrykkelige': ('ettertrykkelig',),
'ettertrykkeligere': ('ettertrykkelig',),
'ettertrykkeligst': ('ettertrykkelig',),
'ettertrykkeligste': ('ettertrykkelig',),
'ettfags': ('ettfags',),
'ettroms': ('ettroms',),
'ettårig': ('ettårig',),
'ettårige': ('ettårig',),
'ettårigere': ('ettårig',),
'ettårigst': ('ettårig',),
'ettårigste': ('ettårig',),
'ettårs': ('ettårs',),
'ettøres': ('ettøres',),
'etymologisk': ('etymologisk',),
'etymologiske': ('etymologisk',),
'etymologiskere': ('etymologisk',),
'etymologiskest': ('etymologisk',),
'etymologiskeste': ('etymologisk',),
'eufemistisk': ('eufemistisk',),
'eufemistiske': ('eufemistisk',),
'eufemistiskere': ('eufemistisk',),
'eufemistiskest': ('eufemistisk',),
'eufemistiskeste': ('eufemistisk',),
'eufonisk': ('eufonisk',),
'eufoniske': ('eufonisk',),
'eufoniskere': ('eufonisk',),
'eufoniskest': ('eufonisk',),
'eufoniskeste': ('eufonisk',),
'euforiserende': ('euforiserende',),
'eugenetisk': ('eugenetisk',),
'eugenetiske': ('eugenetisk',),
'eugenetiskere': ('eugenetisk',),
'eugenetiskest': ('eugenetisk',),
'eugenetiskeste': ('eugenetisk',),
'eugenisk': ('eugenisk',),
'eugeniske': ('eugenisk',),
'eugeniskere': ('eugenisk',),
'eugeniskest': ('eugenisk',),
'eugeniskeste': ('eugenisk',),
'eukaryot': ('eukaryot',),
'eukaryote': ('eukaryot',),
'eukaryotere': ('eukaryot',),
'eukaryotest': ('eukaryot',),
'eukaryoteste': ('eukaryot',),
'euklidsk': ('euklidsk',),
'euklidske': ('euklidsk',),
'euklidskere': ('euklidsk',),
'euklidskest': ('euklidsk',),
'euklidskeste': ('euklidsk',),
'eurasisk': ('eurasisk',),
'eurasiske': ('eurasisk',),
'eurasiskere': ('eurasisk',),
'eurasiskest': ('eurasisk',),
'eurasiskeste': ('eurasisk',),
'europeiserende': ('europeisere',),
'europeisert': ('europeisere',),
'europeiserte': ('europeisere',),
'europeisk': ('europeisk',),
'europeiske': ('europeisk',),
'europeiskere': ('europeisk',),
'europeiskest': ('europeisk',),
'europeiskeste': ('europeisk',),
'eutrof': ('eutrof',),
'eutrofe': ('eutrof',),
'eutrofere': ('eutrof',),
'eutrofest': ('eutrof',),
'eutrofeste': ('eutrof',),
'eutroft': ('eutrof',),
'evakuerende': ('evakuere',),
'evakuert': ('evakuere',),
'evakuerte': ('evakuere',),
'evaluerende': ('evaluere',),
'evaluert': ('evaluere',),
'evaluerte': ('evaluere',),
'evangeliserende': ('evangelisere',),
'evangelisert': ('evangelisere',),
'evangeliserte': ('evangelisere',),
'evangelisk': ('evangelisk',),
'evangeliske': ('evangelisk',),
'evangeliskere': ('evangelisk',),
'evangeliskest': ('evangelisk',),
'evangeliskeste': ('evangelisk',),
'evangelisk-luthersk': ('evangelisk-luthersk',),
'evangelisk-lutherske': ('evangelisk-luthersk',),
'evangelisk-lutherskere': ('evangelisk-luthersk',),
'evangelisk-lutherskest': ('evangelisk-luthersk',),
'evangelisk-lutherskeste': ('evangelisk-luthersk',),
'evaporerende': ('evaporere',),
'evaporert': ('evaporere',),
'evaporerte': ('evaporere',),
'evasiv': ('evasiv',),
'evasive': ('evasiv',),
'evasivere': ('evasiv',),
'evasivest': ('evasiv',),
'evasiveste': ('evasiv',),
'evasivt': ('evasiv',),
'eva': ('eve',),
'evede': ('eve',),
'evende': ('eve',),
'evet': ('eve',),
'evete': ('eve',),
'eventuell': ('eventuell',),
'eventuelle': ('eventuell',),
'eventuellere': ('eventuell',),
'eventuellest': ('eventuell',),
'eventuelleste': ('eventuell',),
'eventuelt': ('eventuell',),
'eventyraktig': ('eventyraktig',),
'eventyraktige': ('eventyraktig',),
'eventyraktigere': ('eventyraktig',),
'eventyraktigst': ('eventyraktig',),
'eventyraktigste': ('eventyraktig',),
'eventyrlig': ('eventyrlig',),
'eventyrlige': ('eventyrlig',),
'eventyrligere': ('eventyrlig',),
'eventyrligst': ('eventyrlig',),
'eventyrligste': ('eventyrlig',),
'eventyrlysten': ('eventyrlysten',),
'eventyrlystent': ('eventyrlysten',),
'eventyrlystne': ('eventyrlysten',),
'eventyrlystnere': ('eventyrlysten',),
'eventyrlystnest': ('eventyrlysten',),
'eventyrlystneste': ('eventyrlysten',),
'evfemistisk': ('evfemistisk',),
'evfemistiske': ('evfemistisk',),
'evfemistiskere': ('evfemistisk',),
'evfemistiskest': ('evfemistisk',),
'evfemistiskeste': ('evfemistisk',),
'evident': ('evident',),
'evidente': ('evident',),
'evidentere': ('evident',),
'evidentest': ('evident',),
'evidenteste': ('evident',),
'evig': ('evig',),
'evige': ('evig',),
'evigere': ('evig',),
'evigst': ('evig',),
'evigste': ('evig',),
'eviggrøn': ('eviggrøn',),
'eviggrøne': ('eviggrøn',),
'eviggrønere': ('eviggrøn',),
'eviggrønest': ('eviggrøn',),
'eviggrøneste': ('eviggrøn',),
'eviggrønt': ('eviggrøn',),
'eviggrønn': ('eviggrønn',),
'eviggrønne': ('eviggrønn',),
'eviggrønnere': ('eviggrønn',),
'eviggrønnest': ('eviggrønn',),
'eviggrønneste': ('eviggrønn',),
'eviggrønt': ('eviggrønn',),
'evigung': ('evigung',),
'evigunge': ('evigung',),
'evigungt': ('evigung',),
'evigyngre': ('evigung',),
'evigyngst': ('evigung',),
'evigyngste': ('evigung',),
'evigvarende': ('evigvarende',),
'evinnelig': ('evinnelig',),
'evinnelige': ('evinnelig',),
'evinneligere': ('evinnelig',),
'evinneligst': ('evinnelig',),
'evinneligste': ('evinnelig',),
'evna': ('evne',),
'evnede': ('evne',),
'evnende': ('evne',),
'evnet': ('evne',),
'evnete': ('evne',),
'evnelaus': ('evnelaus',),
'evnelause': ('evnelaus',),
'evnelausere': ('evnelaus',),
'evnelausest': ('evnelaus',),
'evnelauseste': ('evnelaus',),
'evnelaust': ('evnelaus',),
'evneløs': ('evneløs',),
'evneløse': ('evneløs',),
'evneløsere': ('evneløs',),
'evneløsest': ('evneløs',),
'evneløseste': ('evneløs',),
'evneløst': ('evneløs',),
'evnerik': ('evnerik',),
'evnerike': ('evnerik',),
'evnerikere': ('evnerik',),
'evnerikest': ('evnerik',),
'evnerikeste': ('evnerik',),
'evnerikt': ('evnerik',),
'evneveik': ('evneveik',),
'evneveike': ('evneveik',),
'evneveikere': ('evneveik',),
'evneveikest': ('evneveik',),
'evneveikeste': ('evneveik',),
'evneveikt': ('evneveik',),
'evnevek': ('evnevek',),
'evneveke': ('evnevek',),
'evnevekere': ('evnevek',),
'evnevekest': ('evnevek',),
'evnevekeste': ('evnevek',),
'evnevekt': ('evnevek',),
'evolusjonistisk': ('evolusjonistisk',),
'evolusjonistiske': ('evolusjonistisk',),
'evolusjonistiskere': ('evolusjonistisk',),
'evolusjonistiskest': ('evolusjonistisk',),
'evolusjonistiskeste': ('evolusjonistisk',),
'exa': ('exe',),
'exede': ('exe',),
'exende': ('exe',),
'exet': ('exe',),
'exete': ('exe',),
'fôra': ('fôre',),
'fôrede': ('fôre',),
'fôrende': ('fôre',),
'fôret': ('fôre',),
'fôrete': ('fôre',),
'fôrt': ('fôre',),
'fôrte': ('fôre',),
'fôra': ('fôre',),
'fôrede': ('fôre',),
'fôrende': ('fôre',),
'fôret': ('fôre',),
'fôrete': ('fôre',),
'fôrt': ('fôre',),
'fôrte': ('fôre',),
'fabelaktig': ('fabelaktig',),
'fabelaktige': ('fabelaktig',),
'fabelaktigere': ('fabelaktig',),
'fabelaktigst': ('fabelaktig',),
'fabelaktigste': ('fabelaktig',),
'fabla': ('fable',),
'fablede': ('fable',),
'fablende': ('fable',),
'fablet': ('fable',),
'fablete': ('fable',),
'fabrikkerende': ('fabrikkere',),
'fabrikkert': ('fabrikkere',),
'fabrikkerte': ('fabrikkere',),
'fabrikkmessig': ('fabrikkmessig',),
'fabrikkmessige': ('fabrikkmessig',),
'fabrikkmessigere': ('fabrikkmessig',),
'fabrikkmessigst': ('fabrikkmessig',),
'fabrikkmessigste': ('fabrikkmessig',),
'fabrikkny': ('fabrikkny',),
'fabrikknye': ('fabrikkny',),
'fabrikknyere': ('fabrikkny',),
'fabrikknyest': ('fabrikkny',),
'fabrikknyeste': ('fabrikkny',),
'fabrikknytt': ('fabrikkny',),
'fabulerende': ('fabulere',),
'fabulert': ('fabulere',),
'fabulerte': ('fabulere',),
'fada': ('fade',),
'fadede': ('fade',),
'fadende': ('fade',),
'fadet': ('fade',),
'fadete': ('fade',),
'faderlig': ('faderlig',),
'faderlige': ('faderlig',),
'faderligere': ('faderlig',),
'faderligst': ('faderlig',),
'faderligste': ('faderlig',),
'faderløs': ('faderløs',),
'faderløse': ('faderløs',),
'faderløsere': ('faderløs',),
'faderløsest': ('faderløs',),
'faderløseste': ('faderløs',),
'faderløst': ('faderløs',),
'faens': ('faens',),
'fager': ('fager',),
'fagert': ('fager',),
'fagre': ('fager',),
'fagrere': ('fager',),
'fagrest': ('fager',),
'fagreste': ('fager',),
'faglig': ('faglig',),
'faglige': ('faglig',),
'fagligere': ('faglig',),
'fagligst': ('faglig',),
'fagligste': ('faglig',),
'faglært': ('faglært',),
'faglærte': ('faglært',),
'faglærtere': ('faglært',),
'faglærtest': ('faglært',),
'faglærteste': ('faglært',),
'fagmessig': ('fagmessig',),
'fagmessige': ('fagmessig',),
'fagmessigere': ('fagmessig',),
'fagmessigst': ('fagmessig',),
'fagmessigste': ('fagmessig',),
'fagna': ('fagne',),
'fagnede': ('fagne',),
'fagnende': ('fagne',),
'fagnet': ('fagne',),
'fagnete': ('fagne',),
'fagorganisert': ('fagorganisert',),
'fagorganiserte': ('fagorganisert',),
'fagorganisertere': ('fagorganisert',),
'fagorganisertest': ('fagorganisert',),
'fagorganiserteste': ('fagorganisert',),
'fair': ('fair',),
'fakka': ('fakke',),
'fakkede': ('fakke',),
'fakkende': ('fakke',),
'fakket': ('fakke',),
'fakkete': ('fakke',),
'faksa': ('fakse',),
'faksede': ('fakse',),
'faksende': ('fakse',),
'fakset': ('fakse',),
'faksete': ('fakse',),
'fakset': ('fakset',),
'faksete': ('fakset',),
'faksetere': ('fakset',),
'faksetest': ('fakset',),
'fakseteste': ('fakset',),
'faksete': ('faksete',),
'faksimilerende': ('faksimilere',),
'faksimilert': ('faksimilere',),
'faksimilerte': ('faksimilere',),
'faktisk': ('faktisk',),
'faktiske': ('faktisk',),
'faktiskere': ('faktisk',),
'faktiskest': ('faktisk',),
'faktiskeste': ('faktisk',),
'faktoriserende': ('faktorisere',),
'faktorisert': ('faktorisere',),
'faktoriserte': ('faktorisere',),
'faktuell': ('faktuell',),
'faktuelle': ('faktuell',),
'faktuellere': ('faktuell',),
'faktuellest': ('faktuell',),
'faktuelleste': ('faktuell',),
'faktuelt': ('faktuell',),
'fakturerende': ('fakturere',),
'fakturert': ('fakturere',),
'fakturerte': ('fakturere',),
'fakultativ': ('fakultativ',),
'fakultative': ('fakultativ',),
'fakultativere': ('fakultativ',),
'fakultativest': ('fakultativ',),
'fakultativeste': ('fakultativ',),
'fakultativt': ('fakultativ',),
'fal': ('fal',),
'falbudt': ('falby',),
'falbudte': ('falby',),
'falbydd': ('falby',),
'falbydde': ('falby',),
'falbyende': ('falby',),
'falda': ('falde',),
'faldede': ('falde',),
'faldende': ('falde',),
'faldet': ('falde',),
'faldete': ('falde',),
'falklandsk': ('falklandsk',),
'falklandske': ('falklandsk',),
'falklandskere': ('falklandsk',),
'falklandskest': ('falklandsk',),
'falklandskeste': ('falklandsk',),
'fallende': ('falle',),
'falt': ('falle',),
'falte': ('falle',),
'falleferdig': ('falleferdig',),
'falleferdige': ('falleferdig',),
'falleferdigere': ('falleferdig',),
'falleferdigst': ('falleferdig',),
'falleferdigste': ('falleferdig',),
'fallen': ('fallen',),
'fallent': ('fallen',),
'falne': ('fallen',),
'falnere': ('fallen',),
'falnest': ('fallen',),
'falneste': ('fallen',),
'fallerende': ('fallere',),
'fallert': ('fallere',),
'fallerte': ('fallere',),
'fallesjuk': ('fallesjuk',),
'fallesjuke': ('fallesjuk',),
'fallesjukere': ('fallesjuk',),
'fallesjukest': ('fallesjuk',),
'fallesjukeste': ('fallesjuk',),
'fallesjukt': ('fallesjuk',),
'fallesyk': ('fallesyk',),
'fallesyke': ('fallesyk',),
'fallesykere': ('fallesyk',),
'fallesykest': ('fallesyk',),
'fallesykeste': ('fallesyk',),
'fallesykt': ('fallesyk',),
'fallisk': ('fallisk',),
'falliske': ('fallisk',),
'falliskere': ('fallisk',),
'falliskest': ('fallisk',),
'falliskeste': ('fallisk',),
'fallitt': ('fallitt',),
'fallitte': ('fallitt',),
'fallittere': ('fallitt',),
'fallittest': ('fallitt',),
'fallitteste': ('fallitt',),
'falma': ('falme',),
'falmede': ('falme',),
'falmende': ('falme',),
'falmet': ('falme',),
'falmete': ('falme',),
'falsa': ('false',),
'falsede': ('false',),
'falsende': ('false',),
'falset': ('false',),
'falsete': ('false',),
'falsifiserbar': ('falsifiserbar',),
'falsifiserbare': ('falsifiserbar',),
'falsifiserbarere': ('falsifiserbar',),
'falsifiserbarest': ('falsifiserbar',),
'falsifiserbareste': ('falsifiserbar',),
'falsifiserbart': ('falsifiserbar',),
'falsifiserende': ('falsifisere',),
'falsifisert': ('falsifisere',),
'falsifiserte': ('falsifisere',),
'falsk': ('falsk',),
'falske': ('falsk',),
'falskere': ('falsk',),
'falskest': ('falsk',),
'falskeste': ('falsk',),
'falskt': ('falsk',),
'familievennlig': ('familievennlig',),
'familievennlige': ('familievennlig',),
'familievennligere': ('familievennlig',),
'familievennligst': ('familievennlig',),
'familievennligste': ('familievennlig',),
'familiær': ('familiær',),
'familiære': ('familiær',),
'familiærere': ('familiær',),
'familiærest': ('familiær',),
'familiæreste': ('familiær',),
'familiært': ('familiær',),
'famla': ('famle',),
'famlede': ('famle',),
'famlende': ('famle',),
'famlet': ('famle',),
'famlete': ('famle',),
'famlende': ('famlende',),
'famna': ('famne',),
'famnede': ('famne',),
'famnende': ('famne',),
'famnet': ('famne',),
'famnete': ('famne',),
'famna': ('famne',),
'famnede': ('famne',),
'famnende': ('famne',),
'famnet': ('famne',),
'famnete': ('famne',),
'famøs': ('famøs',),
'famøse': ('famøs',),
'famøsere': ('famøs',),
'famøsest': ('famøs',),
'famøseste': ('famøs',),
'famøst': ('famøs',),
'fanatisk': ('fanatisk',),
'fanatiske': ('fanatisk',),
'fanatiskere': ('fanatisk',),
'fanatiskest': ('fanatisk',),
'fanatiskeste': ('fanatisk',),
'fancy': ('fancy',),
'fandenivoldsk': ('fandenivoldsk',),
'fandenivoldske': ('fandenivoldsk',),
'fandenivoldskere': ('fandenivoldsk',),
'fandenivoldskest': ('fandenivoldsk',),
'fandenivoldskeste': ('fandenivoldsk',),
'fandens': ('fandens',),
'fanga': ('fange',),
'fangede': ('fange',),
'fangende': ('fange',),
'fanget': ('fange',),
'fangete': ('fange',),
'fangen': ('fangen',),
'fangent': ('fangen',),
'fangne': ('fangen',),
'fangnere': ('fangen',),
'fangnest': ('fangen',),
'fangneste': ('fangen',),
'fangsta': ('fangste',),
'fangstede': ('fangste',),
'fangstende': ('fangste',),
'fangstet': ('fangste',),
'fangstete': ('fangste',),
'fans': ('fans',),
'fantaserende': ('fantasere',),
'fantasert': ('fantasere',),
'fantaserte': ('fantasere',),
'fantasifull': ('fantasifull',),
'fantasifulle': ('fantasifull',),
'fantasifullere': ('fantasifull',),
'fantasifullest': ('fantasifull',),
'fantasifulleste': ('fantasifull',),
'fantasifullt': ('fantasifull',),
'fantasilaus': ('fantasilaus',),
'fantasilause': ('fantasilaus',),
'fantasilausere': ('fantasilaus',),
'fantasilausest': ('fantasilaus',),
'fantasilauseste': ('fantasilaus',),
'fantasilaust': ('fantasilaus',),
'fantasiløs': ('fantasiløs',),
'fantasiløse': ('fantasiløs',),
'fantasiløsere': ('fantasiløs',),
'fantasiløsest': ('fantasiløs',),
'fantasiløseste': ('fantasiløs',),
'fantasiløst': ('fantasiløs',),
'fantasirik': ('fantasirik',),
'fantasirike': ('fantasirik',),
'fantasirikere': ('fantasirik',),
'fantasirikest': ('fantasirik',),
'fantasirikeste': ('fantasirik',),
'fantasirikt': ('fantasirik',),
'fantastisk': ('fantastisk',),
'fantastiske': ('fantastisk',),
'fantastiskere': ('fantastisk',),
'fantastiskest': ('fantastisk',),
'fantastiskeste': ('fantastisk',),
'fantegående': ('fantegå',),
'fantegått': ('fantegå',),
'fantegåtte': ('fantegå',),
'faraoisk': ('faraoisk',),
'faraoiske': ('faraoisk',),
'faraoiskere': ('faraoisk',),
'faraoiskest': ('faraoisk',),
'faraoiskeste': ('faraoisk',),
'farbar': ('farbar',),
'farbare': ('farbar',),
'farbarere': ('farbar',),
'farbarest': ('farbar',),
'farbareste': ('farbar',),
'farbart': ('farbar',),
'farende': ('fare',),
'fart': ('fare',),
'farte': ('fare',),
'farefri': ('farefri',),
'farefrie': ('farefri',),
'farefriere': ('farefri',),
'farefriest': ('farefri',),
'farefrieste': ('farefri',),
'farefritt': ('farefri',),
'farefull': ('farefull',),
'farefulle': ('farefull',),
'farefullere': ('farefull',),
'farefullest': ('farefull',),
'farefulleste': ('farefull',),
'farefullt': ('farefull',),
'faren': ('faren',),
'farent': ('faren',),
'farne': ('faren',),
'farnere': ('faren',),
'farnest': ('faren',),
'farneste': ('faren',),
'faretruende': ('faretruende',),
'farga': ('farga',),
'farga': ('farge',),
'fargede': ('farge',),
'fargende': ('farge',),
'farget': ('farge',),
'fargete': ('farge',),
'fargeblind': ('fargeblind',),
'fargeblinde': ('fargeblind',),
'fargeblindere': ('fargeblind',),
'fargeblindest': ('fargeblind',),
'fargeblindeste': ('fargeblind',),
'fargeblindt': ('fargeblind',),
'fargeekte': ('fargeekte',),
'fargelaus': ('fargelaus',),
'fargelause': ('fargelaus',),
'fargelausere': ('fargelaus',),
'fargelausest': ('fargelaus',),
'fargelauseste': ('fargelaus',),
'fargelaust': ('fargelaus',),
'fargeløs': ('fargeløs',),
'fargeløse': ('fargeløs',),
'fargeløsere': ('fargeløs',),
'fargeløsest': ('fargeløs',),
'fargeløseste': ('fargeløs',),
'fargeløst': ('fargeløs',),
'fargerik': ('fargerik',),
'fargerike': ('fargerik',),
'fargerikere': ('fargerik',),
'fargerikest': ('fargerik',),
'fargerikeste': ('fargerik',),
'fargerikt': ('fargerik',),
'fargede': ('farget',),
'farget': ('farget',),
'fargete': ('farget',),
'fargetere': ('farget',),
'fargetest': ('farget',),
'fargeteste': ('farget',),
'fariseisk': ('fariseisk',),
'fariseiske': ('fariseisk',),
'fariseiskere': ('fariseisk',),
'fariseiskest': ('fariseisk',),
'fariseiskeste': ('fariseisk',),
'farlaus': ('farlaus',),
'farlause': ('farlaus',),
'farlausere': ('farlaus',),
'farlausest': ('farlaus',),
'farlauseste': ('farlaus',),
'farlaust': ('farlaus',),
'farlig': ('farlig',),
'farlige': ('farlig',),
'farligere': ('farlig',),
'farligst': ('farlig',),
'farligste': ('farlig',),
'farløs': ('farløs',),
'farløse': ('farløs',),
'farløsere': ('farløs',),
'farløsest': ('farløs',),
'farløseste': ('farløs',),
'farløst': ('farløs',),
'farmakologisk': ('farmakologisk',),
'farmakologiske': ('farmakologisk',),
'farmakologiskere': ('farmakologisk',),
'farmakologiskest': ('farmakologisk',),
'farmakologiskeste': ('farmakologisk',),
'farmasøytisk': ('farmasøytisk',),
'farmasøytiske': ('farmasøytisk',),
'farmasøytiskere': ('farmasøytisk',),
'farmasøytiskest': ('farmasøytisk',),
'farmasøytiskeste': ('farmasøytisk',),
'farserende': ('farsere',),
'farsert': ('farsere',),
'farserte': ('farsere',),
'farta': ('farte',),
'fartede': ('farte',),
'fartende': ('farte',),
'fartet': ('farte',),
'fartete': ('farte',),
'fartsgal': ('fartsgal',),
'fartsgale': ('fartsgal',),
'fartsgalere': ('fartsgal',),
'fartsgalest': ('fartsgal',),
'fartsgaleste': ('fartsgal',),
'fartsgalt': ('fartsgal',),
'fasadefri': ('fasadefri',),
'fasadefrie': ('fasadefri',),
'fasadefriere': ('fasadefri',),
'fasadefriest': ('fasadefri',),
'fasadefrieste': ('fasadefri',),
'fasadefritt': ('fasadefri',),
'fascinerende': ('fascinere',),
'fascinert': ('fascinere',),
'fascinerte': ('fascinere',),
'fascistisk': ('fascistisk',),
'fascistiske': ('fascistisk',),
'fascistiskere': ('fascistisk',),
'fascistiskest': ('fascistisk',),
'fascistiskeste': ('fascistisk',),
'fasa': ('fase',),
'fasede': ('fase',),
'fasende': ('fase',),
'faset': ('fase',),
'fasete': ('fase',),
'fasetterende': ('fasettere',),
'fasettert': ('fasettere',),
'fasetterte': ('fasettere',),
'fasjonabel': ('fasjonabel',),
'fasjonabelt': ('fasjonabel',),
'fasjonable': ('fasjonabel',),
'fasjonablere': ('fasjonabel',),
'fasjonablest': ('fasjonabel',),
'fasjonableste': ('fasjonabel',),
'fasla': ('fasle',),
'faslede': ('fasle',),
'faslende': ('fasle',),
'faslet': ('fasle',),
'faslete': ('fasle',),
'fasongerende': ('fasongere',),
'fasongert': ('fasongere',),
'fasongerte': ('fasongere',),
'fasongsydd': ('fasongsydd',),
'fasongsydde': ('fasongsydd',),
'fasongsyddere': ('fasongsydd',),
'fasongsyddest': ('fasongsydd',),
'fasongsyddeste': ('fasongsydd',),
'fast': ('fast',),
'faste': ('fast',),
'fastere': ('fast',),
'fastest': ('fast',),
'fasteste': ('fast',),
'fastboende': ('fastboende',),
'fastbuende': ('fastbuende',),
'fasta': ('faste',),
'fastede': ('faste',),
'fastende': ('faste',),
'fastet': ('faste',),
'fastete': ('faste',),
'fastfrosne': ('fastfrossen',),
'fastfrosnere': ('fastfrossen',),
'fastfrosnest': ('fastfrossen',),
'fastfrosneste': ('fastfrossen',),
'fastfrossen': ('fastfrossen',),
'fastfrosset': ('fastfrossen',),
'fastfrosne': ('fastfrosset',),
'fastfrosnere': ('fastfrosset',),
'fastfrosnest': ('fastfrosset',),
'fastfrosneste': ('fastfrosset',),
'fastfrosset': ('fastfrosset',),
'fastgrodd': ('fastgrodd',),
'fastgrodde': ('fastgrodd',),
'fastgroddere': ('fastgrodd',),
'fastgroddest': ('fastgrodd',),
'fastgroddeste': ('fastgrodd',),
'fastholdende': ('fastholde',),
'fastholdt': ('fastholde',),
'fastholdte': ('fastholde',),
'fastklemt': ('fastklemt',),
'fastklemte': ('fastklemt',),
'fastklemtere': ('fastklemt',),
'fastklemtest': ('fastklemt',),
'fastklemteste': ('fastklemt',),
'fastlagt': ('fastlegge',),
'fastlagte': ('fastlegge',),
'fastleggende': ('fastlegge',),
'fastlåsende': ('fastlåse',),
'fastlåst': ('fastlåse',),
'fastlåste': ('fastlåse',),
'fastlønna': ('fastlønna',),
'fastlønnede': ('fastlønnet',),
'fastlønnet': ('fastlønnet',),
'fastlønnete': ('fastlønnet',),
'fastlønnetere': ('fastlønnet',),
'fastlønnetest': ('fastlønnet',),
'fastlønneteste': ('fastlønnet',),
'fastlønt': ('fastlønt',),
'fastlønte': ('fastlønt',),
'fastløntere': ('fastlønt',),
'fastløntest': ('fastlønt',),
'fastlønteste': ('fastlønt',),
'fastnagla': ('fastnagla',),
'fastnaglede': ('fastnaglet',),
'fastnaglet': ('fastnaglet',),
'fastnaglete': ('fastnaglet',),
'fastnagletere': ('fastnaglet',),
'fastnagletest': ('fastnaglet',),
'fastnagleteste': ('fastnaglet',),
'fastna': ('fastne',),
'fastnede': ('fastne',),
'fastnende': ('fastne',),
'fastnet': ('fastne',),
'fastnete': ('fastne',),
'fastrusta': ('fastrusta',),
'fastrustede': ('fastrustet',),
'fastrustet': ('fastrustet',),
'fastrustete': ('fastrustet',),
'fastrustetere': ('fastrustet',),
'fastrustetest': ('fastrustet',),
'fastrusteteste': ('fastrustet',),
'fastsatt': ('fastsette',),
'fastsatte': ('fastsette',),
'fastsettende': ('fastsette',),
'fasttømra': ('fasttømra',),
'fasttømrede': ('fasttømret',),
'fasttømret': ('fasttømret',),
'fasttømrete': ('fasttømret',),
'fasttømretere': ('fasttømret',),
'fasttømretest': ('fasttømret',),
'fasttømreteste': ('fasttømret',),
'fatal': ('fatal',),
'fatale': ('fatal',),
'fatalere': ('fatal',),
'fatalest': ('fatal',),
'fataleste': ('fatal',),
'fatalt': ('fatal',),
'fatalistisk': ('fatalistisk',),
'fatalistiske': ('fatalistisk',),
'fatalistiskere': ('fatalistisk',),
'fatalistiskest': ('fatalistisk',),
'fatalistiskeste': ('fatalistisk',),
'fata': ('fate',),
'fatede': ('fate',),
'fatende': ('fate',),
'fatet': ('fate',),
'fatete': ('fate',),
'fatla': ('fatle',),
'fatlede': ('fatle',),
'fatlende': ('fatle',),
'fatlet': ('fatle',),
'fatlete': ('fatle',),
'fatta': ('fatta',),
'fattbar': ('fattbar',),
'fattbare': ('fattbar',),
'fattbarere': ('fattbar',),
'fattbarest': ('fattbar',),
'fattbareste': ('fattbar',),
'fattbart': ('fattbar',),
'fatta': ('fatte',),
'fattede': ('fatte',),
'fattende': ('fatte',),
'fattet': ('fatte',),
'fattete': ('fatte',),
'fattelig': ('fattelig',),
'fattelige': ('fattelig',),
'fatteligere': ('fattelig',),
'fatteligst': ('fattelig',),
'fatteligste': ('fattelig',),
'fattede': ('fattet',),
'fattet': ('fattet',),
'fattete': ('fattet',),
'fattetere': ('fattet',),
'fattetest': ('fattet',),
'fatteteste': ('fattet',),
'fattig': ('fattig',),
'fattige': ('fattig',),
'fattigere': ('fattig',),
'fattigst': ('fattig',),
'fattigste': ('fattig',),
'fattigfornem': ('fattigfornem',),
'fattigfornemme': ('fattigfornem',),
'fattigfornemmere': ('fattigfornem',),
'fattigfornemmest': ('fattigfornem',),
'fattigfornemmeste': ('fattigfornem',),
'fattigfornemt': ('fattigfornem',),
'fattigslig': ('fattigslig',),
'fattigslige': ('fattigslig',),
'fattigsligere': ('fattigslig',),
'fattigsligst': ('fattigslig',),
'fattigsligste': ('fattigslig',),
'favna': ('favne',),
'favnede': ('favne',),
'favnende': ('favne',),
'favnet': ('favne',),
'favnete': ('favne',),
'favna': ('favne',),
'favnede': ('favne',),
'favnende': ('favne',),
'favnet': ('favne',),
'favnete': ('favne',),
'favoriserende': ('favorisere',),
'favorisert': ('favorisere',),
'favoriserte': ('favorisere',),
'feberdrivende': ('feberdrivende',),
'feberhet': ('feberhet',),
'feberhete': ('feberhet',),
'feberhetere': ('feberhet',),
'feberhetest': ('feberhet',),
'feberheteste': ('feberhet',),
'feberhett': ('feberhet',),
'feberstillende': ('feberstillende',),
'febril': ('febril',),
'febrile': ('febril',),
'febrilere': ('febril',),
'febrilest': ('febril',),
'febrileste': ('febril',),
'febrilt': ('febril',),
'febrilsk': ('febrilsk',),
'febrilske': ('febrilsk',),
'febrilskere': ('febrilsk',),
'febrilskest': ('febrilsk',),
'febrilskeste': ('febrilsk',),
'fedrene': ('fedrene',),
'feida': ('feide',),
'feidede': ('feide',),
'feidende': ('feide',),
'feidet': ('feide',),
'feidete': ('feide',),
'feia': ('feie',),
'feid': ('feie',),
'feide': ('feie',),
'feiede': ('feie',),
'feiende': ('feie',),
'feiet': ('feie',),
'feiete': ('feie',),
'feiende': ('feiende',),
'feig': ('feig',),
'feige': ('feig',),
'feigere': ('feig',),
'feigest': ('feig',),
'feigeste': ('feig',),
'feigt': ('feig',),
'feilaktig': ('feilaktig',),
'feilaktige': ('feilaktig',),
'feilaktigere': ('feilaktig',),
'feilaktigst': ('feilaktig',),
'feilaktigste': ('feilaktig',),
'feilbedømmende': ('feilbedømme',),
'feilbedømt': ('feilbedømme',),
'feilbedømte': ('feilbedømme',),
'feila': ('feile',),
'feilede': ('feile',),
'feilende': ('feile',),
'feilet': ('feile',),
'feilete': ('feile',),
'feilt': ('feile',),
'feilte': ('feile',),
'feilslått': ('feilslått',),
'feilslåtte': ('feilslått',),
'feilslåttere': ('feilslått',),
'feilslåttest': ('feilslått',),
'feilslåtteste': ('feilslått',),
'feilvurderende': ('feilvurdere',),
'feilvurdert': ('feilvurdere',),
'feilvurderte': ('feilvurdere',),
'feira': ('feire',),
'feirede': ('feire',),
'feirende': ('feire',),
'feiret': ('feire',),
'feirete': ('feire',),
'feit': ('feit',),
'feite': ('feit',),
'feitere': ('feit',),
'feitest': ('feit',),
'feiteste': ('feit',),
'feitt': ('feit',),
'fett': ('feit',),
'feita': ('feite',),
'feitede': ('feite',),
'feitende': ('feite',),
'feitet': ('feite',),
'feitete': ('feite',),
'feitladen': ('feitladen',),
'feitladent': ('feitladen',),
'feitladne': ('feitladen',),
'feitladnere': ('feitladen',),
'feitladnest': ('feitladen',),
'feitladneste': ('feitladen',),
'feitlaten': ('feitlaten',),
'feitlatent': ('feitlaten',),
'feitlatne': ('feitlaten',),
'feitlatnere': ('feitlaten',),
'feitlatnest': ('feitlaten',),
'feitlatneste': ('feitlaten',),
'feitna': ('feitne',),
'feitnede': ('feitne',),
'feitnende': ('feitne',),
'feitnet': ('feitne',),
'feitnete': ('feitne',),
'fekta': ('fekte',),
'fektede': ('fekte',),
'fektende': ('fekte',),
'fektet': ('fekte',),
'fektete': ('fekte',),
'fellende': ('felle',),
'felt': ('felle',),
'felte': ('felle',),
'fellende': ('fellende',),
'felles': ('felles',),
'felleskirkelig': ('felleskirkelig',),
'felleskirkelige': ('felleskirkelig',),
'felleskirkeligere': ('felleskirkelig',),
'felleskirkeligst': ('felleskirkelig',),
'felleskirkeligste': ('felleskirkelig',),
'femblada': ('femblada',),
'fembladede': ('fembladet',),
'fembladet': ('fembladet',),
'fembladete': ('fembladet',),
'fembladetere': ('fembladet',),
'fembladetest': ('fembladet',),
'fembladeteste': ('fembladet',),
'femdobbel': ('femdobbel',),
'femdobbelt': ('femdobbel',),
'femdoble': ('femdobbel',),
'femdoblere': ('femdobbel',),
'femdoblest': ('femdobbel',),
'femdobleste': ('femdobbel',),
'femdobbelt': ('femdobbelt',),
'femdobbelte': ('femdobbelt',),
'femdobbeltere': ('femdobbelt',),
'femdobbeltest': ('femdobbelt',),
'femdobbelteste': ('femdobbelt',),
'femdobla': ('femdoble',),
'femdoblede': ('femdoble',),
'femdoblende': ('femdoble',),
'femdoblet': ('femdoble',),
'femdoblete': ('femdoble',),
'femetasjes': ('femetasjes',),
'femfota': ('femfota',),
'femfotede': ('femfotet',),
'femfotet': ('femfotet',),
'femfotete': ('femfotet',),
'femfotetere': ('femfotet',),
'femfotetest': ('femfotet',),
'femfoteteste': ('femfotet',),
'femføtt': ('femføtt',),
'femføtte': ('femføtt',),
'femføttere': ('femføtt',),
'femføttest': ('femføtt',),
'femføtteste': ('femføtt',),
'feminin': ('feminin',),
'feminine': ('feminin',),
'femininere': ('feminin',),
'femininest': ('feminin',),
'feminineste': ('feminin',),
'feminint': ('feminin',),
'feminiserende': ('feminisere',),
'feminisert': ('feminisere',),
'feminiserte': ('feminisere',),
'femkanta': ('femkanta',),
'femkantede': ('femkantet',),
'femkantet': ('femkantet',),
'femkantete': ('femkantet',),
'femkantetere': ('femkantet',),
'femkantetest': ('femkantet',),
'femkanteteste': ('femkantet',),
'femmasta': ('femmasta',),
'femmastede': ('femmastet',),
'femmastet': ('femmastet',),
'femmastete': ('femmastet',),
'femmastetere': ('femmastet',),
'femmastetest': ('femmastet',),
'femmasteteste': ('femmastet',),
'femroms': ('femroms',),
'femsida': ('femsida',),
'femsidede': ('femsidet',),
'femsidet': ('femsidet',),
'femsidete': ('femsidet',),
'femsidetere': ('femsidet',),
'femsidetest': ('femsidet',),
'femsideteste': ('femsidet',),
'femte': ('femte',),
'femtende': ('femtende',),
'femtenårig': ('femtenårig',),
'femtenårige': ('femtenårig',),
'femtenårigere': ('femtenårig',),
'femtenårigst': ('femtenårig',),
'femtenårigste': ('femtenårig',),
'femtenårs': ('femtenårs',),
'femtiende': ('femtiende',),
'femtiårig': ('femtiårig',),
'femtiårige': ('femtiårig',),
'femtiårigere': ('femtiårig',),
'femtiårigst': ('femtiårig',),
'femtiårigste': ('femtiårig',),
'femtiøres': ('femtiøres',),
'femtoms': ('femtoms',),
'femårig': ('femårig',),
'femårige': ('femårig',),
'femårigere': ('femårig',),
'femårigst': ('femårig',),
'femårigste': ('femårig',),
'femårs': ('femårs',),
'femøres': ('femøres',),
'fenga': ('fenge',),
'fengede': ('fenge',),
'fengende': ('fenge',),
'fenget': ('fenge',),
'fengete': ('fenge',),
'fengt': ('fenge',),
'fengte': ('fenge',),
'fengende': ('fengende',),
'fengsla': ('fengsle',),
'fengslede': ('fengsle',),
'fengslende': ('fengsle',),
'fengslet': ('fengsle',),
'fengslete': ('fengsle',),
'fengslig': ('fengslig',),
'fengslige': ('fengslig',),
'fengsligere': ('fengslig',),
'fengsligst': ('fengslig',),
'fengsligste': ('fengslig',),
'fennoskandisk': ('fennoskandisk',),
'fennoskandiske': ('fennoskandisk',),
'fennoskandiskere': ('fennoskandisk',),
'fennoskandiskest': ('fennoskandisk',),
'fennoskandiskeste': ('fennoskandisk',),
'fenologisk': ('fenologisk',),
'fenologiske': ('fenologisk',),
'fenologiskere': ('fenologisk',),
'fenologiskest': ('fenologisk',),
'fenologiskeste': ('fenologisk',),
'fenomenal': ('fenomenal',),
'fenomenale': ('fenomenal',),
'fenomenalere': ('fenomenal',),
'fenomenalest': ('fenomenal',),
'fenomenaleste': ('fenomenal',),
'fenomenalt': ('fenomenal',),
'fenomenologisk': ('fenomenologisk',),
'fenomenologiske': ('fenomenologisk',),
'fenomenologiskere': ('fenomenologisk',),
'fenomenologiskest': ('fenomenologisk',),
'fenomenologiskeste': ('fenomenologisk',),
'ferda': ('ferde',),
'ferdede': ('ferde',),
'ferdende': ('ferde',),
'ferdet': ('ferde',),
'ferdete': ('ferde',),
'ferdig': ('ferdig',),
'ferdige': ('ferdig',),
'ferdigere': ('ferdig',),
'ferdigst': ('ferdig',),
'ferdigste': ('ferdig',),
'ferdigbehandla': ('ferdigbehandle',),
'ferdigbehandlede': ('ferdigbehandle',),
'ferdigbehandlende': ('ferdigbehandle',),
'ferdigbehandlet': ('ferdigbehandle',),
'ferdigbehandlete': ('ferdigbehandle',),
'ferdiglaga': ('ferdiglaga',),
'ferdiglagd': ('ferdiglagd',),
'ferdiglagde': ('ferdiglagd',),
'ferdiglagdere': ('ferdiglagd',),
'ferdiglagdest': ('ferdiglagd',),
'ferdiglagdeste': ('ferdiglagd',),
'ferdiglagede': ('ferdiglaget',),
'ferdiglaget': ('ferdiglaget',),
'ferdiglagete': ('ferdiglaget',),
'ferdiglagetere': ('ferdiglaget',),
'ferdiglagetest': ('ferdiglaget',),
'ferdiglageteste': ('ferdiglaget',),
'ferdigpakka': ('ferdigpakka',),
'ferdigpakkede': ('ferdigpakket',),
'ferdigpakket': ('ferdigpakket',),
'ferdigpakkete': ('ferdigpakket',),
'ferdigpakketere': ('ferdigpakket',),
'ferdigpakketest': ('ferdigpakket',),
'ferdigpakketeste': ('ferdigpakket',),
'ferga': ('ferge',),
'fergede': ('ferge',),
'fergende': ('ferge',),
'ferget': ('ferge',),
'fergete': ('ferge',),
'ferierende': ('feriere',),
'feriert': ('feriere',),
'ferierte': ('feriere',),
'ferja': ('ferje',),
'ferjede': ('ferje',),
'ferjende': ('ferje',),
'ferjet': ('ferje',),
'ferjete': ('ferje',),
'ferm': ('ferm',),
'ferme': ('ferm',),
'fermere': ('ferm',),
'fermest': ('ferm',),
'fermeste': ('ferm',),
'fermt': ('ferm',),
'ferma': ('ferme',),
'fermede': ('ferme',),
'fermende': ('ferme',),
'fermet': ('ferme',),
'fermete': ('ferme',),
'fermenterende': ('fermentere',),
'fermentert': ('fermentere',),
'fermenterte': ('fermentere',),
'fernisserende': ('fernissere',),
'fernissert': ('fernissere',),
'fernisserte': ('fernissere',),
'fersk': ('fersk',),
'ferske': ('fersk',),
'ferskere': ('fersk',),
'ferskest': ('fersk',),
'ferskeste': ('fersk',),
'ferskt': ('fersk',),
'ferska': ('ferske',),
'ferskede': ('ferske',),
'ferskende': ('ferske',),
'fersket': ('ferske',),
'ferskete': ('ferske',),
'ferskenfargede': ('ferskenfarget',),
'ferskenfarget': ('ferskenfarget',),
'ferskenfargete': ('ferskenfarget',),
'ferskenfargetere': ('ferskenfarget',),
'ferskenfargetest': ('ferskenfarget',),
'ferskenfargeteste': ('ferskenfarget',),
'fertil': ('fertil',),
'fertile': ('fertil',),
'fertilere': ('fertil',),
'fertilest': ('fertil',),
'fertileste': ('fertil',),
'fertilt': ('fertil',),
'festa': ('feste',),
'festede': ('feste',),
'festende': ('feste',),
'festet': ('feste',),
'festete': ('feste',),
'festa': ('feste',),
'festede': ('feste',),
'festende': ('feste',),
'festet': ('feste',),
'festete': ('feste',),
'festlig': ('festlig',),
'festlige': ('festlig',),
'festligere': ('festlig',),
'festligst': ('festlig',),
'festligste': ('festlig',),
'festna': ('festne',),
'festnede': ('festne',),
'festnende': ('festne',),
'festnet': ('festne',),
'festnete': ('festne',),
'feststemt': ('feststemt',),
'feststemte': ('feststemt',),
'feststemtere': ('feststemt',),
'feststemtest': ('feststemt',),
'feststemteste': ('feststemt',),
'fet': ('fet',),
'fete': ('fet',),
'fetere': ('fet',),
'fetest': ('fet',),
'feteste': ('fet',),
'fett': ('fet',),
'feta': ('fete',),
'fetede': ('fete',),
'fetende': ('fete',),
'fetet': ('fete',),
'fetete': ('fete',),
'feterende': ('fetere',),
'fetert': ('fetere',),
'feterte': ('fetere',),
'fetlaten': ('fetlaten',),
'fetlatent': ('fetlaten',),
'fetlatne': ('fetlaten',),
'fetlatnere': ('fetlaten',),
'fetlatnest': ('fetlaten',),
'fetlatneste': ('fetlaten',),
'fetna': ('fetne',),
'fetnede': ('fetne',),
'fetnende': ('fetne',),
'fetnet': ('fetne',),
'fetnete': ('fetne',),
'fettet': ('fettet',),
'fettete': ('fettet',),
'fettetere': ('fettet',),
'fettetest': ('fettet',),
'fetteteste': ('fettet',),
'fettete': ('fettete',),
'fettglinsende': ('fettglinsende',),
'fiberrik': ('fiberrik',),
'fiberrike': ('fiberrik',),
'fiberrikere': ('fiberrik',),
'fiberrikest': ('fiberrik',),
'fiberrikeste': ('fiberrik',),
'fiberrikt': ('fiberrik',),
'fibrøs': ('fibrøs',),
'fibrøse': ('fibrøs',),
'fibrøsere': ('fibrøs',),
'fibrøsest': ('fibrøs',),
'fibrøseste': ('fibrøs',),
'fibrøst': ('fibrøs',),
'fiendsk': ('fiendsk',),
'fiendske': ('fiendsk',),
'fiendskere': ('fiendsk',),
'fiendskest': ('fiendsk',),
'fiendskeste': ('fiendsk',),
'fiendtlig': ('fiendtlig',),
'fiendtlige': ('fiendtlig',),
'fiendtligere': ('fiendtlig',),
'fiendtligst': ('fiendtlig',),
'fiendtligste': ('fiendtlig',),
'fiendtligsinna': ('fiendtligsinna',),
'fiendtligsinnede': ('fiendtligsinnet',),
'fiendtligsinnet': ('fiendtligsinnet',),
'fiendtligsinnete': ('fiendtligsinnet',),
'fiendtligsinnetere': ('fiendtligsinnet',),
'fiendtligsinnetest': ('fiendtligsinnet',),
'fiendtligsinneteste': ('fiendtligsinnet',),
'fiffa': ('fiffe',),
'fiffede': ('fiffe',),
'fiffende': ('fiffe',),
'fiffet': ('fiffe',),
'fiffete': ('fiffe',),
'fiffig': ('fiffig',),
'fiffige': ('fiffig',),
'fiffigere': ('fiffig',),
'fiffigst': ('fiffig',),
'fiffigste': ('fiffig',),
'fighta': ('fighte',),
'fightede': ('fighte',),
'fightende': ('fighte',),
'fightet': ('fighte',),
'fightete': ('fighte',),
'figurativ': ('figurativ',),
'figurative': ('figurativ',),
'figurativere': ('figurativ',),
'figurativest': ('figurativ',),
'figurativeste': ('figurativ',),
'figurativt': ('figurativ',),
'figurerende': ('figurere',),
'figurert': ('figurere',),
'figurerte': ('figurere',),
'figurlig': ('figurlig',),
'figurlige': ('figurlig',),
'figurligere': ('figurlig',),
'figurligst': ('figurlig',),
'figurligste': ('figurlig',),
'fijiansk': ('fijiansk',),
'fijianske': ('fijiansk',),
'fijianskere': ('fijiansk',),
'fijianskest': ('fijiansk',),
'fijianskeste': ('fijiansk',),
'fika': ('fike',),
'fikede': ('fike',),
'fikende': ('fike',),
'fiket': ('fike',),
'fikete': ('fike',),
'fikt': ('fike',),
'fikte': ('fike',),
'fiken': ('fiken',),
'fikent': ('fiken',),
'fikne': ('fiken',),
'fiknere': ('fiken',),
'fiknest': ('fiken',),
'fikneste': ('fiken',),
'fikla': ('fikle',),
'fiklede': ('fikle',),
'fiklende': ('fikle',),
'fiklet': ('fikle',),
'fiklete': ('fikle',),
'fiks': ('fiks',),
'fikse': ('fiks',),
'fiksere': ('fiks',),
'fiksest': ('fiks',),
'fikseste': ('fiks',),
'fikst': ('fiks',),
'fiksa': ('fikse',),
'fiksede': ('fikse',),
'fiksende': ('fikse',),
'fikset': ('fikse',),
'fiksete': ('fikse',),
'fikserende': ('fiksere',),
'fiksert': ('fiksere',),
'fikserte': ('fiksere',),
'fiktiv': ('fiktiv',),
'fiktive': ('fiktiv',),
'fiktivere': ('fiktiv',),
'fiktivest': ('fiktiv',),
'fiktiveste': ('fiktiv',),
'fiktivt': ('fiktiv',),
'filantropisk': ('filantropisk',),
'filantropiske': ('filantropisk',),
'filantropiskere': ('filantropisk',),
'filantropiskest': ('filantropisk',),
'filantropiskeste': ('filantropisk',),
'filatelistisk': ('filatelistisk',),
'filatelistiske': ('filatelistisk',),
'filatelistiskere': ('filatelistisk',),
'filatelistiskest': ('filatelistisk',),
'filatelistiskeste': ('filatelistisk',),
'fila': ('file',),
'filede': ('file',),
'filende': ('file',),
'filet': ('file',),
'filete': ('file',),
'filt': ('file',),
'filte': ('file',),
'filerende': ('filere',),
'filert': ('filere',),
'filerte': ('filere',),
'filerende': ('filere',),
'filert': ('filere',),
'filerte': ('filere',),
'filerende': ('filere',),
'filert': ('filere',),
'filerte': ('filere',),
'fileterende': ('filetere',),
'filetert': ('filetere',),
'fileterte': ('filetere',),
'fileterende': ('filetere',),
'filetert': ('filetere',),
'fileterte': ('filetere',),
'filharmonisk': ('filharmonisk',),
'filharmoniske': ('filharmonisk',),
'filharmoniskere': ('filharmonisk',),
'filharmoniskest': ('filharmonisk',),
'filharmoniskeste': ('filharmonisk',),
'filippinsk': ('filippinsk',),
'filippinske': ('filippinsk',),
'filippinskere': ('filippinsk',),
'filippinskest': ('filippinsk',),
'filippinskeste': ('filippinsk',),
'filistrøs': ('filistrøs',),
'filistrøse': ('filistrøs',),
'filistrøsere': ('filistrøs',),
'filistrøsest': ('filistrøs',),
'filistrøseste': ('filistrøs',),
'filistrøst': ('filistrøs',),
'fille': ('fille',),
'fillet': ('fillet',),
'fillete': ('fillet',),
'filletere': ('fillet',),
'filletest': ('fillet',),
'filleteste': ('fillet',),
'fillete': ('fillete',),
'filmatiserende': ('filmatisere',),
'filmatisert': ('filmatisere',),
'filmatiserte': ('filmatisere',),
'filmatisk': ('filmatisk',),
'filmatiske': ('filmatisk',),
'filmatiskere': ('filmatisk',),
'filmatiskest': ('filmatisk',),
'filmatiskeste': ('filmatisk',),
'filma': ('filme',),
'filmede': ('filme',),
'filmende': ('filme',),
'filmet': ('filme',),
'filmete': ('filme',),
'filologisk': ('filologisk',),
'filologiske': ('filologisk',),
'filologiskere': ('filologisk',),
'filologiskest': ('filologisk',),
'filologiskeste': ('filologisk',),
'filosoferende': ('filosofere',),
'filosofert': ('filosofere',),
'filosoferte': ('filosofere',),
'filosofisk': ('filosofisk',),
'filosofiske': ('filosofisk',),
'filosofiskere': ('filosofisk',),
'filosofiskest': ('filosofisk',),
'filosofiskeste': ('filosofisk',),
'filthåra': ('filthåra',),
'filthårede': ('filthåret',),
'filthåret': ('filthåret',),
'filthårete': ('filthåret',),
'filthåretere': ('filthåret',),
'filthåretest': ('filthåret',),
'filthåreteste': ('filthåret',),
'filtra': ('filtre',),
'filtrede': ('filtre',),
'filtrende': ('filtre',),
'filtret': ('filtre',),
'filtrete': ('filtre',),
'filtrerende': ('filtrere',),
'filtrert': ('filtrere',),
'filtrerte': ('filtrere',),
'fin': ('fin',),
'fine': ('fin',),
'finere': ('fin',),
'finest': ('fin',),
'fineste': ('fin',),
'fint': ('fin',),
'final': ('final',),
'finale': ('final',),
'finalere': ('final',),
'finalest': ('final',),
'finaleste': ('final',),
'finalt': ('final',),
'finansiell': ('finansiell',),
'finansielle': ('finansiell',),
'finansiellere': ('finansiell',),
'finansiellest': ('finansiell',),
'finansielleste': ('finansiell',),
'finansielt': ('finansiell',),
'finansierende': ('finansiere',),
'finansiert': ('finansiere',),
'finansierte': ('finansiere',),
'finerende': ('finere',),
'finert': ('finere',),
'finerte': ('finere',),
'finfin': ('finfin',),
'finfine': ('finfin',),
'finfinere': ('finfin',),
'finfinest': ('finfin',),
'finfineste': ('finfin',),
'finfint': ('finfin',),
'finfordelende': ('finfordele',),
'finfordelt': ('finfordele',),
'finfordelte': ('finfordele',),
'finfølende': ('finfølende',),
'fingerende': ('fingere',),
'fingert': ('fingere',),
'fingerte': ('fingere',),
'fingerferdig': ('fingerferdig',),
'fingerferdige': ('fingerferdig',),
'fingerferdigere': ('fingerferdig',),
'fingerferdigst': ('fingerferdig',),
'fingerferdigste': ('fingerferdig',),
'fingernem': ('fingernem',),
'fingernemme': ('fingernem',),
'fingernemmere': ('fingernem',),
'fingernemmest': ('fingernem',),
'fingernemmeste': ('fingernem',),
'fingernemt': ('fingernem',),
'fingert': ('fingert',),
'fingerte': ('fingert',),
'fingertere': ('fingert',),
'fingertest': ('fingert',),
'fingerteste': ('fingert',),
'fingra': ('fingra',),
'fingra': ('fingre',),
'fingrede': ('fingre',),
'fingrende': ('fingre',),
'fingret': ('fingre',),
'fingrete': ('fingre',),
'fingrede': ('fingret',),
'fingret': ('fingret',),
'fingrete': ('fingret',),
'fingretere': ('fingret',),
'fingretest': ('fingret',),
'fingreteste': ('fingret',),
'finhakka': ('finhakke',),
'finhakkede': ('finhakke',),
'finhakkende': ('finhakke',),
'finhakket': ('finhakke',),
'finhakkete': ('finhakke',),
'finhøvla': ('finhøvle',),
'finhøvlede': ('finhøvle',),
'finhøvlende': ('finhøvle',),
'finhøvlet': ('finhøvle',),
'finhøvlete': ('finhøvle',),
'fininnstillende': ('fininnstille',),
'fininnstilt': ('fininnstille',),
'fininnstilte': ('fininnstille',),
'finitt': ('finitt',),
'finitte': ('finitt',),
'finittere': ('finitt',),
'finittest': ('finitt',),
'finitteste': ('finitt',),
'finkjemma': ('finkjemme',),
'finkjemmede': ('finkjemme',),
'finkjemmende': ('finkjemme',),
'finkjemmet': ('finkjemme',),
'finkjemmete': ('finkjemme',),
'finkjemt': ('finkjemme',),
'finkjemte': ('finkjemme',),
'finkorna': ('finkorna',),
'finkornede': ('finkornet',),
'finkornet': ('finkornet',),
'finkornete': ('finkornet',),
'finkornetere': ('finkornet',),
'finkornetest': ('finkornet',),
'finkorneteste': ('finkornet',),
'finlandsk': ('finlandsk',),
'finlandske': ('finlandsk',),
'finlandskere': ('finlandsk',),
'finlandskest': ('finlandsk',),
'finlandskeste': ('finlandsk',),
'finmalende': ('finmale',),
'finmalt': ('finmale',),
'finmalte': ('finmale',),
'finmaska': ('finmaska',),
'finmaskede': ('finmasket',),
'finmasket': ('finmasket',),
'finmaskete': ('finmasket',),
'finmasketere': ('finmasket',),
'finmasketest': ('finmasket',),
'finmasketeste': ('finmasket',),
'finnende': ('finne',),
'funne': ('finne',),
'funnen': ('finne',),
'funnet': ('finne',),
'finnet': ('finnet',),
'finnete': ('finnet',),
'finnetere': ('finnet',),
'finnetest': ('finnet',),
'finneteste': ('finnet',),
'finnete': ('finnete',),
'finpussa': ('finpusse',),
'finpussede': ('finpusse',),
'finpussende': ('finpusse',),
'finpusset': ('finpusse',),
'finpussete': ('finpusse',),
'finsikta': ('finsikte',),
'finsiktede': ('finsikte',),
'finsiktende': ('finsikte',),
'finsiktet': ('finsikte',),
'finsiktete': ('finsikte',),
'finsk': ('finsk',),
'finske': ('finsk',),
'finskere': ('finsk',),
'finskest': ('finsk',),
'finskeste': ('finsk',),
'finsk-ugrisk': ('finsk-ugrisk',),
'finsk-ugriske': ('finsk-ugrisk',),
'finsk-ugriskere': ('finsk-ugrisk',),
'finsk-ugriskest': ('finsk-ugrisk',),
'finsk-ugriskeste': ('finsk-ugrisk',),
'finskåren': ('finskåren',),
'finskåret': ('finskåren',),
'finskårne': ('finskåren',),
'finskårnere': ('finskåren',),
'finskårnest': ('finskåren',),
'finskårneste': ('finskåren',),
'finskåret': ('finskåret',),
'finskårne': ('finskåret',),
'finskårnere': ('finskåret',),
'finskårnest': ('finskåret',),
'finskårneste': ('finskåret',),
'finstilt': ('finstilt',),
'finstilte': ('finstilt',),
'finstiltere': ('finstilt',),
'finstiltest': ('finstilt',),
'finstilteste': ('finstilt',),
'finta': ('finte',),
'fintede': ('finte',),
'fintende': ('finte',),
'fintet': ('finte',),
'fintete': ('finte',),
'fintalt': ('fintelle',),
'fintalte': ('fintelle',),
'fintella': ('fintelle',),
'fintellede': ('fintelle',),
'fintellende': ('fintelle',),
'fintellet': ('fintelle',),
'fintellete': ('fintelle',),
'fintelt': ('fintelle',),
'fintelte': ('fintelle',),
'fintfølende': ('fintfølende',),
'finurlig': ('finurlig',),
'finurlige': ('finurlig',),
'finurligere': ('finurlig',),
'finurligst': ('finurlig',),
'finurligste': ('finurlig',),
'fiolblå': ('fiolblå',),
'fiolblåe': ('fiolblå',),
'fiolblåere': ('fiolblå',),
'fiolblåest': ('fiolblå',),
'fiolblåeste': ('fiolblå',),
'fiolblått': ('fiolblå',),
'fiolett': ('fiolett',),
'fiolette': ('fiolett',),
'fiolettere': ('fiolett',),
'fiolettest': ('fiolett',),
'fioletteste': ('fiolett',),
'firbeint': ('firbeint',),
'firbeinte': ('firbeint',),
'firbeintere': ('firbeint',),
'firbeintest': ('firbeint',),
'firbeinteste': ('firbeint',),
'firbent': ('firbent',),
'firbente': ('firbent',),
'firbentere': ('firbent',),
'firbentest': ('firbent',),
'firbenteste': ('firbent',),
'firblada': ('firblada',),
'firbladede': ('firbladet',),
'firbladet': ('firbladet',),
'firbladete': ('firbladet',),
'firbladetere': ('firbladet',),
'firbladetest': ('firbladet',),
'firbladeteste': ('firbladet',),
'firdelt': ('firdelt',),
'firdelte': ('firdelt',),
'firdeltere': ('firdelt',),
'firdeltest': ('firdelt',),
'firdelteste': ('firdelt',),
'firdobbel': ('firdobbel',),
'firdobbelt': ('firdobbel',),
'firdoble': ('firdobbel',),
'firdoblere': ('firdobbel',),
'firdoblest': ('firdobbel',),
'firdobleste': ('firdobbel',),
'firdobbelt': ('firdobbelt',),
'firdobbelte': ('firdobbelt',),
'firdobbeltere': ('firdobbelt',),
'firdobbeltest': ('firdobbelt',),
'firdobbelteste': ('firdobbelt',),
'firdobla': ('firdoble',),
'firdoblede': ('firdoble',),
'firdoblende': ('firdoble',),
'firdoblet': ('firdoble',),
'firdoblete': ('firdoble',),
'fira': ('fire',),
'firede': ('fire',),
'firende': ('fire',),
'firet': ('fire',),
'firete': ('fire',),
'firt': ('fire',),
'firte': ('fire',),
'firebeint': ('firebeint',),
'firebeinte': ('firebeint',),
'firebeintere': ('firebeint',),
'firebeintest': ('firebeint',),
'firebeinteste': ('firebeint',),
'firebent': ('firebent',),
'firebente': ('firebent',),
'firebentere': ('firebent',),
'firebentest': ('firebent',),
'firebenteste': ('firebent',),
'fireblada': ('fireblada',),
'firebladede': ('firebladet',),
'firebladet': ('firebladet',),
'firebladete': ('firebladet',),
'firebladetere': ('firebladet',),
'firebladetest': ('firebladet',),
'firebladeteste': ('firebladet',),
'firedelt': ('firedelt',),
'firedelte': ('firedelt',),
'firedeltere': ('firedelt',),
'firedeltest': ('firedelt',),
'firedelteste': ('firedelt',),
'firedimensjonal': ('firedimensjonal',),
'firedimensjonale': ('firedimensjonal',),
'firedimensjonalere': ('firedimensjonal',),
'firedimensjonalest': ('firedimensjonal',),
'firedimensjonaleste': ('firedimensjonal',),
'firedimensjonalt': ('firedimensjonal',),
'firedobbel': ('firedobbel',),
'firedobbelt': ('firedobbel',),
'firedoble': ('firedobbel',),
'firedoblere': ('firedobbel',),
'firedoblest': ('firedobbel',),
'firedobleste': ('firedobbel',),
'firedobbelt': ('firedobbelt',),
'firedobbelte': ('firedobbelt',),
'firedobbeltere': ('firedobbelt',),
'firedobbeltest': ('firedobbelt',),
'firedobbelteste': ('firedobbelt',),
'firedobla': ('firedoble',),
'firedoblede': ('firedoble',),
'firedoblende': ('firedoble',),
'firedoblet': ('firedoble',),
'firedoblete': ('firedoble',),
'fireetasjes': ('fireetasjes',),
'firefelta': ('firefelta',),
'firefeltede': ('firefeltet',),
'firefeltet': ('firefeltet',),
'firefeltete': ('firefeltet',),
'firefeltetere': ('firefeltet',),
'firefeltetest': ('firefeltet',),
'firefelteteste': ('firefeltet',),
'firefelts': ('firefelts',),
'firefota': ('firefota',),
'firefotede': ('firefotet',),
'firefotet': ('firefotet',),
'firefotete': ('firefotet',),
'firefotetere': ('firefotet',),
'firefotetest': ('firefotet',),
'firefoteteste': ('firefotet',),
'fireføtt': ('fireføtt',),
'fireføtte': ('fireføtt',),
'fireføttere': ('fireføtt',),
'fireføttest': ('fireføtt',),
'fireføtteste': ('fireføtt',),
'firehendig': ('firehendig',),
'firehendige': ('firehendig',),
'firehendigere': ('firehendig',),
'firehendigst': ('firehendig',),
'firehendigste': ('firehendig',),
'firehjuls': ('firehjuls',),
'fireliters': ('fireliters',),
'firemasta': ('firemasta',),
'firemastede': ('firemastet',),
'firemastet': ('firemastet',),
'firemastete': ('firemastet',),
'firemastetere': ('firemastet',),
'firemastetest': ('firemastet',),
'firemasteteste': ('firemastet',),
'fireroms': ('fireroms',),
'firesifra': ('firesifra',),
'firesifrede': ('firesifret',),
'firesifret': ('firesifret',),
'firesifrete': ('firesifret',),
'firesifretere': ('firesifret',),
'firesifretest': ('firesifret',),
'firesifreteste': ('firesifret',),
'firesylindra': ('firesylindra',),
'firesylindrede': ('firesylindret',),
'firesylindret': ('firesylindret',),
'firesylindrete': ('firesylindret',),
'firesylindretere': ('firesylindret',),
'firesylindretest': ('firesylindret',),
'firesylindreteste': ('firesylindret',),
'firetoms': ('firetoms',),
'fireårig': ('fireårig',),
'fireårige': ('fireårig',),
'fireårigere': ('fireårig',),
'fireårigst': ('fireårig',),
'fireårigste': ('fireårig',),
'fireårs': ('fireårs',),
'firfota': ('firfota',),
'firfotede': ('firfotet',),
'firfotet': ('firfotet',),
'firfotete': ('firfotet',),
'firfotetere': ('firfotet',),
'firfotetest': ('firfotet',),
'firfoteteste': ('firfotet',),
'firføtt': ('firføtt',),
'firføtte': ('firføtt',),
'firføttere': ('firføtt',),
'firføttest': ('firføtt',),
'firføtteste': ('firføtt',),
'firhendig': ('firhendig',),
'firhendige': ('firhendig',),
'firhendigere': ('firhendig',),
'firhendigst': ('firhendig',),
'firhendigste': ('firhendig',),
'firhjuls': ('firhjuls',),
'firkanta': ('firkanta',),
'firkantede': ('firkantet',),
'firkantet': ('firkantet',),
'firkantete': ('firkantet',),
'firkantetere': ('firkantet',),
'firkantetest': ('firkantet',),
'firkanteteste': ('firkantet',),
'firmasta': ('firmasta',),
'firmastede': ('firmastet',),
'firmastet': ('firmastet',),
'firmastete': ('firmastet',),
'firmastetere': ('firmastet',),
'firmastetest': ('firmastet',),
'firmasteteste': ('firmastet',),
'firsifra': ('firsifra',),
'firsifrede': ('firsifret',),
'firsifret': ('firsifret',),
'firsifrete': ('firsifret',),
'firsifretere': ('firsifret',),
'firsifretest': ('firsifret',),
'firsifreteste': ('firsifret',),
'firskåren': ('firskåren',),
'firskåret': ('firskåren',),
'firskårne': ('firskåren',),
'firskårnere': ('firskåren',),
'firskårnest': ('firskåren',),
'firskårneste': ('firskåren',),
'firskåren': ('firskåren',),
'firskårent': ('firskåren',),
'firskårne': ('firskåren',),
'firskårnere': ('firskåren',),
'firskårnest': ('firskåren',),
'firskårneste': ('firskåren',),
'firskåret': ('firskåret',),
'firskårne': ('firskåret',),
'firskårnere': ('firskåret',),
'firskårnest': ('firskåret',),
'firskårneste': ('firskåret',),
'firstrøken': ('firstrøken',),
'firstrøket': ('firstrøken',),
'firstrøkne': ('firstrøken',),
'firstrøknere': ('firstrøken',),
'firstrøknest': ('firstrøken',),
'firstrøkneste': ('firstrøken',),
'firstrøket': ('firstrøket',),
'firstrøkne': ('firstrøket',),
'firstrøknere': ('firstrøket',),
'firstrøknest': ('firstrøket',),
'firstrøkneste': ('firstrøket',),
'firtoms': ('firtoms',),
'fisblid': ('fisblid',),
'fisblide': ('fisblid',),
'fisblidere': ('fisblid',),
'fisblidest': ('fisblid',),
'fisblideste': ('fisblid',),
'fisblidt': ('fisblid',),
'fesen': ('fise',),
'feset': ('fise',),
'fesne': ('fise',),
'fisende': ('fise',),
'fist': ('fise',),
'fiste': ('fise',),
'fiseblid': ('fiseblid',),
'fiseblide': ('fiseblid',),
'fiseblidere': ('fiseblid',),
'fiseblidest': ('fiseblid',),
'fiseblideste': ('fiseblid',),
'fiseblidt': ('fiseblid',),
'fisefin': ('fisefin',),
'fisefine': ('fisefin',),
'fisefinere': ('fisefin',),
'fisefinest': ('fisefin',),
'fisefineste': ('fisefin',),
'fisefint': ('fisefin',),
'fisefornem': ('fisefornem',),
'fisefornemme': ('fisefornem',),
'fisefornemmere': ('fisefornem',),
'fisefornemmest': ('fisefornem',),
'fisefornemmeste': ('fisefornem',),
'fisefornemt': ('fisefornem',),
'fisfin': ('fisfin',),
'fisfine': ('fisfin',),
'fisfinere': ('fisfin',),
'fisfinest': ('fisfin',),
'fisfineste': ('fisfin',),
'fisfint': ('fisfin',),
'fisfornem': ('fisfornem',),
'fisfornemme': ('fisfornem',),
'fisfornemmere': ('fisfornem',),
'fisfornemmest': ('fisfornem',),
'fisfornemmeste': ('fisfornem',),
'fisfornemt': ('fisfornem',),
'fisjonerende': ('fisjonere',),
'fisjonert': ('fisjonere',),
'fisjonerte': ('fisjonere',),
'fiskal': ('fiskal',),
'fiskale': ('fiskal',),
'fiskalere': ('fiskal',),
'fiskalest': ('fiskal',),
'fiskaleste': ('fiskal',),
'fiskalt': ('fiskal',),
'fiska': ('fiske',),
'fiskede': ('fiske',),
'fiskende': ('fiske',),
'fisket': ('fiske',),
'fiskete': ('fiske',),
'fiska': ('fiske',),
'fiskede': ('fiske',),
'fiskende': ('fiske',),
'fisket': ('fiske',),
'fiskete': ('fiske',),
'fiska': ('fiske',),
'fiskede': ('fiske',),
'fiskende': ('fiske',),
'fisket': ('fiske',),
'fiskete': ('fiske',),
'fisla': ('fisle',),
'fislede': ('fisle',),
'fislende': ('fisle',),
'fislet': ('fisle',),
'fislete': ('fisle',),
'fissil': ('fissil',),
'fissile': ('fissil',),
'fissilere': ('fissil',),
'fissilest': ('fissil',),
'fissileste': ('fissil',),
'fissilt': ('fissil',),
'fjamsa': ('fjamse',),
'fjamsede': ('fjamse',),
'fjamsende': ('fjamse',),
'fjamset': ('fjamse',),
'fjamsete': ('fjamse',),
'fjasa': ('fjase',),
'fjasede': ('fjase',),
'fjasende': ('fjase',),
'fjaset': ('fjase',),
'fjasete': ('fjase',),
'fjast': ('fjase',),
'fjaste': ('fjase',),
'fjaset': ('fjaset',),
'fjasete': ('fjaset',),
'fjasetere': ('fjaset',),
'fjasetest': ('fjaset',),
'fjaseteste': ('fjaset',),
'fjasete': ('fjasete',),
'fjelg': ('fjelg',),
'fjelge': ('fjelg',),
'fjelgere': ('fjelg',),
'fjelgest': ('fjelg',),
'fjelgeste': ('fjelg',),
'fjelgt': ('fjelg',),
'fjelga': ('fjelge',),
'fjelgede': ('fjelge',),
'fjelgende': ('fjelge',),
'fjelget': ('fjelge',),
'fjelgete': ('fjelge',),
'fjerde': ('fjerde',),
'fjern': ('fjern',),
'fjerne': ('fjern',),
'fjernere': ('fjern',),
'fjernest': ('fjern',),
'fjerneste': ('fjern',),
'fjernt': ('fjern',),
'fjerna': ('fjerne',),
'fjernede': ('fjerne',),
'fjernende': ('fjerne',),
'fjernet': ('fjerne',),
'fjernete': ('fjerne',),
'fjernstyrende': ('fjernstyre',),
'fjernstyrt': ('fjernstyre',),
'fjernstyrte': ('fjernstyre',),
'fjernstyrt': ('fjernstyrt',),
'fjernstyrte': ('fjernstyrt',),
'fjernstyrtere': ('fjernstyrt',),
'fjernstyrtest': ('fjernstyrt',),
'fjernstyrteste': ('fjernstyrt',),
'fjerta': ('fjerte',),
'fjertede': ('fjerte',),
'fjertende': ('fjerte',),
'fjertet': ('fjerte',),
'fjertete': ('fjerte',),
'fjeska': ('fjeske',),
'fjeskede': ('fjeske',),
'fjeskende': ('fjeske',),
'fjesket': ('fjeske',),
'fjeskete': ('fjeske',),
'fjetra': ('fjetre',),
'fjetrede': ('fjetre',),
'fjetrende': ('fjetre',),
'fjetret': ('fjetre',),
'fjetrete': ('fjetre',),
'fjolla': ('fjolle',),
'fjollede': ('fjolle',),
'fjollende': ('fjolle',),
'fjollet': ('fjolle',),
'fjollete': ('fjolle',),
'fjollet': ('fjollet',),
'fjollete': ('fjollet',),
'fjolletere': ('fjollet',),
'fjolletest': ('fjollet',),
'fjolleteste': ('fjollet',),
'fjollete': ('fjollete',),
'fjong': ('fjong',),
'fjonge': ('fjong',),
'fjongere': ('fjong',),
'fjongest': ('fjong',),
'fjongeste': ('fjong',),
'fjongt': ('fjong',),
'fjoreldre': ('fjorgammal',),
'fjoreldst': ('fjorgammal',),
'fjoreldste': ('fjorgammal',),
'fjorgamle': ('fjorgammal',),
'fjorgammal': ('fjorgammal',),
'fjorgammalt': ('fjorgammal',),
'fjoreldre': ('fjorgammel',),
'fjoreldst': ('fjorgammel',),
'fjoreldste': ('fjorgammel',),
'fjorgamle': ('fjorgammel',),
'fjorgammel': ('fjorgammel',),
'fjorgammelt': ('fjorgammel',),
'fjortende': ('fjortende',),
'fjortenårig': ('fjortenårig',),
'fjortenårige': ('fjortenårig',),
'fjortenårigere': ('fjortenårig',),
'fjortenårigst': ('fjortenårig',),
'fjortenårigste': ('fjortenårig',),
'fjortenårs': ('fjortenårs',),
'fjottet': ('fjottet',),
'fjottete': ('fjottet',),
'fjottetere': ('fjottet',),
'fjottetest': ('fjottet',),
'fjotteteste': ('fjottet',),
'fjottete': ('fjottete',),
'fjuska': ('fjuske',),
'fjuskede': ('fjuske',),
'fjuskende': ('fjuske',),
'fjusket': ('fjuske',),
'fjuskete': ('fjuske',),
'fjæra': ('fjære',),
'fjærede': ('fjære',),
'fjærende': ('fjære',),
'fjæret': ('fjære',),
'fjærete': ('fjære',),
'fjæra': ('fjære',),
'fjærede': ('fjære',),
'fjærende': ('fjære',),
'fjæret': ('fjære',),
'fjærete': ('fjære',),
'fjæret': ('fjæret',),
'fjærete': ('fjæret',),
'fjæretere': ('fjæret',),
'fjæretest': ('fjæret',),
'fjæreteste': ('fjæret',),
'fjærete': ('fjærete',),
'fjærlett': ('fjærlett',),
'fjærlette': ('fjærlett',),
'fjærlettere': ('fjærlett',),
'fjærlettest': ('fjærlett',),
'fjærletteste': ('fjærlett',),
'fjøra': ('fjøre',),
'fjørede': ('fjøre',),
'fjørende': ('fjøre',),
'fjøret': ('fjøre',),
'fjørete': ('fjøre',),
'fjøret': ('fjøret',),
'fjørete': ('fjøret',),
'fjøretere': ('fjøret',),
'fjøretest': ('fjøret',),
'fjøreteste': ('fjøret',),
'fjørete': ('fjørete',),
'fjørlett': ('fjørlett',),
'fjørlette': ('fjørlett',),
'fjørlettere': ('fjørlett',),
'fjørlettest': ('fjørlett',),
'fjørletteste': ('fjørlett',),
'flagga': ('flagge',),
'flaggede': ('flagge',),
'flaggende': ('flagge',),
'flagget': ('flagge',),
'flaggete': ('flagge',),
'flagrant': ('flagrant',),
'flagrante': ('flagrant',),
'flagrantere': ('flagrant',),
'flagrantest': ('flagrant',),
'flagranteste': ('flagrant',),
'flagra': ('flagre',),
'flagrede': ('flagre',),
'flagrende': ('flagre',),
'flagret': ('flagre',),
'flagrete': ('flagre',),
'flaka': ('flake',),
'flakede': ('flake',),
'flakende': ('flake',),
'flaket': ('flake',),
'flakete': ('flake',),
'flakt': ('flake',),
'flakte': ('flake',),
'flakk': ('flakk',),
'flakke': ('flakk',),
'flakkere': ('flakk',),
'flakkest': ('flakk',),
'flakkeste': ('flakk',),
'flakt': ('flakk',),
'flakka': ('flakke',),
'flakkede': ('flakke',),
'flakkende': ('flakke',),
'flakket': ('flakke',),
'flakkete': ('flakke',),
'flakna': ('flakne',),
'flaknede': ('flakne',),
'flaknende': ('flakne',),
'flaknet': ('flakne',),
'flaknete': ('flakne',),
'flaksa': ('flakse',),
'flaksede': ('flakse',),
'flaksende': ('flakse',),
'flakset': ('flakse',),
'flaksete': ('flakse',),
'flamberende': ('flambere',),
'flambert': ('flambere',),
'flamberte': ('flambere',),
'flamma': ('flamme',),
'flammede': ('flamme',),
'flammende': ('flamme',),
'flammet': ('flamme',),
'flammete': ('flamme',),
'flammende': ('flammende',),
'flammesikker': ('flammesikker',),
'flammesikkert': ('flammesikker',),
'flammesikre': ('flammesikker',),
'flammesikrere': ('flammesikker',),
'flammesikrest': ('flammesikker',),
'flammesikreste': ('flammesikker',),
'flammet': ('flammet',),
'flammete': ('flammet',),
'flammetere': ('flammet',),
'flammetest': ('flammet',),
'flammeteste': ('flammet',),
'flammete': ('flammete',),
'flamsk': ('flamsk',),
'flamske': ('flamsk',),
'flamskere': ('flamsk',),
'flamskest': ('flamsk',),
'flamskeste': ('flamsk',),
'flamsktalende': ('flamsktalende',),
'flana': ('flane',),
'flanede': ('flane',),
'flanende': ('flane',),
'flanet': ('flane',),
'flanete': ('flane',),
'flant': ('flane',),
'flante': ('flane',),
'flanerende': ('flanere',),
'flanert': ('flanere',),
'flanerte': ('flanere',),
'flankerende': ('flankere',),
'flankert': ('flankere',),
'flankerte': ('flankere',),
'flara': ('flare',),
'flarede': ('flare',),
'flarende': ('flare',),
'flaret': ('flare',),
'flarete': ('flare',),
'flart': ('flare',),
'flarte': ('flare',),
'flaska': ('flaske',),
'flaskede': ('flaske',),
'flaskende': ('flaske',),
'flasket': ('flaske',),
'flaskete': ('flaske',),
'flaska': ('flaske',),
'flaskede': ('flaske',),
'flaskende': ('flaske',),
'flasket': ('flaske',),
'flaskete': ('flaske',),
'flaskegrøn': ('flaskegrøn',),
'flaskegrøne': ('flaskegrøn',),
'flaskegrønere': ('flaskegrøn',),
'flaskegrønest': ('flaskegrøn',),
'flaskegrøneste': ('flaskegrøn',),
'flaskegrønt': ('flaskegrøn',),
'flaskegrønn': ('flaskegrønn',),
'flaskegrønne': ('flaskegrønn',),
'flaskegrønnere': ('flaskegrønn',),
'flaskegrønnest': ('flaskegrønn',),
'flaskegrønneste': ('flaskegrønn',),
'flaskegrønt': ('flaskegrønn',),
'flassa': ('flasse',),
'flassede': ('flasse',),
'flassende': ('flasse',),
'flasset': ('flasse',),
'flassete': ('flasse',),
'flasset': ('flasset',),
'flassete': ('flasset',),
'flassetere': ('flasset',),
'flassetest': ('flasset',),
'flasseteste': ('flasset',),
'flassete': ('flassete',),
'flat': ('flat',),
'flate': ('flat',),
'flatere': ('flat',),
'flatest': ('flat',),
'flateste': ('flat',),
'flatt': ('flat',),
'flatbotna': ('flatbotna',),
'flatbotnede': ('flatbotnet',),
'flatbotnet': ('flatbotnet',),
'flatbotnete': ('flatbotnet',),
'flatbotnetere': ('flatbotnet',),
'flatbotnetest': ('flatbotnet',),
'flatbotneteste': ('flatbotnet',),
'flatbrysta': ('flatbrysta',),
'flatbrystede': ('flatbrystet',),
'flatbrystet': ('flatbrystet',),
'flatbrystete': ('flatbrystet',),
'flatbrystetere': ('flatbrystet',),
'flatbrystetest': ('flatbrystet',),
'flatbrysteteste': ('flatbrystet',),
'flatbunna': ('flatbunna',),
'flatbunnede': ('flatbunnet',),
'flatbunnet': ('flatbunnet',),
'flatbunnete': ('flatbunnet',),
'flatbunnetere': ('flatbunnet',),
'flatbunnetest': ('flatbunnet',),
'flatbunneteste': ('flatbunnet',),
'flata': ('flate',),
'flatede': ('flate',),
'flatende': ('flate',),
'flatet': ('flate',),
'flatete': ('flate',),
'flatklemt': ('flatklemt',),
'flatklemte': ('flatklemt',),
'flatklemtere': ('flatklemt',),
'flatklemtest': ('flatklemt',),
'flatklemteste': ('flatklemt',),
'flatlendt': ('flatlendt',),
'flatlendte': ('flatlendt',),
'flatlendtere': ('flatlendt',),
'flatlendtest': ('flatlendt',),
'flatlendteste': ('flatlendt',),
'flatna': ('flatne',),
'flatnede': ('flatne',),
'flatnende': ('flatne',),
'flatnet': ('flatne',),
'flatnete': ('flatne',),
'flatterende': ('flattere',),
'flattert': ('flattere',),
'flatterte': ('flattere',),
'flatterende': ('flatterende',),
'flattrykt': ('flattrykt',),
'flattrykte': ('flattrykt',),
'flattryktere': ('flattrykt',),
'flattryktest': ('flattrykt',),
'flattrykteste': ('flattrykt',),
'flau': ('flau',),
'flaue': ('flau',),
'flauere': ('flau',),
'flauest': ('flau',),
'flaueste': ('flau',),
'flaut': ('flau',),
'flautt': ('flau',),
'flaua': ('flaue',),
'flauede': ('flaue',),
'flauende': ('flaue',),
'flauet': ('flaue',),
'flauete': ('flaue',),
'flegmatisk': ('flegmatisk',),
'flegmatiske': ('flegmatisk',),
'flegmatiskere': ('flegmatisk',),
'flegmatiskest': ('flegmatisk',),
'flegmatiskeste': ('flegmatisk',),
'fleinskalla': ('fleinskalla',),
'fleinskallede': ('fleinskallet',),
'fleinskallet': ('fleinskallet',),
'fleinskallete': ('fleinskallet',),
'fleinskalletere': ('fleinskallet',),
'fleinskalletest': ('fleinskallet',),
'fleinskalleteste': ('fleinskallet',),
'fleipa': ('fleipe',),
'fleipede': ('fleipe',),
'fleipende': ('fleipe',),
'fleipet': ('fleipe',),
'fleipete': ('fleipe',),
'fleipt': ('fleipe',),
'fleipte': ('fleipe',),
'fleipet': ('fleipet',),
'fleipete': ('fleipet',),
'fleipetere': ('fleipet',),
'fleipetest': ('fleipet',),
'fleipeteste': ('fleipet',),
'fleipete': ('fleipete',),
'flekka': ('flekke',),
'flekkede': ('flekke',),
'flekkende': ('flekke',),
'flekket': ('flekke',),
'flekkete': ('flekke',),
'flekka': ('flekke',),
'flekkede': ('flekke',),
'flekkende': ('flekke',),
'flekket': ('flekke',),
'flekkete': ('flekke',),
'flekt': ('flekke',),
'flekte': ('flekke',),
'flekket': ('flekket',),
'flekkete': ('flekket',),
'flekketere': ('flekket',),
'flekketest': ('flekket',),
'flekketeste': ('flekket',),
'flekkete': ('flekkete',),
'fleksa': ('flekse',),
'fleksede': ('flekse',),
'fleksende': ('flekse',),
'flekset': ('flekse',),
'fleksete': ('flekse',),
'fleksibel': ('fleksibel',),
'fleksibelt': ('fleksibel',),
'fleksible': ('fleksibel',),
'fleksiblere': ('fleksibel',),
'fleksiblest': ('fleksibel',),
'fleksibleste': ('fleksibel',),
'flekterende': ('flektere',),
'flektert': ('flektere',),
'flekterte': ('flektere',),
'flenga': ('flenge',),
'flengede': ('flenge',),
'flengende': ('flenge',),
'flenget': ('flenge',),
'flengete': ('flenge',),
'flengt': ('flenge',),
'flengte': ('flenge',),
'flengende': ('flengende',),
'flensa': ('flense',),
'flensede': ('flense',),
'flensende': ('flense',),
'flenset': ('flense',),
'flensete': ('flense',),
'flensa': ('flense',),
'flensede': ('flense',),
'flensende': ('flense',),
'flenset': ('flense',),
'flensete': ('flense',),
'flerbo': ('flerbo',),
'flerbu': ('flerbu',),
'flercella': ('flercella',),
'flercellede': ('flercellet',),
'flercellet': ('flercellet',),
'flercellete': ('flercellet',),
'flercelletere': ('flercellet',),
'flercelletest': ('flercellet',),
'flercelleteste': ('flercellet',),
'flerdobbel': ('flerdobbel',),
'flerdobbelt': ('flerdobbel',),
'flerdoble': ('flerdobbel',),
'flerdoblere': ('flerdobbel',),
'flerdoblest': ('flerdobbel',),
'flerdobleste': ('flerdobbel',),
'flerdobbelt': ('flerdobbelt',),
'flerdobbelte': ('flerdobbelt',),
'flerdobbeltere': ('flerdobbelt',),
'flerdobbeltest': ('flerdobbelt',),
'flerdobbelteste': ('flerdobbelt',),
'flerdobla': ('flerdoble',),
'flerdoblede': ('flerdoble',),
'flerdoblende': ('flerdoble',),
'flerdoblet': ('flerdoble',),
'flerdoblete': ('flerdoble',),
'flerfargede': ('flerfarget',),
'flerfarget': ('flerfarget',),
'flerfargete': ('flerfarget',),
'flerfargetere': ('flerfarget',),
'flerfargetest': ('flerfarget',),
'flerfargeteste': ('flerfarget',),
'flerfasa': ('flerfasa',),
'flerfasede': ('flerfaset',),
'flerfaset': ('flerfaset',),
'flerfasete': ('flerfaset',),
'flerfasetere': ('flerfaset',),
'flerfasetest': ('flerfaset',),
'flerfaseteste': ('flerfaset',),
'flerfoldig': ('flerfoldig',),
'flerfoldige': ('flerfoldig',),
'flerfoldigere': ('flerfoldig',),
'flerfoldigst': ('flerfoldig',),
'flerfoldigste': ('flerfoldig',),
'flernasjonal': ('flernasjonal',),
'flernasjonale': ('flernasjonal',),
'flernasjonalere': ('flernasjonal',),
'flernasjonalest': ('flernasjonal',),
'flernasjonaleste': ('flernasjonal',),
'flernasjonalt': ('flernasjonal',),
'flersida': ('flersida',),
'flersidede': ('flersidet',),
'flersidet': ('flersidet',),
'flersidete': ('flersidet',),
'flersidetere': ('flersidet',),
'flersidetest': ('flersidet',),
'flersideteste': ('flersidet',),
'flersidig': ('flersidig',),
'flersidige': ('flersidig',),
'flersidigere': ('flersidig',),
'flersidigst': ('flersidig',),
'flersidigste': ('flersidig',),
'flersifra': ('flersifra',),
'flersifrede': ('flersifret',),
'flersifret': ('flersifret',),
'flersifrete': ('flersifret',),
'flersifretere': ('flersifret',),
'flersifretest': ('flersifret',),
'flersifreteste': ('flersifret',),
'flerspråklig': ('flerspråklig',),
'flerspråklige': ('flerspråklig',),
'flerspråkligere': ('flerspråklig',),
'flerspråkligst': ('flerspråklig',),
'flerspråkligste': ('flerspråklig',),
'flerstemmig': ('flerstemmig',),
'flerstemmige': ('flerstemmig',),
'flerstemmigere': ('flerstemmig',),
'flerstemmigst': ('flerstemmig',),
'flerstemmigste': ('flerstemmig',),
'flerstemt': ('flerstemt',),
'flerstemte': ('flerstemt',),
'flerstemtere': ('flerstemt',),
'flerstemtest': ('flerstemt',),
'flerstemteste': ('flerstemt',),
'flertydig': ('flertydig',),
'flertydige': ('flertydig',),
'flertydigere': ('flertydig',),
'flertydigst': ('flertydig',),
'flertydigste': ('flertydig',),
'flerverdig': ('flerverdig',),
'flerverdige': ('flerverdig',),
'flerverdigere': ('flerverdig',),
'flerverdigst': ('flerverdig',),
'flerverdigste': ('flerverdig',),
'flerårig': ('flerårig',),
'flerårige': ('flerårig',),
'flerårigere': ('flerårig',),
'flerårigst': ('flerårig',),
'flerårigste': ('flerårig',),
'flesket': ('flesket',),
'fleskete': ('flesket',),
'flesketere': ('flesket',),
'flesketest': ('flesket',),
'flesketeste': ('flesket',),
'fleskete': ('fleskete',),
'fletta': ('flette',),
'flettede': ('flette',),
'flettende': ('flette',),
'flettet': ('flette',),
'flettete': ('flette',),
'fletta': ('flette',),
'flettede': ('flette',),
'flettende': ('flette',),
'flettet': ('flette',),
'flettete': ('flette',),
'flidd': ('fli',),
'flidde': ('fli',),
'fliende': ('fli',),
'flidd': ('flidd',),
'flidde': ('flidd',),
'fliddere': ('flidd',),
'fliddest': ('flidd',),
'fliddeste': ('flidd',),
'fliket': ('fliket',),
'flikete': ('fliket',),
'fliketere': ('fliket',),
'fliketest': ('fliket',),
'fliketeste': ('fliket',),
'flikete': ('flikete',),
'flikka': ('flikke',),
'flikkede': ('flikke',),
'flikkende': ('flikke',),
'flikket': ('flikke',),
'flikkete': ('flikke',),
'flimra': ('flimre',),
'flimrede': ('flimre',),
'flimrende': ('flimre',),
'flimret': ('flimre',),
'flimrete': ('flimre',),
'flink': ('flink',),
'flinke': ('flink',),
'flinkere': ('flink',),
'flinkest': ('flink',),
'flinkeste': ('flink',),
'flinkt': ('flink',),
'flinthard': ('flinthard',),
'flintharde': ('flinthard',),
'flinthardere': ('flinthard',),
'flinthardest': ('flinthard',),
'flinthardeste': ('flinthard',),
'flinthardt': ('flinthard',),
'flintskalla': ('flintskalla',),
'flintskallede': ('flintskallet',),
'flintskallet': ('flintskallet',),
'flintskallete': ('flintskallet',),
'flintskalletere': ('flintskallet',),
'flintskalletest': ('flintskallet',),
'flintskalleteste': ('flintskallet',),
'flippa': ('flippe',),
'flippede': ('flippe',),
'flippende': ('flippe',),
'flippet': ('flippe',),
'flippete': ('flippe',),
'flirende': ('flire',),
'flirt': ('flire',),
'flirte': ('flire',),
'flisbelagt': ('flisbelagt',),
'flisbelagte': ('flisbelagt',),
'flisbelagtere': ('flisbelagt',),
'flisbelagtest': ('flisbelagt',),
'flisbelagteste': ('flisbelagt',),
'flisa': ('flise',),
'flisede': ('flise',),
'flisende': ('flise',),
'fliset': ('flise',),
'flisete': ('flise',),
'flist': ('flise',),
'fliste': ('flise',),
'flisebelagt': ('flisebelagt',),
'flisebelagte': ('flisebelagt',),
'flisebelagtere': ('flisebelagt',),
'flisebelagtest': ('flisebelagt',),
'flisebelagteste': ('flisebelagt',),
'fliselagt': ('fliselagt',),
'fliselagte': ('fliselagt',),
'fliselagtere': ('fliselagt',),
'fliselagtest': ('fliselagt',),
'fliselagteste': ('fliselagt',),
'fliselagt': ('fliselegge',),
'fliselagte': ('fliselegge',),
'fliseleggende': ('fliselegge',),
'fliset': ('fliset',),
'flisete': ('fliset',),
'flisetere': ('fliset',),
'flisetest': ('fliset',),
'fliseteste': ('fliset',),
'flisete': ('flisete',),
'flislagt': ('flislagt',),
'flislagte': ('flislagt',),
'flislagtere': ('flislagt',),
'flislagtest': ('flislagt',),
'flislagteste': ('flislagt',),
'flislagt': ('flislegge',),
'flislagte': ('flislegge',),
'flisleggende': ('flislegge',),
'flittig': ('flittig',),
'flittige': ('flittig',),
'flittigere': ('flittig',),
'flittigst': ('flittig',),
'flittigste': ('flittig',),
'floka': ('floke',),
'flokede': ('floke',),
'flokende': ('floke',),
'floket': ('floke',),
'flokete': ('floke',),
'floket': ('floket',),
'flokete': ('floket',),
'floketere': ('floket',),
'floketest': ('floket',),
'floketeste': ('floket',),
'flokete': ('flokete',),
'flokka': ('flokke',),
'flokkede': ('flokke',),
'flokkende': ('flokke',),
'flokket': ('flokke',),
'flokkete': ('flokke',),
'floksa': ('flokse',),
'floksede': ('flokse',),
'floksende': ('flokse',),
'flokset': ('flokse',),
'floksete': ('flokse',),
'flomherja': ('flomherja',),
'flomherjede': ('flomherjet',),
'flomherjet': ('flomherjet',),
'flomherjete': ('flomherjet',),
'flomherjetere': ('flomherjet',),
'flomherjetest': ('flomherjet',),
'flomherjeteste': ('flomherjet',),
'flomma': ('flomme',),
'flommede': ('flomme',),
'flommende': ('flomme',),
'flommet': ('flomme',),
'flommete': ('flomme',),
'floppa': ('floppe',),
'floppede': ('floppe',),
'floppende': ('floppe',),
'floppet': ('floppe',),
'floppete': ('floppe',),
'floppa': ('floppe',),
'floppede': ('floppe',),
'floppende': ('floppe',),
'floppet': ('floppe',),
'floppete': ('floppe',),
'floragraferende': ('floragrafere',),
'floragrafert': ('floragrafere',),
'floragraferte': ('floragrafere',),
'florentinsk': ('florentinsk',),
'florentinske': ('florentinsk',),
'florentinskere': ('florentinsk',),
'florentinskest': ('florentinsk',),
'florentinskeste': ('florentinsk',),
'florerende': ('florere',),
'florert': ('florere',),
'florerte': ('florere',),
'florisant': ('florisant',),
'florisante': ('florisant',),
'florisantere': ('florisant',),
'florisantest': ('florisant',),
'florisanteste': ('florisant',),
'florlett': ('florlett',),
'florlette': ('florlett',),
'florlettere': ('florlett',),
'florlettest': ('florlett',),
'florletteste': ('florlett',),
'floromvundet': ('floromvundet',),
'floromvundne': ('floromvundet',),
'floromvundnere': ('floromvundet',),
'floromvundnest': ('floromvundet',),
'floromvundneste': ('floromvundet',),
'flotta': ('flotte',),
'flottede': ('flotte',),
'flottende': ('flotte',),
'flottet': ('flotte',),
'flottete': ('flotte',),
'fluid': ('fluid',),
'fluide': ('fluid',),
'fluidere': ('fluid',),
'fluidest': ('fluid',),
'fluideste': ('fluid',),
'flukta': ('flukte',),
'fluktede': ('flukte',),
'fluktende': ('flukte',),
'fluktet': ('flukte',),
'fluktete': ('flukte',),
'fluktsikker': ('fluktsikker',),
'fluktsikkert': ('fluktsikker',),
'fluktsikre': ('fluktsikker',),
'fluktsikrere': ('fluktsikker',),
'fluktsikrest': ('fluktsikker',),
'fluktsikreste': ('fluktsikker',),
'fluktuerende': ('fluktuere',),
'fluktuert': ('fluktuere',),
'fluktuerte': ('fluktuere',),
'fluorescerende': ('fluorescere',),
'fluorescert': ('fluorescere',),
'fluorescerte': ('fluorescere',),
'fluoriderende': ('fluoridere',),
'fluoridert': ('fluoridere',),
'fluoriderte': ('fluoridere',),
'fluoriserende': ('fluorisere',),
'fluorisert': ('fluorisere',),
'fluoriserte': ('fluorisere',),
'flydd': ('fly',),
'flydde': ('fly',),
'flyende': ('fly',),
'fløyen': ('fly',),
'fløyet': ('fly',),
'fløyne': ('fly',),
'flybåren': ('flybåren',),
'flybåret': ('flybåren',),
'flybårne': ('flybåren',),
'flybårnere': ('flybåren',),
'flybårnest': ('flybåren',),
'flybårneste': ('flybåren',),
'flybåret': ('flybåret',),
'flybårne': ('flybåret',),
'flybårnere': ('flybåret',),
'flybårnest': ('flybåret',),
'flybårneste': ('flybåret',),
'flydyktig': ('flydyktig',),
'flydyktige': ('flydyktig',),
'flydyktigere': ('flydyktig',),
'flydyktigst': ('flydyktig',),
'flydyktigste': ('flydyktig',),
'flyende': ('flyende',),
'flyferdig': ('flyferdig',),
'flyferdige': ('flyferdig',),
'flyferdigere': ('flyferdig',),
'flyferdigst': ('flyferdig',),
'flyferdigste': ('flyferdig',),
'flydd': ('flyge',),
'flydde': ('flyge',),
'flygende': ('flyge',),
'fløyen': ('flyge',),
'fløyet': ('flyge',),
'fløyne': ('flyge',),
'flygedyktig': ('flygedyktig',),
'flygedyktige': ('flygedyktig',),
'flygedyktigere': ('flygedyktig',),
'flygedyktigst': ('flygedyktig',),
'flygedyktigste': ('flygedyktig',),
'flygeferdig': ('flygeferdig',),
'flygeferdige': ('flygeferdig',),
'flygeferdigere': ('flygeferdig',),
'flygeferdigst': ('flygeferdig',),
'flygeferdigste': ('flygeferdig',),
'flygende': ('flygende',),
'flykta': ('flykte',),
'flyktede': ('flykte',),
'flyktende': ('flykte',),
'flyktet': ('flykte',),
'flyktete': ('flykte',),
'flyktig': ('flyktig',),
'flyktige': ('flyktig',),
'flyktigere': ('flyktig',),
'flyktigst': ('flyktig',),
'flyktigste': ('flyktig',),
'flytende': ('flyte',),
'flytt': ('flyte',),
'flytte': ('flyte',),
'flytende': ('flytende',),
'flyttbar': ('flyttbar',),
'flyttbare': ('flyttbar',),
'flyttbarere': ('flyttbar',),
'flyttbarest': ('flyttbar',),
'flyttbareste': ('flyttbar',),
'flyttbart': ('flyttbar',),
'flytta': ('flytte',),
'flyttede': ('flytte',),
'flyttende': ('flytte',),
'flyttet': ('flytte',),
'flyttete': ('flytte',),
'flådd': ('flå',),
'flådde': ('flå',),
'flående': ('flå',),
'flå': ('flå',),
'flåe': ('flå',),
'flåere': ('flå',),
'flåest': ('flå',),
'flåeste': ('flå',),
'flått': ('flå',),
'flåkjefta': ('flåkjefta',),
'flåkjeftede': ('flåkjeftet',),
'flåkjeftet': ('flåkjeftet',),
'flåkjeftete': ('flåkjeftet',),
'flåkjeftetere': ('flåkjeftet',),
'flåkjeftetest': ('flåkjeftet',),
'flåkjefteteste': ('flåkjeftet',),
'flåsende': ('flåse',),
'flåst': ('flåse',),
'flåste': ('flåse',),
'flåset': ('flåset',),
'flåsete': ('flåset',),
'flåsetere': ('flåset',),
'flåsetest': ('flåset',),
'flåseteste': ('flåset',),
'flåsete': ('flåsete',),
'flædd': ('flæ',),
'flædde': ('flæ',),
'flæende': ('flæ',),
'flæra': ('flære',),
'flærede': ('flære',),
'flærende': ('flære',),
'flæret': ('flære',),
'flærete': ('flære',),
'flødd': ('flø',),
'flødde': ('flø',),
'fløende': ('flø',),
'fløkende': ('fløke',),
'fløkt': ('fløke',),
'fløkte': ('fløke',),
'flømma': ('flømme',),
'flømmede': ('flømme',),
'flømmende': ('flømme',),
'flømmet': ('flømme',),
'flømmete': ('flømme',),
'flømt': ('flømme',),
'flømte': ('flømme',),
'flørta': ('flørte',),
'flørtede': ('flørte',),
'flørtende': ('flørte',),
'flørtet': ('flørte',),
'flørtete': ('flørte',),
'fløta': ('fløte',),
'fløtede': ('fløte',),
'fløtende': ('fløte',),
'fløtet': ('fløte',),
'fløtete': ('fløte',),
'fløtt': ('fløte',),
'fløtte': ('fløte',),
'fløyta': ('fløyte',),
'fløytede': ('fløyte',),
'fløytende': ('fløyte',),
'fløytet': ('fløyte',),
'fløytete': ('fløyte',),
'fløyta': ('fløyte',),
'fløytede': ('fløyte',),
'fløytende': ('fløyte',),
'fløytet': ('fløyte',),
'fløytete': ('fløyte',),
'fløytt': ('fløyte',),
'fløytte': ('fløyte',),
'fnisende': ('fnise',),
'fnist': ('fnise',),
'fniste': ('fnise',),
'fniset': ('fniset',),
'fnisete': ('fniset',),
'fnisetere': ('fniset',),
'fnisetest': ('fniset',),
'fniseteste': ('fniset',),
'fnisete': ('fnisete',),
'fnugglett': ('fnugglett',),
'fnugglette': ('fnugglett',),
'fnugglettere': ('fnugglett',),
'fnugglettest': ('fnugglett',),
'fnuggletteste': ('fnugglett',),
'fnysende': ('fnyse',),
'fnyst': ('fnyse',),
'fnyste': ('fnyse',),
'fnysende': ('fnysende',),
'fokal': ('fokal',),
'fokale': ('fokal',),
'fokalere': ('fokal',),
'fokalest': ('fokal',),
'fokaleste': ('fokal',),
'fokalt': ('fokal',),
'fokuserende': ('fokusere',),
'fokusert': ('fokusere',),
'fokuserte': ('fokusere',),
'folda': ('folde',),
'foldede': ('folde',),
'foldende': ('folde',),
'foldet': ('folde',),
'foldete': ('folde',),
'fola': ('fole',),
'folede': ('fole',),
'folende': ('fole',),
'folet': ('fole',),
'folete': ('fole',),
'folierende': ('foliere',),
'foliert': ('foliere',),
'folierte': ('foliere',),
'folka': ('folke',),
'folkede': ('folke',),
'folkende': ('folke',),
'folket': ('folke',),
'folkete': ('folke',),
'folkelig': ('folkelig',),
'folkelige': ('folkelig',),
'folkeligere': ('folkelig',),
'folkeligst': ('folkelig',),
'folkeligste': ('folkelig',),
'folkevalgt': ('folkevalgt',),
'folkevalgte': ('folkevalgt',),
'folkevalgtere': ('folkevalgt',),
'folkevalgtest': ('folkevalgt',),
'folkevalgteste': ('folkevalgt',),
'folkeverre': ('folkevond',),
'folkeverst': ('folkevond',),
'folkeverste': ('folkevond',),
'folkevond': ('folkevond',),
'folkevonde': ('folkevond',),
'folkevondere': ('folkevond',),
'folkevondest': ('folkevond',),
'folkevondeste': ('folkevond',),
'folkevondt': ('folkevond',),
'folkloristisk': ('folkloristisk',),
'folkloristiske': ('folkloristisk',),
'folkloristiskere': ('folkloristisk',),
'folkloristiskest': ('folkloristisk',),
'folkloristiskeste': ('folkloristisk',),
'folksom': ('folksom',),
'folksomme': ('folksom',),
'folksommere': ('folksom',),
'folksomst': ('folksom',),
'folksomste': ('folksom',),
'folksomt': ('folksom',),
'folla': ('folle',),
'follede': ('folle',),
'follende': ('folle',),
'follet': ('folle',),
'follete': ('folle',),
'follrik': ('follrik',),
'follrike': ('follrik',),
'follrikere': ('follrik',),
'follrikest': ('follrik',),
'follrikeste': ('follrik',),
'follrikt': ('follrik',),
'folna': ('folne',),
'folnede': ('folne',),
'folnende': ('folne',),
'folnet': ('folne',),
'folnete': ('folne',),
'fomla': ('fomle',),
'fomlede': ('fomle',),
'fomlende': ('fomle',),
'fomlet': ('fomle',),
'fomlete': ('fomle',),
'fonetisk': ('fonetisk',),
'fonetiske': ('fonetisk',),
'fonetiskere': ('fonetisk',),
'fonetiskest': ('fonetisk',),
'fonetiskeste': ('fonetisk',),
'fonna': ('fonne',),
'fonnede': ('fonne',),
'fonnende': ('fonne',),
'fonnet': ('fonne',),
'fonnete': ('fonne',),
'fonnet': ('fonnet',),
'fonnete': ('fonnet',),
'fonnetere': ('fonnet',),
'fonnetest': ('fonnet',),
'fonneteste': ('fonnet',),
'fonnete': ('fonnete',),
'fonologisk': ('fonologisk',),
'fonologiske': ('fonologisk',),
'fonologiskere': ('fonologisk',),
'fonologiskest': ('fonologisk',),
'fonologiskeste': ('fonologisk',),
'forakta': ('forakte',),
'foraktede': ('forakte',),
'foraktende': ('forakte',),
'foraktet': ('forakte',),
'foraktete': ('forakte',),
'foraktelig': ('foraktelig',),
'foraktelige': ('foraktelig',),
'forakteligere': ('foraktelig',),
'forakteligst': ('foraktelig',),
'forakteligste': ('foraktelig',),
'foranderlig': ('foranderlig',),
'foranderlige': ('foranderlig',),
'foranderligere': ('foranderlig',),
'foranderligst': ('foranderlig',),
'foranderligste': ('foranderlig',),
'forandra': ('forandre',),
'forandrede': ('forandre',),
'forandrende': ('forandre',),
'forandret': ('forandre',),
'forandrete': ('forandre',),
'forankra': ('forankre',),
'forankrede': ('forankre',),
'forankrende': ('forankre',),
'forankret': ('forankre',),
'forankrete': ('forankre',),
'foranlediga': ('foranledige',),
'foranledigede': ('foranledige',),
'foranledigende': ('foranledige',),
'foranlediget': ('foranledige',),
'foranledigete': ('foranledige',),
'forannevnt': ('forannevnt',),
'forannevnte': ('forannevnt',),
'forannevntere': ('forannevnt',),
'forannevntest': ('forannevnt',),
'forannevnteste': ('forannevnt',),
'foranstalta': ('foranstalte',),
'foranstaltede': ('foranstalte',),
'foranstaltende': ('foranstalte',),
'foranstaltet': ('foranstalte',),
'foranstaltete': ('foranstalte',),
'foranstilt': ('foranstilt',),
'foranstilte': ('foranstilt',),
'foranstiltere': ('foranstilt',),
'foranstiltest': ('foranstilt',),
'foranstilteste': ('foranstilt',),
'forarbeida': ('forarbeide',),
'forarbeidd': ('forarbeide',),
'forarbeidde': ('forarbeide',),
'forarbeidede': ('forarbeide',),
'forarbeidende': ('forarbeide',),
'forarbeidet': ('forarbeide',),
'forarbeidete': ('forarbeide',),
'forarga': ('forarge',),
'forargede': ('forarge',),
'forargende': ('forarge',),
'forarget': ('forarge',),
'forargete': ('forarge',),
'forargelig': ('forargelig',),
'forargelige': ('forargelig',),
'forargeligere': ('forargelig',),
'forargeligst': ('forargelig',),
'forargeligste': ('forargelig',),
'forarma': ('forarme',),
'forarmede': ('forarme',),
'forarmende': ('forarme',),
'forarmet': ('forarme',),
'forarmete': ('forarme',),
'forbanna': ('forbanna',),
'forbanna': ('forbanne',),
'forbannede': ('forbanne',),
'forbannende': ('forbanne',),
'forbannet': ('forbanne',),
'forbannete': ('forbanne',),
'forbant': ('forbanne',),
'forbante': ('forbanne',),
'forbannede': ('forbannet',),
'forbannet': ('forbannet',),
'forbannete': ('forbannet',),
'forbannetere': ('forbannet',),
'forbannetest': ('forbannet',),
'forbanneteste': ('forbannet',),
'forbarma': ('forbarme',),
'forbarmede': ('forbarme',),
'forbarmende': ('forbarme',),
'forbarmet': ('forbarme',),
'forbarmete': ('forbarme',),
'forbaska': ('forbaska',),
'forbaskede': ('forbasket',),
'forbasket': ('forbasket',),
'forbaskete': ('forbasket',),
'forbasketere': ('forbasket',),
'forbasketest': ('forbasket',),
'forbasketeste': ('forbasket',),
'forbausa': ('forbause',),
'forbausede': ('forbause',),
'forbausende': ('forbause',),
'forbauset': ('forbause',),
'forbausete': ('forbause',),
'forbedra': ('forbedre',),
'forbedrede': ('forbedre',),
'forbedrende': ('forbedre',),
'forbedret': ('forbedre',),
'forbedrete': ('forbedre',),
'forbeholdende': ('forbeholde',),
'forbeholdt': ('forbeholde',),
'forbeholdte': ('forbeholde',),
'forbeholden': ('forbeholden',),
'forbeholdent': ('forbeholden',),
'forbeholdne': ('forbeholden',),
'forbeholdnere': ('forbeholden',),
'forbeholdnest': ('forbeholden',),
'forbeholdneste': ('forbeholden',),
'forbeina': ('forbeine',),
'forbeinede': ('forbeine',),
'forbeinende': ('forbeine',),
'forbeinet': ('forbeine',),
'forbeinete': ('forbeine',),
'forbena': ('forbene',),
'forbenede': ('forbene',),
'forbenende': ('forbene',),
'forbenet': ('forbene',),
'forbenete': ('forbene',),
'forberedende': ('forberede',),
'forberedt': ('forberede',),
'forberedte': ('forberede',),
'forberedende': ('forberedende',),
'forberedt': ('forberedt',),
'forberedte': ('forberedt',),
'forberedtere': ('forberedt',),
'forberedtest': ('forberedt',),
'forberedteste': ('forberedt',),
'forbigående': ('forbigå',),
'forbigått': ('forbigå',),
'forbigåtte': ('forbigå',),
'forbigående': ('forbigående',),
'forbilledlig': ('forbilledlig',),
'forbilledlige': ('forbilledlig',),
'forbilledligere': ('forbilledlig',),
'forbilledligst': ('forbilledlig',),
'forbilledligste': ('forbilledlig',),
'forbindende': ('forbinde',),
'forbunden': ('forbinde',),
'forbundet': ('forbinde',),
'forbundne': ('forbinde',),
'forbindtlig': ('forbindtlig',),
'forbindtlige': ('forbindtlig',),
'forbindtligere': ('forbindtlig',),
'forbindtligst': ('forbindtlig',),
'forbindtligste': ('forbindtlig',),
'forbipasserende': ('forbipasserende',),
'forbistra': ('forbistra',),
'forbistrede': ('forbistret',),
'forbistret': ('forbistret',),
'forbistrete': ('forbistret',),
'forbistretere': ('forbistret',),
'forbistretest': ('forbistret',),
'forbistreteste': ('forbistret',),
'forbitra': ('forbitra',),
'forbitra': ('forbitre',),
'forbitrede': ('forbitre',),
'forbitrende': ('forbitre',),
'forbitret': ('forbitre',),
'forbitrete': ('forbitre',),
'forbitrede': ('forbitret',),
'forbitret': ('forbitret',),
'forbitrete': ('forbitret',),
'forbitretere': ('forbitret',),
'forbitretest': ('forbitret',),
'forbitreteste': ('forbitret',),
'forblenda': ('forblende',),
'forblendede': ('forblende',),
'forblendende': ('forblende',),
'forblendet': ('forblende',),
'forblendete': ('forblende',),
'forblitt': ('forbli',),
'forblitte': ('forbli',),
'forblivende': ('forbli',),
'forblinda': ('forblinde',),
'forblindede': ('forblinde',),
'forblindende': ('forblinde',),
'forblindet': ('forblinde',),
'forblindete': ('forblinde',),
'forblomma': ('forblomma',),
'forblommede': ('forblommet',),
'forblommet': ('forblommet',),
'forblommete': ('forblommet',),
'forblommetere': ('forblommet',),
'forblommetest': ('forblommet',),
'forblommeteste': ('forblommet',),
'forblåst': ('forblåst',),
'forblåste': ('forblåst',),
'forblåstere': ('forblåst',),
'forblåstest': ('forblåst',),
'forblåsteste': ('forblåst',),
'forblødd': ('forblø',),
'forblødde': ('forblø',),
'forbløende': ('forblø',),
'forbløffa': ('forbløffe',),
'forbløffede': ('forbløffe',),
'forbløffende': ('forbløffe',),
'forbløffet': ('forbløffe',),
'forbløffete': ('forbløffe',),
'forbløffende': ('forbløffende',),
'forborgen': ('forborgen',),
'forborgent': ('forborgen',),
'forborgne': ('forborgen',),
'forborgnere': ('forborgen',),
'forborgnest': ('forborgen',),
'forborgneste': ('forborgen',),
'forbrukende': ('forbruke',),
'forbrukt': ('forbruke',),
'forbrukte': ('forbruke',),
'forbrukervennlig': ('forbrukervennlig',),
'forbrukervennlige': ('forbrukervennlig',),
'forbrukervennligere': ('forbrukervennlig',),
'forbrukervennligst': ('forbrukervennlig',),
'forbrukervennligste': ('forbrukervennlig',),
'forbrutt': ('forbryte',),
'forbrutte': ('forbryte',),
'forbrytende': ('forbryte',),
'forbrytersk': ('forbrytersk',),
'forbryterske': ('forbrytersk',),
'forbryterskere': ('forbrytersk',),
'forbryterskest': ('forbrytersk',),
'forbryterskeste': ('forbrytersk',),
'forbuden': ('forbuden',),
'forbudent': ('forbuden',),
'forbudne': ('forbuden',),
'forbudnere': ('forbuden',),
'forbudnest': ('forbuden',),
'forbudneste': ('forbuden',),
'forbudt': ('forbudt',),
'forbudte': ('forbudt',),
'forbudtere': ('forbudt',),
'forbudtest': ('forbudt',),
'forbudteste': ('forbudt',),
'forbundsvis': ('forbundsvis',),
'forbundsvise': ('forbundsvis',),
'forbundsvisere': ('forbundsvis',),
'forbundsvisest': ('forbundsvis',),
'forbundsviseste': ('forbundsvis',),
'forbundsvist': ('forbundsvis',),
'forbudt': ('forby',),
'forbudte': ('forby',),
'forbydd': ('forby',),
'forbydde': ('forby',),
'forbyende': ('forby',),
'forbytta': ('forbytte',),
'forbyttede': ('forbytte',),
'forbyttende': ('forbytte',),
'forbyttet': ('forbytte',),
'forbyttete': ('forbytte',),
'fordampa': ('fordampe',),
'fordampede': ('fordampe',),
'fordampende': ('fordampe',),
'fordampet': ('fordampe',),
'fordampete': ('fordampe',),
'fordanska': ('fordanske',),
'fordanskede': ('fordanske',),
'fordanskende': ('fordanske',),
'fordansket': ('fordanske',),
'fordanskete': ('fordanske',),
'fordekt': ('fordekt',),
'fordekte': ('fordekt',),
'fordektere': ('fordekt',),
'fordektest': ('fordekt',),
'fordekteste': ('fordekt',),
'fordektig': ('fordektig',),
'fordektige': ('fordektig',),
'fordektigere': ('fordektig',),
'fordektigst': ('fordektig',),
'fordektigste': ('fordektig',),
'fordelaktig': ('fordelaktig',),
'fordelaktige': ('fordelaktig',),
'fordelaktigere': ('fordelaktig',),
'fordelaktigst': ('fordelaktig',),
'fordelaktigste': ('fordelaktig',),
'fordelende': ('fordele',),
'fordelt': ('fordele',),
'fordelte': ('fordele',),
'forderva': ('forderve',),
'fordervede': ('forderve',),
'fordervende': ('forderve',),
'fordervet': ('forderve',),
'fordervete': ('forderve',),
'fordervelig': ('fordervelig',),
'fordervelige': ('fordervelig',),
'forderveligere': ('fordervelig',),
'forderveligst': ('fordervelig',),
'forderveligste': ('fordervelig',),
'fordjupa': ('fordjupe',),
'fordjupede': ('fordjupe',),
'fordjupende': ('fordjupe',),
'fordjupet': ('fordjupe',),
'fordjupete': ('fordjupe',),
'fordobla': ('fordoble',),
'fordoblede': ('fordoble',),
'fordoblende': ('fordoble',),
'fordoblet': ('fordoble',),
'fordoblete': ('fordoble',),
'fordomsfull': ('fordomsfull',),
'fordomsfulle': ('fordomsfull',),
'fordomsfullere': ('fordomsfull',),
'fordomsfullest': ('fordomsfull',),
'fordomsfulleste': ('fordomsfull',),
'fordomsfullt': ('fordomsfull',),
'fordomslaus': ('fordomslaus',),
'fordomslause': ('fordomslaus',),
'fordomslausere': ('fordomslaus',),
'fordomslausest': ('fordomslaus',),
'fordomslauseste': ('fordomslaus',),
'fordomslaust': ('fordomslaus',),
'fordomsløs': ('fordomsløs',),
'fordomsløse': ('fordomsløs',),
'fordomsløsere': ('fordomsløs',),
'fordomsløsest': ('fordomsløs',),
'fordomsløseste': ('fordomsløs',),
'fordomsløst': ('fordomsløs',),
'fordradd': ('fordra',),
'fordradde': ('fordra',),
'fordragende': ('fordra',),
'fordratt': ('fordra',),
'fordratte': ('fordra',),
'fordragelig': ('fordragelig',),
'fordragelige': ('fordragelig',),
'fordrageligere': ('fordragelig',),
'fordrageligst': ('fordragelig',),
'fordrageligste': ('fordragelig',),
'fordra': ('fordre',),
'fordrede': ('fordre',),
'fordrende': ('fordre',),
'fordret': ('fordre',),
'fordrete': ('fordre',),
'fordreia': ('fordreie',),
'fordreid': ('fordreie',),
'fordreidd': ('fordreie',),
'fordreidde': ('fordreie',),
'fordreide': ('fordreie',),
'fordreiede': ('fordreie',),
'fordreiende': ('fordreie',),
'fordreiet': ('fordreie',),
'fordreiete': ('fordreie',),
'fordringsfull': ('fordringsfull',),
'fordringsfulle': ('fordringsfull',),
'fordringsfullere': ('fordringsfull',),
'fordringsfullest': ('fordringsfull',),
'fordringsfulleste': ('fordringsfull',),
'fordringsfullt': ('fordringsfull',),
'fordringslaus': ('fordringslaus',),
'fordringslause': ('fordringslaus',),
'fordringslausere': ('fordringslaus',),
'fordringslausest': ('fordringslaus',),
'fordringslauseste': ('fordringslaus',),
'fordringslaust': ('fordringslaus',),
'fordringsløs': ('fordringsløs',),
'fordringsløse': ('fordringsløs',),
'fordringsløsere': ('fordringsløs',),
'fordringsløsest': ('fordringsløs',),
'fordringsløseste': ('fordringsløs',),
'fordringsløst': ('fordringsløs',),
'fordrista': ('fordriste',),
'fordristede': ('fordriste',),
'fordristende': ('fordriste',),
'fordristet': ('fordriste',),
'fordristete': ('fordriste',),
'fordreven': ('fordrive',),
'fordrevet': ('fordrive',),
'fordrevne': ('fordrive',),
'fordrivende': ('fordrive',),
'fordrukken': ('fordrukken',),
'fordrukkent': ('fordrukken',),
'fordrukne': ('fordrukken',),
'fordruknere': ('fordrukken',),
'fordruknest': ('fordrukken',),
'fordrukneste': ('fordrukken',),
'fordufta': ('fordufte',),
'forduftede': ('fordufte',),
'forduftende': ('fordufte',),
'forduftet': ('fordufte',),
'forduftete': ('fordufte',),
'fordulgt': ('fordulgt',),
'fordulgte': ('fordulgt',),
'fordulgtere': ('fordulgt',),
'fordulgtest': ('fordulgt',),
'fordulgteste': ('fordulgt',),
'fordumma': ('fordumme',),
'fordummede': ('fordumme',),
'fordummende': ('fordumme',),
'fordummet': ('fordumme',),
'fordummete': ('fordumme',),
'fordums': ('fordums',),
'fordunkla': ('fordunkle',),
'fordunklede': ('fordunkle',),
'fordunklende': ('fordunkle',),
'fordunklet': ('fordunkle',),
'fordunklete': ('fordunkle',),
'fordunsta': ('fordunste',),
'fordunstede': ('fordunste',),
'fordunstende': ('fordunste',),
'fordunstet': ('fordunste',),
'fordunstete': ('fordunste',),
'fordypa': ('fordype',),
'fordypede': ('fordype',),
'fordypende': ('fordype',),
'fordypet': ('fordype',),
'fordypete': ('fordype',),
'fordyra': ('fordyre',),
'fordyrede': ('fordyre',),
'fordyrende': ('fordyre',),
'fordyret': ('fordyre',),
'fordyrete': ('fordyre',),
'fordømmende': ('fordømme',),
'fordømt': ('fordømme',),
'fordømte': ('fordømme',),
'fordømt': ('fordømt',),
'fordømte': ('fordømt',),
'fordømtere': ('fordømt',),
'fordømtest': ('fordømt',),
'fordømteste': ('fordømt',),
'fordøya': ('fordøye',),
'fordøyd': ('fordøye',),
'fordøyde': ('fordøye',),
'fordøyede': ('fordøye',),
'fordøyende': ('fordøye',),
'fordøyet': ('fordøye',),
'fordøyete': ('fordøye',),
'fordøyelig': ('fordøyelig',),
'fordøyelige': ('fordøyelig',),
'fordøyeligere': ('fordøyelig',),
'fordøyeligst': ('fordøyelig',),
'fordøyeligste': ('fordøyelig',),
'forebragt': ('forebringe',),
'forebragte': ('forebringe',),
'forebrakt': ('forebringe',),
'forebrakte': ('forebringe',),
'forebringende': ('forebringe',),
'forebygd': ('forebygge',),
'forebygde': ('forebygge',),
'forebygga': ('forebygge',),
'forebyggede': ('forebygge',),
'forebyggende': ('forebygge',),
'forebygget': ('forebygge',),
'forebyggete': ('forebygge',),
'foredla': ('foredle',),
'foredlede': ('foredle',),
'foredlende': ('foredle',),
'foredlet': ('foredle',),
'foredlete': ('foredle',),
'foredradd': ('foredra',),
'foredradde': ('foredra',),
'foredragende': ('foredra',),
'foredratt': ('foredra',),
'foredratte': ('foredra',),
'forefallende': ('forefalle',),
'forefalt': ('forefalle',),
'forefalte': ('forefalle',),
'forefallende': ('forefallende',),
'foregiende': ('foregi',),
'foregitt': ('foregi',),
'foregitte': ('foregi',),
'foregivende': ('foregi',),
'foregrepen': ('foregripe',),
'foregrepet': ('foregripe',),
'foregrepne': ('foregripe',),
'foregripende': ('foregripe',),
'foregående': ('foregå',),
'foregått': ('foregå',),
'foregåtte': ('foregå',),
'foregående': ('foregående',),
'foreholdende': ('foreholde',),
'foreholdt': ('foreholde',),
'foreholdte': ('foreholde',),
'forekommen': ('forekomme',),
'forekommende': ('forekomme',),
'forekommet': ('forekomme',),
'forekomne': ('forekomme',),
'forekommende': ('forekommende',),
'forelda': ('forelda',),
'foreldede': ('foreldet',),
'foreldet': ('foreldet',),
'foreldete': ('foreldet',),
'foreldetere': ('foreldet',),
'foreldetest': ('foreldet',),
'foreldeteste': ('foreldet',),
'foreldrelaus': ('foreldrelaus',),
'foreldrelause': ('foreldrelaus',),
'foreldrelausere': ('foreldrelaus',),
'foreldrelausest': ('foreldrelaus',),
'foreldrelauseste': ('foreldrelaus',),
'foreldrelaust': ('foreldrelaus',),
'foreldreløs': ('foreldreløs',),
'foreldreløse': ('foreldreløs',),
'foreldreløsere': ('foreldreløs',),
'foreldreløsest': ('foreldreløs',),
'foreldreløseste': ('foreldreløs',),
'foreldreløst': ('foreldreløs',),
'forelagt': ('forelegge',),
'forelagte': ('forelegge',),
'foreleggende': ('forelegge',),
'forelesende': ('forelese',),
'forelest': ('forelese',),
'foreleste': ('forelese',),
'foreliggen': ('foreligge',),
'foreliggende': ('foreligge',),
'foreligget': ('foreligge',),
'foreligne': ('foreligge',),
'forelska': ('forelska',),
'forelska': ('forelske',),
'forelskede': ('forelske',),
'forelskende': ('forelske',),
'forelsket': ('forelske',),
'forelskete': ('forelske',),
'forelskede': ('forelsket',),
'forelsket': ('forelsket',),
'forelskete': ('forelsket',),
'forelsketere': ('forelsket',),
'forelsketest': ('forelsket',),
'forelsketeste': ('forelsket',),
'foreløpig': ('foreløpig',),
'foreløpige': ('foreløpig',),
'foreløpigere': ('foreløpig',),
'foreløpigst': ('foreløpig',),
'foreløpigste': ('foreløpig',),
'forena': ('forene',),
'forenede': ('forene',),
'forenende': ('forene',),
'forenet': ('forene',),
'forenete': ('forene',),
'forent': ('forene',),
'forente': ('forene',),
'forena': ('forene',),
'forenede': ('forene',),
'forenende': ('forene',),
'forenet': ('forene',),
'forenete': ('forene',),
'forent': ('forene',),
'forente': ('forene',),
'forenelig': ('forenelig',),
'forenelige': ('forenelig',),
'foreneligere': ('forenelig',),
'foreneligst': ('forenelig',),
'foreneligste': ('forenelig',),
'forenkla': ('forenkle',),
'forenklede': ('forenkle',),
'forenklende': ('forenkle',),
'forenklet': ('forenkle',),
'forenklete': ('forenkle',),
'forenlig': ('forenlig',),
'forenlige': ('forenlig',),
'forenligere': ('forenlig',),
'forenligst': ('forenlig',),
'forenligste': ('forenlig',),
'foresatt': ('foresatt',),
'foresatte': ('foresatt',),
'foresattere': ('foresatt',),
'foresattest': ('foresatt',),
'foresatteste': ('foresatt',),
'foresatt': ('foresette',),
'foresatte': ('foresette',),
'foresettende': ('foresette',),
'foresagt': ('foresi',),
'foresagte': ('foresi',),
'foresiende': ('foresi',),
'foreskreven': ('foreskrive',),
'foreskrevet': ('foreskrive',),
'foreskrevne': ('foreskrive',),
'foreskrivende': ('foreskrive',),
'foreslående': ('foreslå',),
'foreslått': ('foreslå',),
'foreslåtte': ('foreslå',),
'forespeila': ('forespeile',),
'forespeilede': ('forespeile',),
'forespeilende': ('forespeile',),
'forespeilet': ('forespeile',),
'forespeilete': ('forespeile',),
'forespeilt': ('forespeile',),
'forespeilte': ('forespeile',),
'forespurt': ('forespørre',),
'forespurte': ('forespørre',),
'forespørrende': ('forespørre',),
'forestillende': ('forestille',),
'forestilt': ('forestille',),
'forestilte': ('forestille',),
'forestående': ('forestå',),
'forestått': ('forestå',),
'foreståtte': ('forestå',),
'forestående': ('forestående',),
'foresveva': ('foresveve',),
'foresvevd': ('foresveve',),
'foresvevde': ('foresveve',),
'foresvevede': ('foresveve',),
'foresvevende': ('foresveve',),
'foresvevet': ('foresveve',),
'foresvevete': ('foresveve',),
'foretakende': ('foreta',),
'foretatt': ('foreta',),
'foretatte': ('foreta',),
'foretaksom': ('foretaksom',),
'foretaksomme': ('foretaksom',),
'foretaksommere': ('foretaksom',),
'foretaksommest': ('foretaksom',),
'foretaksommeste': ('foretaksom',),
'foretaksomt': ('foretaksom',),
'foretrekkende': ('foretrekke',),
'foretrukken': ('foretrekke',),
'foretrukket': ('foretrekke',),
'foretrukne': ('foretrekke',),
'foreviga': ('forevige',),
'forevigede': ('forevige',),
'forevigende': ('forevige',),
'foreviget': ('forevige',),
'forevigete': ('forevige',),
'forevisende': ('forevise',),
'forevist': ('forevise',),
'foreviste': ('forevise',),
'forfallende': ('forfalle',),
'forfalt': ('forfalle',),
'forfalte': ('forfalle',),
'forfallen': ('forfallen',),
'forfallent': ('forfallen',),
'forfalne': ('forfallen',),
'forfalnere': ('forfallen',),
'forfalnest': ('forfallen',),
'forfalneste': ('forfallen',),
'forfalska': ('forfalske',),
'forfalskede': ('forfalske',),
'forfalskende': ('forfalske',),
'forfalsket': ('forfalske',),
'forfalskete': ('forfalske',),
'forfatningsstridig': ('forfatningsstridig',),
'forfatningsstridige': ('forfatningsstridig',),
'forfatningsstridigere': ('forfatningsstridig',),
'forfatningsstridigst': ('forfatningsstridig',),
'forfatningsstridigste': ('forfatningsstridig',),
'forfatningstro': ('forfatningstro',),
'forfatningstru': ('forfatningstru',),
'forfatningstrue': ('forfatningstru',),
'forfatningstruere': ('forfatningstru',),
'forfatningstruest': ('forfatningstru',),
'forfatningstrueste': ('forfatningstru',),
'forfatta': ('forfatte',),
'forfattede': ('forfatte',),
'forfattende': ('forfatte',),
'forfattet': ('forfatte',),
'forfattete': ('forfatte',),
'forfeila': ('forfeile',),
'forfeilede': ('forfeile',),
'forfeilende': ('forfeile',),
'forfeilet': ('forfeile',),
'forfeilete': ('forfeile',),
'forfeilt': ('forfeile',),
'forfeilte': ('forfeile',),
'forfekta': ('forfekte',),
'forfektede': ('forfekte',),
'forfektende': ('forfekte',),
'forfektet': ('forfekte',),
'forfektete': ('forfekte',),
'forfengelig': ('forfengelig',),
'forfengelige': ('forfengelig',),
'forfengeligere': ('forfengelig',),
'forfengeligst': ('forfengelig',),
'forfengeligste': ('forfengelig',),
'forferda': ('forferde',),
'forferdede': ('forferde',),
'forferdende': ('forferde',),
'forferdet': ('forferde',),
'forferdete': ('forferde',),
'forferdelig': ('forferdelig',),
'forferdelige': ('forferdelig',),
'forferdeligere': ('forferdelig',),
'forferdeligst': ('forferdelig',),
'forferdeligste': ('forferdelig',),
'forferdiga': ('forferdige',),
'forferdigede': ('forferdige',),
'forferdigende': ('forferdige',),
'forferdiget': ('forferdige',),
'forferdigete': ('forferdige',),
'forfina': ('forfina',),
'forfina': ('forfine',),
'forfinede': ('forfine',),
'forfinende': ('forfine',),
'forfinet': ('forfine',),
'forfinete': ('forfine',),
'forfinede': ('forfinet',),
'forfinet': ('forfinet',),
'forfinete': ('forfinet',),
'forfinetere': ('forfinet',),
'forfinetest': ('forfinet',),
'forfineteste': ('forfinet',),
'forfjamsa': ('forfjamsa',),
'forfjamsa': ('forfjamse',),
'forfjamsede': ('forfjamse',),
'forfjamsende': ('forfjamse',),
'forfjamset': ('forfjamse',),
'forfjamsete': ('forfjamse',),
'forfjamsede': ('forfjamset',),
'forfjamset': ('forfjamset',),
'forfjamsete': ('forfjamset',),
'forfjamsetere': ('forfjamset',),
'forfjamsetest': ('forfjamset',),
'forfjamseteste': ('forfjamset',),
'forfjetra': ('forfjetra',),
'forfjetrede': ('forfjetret',),
'forfjetret': ('forfjetret',),
'forfjetrete': ('forfjetret',),
'forfjetretere': ('forfjetret',),
'forfjetretest': ('forfjetret',),
'forfjetreteste': ('forfjetret',),
'forflata': ('forflate',),
'forflatede': ('forflate',),
'forflatende': ('forflate',),
'forflatet': ('forflate',),
'forflatete': ('forflate',),
'forflera': ('forflere',),
'forflerede': ('forflere',),
'forflerende': ('forflere',),
'forfleret': ('forflere',),
'forflerete': ('forflere',),
'forflert': ('forflere',),
'forflerte': ('forflere',),
'forflytta': ('forflytte',),
'forflyttede': ('forflytte',),
'forflyttende': ('forflytte',),
'forflyttet': ('forflytte',),
'forflyttete': ('forflytte',),
'forfløyen': ('forfløyen',),
'forfløyenne': ('forfløyen',),
'forfløyennere': ('forfløyen',),
'forfløyennest': ('forfløyen',),
'forfløyenneste': ('forfløyen',),
'forfløyent': ('forfløyen',),
'forfløyne': ('forfløyen',),
'forfløynere': ('forfløyen',),
'forfløynest': ('forfløyen',),
'forfløyneste': ('forfløyen',),
'forfordelende': ('forfordele',),
'forfordelt': ('forfordele',),
'forfordelte': ('forfordele',),
'forfremma': ('forfremme',),
'forfremmede': ('forfremme',),
'forfremmende': ('forfremme',),
'forfremmet': ('forfremme',),
'forfremmete': ('forfremme',),
'forfriska': ('forfriske',),
'forfriskede': ('forfriske',),
'forfriskende': ('forfriske',),
'forfrisket': ('forfriske',),
'forfriskete': ('forfriske',),
'forfrosne': ('forfryse',),
'forfrossen': ('forfryse',),
'forfrosset': ('forfryse',),
'forfryse': ('forfryse',),
'forfrysende': ('forfryse',),
'forfylla': ('forfylla',),
'forfyllede': ('forfyllet',),
'forfyllet': ('forfyllet',),
'forfyllete': ('forfyllet',),
'forfylletere': ('forfyllet',),
'forfylletest': ('forfyllet',),
'forfylleteste': ('forfyllet',),
'forfulgt': ('forfølge',),
'forfulgte': ('forfølge',),
'forfølgende': ('forfølge',),
'forførende': ('forføre',),
'forført': ('forføre',),
'forførte': ('forføre',),
'forførerisk': ('forførerisk',),
'forføreriske': ('forførerisk',),
'forføreriskere': ('forførerisk',),
'forføreriskest': ('forførerisk',),
'forføreriskeste': ('forførerisk',),
'forførersk': ('forførersk',),
'forførerske': ('forførersk',),
'forførerskere': ('forførersk',),
'forførerskest': ('forførersk',),
'forførerskeste': ('forførersk',),
'forføya': ('forføye',),
'forføyd': ('forføye',),
'forføydd': ('forføye',),
'forføydde': ('forføye',),
'forføyde': ('forføye',),
'forføyede': ('forføye',),
'forføyende': ('forføye',),
'forføyet': ('forføye',),
'forføyete': ('forføye',),
'forgangen': ('forgangen',),
'forgangent': ('forgangen',),
'forgangne': ('forgangen',),
'forgangnere': ('forgangen',),
'forgangnest': ('forgangen',),
'forgangneste': ('forgangen',),
'forgapa': ('forgape',),
'forgapende': ('forgape',),
'forgapt': ('forgape',),
'forgapte': ('forgape',),
'forgassa': ('forgasse',),
'forgassede': ('forgasse',),
'forgassende': ('forgasse',),
'forgasset': ('forgasse',),
'forgassete': ('forgasse',),
'forgiende': ('forgi',),
'forgitt': ('forgi',),
'forgitte': ('forgi',),
'forgivende': ('forgi',),
'forgifta': ('forgifte',),
'forgiftede': ('forgifte',),
'forgiftende': ('forgifte',),
'forgiftet': ('forgifte',),
'forgiftete': ('forgifte',),
'forgjelda': ('forgjelde',),
'forgjeldede': ('forgjelde',),
'forgjeldende': ('forgjelde',),
'forgjeldet': ('forgjelde',),
'forgjeldete': ('forgjelde',),
'forgjengelig': ('forgjengelig',),
'forgjengelige': ('forgjengelig',),
'forgjengeligere': ('forgjengelig',),
'forgjengeligst': ('forgjengelig',),
'forgjengeligste': ('forgjengelig',),
'forgjeves': ('forgjeves',),
'forgjort': ('forgjøre',),
'forgjorte': ('forgjøre',),
'forgjørende': ('forgjøre',),
'forglemmende': ('forglemme',),
'forglemt': ('forglemme',),
'forglemte': ('forglemme',),
'forglømmende': ('forglømme',),
'forglømt': ('forglømme',),
'forglømte': ('forglømme',),
'forgreina': ('forgreine',),
'forgreinede': ('forgreine',),
'forgreinende': ('forgreine',),
'forgreinet': ('forgreine',),
'forgreinete': ('forgreine',),
'forgreint': ('forgreine',),
'forgreinte': ('forgreine',),
'forgremma': ('forgremma',),
'forgremmede': ('forgremmet',),
'forgremmet': ('forgremmet',),
'forgremmete': ('forgremmet',),
'forgremmetere': ('forgremmet',),
'forgremmetest': ('forgremmet',),
'forgremmeteste': ('forgremmet',),
'forgremt': ('forgremt',),
'forgremte': ('forgremt',),
'forgremtere': ('forgremt',),
'forgremtest': ('forgremt',),
'forgremteste': ('forgremt',),
'forgrena': ('forgrene',),
'forgrenede': ('forgrene',),
'forgrenende': ('forgrene',),
'forgrenet': ('forgrene',),
'forgrenete': ('forgrene',),
'forgrent': ('forgrene',),
'forgrente': ('forgrene',),
'forgrepen': ('forgripe',),
'forgrepet': ('forgripe',),
'forgrepne': ('forgripe',),
'forgripende': ('forgripe',),
'forgrova': ('forgrove',),
'forgrovede': ('forgrove',),
'forgrovende': ('forgrove',),
'forgrovet': ('forgrove',),
'forgrovete': ('forgrove',),
'forgrått': ('forgrått',),
'forgråtte': ('forgrått',),
'forgråttere': ('forgrått',),
'forgråttest': ('forgrått',),
'forgråtteste': ('forgrått',),
'forgubba': ('forgubbe',),
'forgubbede': ('forgubbe',),
'forgubbende': ('forgubbe',),
'forgubbet': ('forgubbe',),
'forgubbete': ('forgubbe',),
'forguda': ('forgude',),
'forgudede': ('forgude',),
'forgudende': ('forgude',),
'forgudet': ('forgude',),
'forgudete': ('forgude',),
'forgylla': ('forgylle',),
'forgyllede': ('forgylle',),
'forgyllende': ('forgylle',),
'forgyllet': ('forgylle',),
'forgyllete': ('forgylle',),
'forgylt': ('forgylle',),
'forgylte': ('forgylle',),
'forgående': ('forgå',),
'forgått': ('forgå',),
'forgåtte': ('forgå',),
'forhala': ('forhale',),
'forhalede': ('forhale',),
'forhalende': ('forhale',),
'forhalet': ('forhale',),
'forhalete': ('forhale',),
'forhalt': ('forhale',),
'forhalte': ('forhale',),
'forhandla': ('forhandle',),
'forhandlede': ('forhandle',),
'forhandlende': ('forhandle',),
'forhandlet': ('forhandle',),
'forhandlete': ('forhandle',),
'forhandsbestillende': ('forhandsbestille',),
'forhandsbestilt': ('forhandsbestille',),
'forhandsbestilte': ('forhandsbestille',),
'forhandsomtala': ('forhandsomtale',),
'forhandsomtalende': ('forhandsomtale',),
'forhandsomtalt': ('forhandsomtale',),
'forhandsomtalte': ('forhandsomtale',),
'forhandsstemmende': ('forhandsstemme',),
'forhandsstemt': ('forhandsstemme',),
'forhandsstemte': ('forhandsstemme',),
'forhasta': ('forhaste',),
'forhastede': ('forhaste',),
'forhastende': ('forhaste',),
'forhastet': ('forhaste',),
'forhastete': ('forhaste',),
'forhatt': ('forhatt',),
'forhatte': ('forhatt',),
'forhattere': ('forhatt',),
'forhattest': ('forhatt',),
'forhatteste': ('forhatt',),
'forheksa': ('forhekse',),
'forheksede': ('forhekse',),
'forheksende': ('forhekse',),
'forhekset': ('forhekse',),
'forheksete': ('forhekse',),
'forhenværende': ('forhenværende',),
'forherda': ('forherde',),
'forherdede': ('forherde',),
'forherdende': ('forherde',),
'forherdet': ('forherde',),
'forherdete': ('forherde',),
'forherliga': ('forherlige',),
'forherligede': ('forherlige',),
'forherligende': ('forherlige',),
'forherliget': ('forherlige',),
'forherligete': ('forherlige',),
'forhindra': ('forhindre',),
'forhindrede': ('forhindre',),
'forhindrende': ('forhindre',),
'forhindret': ('forhindre',),
'forhindrete': ('forhindre',),
'forhipne': ('forhippen',),
'forhipnere': ('forhippen',),
'forhipnest': ('forhippen',),
'forhipneste': ('forhippen',),
'forhippen': ('forhippen',),
'forhippent': ('forhippen',),
'forhistorisk': ('forhistorisk',),
'forhistoriske': ('forhistorisk',),
'forhistoriskere': ('forhistorisk',),
'forhistoriskest': ('forhistorisk',),
'forhistoriskeste': ('forhistorisk',),
'forhjulsdrevet': ('forhjulsdrevet',),
'forhjulsdrevne': ('forhjulsdrevet',),
'forhjulsdrevnere': ('forhjulsdrevet',),
'forhjulsdrevnest': ('forhjulsdrevet',),
'forhjulsdrevneste': ('forhjulsdrevet',),
'forholdende': ('forholde',),
'forholdt': ('forholde',),
'forholdte': ('forholde',),
'forholdsmessig': ('forholdsmessig',),
'forholdsmessige': ('forholdsmessig',),
'forholdsmessigere': ('forholdsmessig',),
'forholdsmessigst': ('forholdsmessig',),
'forholdsmessigste': ('forholdsmessig',),
'forhutla': ('forhutla',),
'forhutlede': ('forhutlet',),
'forhutlet': ('forhutlet',),
'forhutlete': ('forhutlet',),
'forhutletere': ('forhutlet',),
'forhutletest': ('forhutlet',),
'forhutleteste': ('forhutlet',),
'forhyrende': ('forhyre',),
'forhyrt': ('forhyre',),
'forhyrte': ('forhyre',),
'forhåndsbestillende': ('forhåndsbestille',),
'forhåndsbestilt': ('forhåndsbestille',),
'forhåndsbestilte': ('forhåndsbestille',),
'forhåndsomtala': ('forhåndsomtale',),
'forhåndsomtalende': ('forhåndsomtale',),
'forhåndsomtalt': ('forhåndsomtale',),
'forhåndsomtalte': ('forhåndsomtale',),
'forhåndsstemmende': ('forhåndsstemme',),
'forhåndsstemt': ('forhåndsstemme',),
'forhåndsstemte': ('forhåndsstemme',),
'forhåna': ('forhåne',),
'forhånede': ('forhåne',),
'forhånende': ('forhåne',),
'forhånet': ('forhåne',),
'forhånete': ('forhåne',),
'forhånt': ('forhåne',),
'forhånte': ('forhåne',),
'forhåpningsfull': ('forhåpningsfull',),
'forhåpningsfulle': ('forhåpningsfull',),
'forhåpningsfullere': ('forhåpningsfull',),
'forhåpningsfullest': ('forhåpningsfull',),
'forhåpningsfulleste': ('forhåpningsfull',),
'forhåpningsfullt': ('forhåpningsfull',),
'forhørende': ('forhøre',),
'forhørt': ('forhøre',),
'forhørte': ('forhøre',),
'forhøya': ('forhøye',),
'forhøyd': ('forhøye',),
'forhøyde': ('forhøye',),
'forhøyede': ('forhøye',),
'forhøyende': ('forhøye',),
'forhøyet': ('forhøye',),
'forhøyete': ('forhøye',),
'forivra': ('forivre',),
'forivrede': ('forivre',),
'forivrende': ('forivre',),
'forivret': ('forivre',),
'forivrete': ('forivre',),
'forjaga': ('forjaga',),
'forjagd': ('forjagd',),
'forjagde': ('forjagd',),
'forjagdere': ('forjagd',),
'forjagdest': ('forjagd',),
'forjagdeste': ('forjagd',),
'forjagede': ('forjaget',),
'forjaget': ('forjaget',),
'forjagete': ('forjaget',),
'forjagetere': ('forjaget',),
'forjagetest': ('forjaget',),
'forjageteste': ('forjaget',),
'forjetta': ('forjette',),
'forjettede': ('forjette',),
'forjettende': ('forjette',),
'forjettet': ('forjette',),
'forjettete': ('forjette',),
'forkalka': ('forkalke',),
'forkalkede': ('forkalke',),
'forkalkende': ('forkalke',),
'forkalket': ('forkalke',),
'forkalkete': ('forkalke',),
'forkasta': ('forkaste',),
'forkastede': ('forkaste',),
'forkastende': ('forkaste',),
'forkastet': ('forkaste',),
'forkastete': ('forkaste',),
'forkastelig': ('forkastelig',),
'forkastelige': ('forkastelig',),
'forkasteligere': ('forkastelig',),
'forkasteligst': ('forkastelig',),
'forkasteligste': ('forkastelig',),
'forkava': ('forkava',),
'forkavd': ('forkavd',),
'forkavde': ('forkavd',),
'forkavdere': ('forkavd',),
'forkavdest': ('forkavd',),
'forkavdeste': ('forkavd',),
'forkavede': ('forkavet',),
'forkavet': ('forkavet',),
'forkavete': ('forkavet',),
'forkavetere': ('forkavet',),
'forkavetest': ('forkavet',),
'forkaveteste': ('forkavet',),
'forkjetra': ('forkjetre',),
'forkjetrede': ('forkjetre',),
'forkjetrende': ('forkjetre',),
'forkjetret': ('forkjetre',),
'forkjetrete': ('forkjetre',),
'forkjælende': ('forkjæle',),
'forkjælt': ('forkjæle',),
'forkjælte': ('forkjæle',),
'forkjært': ('forkjært',),
'forkjærte': ('forkjært',),
'forkjærtere': ('forkjært',),
'forkjærtest': ('forkjært',),
'forkjærteste': ('forkjært',),
'forkjøla': ('forkjøle',),
'forkjølede': ('forkjøle',),
'forkjølende': ('forkjøle',),
'forkjølet': ('forkjøle',),
'forkjølete': ('forkjøle',),
'forkjølt': ('forkjøle',),
'forkjølte': ('forkjøle',),
'forkjøpende': ('forkjøpe',),
'forkjøpt': ('forkjøpe',),
'forkjøpte': ('forkjøpe',),
'forklarende': ('forklare',),
'forklart': ('forklare',),
'forklarte': ('forklare',),
'forklarede': ('forklaret',),
'forklaret': ('forklaret',),
'forklarete': ('forklaret',),
'forklaretere': ('forklaret',),
'forklaretest': ('forklaret',),
'forklareteste': ('forklaret',),
'forklarlig': ('forklarlig',),
'forklarlige': ('forklarlig',),
'forklarligere': ('forklarlig',),
'forklarligst': ('forklarlig',),
'forklarligste': ('forklarlig',),
'forkledd': ('forkle',),
'forkledde': ('forkle',),
'forkleende': ('forkle',),
'forkleina': ('forkleine',),
'forkleinede': ('forkleine',),
'forkleinende': ('forkleine',),
'forkleinet': ('forkleine',),
'forkleinete': ('forkleine',),
'forkludra': ('forkludre',),
'forkludrede': ('forkludre',),
'forkludrende': ('forkludre',),
'forkludret': ('forkludre',),
'forkludrete': ('forkludre',),
'forknytt': ('forknytt',),
'forknytte': ('forknytt',),
'forknyttere': ('forknytt',),
'forknyttest': ('forknytt',),
'forknytteste': ('forknytt',),
'forkobra': ('forkobre',),
'forkobrede': ('forkobre',),
'forkobrende': ('forkobre',),
'forkobret': ('forkobre',),
'forkobrete': ('forkobre',),
'forkommen': ('forkomme',),
'forkommende': ('forkomme',),
'forkommet': ('forkomme',),
'forkomne': ('forkomme',),
'forkommen': ('forkommen',),
'forkomment': ('forkommen',),
'forkomne': ('forkommen',),
'forkomnere': ('forkommen',),
'forkomnest': ('forkommen',),
'forkomneste': ('forkommen',),
'forkopra': ('forkopre',),
'forkoprede': ('forkopre',),
'forkoprende': ('forkopre',),
'forkopret': ('forkopre',),
'forkoprete': ('forkopre',),
'forkorta': ('forkorte',),
'forkortede': ('forkorte',),
'forkortende': ('forkorte',),
'forkortet': ('forkorte',),
'forkortete': ('forkorte',),
'forkromma': ('forkromme',),
'forkrommede': ('forkromme',),
'forkrommende': ('forkromme',),
'forkrommet': ('forkromme',),
'forkrommete': ('forkromme',),
'forkrøpla': ('forkrøpla',),
'forkrøplede': ('forkrøplet',),
'forkrøplet': ('forkrøplet',),
'forkrøplete': ('forkrøplet',),
'forkrøpletere': ('forkrøplet',),
'forkrøpletest': ('forkrøplet',),
'forkrøpleteste': ('forkrøplet',),
'forkua': ('forkue',),
'forkuede': ('forkue',),
'forkuende': ('forkue',),
'forkuet': ('forkue',),
'forkuete': ('forkue',),
'forkulla': ('forkulle',),
'forkullede': ('forkulle',),
'forkullende': ('forkulle',),
'forkullet': ('forkulle',),
'forkullete': ('forkulle',),
'forkvakla': ('forkvakle',),
'forkvaklede': ('forkvakle',),
'forkvaklende': ('forkvakle',),
'forkvaklet': ('forkvakle',),
'forkvaklete': ('forkvakle',),
'forkynnende': ('forkynne',),
'forkynt': ('forkynne',),
'forkynte': ('forkynne',),
'forlangende': ('forlange',),
'forlangt': ('forlange',),
'forlangte': ('forlange',),
'forlatende': ('forlate',),
'forlatt': ('forlate',),
'forlatte': ('forlate',),
'forlatt': ('forlatt',),
'forlatte': ('forlatt',),
'forlattere': ('forlatt',),
'forlattest': ('forlatt',),
'forlatteste': ('forlatt',),
'forleda': ('forlede',),
'forledede': ('forlede',),
'forledende': ('forlede',),
'forledet': ('forlede',),
'forledete': ('forlede',),
'forleden': ('forleden',),
'forlegen': ('forlegen',),
'forlegent': ('forlegen',),
'forlegne': ('forlegen',),
'forlegnere': ('forlegen',),
'forlegnest': ('forlegen',),
'forlegneste': ('forlegen',),
'forlagt': ('forlegge',),
'forlagte': ('forlegge',),
'forleggende': ('forlegge',),
'forlenga': ('forlenge',),
'forlengede': ('forlenge',),
'forlengende': ('forlenge',),
'forlenget': ('forlenge',),
'forlengete': ('forlenge',),
'forlesende': ('forlese',),
'forlest': ('forlese',),
'forleste': ('forlese',),
'forlibende': ('forlibe',),
'forlibt': ('forlibe',),
'forlibte': ('forlibe',),
'forlikende': ('forlike',),
'forlikt': ('forlike',),
'forlikte': ('forlike',),
'forlikelig': ('forlikelig',),
'forlikelige': ('forlikelig',),
'forlikeligere': ('forlikelig',),
'forlikeligst': ('forlikelig',),
'forlikeligste': ('forlikelig',),
'forlisende': ('forlise',),
'forlist': ('forlise',),
'forliste': ('forlise',),
'forlodds': ('forlodds',),
'forlokka': ('forlokke',),
'forlokkede': ('forlokke',),
'forlokkende': ('forlokke',),
'forlokket': ('forlokke',),
'forlokkete': ('forlokke',),
'forlokkende': ('forlokkende',),
'forloren': ('forloren',),
'forlorent': ('forloren',),
'forlorne': ('forloren',),
'forlornere': ('forloren',),
'forlornest': ('forloren',),
'forlorneste': ('forloren',),
'forlova': ('forlove',),
'forlovede': ('forlove',),
'forlovende': ('forlove',),
'forlovet': ('forlove',),
'forlovete': ('forlove',),
'forlydende': ('forlyde',),
'forlydt': ('forlyde',),
'forlydte': ('forlyde',),
'forlysta': ('forlyste',),
'forlystede': ('forlyste',),
'forlystende': ('forlyste',),
'forlystet': ('forlyste',),
'forlystete': ('forlyste',),
'forløfta': ('forløfte',),
'forløftede': ('forløfte',),
'forløftende': ('forløfte',),
'forløftet': ('forløfte',),
'forløftete': ('forløfte',),
'forløpende': ('forløpe',),
'forløpet': ('forløpe',),
'forløpt': ('forløpe',),
'forløpte': ('forløpe',),
'forløpen': ('forløpen',),
'forløpent': ('forløpen',),
'forløpne': ('forløpen',),
'forløpnere': ('forløpen',),
'forløpnest': ('forløpen',),
'forløpneste': ('forløpen',),
'forløsende': ('forløse',),
'forløst': ('forløse',),
'forløste': ('forløse',),
'forløyet': ('forløyet',),
'forløyne': ('forløyet',),
'forløynere': ('forløyet',),
'forløynest': ('forløyet',),
'forløyneste': ('forløyet',),
'forløysende': ('forløyse',),
'forløyst': ('forløyse',),
'forløyste': ('forløyse',),
'formal': ('formal',),
'formale': ('formal',),
'formalere': ('formal',),
'formalest': ('formal',),
'formaleste': ('formal',),
'formalt': ('formal',),
'formaldannende': ('formaldannende',),
'formalende': ('formale',),
'formalt': ('formale',),
'formalte': ('formale',),
'formaliserende': ('formalisere',),
'formalisert': ('formalisere',),
'formaliserte': ('formalisere',),
'formalistisk': ('formalistisk',),
'formalistiske': ('formalistisk',),
'formalistiskere': ('formalistisk',),
'formalistiskest': ('formalistisk',),
'formalistiskeste': ('formalistisk',),
'formana': ('formane',),
'formanede': ('formane',),
'formanende': ('formane',),
'formanet': ('formane',),
'formanete': ('formane',),
'formant': ('formane',),
'formante': ('formane',),
'formasta': ('formaste',),
'formastede': ('formaste',),
'formastende': ('formaste',),
'formastet': ('formaste',),
'formastete': ('formaste',),
'formastelig': ('formastelig',),
'formastelige': ('formastelig',),
'formasteligere': ('formastelig',),
'formasteligst': ('formastelig',),
'formasteligste': ('formastelig',),
'formaterende': ('formatere',),
'formatert': ('formatere',),
'formaterte': ('formatere',),
'formativ': ('formativ',),
'formative': ('formativ',),
'formativere': ('formativ',),
'formativest': ('formativ',),
'formativeste': ('formativ',),
'formativt': ('formativ',),
'forma': ('forme',),
'formede': ('forme',),
'formende': ('forme',),
'formet': ('forme',),
'formete': ('forme',),
'formell': ('formell',),
'formelle': ('formell',),
'formellere': ('formell',),
'formellest': ('formell',),
'formelleste': ('formell',),
'formelt': ('formell',),
'formenende': ('formene',),
'forment': ('formene',),
'formente': ('formene',),
'formentlig': ('formentlig',),
'formentlige': ('formentlig',),
'formentligere': ('formentlig',),
'formentligst': ('formentlig',),
'formentligste': ('formentlig',),
'formerende': ('formere',),
'formert': ('formere',),
'formerte': ('formere',),
'formerende': ('formere',),
'formert': ('formere',),
'formerte': ('formere',),
'formfullendt': ('formfullendt',),
'formfullendte': ('formfullendt',),
'formfullendtere': ('formfullendt',),
'formfullendtest': ('formfullendt',),
'formfullendteste': ('formfullendt',),
'formgiende': ('formgi',),
'formgitt': ('formgi',),
'formgitte': ('formgi',),
'formgivende': ('formgi',),
'formidabel': ('formidabel',),
'formidabelt': ('formidabel',),
'formidable': ('formidabel',),
'formidablere': ('formidabel',),
'formidablest': ('formidabel',),
'formidableste': ('formidabel',),
'formidla': ('formidle',),
'formidlede': ('formidle',),
'formidlende': ('formidle',),
'formidlet': ('formidle',),
'formidlete': ('formidle',),
'formilda': ('formilde',),
'formildede': ('formilde',),
'formildende': ('formilde',),
'formildet': ('formilde',),
'formildete': ('formilde',),
'forminska': ('forminske',),
'forminskede': ('forminske',),
'forminskende': ('forminske',),
'forminsket': ('forminske',),
'forminskete': ('forminske',),
'formlaus': ('formlaus',),
'formlause': ('formlaus',),
'formlausere': ('formlaus',),
'formlausest': ('formlaus',),
'formlauseste': ('formlaus',),
'formlaust': ('formlaus',),
'formløs': ('formløs',),
'formløse': ('formløs',),
'formløsere': ('formløs',),
'formløsest': ('formløs',),
'formløseste': ('formløs',),
'formløst': ('formløs',),
'formoda': ('formode',),
'formodede': ('formode',),
'formodende': ('formode',),
'formodet': ('formode',),
'formodete': ('formode',),
'formodentlig': ('formodentlig',),
'formodentlige': ('formodentlig',),
'formodentligere': ('formodentlig',),
'formodentligst': ('formodentlig',),
'formodentligste': ('formodentlig',),
'formolda': ('formolde',),
'formoldede': ('formolde',),
'formoldende': ('formolde',),
'formoldet': ('formolde',),
'formoldete': ('formolde',),
'formosansk': ('formosansk',),
'formosanske': ('formosansk',),
'formosanskere': ('formosansk',),
'formosanskest': ('formosansk',),
'formosanskeste': ('formosansk',),
'formuende': ('formuende',),
'formulda': ('formulde',),
'formuldede': ('formulde',),
'formuldende': ('formulde',),
'formuldet': ('formulde',),
'formuldete': ('formulde',),
'formulerende': ('formulere',),
'formulert': ('formulere',),
'formulerte': ('formulere',),
'formumma': ('formumme',),
'formummede': ('formumme',),
'formummende': ('formumme',),
'formummet': ('formumme',),
'formummete': ('formumme',),
'formådd': ('formå',),
'formådde': ('formå',),
'formående': ('formå',),
'formålslaus': ('formålslaus',),
'formålslause': ('formålslaus',),
'formålslausere': ('formålslaus',),
'formålslausest': ('formålslaus',),
'formålslauseste': ('formålslaus',),
'formålslaust': ('formålslaus',),
'formålsløs': ('formålsløs',),
'formålsløse': ('formålsløs',),
'formålsløsere': ('formålsløs',),
'formålsløsest': ('formålsløs',),
'formålsløseste': ('formålsløs',),
'formålsløst': ('formålsløs',),
'formålstjenlig': ('formålstjenlig',),
'formålstjenlige': ('formålstjenlig',),
'formålstjenligere': ('formålstjenlig',),
'formålstjenligst': ('formålstjenlig',),
'formålstjenligste': ('formålstjenlig',),
'formælende': ('formæle',),
'formælt': ('formæle',),
'formælte': ('formæle',),
'formørka': ('formørke',),
'formørkede': ('formørke',),
'formørkende': ('formørke',),
'formørket': ('formørke',),
'formørkete': ('formørke',),
'forn': ('forn',),
'forne': ('forn',),
'fornere': ('forn',),
'fornest': ('forn',),
'forneste': ('forn',),
'fornt': ('forn',),
'fornedra': ('fornedre',),
'fornedrede': ('fornedre',),
'fornedrende': ('fornedre',),
'fornedret': ('fornedre',),
'fornedrete': ('fornedre',),
'fornekta': ('fornekte',),
'fornektede': ('fornekte',),
'fornektende': ('fornekte',),
'fornektet': ('fornekte',),
'fornektete': ('fornekte',),
'fornem': ('fornem',),
'fornemme': ('fornem',),
'fornemmere': ('fornem',),
'fornemmest': ('fornem',),
'fornemmeste': ('fornem',),
'fornemt': ('fornem',),
'fornemma': ('fornemme',),
'fornemmede': ('fornemme',),
'fornemmende': ('fornemme',),
'fornemmet': ('fornemme',),
'fornemmete': ('fornemme',),
'fornemne': ('fornemme',),
'fornikla': ('fornikle',),
'forniklede': ('fornikle',),
'forniklende': ('fornikle',),
'forniklet': ('fornikle',),
'forniklete': ('fornikle',),
'fornorska': ('fornorske',),
'fornorskede': ('fornorske',),
'fornorskende': ('fornorske',),
'fornorsket': ('fornorske',),
'fornorskete': ('fornorske',),
'fornuftig': ('fornuftig',),
'fornuftige': ('fornuftig',),
'fornuftigere': ('fornuftig',),
'fornuftigst': ('fornuftig',),
'fornuftigste': ('fornuftig',),
'fornuftsstridig': ('fornuftsstridig',),
'fornuftsstridige': ('fornuftsstridig',),
'fornuftsstridigere': ('fornuftsstridig',),
'fornuftsstridigst': ('fornuftsstridig',),
'fornuftsstridigste': ('fornuftsstridig',),
'fornuftstridig': ('fornuftstridig',),
'fornuftstridige': ('fornuftstridig',),
'fornuftstridigere': ('fornuftstridig',),
'fornuftstridigst': ('fornuftstridig',),
'fornuftstridigste': ('fornuftstridig',),
'fornybar': ('fornybar',),
'fornybare': ('fornybar',),
'fornybarere': ('fornybar',),
'fornybarest': ('fornybar',),
'fornybareste': ('fornybar',),
'fornybart': ('fornybar',),
'fornya': ('fornye',),
'fornyede': ('fornye',),
'fornyende': ('fornye',),
'fornyet': ('fornye',),
'fornyete': ('fornye',),
'fornærma': ('fornærma',),
'fornærma': ('fornærme',),
'fornærmede': ('fornærme',),
'fornærmende': ('fornærme',),
'fornærmet': ('fornærme',),
'fornærmete': ('fornærme',),
'fornærmelig': ('fornærmelig',),
'fornærmelige': ('fornærmelig',),
'fornærmeligere': ('fornærmelig',),
'fornærmeligst': ('fornærmelig',),
'fornærmeligste': ('fornærmelig',),
'fornærmede': ('fornærmet',),
'fornærmet': ('fornærmet',),
'fornærmete': ('fornærmet',),
'fornærmetere': ('fornærmet',),
'fornærmetest': ('fornærmet',),
'fornærmeteste': ('fornærmet',),
'fornøden': ('fornøden',),
'fornødent': ('fornøden',),
'fornødne': ('fornøden',),
'fornødnere': ('fornøden',),
'fornødnest': ('fornøden',),
'fornødneste': ('fornøden',),
'fornøgd': ('fornøgd',),
'fornøgde': ('fornøgd',),
'fornøgdere': ('fornøgd',),
'fornøgdest': ('fornøgd',),
'fornøgdeste': ('fornøgd',),
'fornøyd': ('fornøyd',),
'fornøyde': ('fornøyd',),
'fornøydere': ('fornøyd',),
'fornøydest': ('fornøyd',),
'fornøydeste': ('fornøyd',),
'fornøya': ('fornøye',),
'fornøyd': ('fornøye',),
'fornøyde': ('fornøye',),
'fornøyede': ('fornøye',),
'fornøyende': ('fornøye',),
'fornøyet': ('fornøye',),
'fornøyete': ('fornøye',),
'fornøyelig': ('fornøyelig',),
'fornøyelige': ('fornøyelig',),
'fornøyeligere': ('fornøyelig',),
'fornøyeligst': ('fornøyelig',),
'fornøyeligste': ('fornøyelig',),
'fornøyelsessjuk': ('fornøyelsessjuk',),
'fornøyelsessjuke': ('fornøyelsessjuk',),
'fornøyelsessjukere': ('fornøyelsessjuk',),
'fornøyelsessjukest': ('fornøyelsessjuk',),
'fornøyelsessjukeste': ('fornøyelsessjuk',),
'fornøyelsessjukt': ('fornøyelsessjuk',),
'fornøyelsessyk': ('fornøyelsessyk',),
'fornøyelsessyke': ('fornøyelsessyk',),
'fornøyelsessykere': ('fornøyelsessyk',),
'fornøyelsessykest': ('fornøyelsessyk',),
'fornøyelsessykeste': ('fornøyelsessyk',),
'fornøyelsessykt': ('fornøyelsessyk',),
'forordna': ('forordne',),
'forordnede': ('forordne',),
'forordnende': ('forordne',),
'forordnet': ('forordne',),
'forordnete': ('forordne',),
'foroverbøyd': ('foroverbøyd',),
'foroverbøyde': ('foroverbøyd',),
'foroverbøydere': ('foroverbøyd',),
'foroverbøydest': ('foroverbøyd',),
'foroverbøydeste': ('foroverbøyd',),
'forpakta': ('forpakte',),
'forpaktede': ('forpakte',),
'forpaktende': ('forpakte',),
'forpaktet': ('forpakte',),
'forpaktete': ('forpakte',),
'forpesta': ('forpeste',),
'forpestede': ('forpeste',),
'forpestende': ('forpeste',),
'forpestet': ('forpeste',),
'forpestete': ('forpeste',),
'forpint': ('forpint',),
'forpinte': ('forpint',),
'forpintere': ('forpint',),
'forpintest': ('forpint',),
'forpinteste': ('forpint',),
'forpjuska': ('forpjuska',),
'forpjuskede': ('forpjusket',),
'forpjusket': ('forpjusket',),
'forpjuskete': ('forpjusket',),
'forpjusketere': ('forpjusket',),
'forpjusketest': ('forpjusket',),
'forpjusketeste': ('forpjusket',),
'forplanta': ('forplante',),
'forplantede': ('forplante',),
'forplantende': ('forplante',),
'forplantet': ('forplante',),
'forplantete': ('forplante',),
'forplantingsdyktig': ('forplantingsdyktig',),
'forplantingsdyktige': ('forplantingsdyktig',),
'forplantingsdyktigere': ('forplantingsdyktig',),
'forplantingsdyktigst': ('forplantingsdyktig',),
'forplantingsdyktigste': ('forplantingsdyktig',),
'forplantningsdyktig': ('forplantningsdyktig',),
'forplantningsdyktige': ('forplantningsdyktig',),
'forplantningsdyktigere': ('forplantningsdyktig',),
'forplantningsdyktigst': ('forplantningsdyktig',),
'forplantningsdyktigste': ('forplantningsdyktig',),
'forpleia': ('forpleie',),
'forpleid': ('forpleie',),
'forpleidd': ('forpleie',),
'forpleidde': ('forpleie',),
'forpleide': ('forpleie',),
'forpleiede': ('forpleie',),
'forpleiende': ('forpleie',),
'forpleiet': ('forpleie',),
'forpleiete': ('forpleie',),
'forplikta': ('forplikte',),
'forpliktede': ('forplikte',),
'forpliktende': ('forplikte',),
'forpliktet': ('forplikte',),
'forpliktete': ('forplikte',),
'forpliktende': ('forpliktende',),
'forprosjekterende': ('forprosjektere',),
'forprosjektert': ('forprosjektere',),
'forprosjekterte': ('forprosjektere',),
'forpuppa': ('forpuppe',),
'forpuppede': ('forpuppe',),
'forpuppende': ('forpuppe',),
'forpuppet': ('forpuppe',),
'forpuppete': ('forpuppe',),
'forpurra': ('forpurre',),
'forpurrede': ('forpurre',),
'forpurrende': ('forpurre',),
'forpurret': ('forpurre',),
'forpurrete': ('forpurre',),
'forrangla': ('forrangla',),
'forranglede': ('forranglet',),
'forranglet': ('forranglet',),
'forranglete': ('forranglet',),
'forrangletere': ('forranglet',),
'forrangletest': ('forranglet',),
'forrangleteste': ('forranglet',),
'forre': ('forre',),
'forregna': ('forregne',),
'forregnede': ('forregne',),
'forregnende': ('forregne',),
'forregnet': ('forregne',),
'forregnete': ('forregne',),
'forrekna': ('forrekne',),
'forreknede': ('forrekne',),
'forreknende': ('forrekne',),
'forreknet': ('forrekne',),
'forreknete': ('forrekne',),
'forrenta': ('forrente',),
'forrentede': ('forrente',),
'forrentende': ('forrente',),
'forrentet': ('forrente',),
'forrentete': ('forrente',),
'forrest': ('forrest',),
'forreste': ('forrest',),
'forretningsdrivende': ('forretningsdrivende',),
'forretningsmessig': ('forretningsmessig',),
'forretningsmessige': ('forretningsmessig',),
'forretningsmessigere': ('forretningsmessig',),
'forretningsmessigst': ('forretningsmessig',),
'forretningsmessigste': ('forretningsmessig',),
'forretta': ('forrette',),
'forrettede': ('forrette',),
'forrettende': ('forrette',),
'forrettet': ('forrette',),
'forrettete': ('forrette',),
'forreven': ('forreven',),
'forrevent': ('forreven',),
'forrevet': ('forreven',),
'forrevne': ('forreven',),
'forrevnere': ('forreven',),
'forrevnest': ('forreven',),
'forrevneste': ('forreven',),
'forrevet': ('forrevet',),
'forrevne': ('forrevet',),
'forrevnere': ('forrevet',),
'forrevnest': ('forrevet',),
'forrevneste': ('forrevet',),
'forringa': ('forringe',),
'forringede': ('forringe',),
'forringende': ('forringe',),
'forringet': ('forringe',),
'forringete': ('forringe',),
'forrykende': ('forrykende',),
'forrykka': ('forrykke',),
'forrykkede': ('forrykke',),
'forrykkende': ('forrykke',),
'forrykket': ('forrykke',),
'forrykkete': ('forrykke',),
'forrykt': ('forrykke',),
'forrykte': ('forrykke',),
'forrykt': ('forrykt',),
'forrykte': ('forrykt',),
'forryktere': ('forrykt',),
'forryktest': ('forrykt',),
'forrykteste': ('forrykt',),
'forrådende': ('forråde',),
'forrådt': ('forråde',),
'forrådte': ('forråde',),
'forråa': ('forråe',),
'forråede': ('forråe',),
'forrående': ('forråe',),
'forrået': ('forråe',),
'forråete': ('forråe',),
'forrædersk': ('forrædersk',),
'forræderske': ('forrædersk',),
'forræderskere': ('forrædersk',),
'forræderskest': ('forrædersk',),
'forræderskeste': ('forrædersk',),
'forsaga': ('forsage',),
'forsagede': ('forsage',),
'forsagende': ('forsage',),
'forsaget': ('forsage',),
'forsagete': ('forsage',),
'forsagt': ('forsagt',),
'forsagte': ('forsagt',),
'forsagtere': ('forsagt',),
'forsagtest': ('forsagt',),
'forsagteste': ('forsagt',),
'forsaka': ('forsake',),
'forsakede': ('forsake',),
'forsakende': ('forsake',),
'forsaket': ('forsake',),
'forsakete': ('forsake',),
'forseende': ('forse',),
'forsett': ('forse',),
'forsette': ('forse',),
'forseggjort': ('forseggjort',),
'forseggjorte': ('forseggjort',),
'forseggjortere': ('forseggjort',),
'forseggjortest': ('forseggjort',),
'forseggjorteste': ('forseggjort',),
'forsegla': ('forsegle',),
'forseglede': ('forsegle',),
'forseglende': ('forsegle',),
'forseglet': ('forsegle',),
'forseglete': ('forsegle',),
'forsenka': ('forsenke',),
'forsenkede': ('forsenke',),
'forsenkende': ('forsenke',),
'forsenket': ('forsenke',),
'forsenkete': ('forsenke',),
'forserende': ('forsere',),
'forsert': ('forsere',),
'forserte': ('forsere',),
'forsert': ('forsert',),
'forserte': ('forsert',),
'forsertere': ('forsert',),
'forsertest': ('forsert',),
'forserteste': ('forsert',),
'forsettlig': ('forsettlig',),
'forsettlige': ('forsettlig',),
'forsettligere': ('forsettlig',),
'forsettligst': ('forsettlig',),
'forsettligste': ('forsettlig',),
'forsikra': ('forsikre',),
'forsikrede': ('forsikre',),
'forsikrende': ('forsikre',),
'forsikret': ('forsikre',),
'forsikrete': ('forsikre',),
'forsiktig': ('forsiktig',),
'forsiktige': ('forsiktig',),
'forsiktigere': ('forsiktig',),
'forsiktigst': ('forsiktig',),
'forsiktigste': ('forsiktig',),
'forsimpla': ('forsimple',),
'forsimplede': ('forsimple',),
'forsimplende': ('forsimple',),
'forsimplet': ('forsimple',),
'forsimplete': ('forsimple',),
'forsinka': ('forsinke',),
'forsinkede': ('forsinke',),
'forsinkende': ('forsinke',),
'forsinket': ('forsinke',),
'forsinkete': ('forsinke',),
'forsinka': ('forsinke',),
'forsinkede': ('forsinke',),
'forsinkende': ('forsinke',),
'forsinket': ('forsinke',),
'forsinkete': ('forsinke',),
'forsirende': ('forsire',),
'forsirt': ('forsire',),
'forsirte': ('forsire',),
'forsjofla': ('forsjofle',),
'forsjoflede': ('forsjofle',),
'forsjoflende': ('forsjofle',),
'forsjoflet': ('forsjofle',),
'forsjoflete': ('forsjofle',),
'forskala': ('forskale',),
'forskalede': ('forskale',),
'forskalende': ('forskale',),
'forskalet': ('forskale',),
'forskalete': ('forskale',),
'forskalt': ('forskale',),
'forskalte': ('forskale',),
'forskansa': ('forskanse',),
'forskansede': ('forskanse',),
'forskansende': ('forskanse',),
'forskanset': ('forskanse',),
'forskansete': ('forskanse',),
'forska': ('forske',),
'forskede': ('forske',),
'forskende': ('forske',),
'forsket': ('forske',),
'forskete': ('forske',),
'forskende': ('forskende',),
'forskjellig': ('forskjellig',),
'forskjellige': ('forskjellig',),
'forskjelligere': ('forskjellig',),
'forskjelligst': ('forskjellig',),
'forskjelligste': ('forskjellig',),
'forskjellsbehandla': ('forskjellsbehandle',),
'forskjellsbehandlede': ('forskjellsbehandle',),
'forskjellsbehandlende': ('forskjellsbehandle',),
'forskjellsbehandlet': ('forskjellsbehandle',),
'forskjellsbehandlete': ('forskjellsbehandle',),
'forskjønna': ('forskjønne',),
'forskjønnede': ('forskjønne',),
'forskjønnende': ('forskjønne',),
'forskjønnet': ('forskjønne',),
'forskjønnete': ('forskjønne',),
'forskotterende': ('forskottere',),
'forskottert': ('forskottere',),
'forskotterte': ('forskottere',),
'forskrekka': ('forskrekke',),
'forskrekkede': ('forskrekke',),
'forskrekkende': ('forskrekke',),
'forskrekket': ('forskrekke',),
'forskrekkete': ('forskrekke',),
'forskrekkelig': ('forskrekkelig',),
'forskrekkelige': ('forskrekkelig',),
'forskrekkeligere': ('forskrekkelig',),
'forskrekkeligst': ('forskrekkelig',),
'forskrekkeligste': ('forskrekkelig',),
'forskremt': ('forskremt',),
'forskremte': ('forskremt',),
'forskremtere': ('forskremt',),
'forskremtest': ('forskremt',),
'forskremteste': ('forskremt',),
'forskreva': ('forskreve',),
'forskrevd': ('forskreve',),
'forskrevde': ('forskreve',),
'forskrevede': ('forskreve',),
'forskrevende': ('forskreve',),
'forskrevet': ('forskreve',),
'forskrevete': ('forskreve',),
'forskriftmessig': ('forskriftmessig',),
'forskriftmessige': ('forskriftmessig',),
'forskriftmessigere': ('forskriftmessig',),
'forskriftmessigst': ('forskriftmessig',),
'forskriftmessigste': ('forskriftmessig',),
'forskriftsmessig': ('forskriftsmessig',),
'forskriftsmessige': ('forskriftsmessig',),
'forskriftsmessigere': ('forskriftsmessig',),
'forskriftsmessigst': ('forskriftsmessig',),
'forskriftsmessigste': ('forskriftsmessig',),
'forskreven': ('forskrive',),
'forskrevet': ('forskrive',),
'forskrevne': ('forskrive',),
'forskrivende': ('forskrive',),
'forskrudd': ('forskrudd',),
'forskrudde': ('forskrudd',),
'forskruddere': ('forskrudd',),
'forskruddest': ('forskrudd',),
'forskruddeste': ('forskrudd',),
'forskusla': ('forskusle',),
'forskuslede': ('forskusle',),
'forskuslende': ('forskusle',),
'forskuslet': ('forskusle',),
'forskuslete': ('forskusle',),
'forskutterende': ('forskuttere',),
'forskuttert': ('forskuttere',),
'forskutterte': ('forskuttere',),
'forskyldende': ('forskylde',),
'forskyldt': ('forskylde',),
'forskyldte': ('forskylde',),
'forskjøven': ('forskyve',),
'forskjøvet': ('forskyve',),
'forskjøvne': ('forskyve',),
'forskyvd': ('forskyve',),
'forskyvde': ('forskyve',),
'forskyvende': ('forskyve',),
'forskåna': ('forskåne',),
'forskånede': ('forskåne',),
'forskånende': ('forskåne',),
'forskånet': ('forskåne',),
'forskånete': ('forskåne',),
'forskånt': ('forskåne',),
'forskånte': ('forskåne',),
'forslagen': ('forslagen',),
'forslagent': ('forslagen',),
'forslagne': ('forslagen',),
'forslagnere': ('forslagen',),
'forslagnest': ('forslagen',),
'forslagneste': ('forslagen',),
'forslitt': ('forslitt',),
'forslitte': ('forslitt',),
'forslittere': ('forslitt',),
'forslittest': ('forslitt',),
'forslitteste': ('forslitt',),
'forslukende': ('forsluke',),
'forslukt': ('forsluke',),
'forslukte': ('forsluke',),
'forsluken': ('forsluken',),
'forslukent': ('forsluken',),
'forslukne': ('forsluken',),
'forsluknere': ('forsluken',),
'forsluknest': ('forsluken',),
'forslukneste': ('forsluken',),
'forslumma': ('forslumme',),
'forslummede': ('forslumme',),
'forslummende': ('forslumme',),
'forslummet': ('forslumme',),
'forslummete': ('forslumme',),
'forslående': ('forslå',),
'forslått': ('forslå',),
'forslåtte': ('forslå',),
'forslått': ('forslått',),
'forslåtte': ('forslått',),
'forslåttere': ('forslått',),
'forslåttest': ('forslått',),
'forslåtteste': ('forslått',),
'forsmedelig': ('forsmedelig',),
'forsmedelige': ('forsmedelig',),
'forsmedeligere': ('forsmedelig',),
'forsmedeligst': ('forsmedelig',),
'forsmedeligste': ('forsmedelig',),
'forsmådd': ('forsmå',),
'forsmådde': ('forsmå',),
'forsmående': ('forsmå',),
'forsnakka': ('forsnakke',),
'forsnakkede': ('forsnakke',),
'forsnakkende': ('forsnakke',),
'forsnakket': ('forsnakke',),
'forsnakkete': ('forsnakke',),
'forsnevra': ('forsnevre',),
'forsnevrede': ('forsnevre',),
'forsnevrende': ('forsnevre',),
'forsnevret': ('forsnevre',),
'forsnevrete': ('forsnevre',),
'forsoffen': ('forsoffen',),
'forsoffent': ('forsoffen',),
'forsofne': ('forsoffen',),
'forsofnere': ('forsoffen',),
'forsofnest': ('forsoffen',),
'forsofneste': ('forsoffen',),
'forsona': ('forsone',),
'forsonede': ('forsone',),
'forsonende': ('forsone',),
'forsonet': ('forsone',),
'forsonete': ('forsone',),
'forsont': ('forsone',),
'forsonte': ('forsone',),
'forsonlig': ('forsonlig',),
'forsonlige': ('forsonlig',),
'forsonligere': ('forsonlig',),
'forsonligst': ('forsonlig',),
'forsonligste': ('forsonlig',),
'forsoren': ('forsoren',),
'forsorent': ('forsoren',),
'forsorne': ('forsoren',),
'forsornere': ('forsoren',),
'forsornest': ('forsoren',),
'forsorneste': ('forsoren',),
'forsoven': ('forsove',),
'forsovende': ('forsove',),
'forsovet': ('forsove',),
'forsovne': ('forsove',),
'forspennende': ('forspenne',),
'forspent': ('forspenne',),
'forspente': ('forspenne',),
'forspennende': ('forspenne',),
'forspent': ('forspenne',),
'forspente': ('forspenne',),
'forspillende': ('forspille',),
'forspilt': ('forspille',),
'forspilte': ('forspille',),
'forspisende': ('forspise',),
'forspist': ('forspise',),
'forspiste': ('forspise',),
'forsprengt': ('forsprengt',),
'forsprengte': ('forsprengt',),
'forsprengtere': ('forsprengt',),
'forsprengtest': ('forsprengt',),
'forsprengteste': ('forsprengt',),
'forspurt': ('forspørre',),
'forspurte': ('forspørre',),
'forspørrende': ('forspørre',),
'forstandig': ('forstandig',),
'forstandige': ('forstandig',),
'forstandigere': ('forstandig',),
'forstandigst': ('forstandig',),
'forstandigste': ('forstandig',),
'forstandsmessig': ('forstandsmessig',),
'forstandsmessige': ('forstandsmessig',),
'forstandsmessigere': ('forstandsmessig',),
'forstandsmessigst': ('forstandsmessig',),
'forstandsmessigste': ('forstandsmessig',),
'forsteina': ('forsteina',),
'forsteinede': ('forsteinet',),
'forsteinet': ('forsteinet',),
'forsteinete': ('forsteinet',),
'forsteinetere': ('forsteinet',),
'forsteinetest': ('forsteinet',),
'forsteineteste': ('forsteinet',),
'forstemmende': ('forstemmende',),
'forstemt': ('forstemt',),
'forstemte': ('forstemt',),
'forstemtere': ('forstemt',),
'forstemtest': ('forstemt',),
'forstemteste': ('forstemt',),
'forstenede': ('forstenet',),
'forstenet': ('forstenet',),
'forstenete': ('forstenet',),
'forstenetere': ('forstenet',),
'forstenetest': ('forstenet',),
'forsteneteste': ('forstenet',),
'forsterka': ('forsterke',),
'forsterkede': ('forsterke',),
'forsterkende': ('forsterke',),
'forsterket': ('forsterke',),
'forsterkete': ('forsterke',),
'forstikkende': ('forstikke',),
'forstukken': ('forstikke',),
'forstukket': ('forstikke',),
'forstukne': ('forstikke',),
'forstillende': ('forstille',),
'forstilt': ('forstille',),
'forstilte': ('forstille',),
'forstokka': ('forstokka',),
'forstokkede': ('forstokket',),
'forstokket': ('forstokket',),
'forstokkete': ('forstokket',),
'forstokketere': ('forstokket',),
'forstokketest': ('forstokket',),
'forstokketeste': ('forstokket',),
'forstua': ('forstue',),
'forstuede': ('forstue',),
'forstuende': ('forstue',),
'forstuet': ('forstue',),
'forstuete': ('forstue',),
'forstua': ('forstue',),
'forstuede': ('forstue',),
'forstuende': ('forstue',),
'forstuet': ('forstue',),
'forstuete': ('forstue',),
'forstua': ('forstue',),
'forstuede': ('forstue',),
'forstuende': ('forstue',),
'forstuet': ('forstue',),
'forstuete': ('forstue',),
'forstumma': ('forstumme',),
'forstummede': ('forstumme',),
'forstummende': ('forstumme',),
'forstummet': ('forstumme',),
'forstummete': ('forstumme',),
'forstuva': ('forstuve',),
'forstuvede': ('forstuve',),
'forstuvende': ('forstuve',),
'forstuvet': ('forstuve',),
'forstuvete': ('forstuve',),
'forstuva': ('forstuve',),
'forstuvede': ('forstuve',),
'forstuvende': ('forstuve',),
'forstuvet': ('forstuve',),
'forstuvete': ('forstuve',),
'forstyrra': ('forstyrra',),
'forstyrra': ('forstyrre',),
'forstyrrede': ('forstyrre',),
'forstyrrende': ('forstyrre',),
'forstyrret': ('forstyrre',),
'forstyrrete': ('forstyrre',),
'forstyrrede': ('forstyrret',),
'forstyrret': ('forstyrret',),
'forstyrrete': ('forstyrret',),
'forstyrretere': ('forstyrret',),
'forstyrretest': ('forstyrret',),
'forstyrreteste': ('forstyrret',),
'forstående': ('forstå',),
'forstått': ('forstå',),
'forståtte': ('forstå',),
'forståelig': ('forståelig',),
'forståelige': ('forståelig',),
'forståeligere': ('forståelig',),
'forståeligst': ('forståelig',),
'forståeligste': ('forståelig',),
'forståelsesfull': ('forståelsesfull',),
'forståelsesfulle': ('forståelsesfull',),
'forståelsesfullere': ('forståelsesfull',),
'forståelsesfullest': ('forståelsesfull',),
'forståelsesfulleste': ('forståelsesfull',),
'forståelsesfullt': ('forståelsesfull',),
'forstøkt': ('forstøkt',),
'forstøkte': ('forstøkt',),
'forstøktere': ('forstøkt',),
'forstøktest': ('forstøkt',),
'forstøkteste': ('forstøkt',),
'forstørra': ('forstørre',),
'forstørrede': ('forstørre',),
'forstørrende': ('forstørre',),
'forstørret': ('forstørre',),
'forstørrete': ('forstørre',),
'forstøtende': ('forstøte',),
'forstøtt': ('forstøte',),
'forstøtte': ('forstøte',),
'forstøtta': ('forstøtte',),
'forstøttede': ('forstøtte',),
'forstøttende': ('forstøtte',),
'forstøttet': ('forstøtte',),
'forstøttete': ('forstøtte',),
'forstøva': ('forstøve',),
'forstøvede': ('forstøve',),
'forstøvende': ('forstøve',),
'forstøvet': ('forstøve',),
'forstøvete': ('forstøve',),
'forsumpa': ('forsumpe',),
'forsumpede': ('forsumpe',),
'forsumpende': ('forsumpe',),
'forsumpet': ('forsumpe',),
'forsumpete': ('forsumpe',),
'forsura': ('forsure',),
'forsurede': ('forsure',),
'forsurende': ('forsure',),
'forsuret': ('forsure',),
'forsurete': ('forsure',),
'forsvarende': ('forsvare',),
'forsvart': ('forsvare',),
'forsvarte': ('forsvare',),
'forsvarlig': ('forsvarlig',),
'forsvarlige': ('forsvarlig',),
'forsvarligere': ('forsvarlig',),
'forsvarligst': ('forsvarlig',),
'forsvarligste': ('forsvarlig',),
'forsvarslaus': ('forsvarslaus',),
'forsvarslause': ('forsvarslaus',),
'forsvarslausere': ('forsvarslaus',),
'forsvarslausest': ('forsvarslaus',),
'forsvarslauseste': ('forsvarslaus',),
'forsvarslaust': ('forsvarslaus',),
'forsvarsløs': ('forsvarsløs',),
'forsvarsløse': ('forsvarsløs',),
'forsvarsløsere': ('forsvarsløs',),
'forsvarsløsest': ('forsvarsløs',),
'forsvarsløseste': ('forsvarsløs',),
'forsvarsløst': ('forsvarsløs',),
'forsvenska': ('forsvenske',),
'forsvenskede': ('forsvenske',),
'forsvenskende': ('forsvenske',),
'forsvensket': ('forsvenske',),
'forsvenskete': ('forsvenske',),
'forsverga': ('forsverge',),
'forsvergede': ('forsverge',),
'forsvergende': ('forsverge',),
'forsverget': ('forsverge',),
'forsvergete': ('forsverge',),
'forsvoren': ('forsverge',),
'forsvoret': ('forsverge',),
'forsvorne': ('forsverge',),
'forsverja': ('forsverje',),
'forsverjede': ('forsverje',),
'forsverjende': ('forsverje',),
'forsverjet': ('forsverje',),
'forsverjete': ('forsverje',),
'forsvoren': ('forsverje',),
'forsvoret': ('forsverje',),
'forsvorne': ('forsverje',),
'forsvinnende': ('forsvinne',),
'forsvunne': ('forsvinne',),
'forsvunnen': ('forsvinne',),
'forsvunnet': ('forsvinne',),
'forsvinnende': ('forsvinnende',),
'forsynda': ('forsynde',),
'forsyndede': ('forsynde',),
'forsyndende': ('forsynde',),
'forsyndet': ('forsynde',),
'forsyndete': ('forsynde',),
'forsynende': ('forsyne',),
'forsynt': ('forsyne',),
'forsynte': ('forsyne',),
'forsynlig': ('forsynlig',),
'forsynlige': ('forsynlig',),
'forsynligere': ('forsynlig',),
'forsynligst': ('forsynlig',),
'forsynligste': ('forsynlig',),
'forsøkende': ('forsøke',),
'forsøkt': ('forsøke',),
'forsøkte': ('forsøke',),
'forsølva': ('forsølve',),
'forsølvede': ('forsølve',),
'forsølvende': ('forsølve',),
'forsølvet': ('forsølve',),
'forsølvete': ('forsølve',),
'forsømmende': ('forsømme',),
'forsømt': ('forsømme',),
'forsømte': ('forsømme',),
'forsømmelig': ('forsømmelig',),
'forsømmelige': ('forsømmelig',),
'forsømmeligere': ('forsømmelig',),
'forsømmeligst': ('forsømmelig',),
'forsømmeligste': ('forsømmelig',),
'forsømt': ('forsømt',),
'forsømte': ('forsømt',),
'forsømtere': ('forsømt',),
'forsømtest': ('forsømt',),
'forsømteste': ('forsømt',),
'forsøpla': ('forsøple',),
'forsøplede': ('forsøple',),
'forsøplende': ('forsøple',),
'forsøplet': ('forsøple',),
'forsøplete': ('forsøple',),
'forsørga': ('forsørge',),
'forsørgd': ('forsørge',),
'forsørgde': ('forsørge',),
'forsørgede': ('forsørge',),
'forsørgende': ('forsørge',),
'forsørget': ('forsørge',),
'forsørgete': ('forsørge',),
'forsøta': ('forsøte',),
'forsøtede': ('forsøte',),
'forsøtende': ('forsøte',),
'forsøtet': ('forsøte',),
'forsøtete': ('forsøte',),
'fort': ('fort',),
'fortere': ('fort',),
'fortest': ('fort',),
'fortakende': ('forta',),
'fortatt': ('forta',),
'fortatte': ('forta',),
'fortapende': ('fortape',),
'fortapt': ('fortape',),
'fortapte': ('fortape',),
'fortapt': ('fortapt',),
'fortapte': ('fortapt',),
'fortaptere': ('fortapt',),
'fortaptest': ('fortapt',),
'fortapteste': ('fortapt',),
'forta': ('forte',),
'fortede': ('forte',),
'fortende': ('forte',),
'fortet': ('forte',),
'fortete': ('forte',),
'fortegna': ('fortegne',),
'fortegnede': ('fortegne',),
'fortegnende': ('fortegne',),
'fortegnet': ('fortegne',),
'fortegnete': ('fortegne',),
'fortalt': ('fortelle',),
'fortalte': ('fortelle',),
'fortellende': ('fortelle',),
'fortellende': ('fortellende',),
'fortenkende': ('fortenke',),
'fortenkt': ('fortenke',),
'fortenkte': ('fortenke',),
'fortenkt': ('fortenkt',),
'fortenkte': ('fortenkt',),
'fortenktere': ('fortenkt',),
'fortenktest': ('fortenkt',),
'fortenkteste': ('fortenkt',),
'forterpa': ('forterpa',),
'forterpede': ('forterpet',),
'forterpet': ('forterpet',),
'forterpete': ('forterpet',),
'forterpetere': ('forterpet',),
'forterpetest': ('forterpet',),
'forterpeteste': ('forterpet',),
'forterska': ('forterska',),
'forterskede': ('fortersket',),
'fortersket': ('fortersket',),
'forterskete': ('fortersket',),
'fortersketere': ('fortersket',),
'fortersketest': ('fortersket',),
'fortersketeste': ('fortersket',),
'fortetta': ('fortette',),
'fortettede': ('fortette',),
'fortettende': ('fortette',),
'fortettet': ('fortette',),
'fortettete': ('fortette',),
'fortidig': ('fortidig',),
'fortidige': ('fortidig',),
'fortidigere': ('fortidig',),
'fortidigst': ('fortidig',),
'fortidigste': ('fortidig',),
'fortia': ('fortie',),
'fortidd': ('fortie',),
'fortidde': ('fortie',),
'fortiede': ('fortie',),
'fortiende': ('fortie',),
'fortiet': ('fortie',),
'fortiete': ('fortie',),
'fortinna': ('fortinne',),
'fortinnede': ('fortinne',),
'fortinnende': ('fortinne',),
'fortinnet': ('fortinne',),
'fortinnete': ('fortinne',),
'fortjenende': ('fortjene',),
'fortjent': ('fortjene',),
'fortjente': ('fortjene',),
'fortjenestefull': ('fortjenestefull',),
'fortjenestefulle': ('fortjenestefull',),
'fortjenestefullere': ('fortjenestefull',),
'fortjenestefullest': ('fortjenestefull',),
'fortjenestefulleste': ('fortjenestefull',),
'fortjenestefullt': ('fortjenestefull',),
'fortjenstfull': ('fortjenstfull',),
'fortjenstfulle': ('fortjenstfull',),
'fortjenstfullere': ('fortjenstfull',),
'fortjenstfullest': ('fortjenstfull',),
'fortjenstfulleste': ('fortjenstfull',),
'fortjenstfullt': ('fortjenstfull',),
'fortløpende': ('fortløpende',),
'fortna': ('fortne',),
'fortnede': ('fortne',),
'fortnende': ('fortne',),
'fortnet': ('fortne',),
'fortnete': ('fortne',),
'fortolka': ('fortolke',),
'fortolkede': ('fortolke',),
'fortolkende': ('fortolke',),
'fortolket': ('fortolke',),
'fortolkete': ('fortolke',),
'fortolla': ('fortolle',),
'fortollede': ('fortolle',),
'fortollende': ('fortolle',),
'fortollet': ('fortolle',),
'fortollete': ('fortolle',),
'fortona': ('fortone',),
'fortonede': ('fortone',),
'fortonende': ('fortone',),
'fortonet': ('fortone',),
'fortonete': ('fortone',),
'fortont': ('fortone',),
'fortonte': ('fortone',),
'fortorva': ('fortorve',),
'fortorvede': ('fortorve',),
'fortorvende': ('fortorve',),
'fortorvet': ('fortorve',),
'fortorvete': ('fortorve',),
'fortredelig': ('fortredelig',),
'fortredelige': ('fortredelig',),
'fortredeligere': ('fortredelig',),
'fortredeligst': ('fortredelig',),
'fortredeligste': ('fortredelig',),
'fortreffelig': ('fortreffelig',),
'fortreffelige': ('fortreffelig',),
'fortreffeligere': ('fortreffelig',),
'fortreffeligst': ('fortreffelig',),
'fortreffeligste': ('fortreffelig',),
'fortrekkende': ('fortrekke',),
'fortrukken': ('fortrekke',),
'fortrukket': ('fortrekke',),
'fortrukne': ('fortrekke',),
'fortrengende': ('fortrenge',),
'fortrengt': ('fortrenge',),
'fortrengte': ('fortrenge',),
'fortrinnlig': ('fortrinnlig',),
'fortrinnlige': ('fortrinnlig',),
'fortrinnligere': ('fortrinnlig',),
'fortrinnligst': ('fortrinnlig',),
'fortrinnligste': ('fortrinnlig',),
'fortrinnsberettiga': ('fortrinnsberettiga',),
'fortrinnsberettigede': ('fortrinnsberettiget',),
'fortrinnsberettiget': ('fortrinnsberettiget',),
'fortrinnsberettigete': ('fortrinnsberettiget',),
'fortrinnsberettigetere': ('fortrinnsberettiget',),
'fortrinnsberettigetest': ('fortrinnsberettiget',),
'fortrinnsberettigeteste': ('fortrinnsberettiget',),
'fortrolig': ('fortrolig',),
'fortrolige': ('fortrolig',),
'fortroligere': ('fortrolig',),
'fortroligst': ('fortrolig',),
'fortroligste': ('fortrolig',),
'fortrolla': ('fortrolle',),
'fortrollede': ('fortrolle',),
'fortrollende': ('fortrolle',),
'fortrollet': ('fortrolle',),
'fortrollete': ('fortrolle',),
'fortrykt': ('fortrykt',),
'fortrykte': ('fortrykt',),
'fortryktere': ('fortrykt',),
'fortryktest': ('fortrykt',),
'fortrykteste': ('fortrykt',),
'fortrylla': ('fortrylle',),
'fortryllede': ('fortrylle',),
'fortryllende': ('fortrylle',),
'fortryllet': ('fortrylle',),
'fortryllete': ('fortrylle',),
'fortrylt': ('fortrylle',),
'fortrylte': ('fortrylle',),
'fortrutt': ('fortryte',),
'fortrutte': ('fortryte',),
'fortrytende': ('fortryte',),
'fortrytelig': ('fortrytelig',),
'fortrytelige': ('fortrytelig',),
'fortryteligere': ('fortrytelig',),
'fortryteligst': ('fortrytelig',),
'fortryteligste': ('fortrytelig',),
'fortrøsta': ('fortrøste',),
'fortrøstede': ('fortrøste',),
'fortrøstende': ('fortrøste',),
'fortrøstet': ('fortrøste',),
'fortrøstete': ('fortrøste',),
'fortrøstningsfull': ('fortrøstningsfull',),
'fortrøstningsfulle': ('fortrøstningsfull',),
'fortrøstningsfullere': ('fortrøstningsfull',),
'fortrøstningsfullest': ('fortrøstningsfull',),
'fortrøstningsfulleste': ('fortrøstningsfull',),
'fortrøstningsfullt': ('fortrøstningsfull',),
'fortsatt': ('fortsette',),
'fortsatte': ('fortsette',),
'fortsettende': ('fortsette',),
'fortulla': ('fortulla',),
'fortullede': ('fortullet',),
'fortullet': ('fortullet',),
'fortullete': ('fortullet',),
'fortulletere': ('fortullet',),
'fortulletest': ('fortullet',),
'fortulleteste': ('fortullet',),
'fortumla': ('fortumla',),
'fortumlede': ('fortumlet',),
'fortumlet': ('fortumlet',),
'fortumlete': ('fortumlet',),
'fortumletere': ('fortumlet',),
'fortumletest': ('fortumlet',),
'fortumleteste': ('fortumlet',),
'fortvila': ('fortvila',),
'fortvilende': ('fortvile',),
'fortvilt': ('fortvile',),
'fortvilte': ('fortvile',),
'fortvilede': ('fortvilet',),
'fortvilet': ('fortvilet',),
'fortvilete': ('fortvilet',),
'fortviletere': ('fortvilet',),
'fortviletest': ('fortvilet',),
'fortvileteste': ('fortvilet',),
'fortvilt': ('fortvilt',),
'fortvilte': ('fortvilt',),
'fortviltere': ('fortvilt',),
'fortviltest': ('fortvilt',),
'fortvilteste': ('fortvilt',),
'fortykka': ('fortykke',),
'fortykkede': ('fortykke',),
'fortykkende': ('fortykke',),
'fortykket': ('fortykke',),
'fortykkete': ('fortykke',),
'fortynna': ('fortynne',),
'fortynnede': ('fortynne',),
'fortynnende': ('fortynne',),
'fortynnet': ('fortynne',),
'fortynnete': ('fortynne',),
'fortærende': ('fortære',),
'fortært': ('fortære',),
'fortærte': ('fortære',),
'fortærende': ('fortærende',),
'fortørna': ('fortørne',),
'fortørnede': ('fortørne',),
'fortørnende': ('fortørne',),
'fortørnet': ('fortørne',),
'fortørnete': ('fortørne',),
'fortøyd': ('fortøye',),
'fortøyde': ('fortøye',),
'fortøyende': ('fortøye',),
'foruleiliga': ('foruleilige',),
'foruleiligede': ('foruleilige',),
'foruleiligende': ('foruleilige',),
'foruleiliget': ('foruleilige',),
'foruleiligete': ('foruleilige',),
'forulempa': ('forulempe',),
'forulempede': ('forulempe',),
'forulempende': ('forulempe',),
'forulempet': ('forulempe',),
'forulempete': ('forulempe',),
'forulykka': ('forulykke',),
'forulykkede': ('forulykke',),
'forulykkende': ('forulykke',),
'forulykket': ('forulykke',),
'forulykkete': ('forulykke',),
'forunderlig': ('forunderlig',),
'forunderlige': ('forunderlig',),
'forunderligere': ('forunderlig',),
'forunderligst': ('forunderlig',),
'forunderligste': ('forunderlig',),
'forundra': ('forundre',),
'forundrede': ('forundre',),
'forundrende': ('forundre',),
'forundret': ('forundre',),
'forundrete': ('forundre',),
'forundra': ('forundre',),
'forundrede': ('forundre',),
'forundrende': ('forundre',),
'forundret': ('forundre',),
'forundrete': ('forundre',),
'forunnende': ('forunne',),
'forunt': ('forunne',),
'forunte': ('forunne',),
'forurensa': ('forurense',),
'forurensede': ('forurense',),
'forurensende': ('forurense',),
'forurenset': ('forurense',),
'forurensete': ('forurense',),
'foruretta': ('forurette',),
'forurettede': ('forurette',),
'forurettende': ('forurette',),
'forurettet': ('forurette',),
'forurettete': ('forurette',),
'foruroliga': ('forurolige',),
'foruroligede': ('forurolige',),
'foruroligende': ('forurolige',),
'foruroliget': ('forurolige',),
'foruroligete': ('forurolige',),
'foruroligende': ('foruroligende',),
'forutberegna': ('forutberegne',),
'forutberegnede': ('forutberegne',),
'forutberegnende': ('forutberegne',),
'forutberegnet': ('forutberegne',),
'forutberegnete': ('forutberegne',),
'forutberekna': ('forutberekne',),
'forutbereknede': ('forutberekne',),
'forutbereknende': ('forutberekne',),
'forutbereknet': ('forutberekne',),
'forutbereknete': ('forutberekne',),
'forutbestemmende': ('forutbestemme',),
'forutbestemt': ('forutbestemme',),
'forutbestemte': ('forutbestemme',),
'forutfatta': ('forutfatta',),
'forutfattede': ('forutfattet',),
'forutfattet': ('forutfattet',),
'forutfattete': ('forutfattet',),
'forutfattetere': ('forutfattet',),
'forutfattetest': ('forutfattet',),
'forutfatteteste': ('forutfattet',),
'forutgående': ('forutgående',),
'forutinntatt': ('forutinntatt',),
'forutinntatte': ('forutinntatt',),
'forutinntattere': ('forutinntatt',),
'forutinntattest': ('forutinntatt',),
'forutinntatteste': ('forutinntatt',),
'forutseende': ('forutse',),
'forutsett': ('forutse',),
'forutsette': ('forutse',),
'forutseende': ('forutseende',),
'forutsetningslaus': ('forutsetningslaus',),
'forutsetningslause': ('forutsetningslaus',),
'forutsetningslausere': ('forutsetningslaus',),
'forutsetningslausest': ('forutsetningslaus',),
'forutsetningslauseste': ('forutsetningslaus',),
'forutsetningslaust': ('forutsetningslaus',),
'forutsetningsløs': ('forutsetningsløs',),
'forutsetningsløse': ('forutsetningsløs',),
'forutsetningsløsere': ('forutsetningsløs',),
'forutsetningsløsest': ('forutsetningsløs',),
'forutsetningsløseste': ('forutsetningsløs',),
'forutsetningsløst': ('forutsetningsløs',),
'forutsatt': ('forutsette',),
'forutsatte': ('forutsette',),
'forutsettende': ('forutsette',),
'forutsigelig': ('forutsigelig',),
'forutsigelige': ('forutsigelig',),
'forutsigeligere': ('forutsigelig',),
'forutsigeligst': ('forutsigelig',),
'forutsigeligste': ('forutsigelig',),
'forutskikka': ('forutskikke',),
'forutskikkede': ('forutskikke',),
'forutskikkende': ('forutskikke',),
'forutskikket': ('forutskikke',),
'forutskikkete': ('forutskikke',),
'forvalta': ('forvalte',),
'forvaltede': ('forvalte',),
'forvaltende': ('forvalte',),
'forvaltet': ('forvalte',),
'forvaltete': ('forvalte',),
'forvandla': ('forvandle',),
'forvandlede': ('forvandle',),
'forvandlende': ('forvandle',),
'forvandlet': ('forvandle',),
'forvandlete': ('forvandle',),
'forvanska': ('forvanske',),
'forvanskede': ('forvanske',),
'forvanskende': ('forvanske',),
'forvansket': ('forvanske',),
'forvanskete': ('forvanske',),
'forvarende': ('forvare',),
'forvart': ('forvare',),
'forvarte': ('forvare',),
'forveda': ('forvede',),
'forvedede': ('forvede',),
'forvedende': ('forvede',),
'forvedet': ('forvede',),
'forvedete': ('forvede',),
'forveksla': ('forveksle',),
'forvekslede': ('forveksle',),
'forvekslende': ('forveksle',),
'forvekslet': ('forveksle',),
'forvekslete': ('forveksle',),
'forvella': ('forvelle',),
'forvellede': ('forvelle',),
'forvellende': ('forvelle',),
'forvellet': ('forvelle',),
'forvellete': ('forvelle',),
'forvelt': ('forvelle',),
'forvelte': ('forvelle',),
'forvennende': ('forvenne',),
'forvent': ('forvenne',),
'forvente': ('forvenne',),
'forvent': ('forvent',),
'forvente': ('forvent',),
'forventere': ('forvent',),
'forventest': ('forvent',),
'forventeste': ('forvent',),
'forventa': ('forvente',),
'forventede': ('forvente',),
'forventende': ('forvente',),
'forventet': ('forvente',),
'forventete': ('forvente',),
'forventningsfull': ('forventningsfull',),
'forventningsfulle': ('forventningsfull',),
'forventningsfullere': ('forventningsfull',),
'forventningsfullest': ('forventningsfull',),
'forventningsfulleste': ('forventningsfull',),
'forventningsfullt': ('forventningsfull',),
'forverra': ('forverre',),
'forverrede': ('forverre',),
'forverrende': ('forverre',),
'forverret': ('forverre',),
'forverrete': ('forverre',),
'forvilla': ('forville',),
'forvillede': ('forville',),
'forvillende': ('forville',),
'forvillet': ('forville',),
'forvillete': ('forville',),
'forvirra': ('forvirra',),
'forvirra': ('forvirre',),
'forvirrede': ('forvirre',),
'forvirrende': ('forvirre',),
'forvirret': ('forvirre',),
'forvirrete': ('forvirre',),
'forvirrede': ('forvirret',),
'forvirret': ('forvirret',),
'forvirrete': ('forvirret',),
'forvirretere': ('forvirret',),
'forvirretest': ('forvirret',),
'forvirreteste': ('forvirret',),
'forvisende': ('forvise',),
'forvist': ('forvise',),
'forviste': ('forvise',),
'forvissa': ('forvisse',),
'forvissede': ('forvisse',),
'forvissende': ('forvisse',),
'forvisset': ('forvisse',),
'forvissete': ('forvisse',),
'forviten': ('forviten',),
'forvitent': ('forviten',),
'forvitne': ('forviten',),
'forvitnere': ('forviten',),
'forvitnest': ('forviten',),
'forvitneste': ('forviten',),
'forvitra': ('forvitre',),
'forvitrede': ('forvitre',),
'forvitrende': ('forvitre',),
'forvitret': ('forvitre',),
'forvitrete': ('forvitre',),
'forvokst': ('forvokst',),
'forvokste': ('forvokst',),
'forvokstere': ('forvokst',),
'forvokstest': ('forvokst',),
'forvoksteste': ('forvokst',),
'forvoldende': ('forvolde',),
'forvoldt': ('forvolde',),
'forvoldte': ('forvolde',),
'forvorpen': ('forvorpen',),
'forvorpent': ('forvorpen',),
'forvorpne': ('forvorpen',),
'forvorpnere': ('forvorpen',),
'forvorpnest': ('forvorpen',),
'forvorpneste': ('forvorpen',),
'forvrengende': ('forvrenge',),
'forvrengt': ('forvrenge',),
'forvrengte': ('forvrenge',),
'forvridd': ('forvri',),
'forvridde': ('forvri',),
'forvriende': ('forvri',),
'forvrøvla': ('forvrøvla',),
'forvrøvlede': ('forvrøvlet',),
'forvrøvlet': ('forvrøvlet',),
'forvrøvlete': ('forvrøvlet',),
'forvrøvletere': ('forvrøvlet',),
'forvrøvletest': ('forvrøvlet',),
'forvrøvleteste': ('forvrøvlet',),
'forvåka': ('forvåka',),
'forvåkede': ('forvåket',),
'forvåket': ('forvåket',),
'forvåkete': ('forvåket',),
'forvåketere': ('forvåket',),
'forvåketest': ('forvåket',),
'forvåketeste': ('forvåket',),
'forvåkt': ('forvåkt',),
'forvåkte': ('forvåkt',),
'forvåktere': ('forvåkt',),
'forvåktest': ('forvåkt',),
'forvåkteste': ('forvåkt',),
'forynga': ('forynge',),
'foryngede': ('forynge',),
'foryngende': ('forynge',),
'forynget': ('forynge',),
'foryngete': ('forynge',),
'forårsaka': ('forårsake',),
'forårsakede': ('forårsake',),
'forårsakende': ('forårsake',),
'forårsaket': ('forårsake',),
'forårsakete': ('forårsake',),
'forærende': ('forære',),
'forært': ('forære',),
'forærte': ('forære',),
'forøda': ('forøde',),
'forødede': ('forøde',),
'forødende': ('forøde',),
'forødet': ('forøde',),
'forødete': ('forøde',),
'forødt': ('forøde',),
'forødte': ('forøde',),
'forøka': ('forøke',),
'forøkede': ('forøke',),
'forøkende': ('forøke',),
'forøket': ('forøke',),
'forøkete': ('forøke',),
'forøkt': ('forøke',),
'forøkte': ('forøke',),
'forønska': ('forønska',),
'forønskede': ('forønsket',),
'forønsket': ('forønsket',),
'forønskete': ('forønsket',),
'forønsketere': ('forønsket',),
'forønsketest': ('forønsket',),
'forønsketeste': ('forønsket',),
'forøva': ('forøve',),
'forøvd': ('forøve',),
'forøvde': ('forøve',),
'forøvede': ('forøve',),
'forøvende': ('forøve',),
'forøvet': ('forøve',),
'forøvete': ('forøve',),
'fosforescerende': ('fosforescere',),
'fosforescert': ('fosforescere',),
'fosforescerte': ('fosforescere',),
'fosforsur': ('fosforsur',),
'fosforsure': ('fosforsur',),
'fosforsurere': ('fosforsur',),
'fosforsurest': ('fosforsur',),
'fosforsureste': ('fosforsur',),
'fosforsurt': ('fosforsur',),
'fossa': ('fosse',),
'fossede': ('fosse',),
'fossende': ('fosse',),
'fosset': ('fosse',),
'fossete': ('fosse',),
'fossil': ('fossil',),
'fossile': ('fossil',),
'fossilere': ('fossil',),
'fossilest': ('fossil',),
'fossileste': ('fossil',),
'fossilt': ('fossil',),
'fosskokende': ('fosskoke',),
'fosskokt': ('fosskoke',),
'fosskokte': ('fosskoke',),
'fossregna': ('fossregne',),
'fossregnede': ('fossregne',),
'fossregnende': ('fossregne',),
'fossregnet': ('fossregne',),
'fossregnete': ('fossregne',),
'fossregnt': ('fossregne',),
'fossregnte': ('fossregne',),
'fossrodd': ('fossro',),
'fossrodde': ('fossro',),
'fossroende': ('fossro',),
'fostra': ('fostre',),
'fostrede': ('fostre',),
'fostrende': ('fostre',),
'fostret': ('fostre',),
'fostrete': ('fostre',),
'fota': ('fote',),
'fotede': ('fote',),
'fotende': ('fote',),
'fotet': ('fote',),
'fotete': ('fote',),
'fotogen': ('fotogen',),
'fotogene': ('fotogen',),
'fotogenere': ('fotogen',),
'fotogenest': ('fotogen',),
'fotogeneste': ('fotogen',),
'fotogent': ('fotogen',),
'fotograferende': ('fotografere',),
'fotografert': ('fotografere',),
'fotograferte': ('fotografere',),
'fotografisk': ('fotografisk',),
'fotografiske': ('fotografisk',),
'fotografiskere': ('fotografisk',),
'fotografiskest': ('fotografisk',),
'fotografiskeste': ('fotografisk',),
'fotokopierende': ('fotokopiere',),
'fotokopiert': ('fotokopiere',),
'fotokopierte': ('fotokopiere',),
'fotostatisk': ('fotostatisk',),
'fotostatiske': ('fotostatisk',),
'fotostatiskere': ('fotostatisk',),
'fotostatiskest': ('fotostatisk',),
'fotostatiskeste': ('fotostatisk',),
'fotosyntetisk': ('fotosyntetisk',),
'fotosyntetiske': ('fotosyntetisk',),
'fotosyntetiskere': ('fotosyntetisk',),
'fotosyntetiskest': ('fotosyntetisk',),
'fotosyntetiskeste': ('fotosyntetisk',),
'fototaktisk': ('fototaktisk',),
'fototaktiske': ('fototaktisk',),
'fototaktiskere': ('fototaktisk',),
'fototaktiskest': ('fototaktisk',),
'fototaktiskeste': ('fototaktisk',),
'fotsid': ('fotsid',),
'fotside': ('fotsid',),
'fotsidere': ('fotsid',),
'fotsidest': ('fotsid',),
'fotsideste': ('fotsid',),
'fotsidt': ('fotsid',),
'frabedt': ('frabe',),
'frabedte': ('frabe',),
'frabeende': ('frabe',),
'frabeordra': ('frabeordre',),
'frabeordrede': ('frabeordre',),
'frabeordrende': ('frabeordre',),
'frabeordret': ('frabeordre',),
'frabeordrete': ('frabeordre',),
'fradragsberettiga': ('fradragsberettiga',),
'fradragsberettigede': ('fradragsberettiget',),
'fradragsberettiget': ('fradragsberettiget',),
'fradragsberettigete': ('fradragsberettiget',),
'fradragsberettigetere': ('fradragsberettiget',),
'fradragsberettigetest': ('fradragsberettiget',),
'fradragsberettigeteste': ('fradragsberettiget',),
'fradømmende': ('fradømme',),
'fradømt': ('fradømme',),
'fradømte': ('fradømme',),
'frafallen': ('frafallen',),
'frafallent': ('frafallen',),
'frafalne': ('frafallen',),
'frafalnere': ('frafallen',),
'frafalnest': ('frafallen',),
'frafalneste': ('frafallen',),
'fraflytta': ('fraflytte',),
'fraflyttede': ('fraflytte',),
'fraflyttende': ('fraflytte',),
'fraflyttet': ('fraflytte',),
'fraflyttete': ('fraflytte',),
'fragil': ('fragil',),
'fragile': ('fragil',),
'fragilere': ('fragil',),
'fragilest': ('fragil',),
'fragileste': ('fragil',),
'fragilt': ('fragil',),
'fragmentarisk': ('fragmentarisk',),
'fragmentariske': ('fragmentarisk',),
'fragmentariskere': ('fragmentarisk',),
'fragmentariskest': ('fragmentarisk',),
'fragmentariskeste': ('fragmentarisk',),
'fragmenterende': ('fragmentere',),
'fragmentert': ('fragmentere',),
'fragmenterte': ('fragmentere',),
'fragående': ('fragå',),
'fragått': ('fragå',),
'fragåtte': ('fragå',),
'fraise': ('fraise',),
'frakjennende': ('frakjenne',),
'frakjent': ('frakjenne',),
'frakjente': ('frakjenne',),
'frakobla': ('frakobla',),
'frakobla': ('frakoble',),
'frakoblede': ('frakoble',),
'frakoblende': ('frakoble',),
'frakoblet': ('frakoble',),
'frakoblete': ('frakoble',),
'frakoblede': ('frakoblet',),
'frakoblet': ('frakoblet',),
'frakoblete': ('frakoblet',),
'frakobletere': ('frakoblet',),
'frakobletest': ('frakoblet',),
'frakobleteste': ('frakoblet',),
'frakopla': ('frakopla',),
'frakopla': ('frakople',),
'frakoplede': ('frakople',),
'frakoplende': ('frakople',),
'frakoplet': ('frakople',),
'frakoplete': ('frakople',),
'frakoplede': ('frakoplet',),
'frakoplet': ('frakoplet',),
'frakoplete': ('frakoplet',),
'frakopletere': ('frakoplet',),
'frakopletest': ('frakoplet',),
'frakopleteste': ('frakoplet',),
'fraksjonerende': ('fraksjonere',),
'fraksjonert': ('fraksjonere',),
'fraksjonerte': ('fraksjonere',),
'fraktal': ('fraktal',),
'fraktale': ('fraktal',),
'fraktalere': ('fraktal',),
'fraktalest': ('fraktal',),
'fraktaleste': ('fraktal',),
'fraktalt': ('fraktal',),
'frakta': ('frakte',),
'fraktede': ('frakte',),
'fraktende': ('frakte',),
'fraktet': ('frakte',),
'fraktete': ('frakte',),
'fralands': ('fralands',),
'fralagt': ('fralegge',),
'fralagte': ('fralegge',),
'fraleggende': ('fralegge',),
'fralokka': ('fralokke',),
'fralokkede': ('fralokke',),
'fralokkende': ('fralokke',),
'fralokket': ('fralokke',),
'fralokkete': ('fralokke',),
'framdaterende': ('framdatere',),
'framdatert': ('framdatere',),
'framdaterte': ('framdatere',),
'framelska': ('framelske',),
'framelskede': ('framelske',),
'framelskende': ('framelske',),
'framelsket': ('framelske',),
'framelskete': ('framelske',),
'framfaren': ('framfaren',),
'framfarent': ('framfaren',),
'framfarne': ('framfaren',),
'framfarnere': ('framfaren',),
'framfarnest': ('framfaren',),
'framfarneste': ('framfaren',),
'framfus': ('framfus',),
'framfuse': ('framfus',),
'framfusere': ('framfus',),
'framfusest': ('framfus',),
'framfuseste': ('framfus',),
'framfust': ('framfus',),
'framfusende': ('framfusende',),
'framførende': ('framføre',),
'framført': ('framføre',),
'framførte': ('framføre',),
'framgangsrik': ('framgangsrik',),
'framgangsrike': ('framgangsrik',),
'framgangsrikere': ('framgangsrik',),
'framgangsrikest': ('framgangsrik',),
'framgangsrikeste': ('framgangsrik',),
'framgangsrikt': ('framgangsrik',),
'framgående': ('framgå',),
'framgått': ('framgå',),
'framgåtte': ('framgå',),
'framherskende': ('framherskende',),
'framheva': ('framheve',),
'framhevd': ('framheve',),
'framhevde': ('framheve',),
'framhevede': ('framheve',),
'framhevende': ('framheve',),
'framhevet': ('framheve',),
'framhevete': ('framheve',),
'framholdende': ('framholde',),
'framholdt': ('framholde',),
'framholdte': ('framholde',),
'framifrå': ('framifrå',),
'framkallende': ('framkalle',),
'framkalt': ('framkalle',),
'framkalte': ('framkalle',),
'framkasta': ('framkaste',),
'framkastede': ('framkaste',),
'framkastende': ('framkaste',),
'framkastet': ('framkaste',),
'framkastete': ('framkaste',),
'framkommelig': ('framkommelig',),
'framkommelige': ('framkommelig',),
'framkommeligere': ('framkommelig',),
'framkommeligst': ('framkommelig',),
'framkommeligste': ('framkommelig',),
'framlagt': ('framlegge',),
'framlagte': ('framlegge',),
'framleggende': ('framlegge',),
'framleid': ('framleie',),
'framleide': ('framleie',),
'framleiede': ('framleie',),
'framleiende': ('framleie',),
'framleiet': ('framleie',),
'framleiete': ('framleie',),
'framlut': ('framlut',),
'framlute': ('framlut',),
'framlutere': ('framlut',),
'framlutest': ('framlut',),
'framluteste': ('framlut',),
'framlutt': ('framlut',),
'frammøtt': ('frammøtt',),
'frammøtte': ('frammøtt',),
'frammøttere': ('frammøtt',),
'frammøttest': ('frammøtt',),
'frammøtteste': ('frammøtt',),
'framoverbøyd': ('framoverbøyd',),
'framoverbøyde': ('framoverbøyd',),
'framoverbøydere': ('framoverbøyd',),
'framoverbøydest': ('framoverbøyd',),
'framoverbøydeste': ('framoverbøyd',),
'framoverlut': ('framoverlut',),
'framoverlute': ('framoverlut',),
'framoverlutere': ('framoverlut',),
'framoverlutest': ('framoverlut',),
'framoverluteste': ('framoverlut',),
'framoverlutt': ('framoverlut',),
'framsatt': ('framsette',),
'framsatte': ('framsette',),
'framsettende': ('framsette',),
'framsagt': ('framsi',),
'framsagte': ('framsi',),
'framsiende': ('framsi',),
'framskaffa': ('framskaffe',),
'framskaffede': ('framskaffe',),
'framskaffende': ('framskaffe',),
'framskaffet': ('framskaffe',),
'framskaffete': ('framskaffe',),
'framskreden': ('framskreden',),
'framskredent': ('framskreden',),
'framskredne': ('framskreden',),
'framskrednere': ('framskreden',),
'framskrednest': ('framskreden',),
'framskredneste': ('framskreden',),
'framskrittsfiendtlig': ('framskrittsfiendtlig',),
'framskrittsfiendtlige': ('framskrittsfiendtlig',),
'framskrittsfiendtligere': ('framskrittsfiendtlig',),
'framskrittsfiendtligst': ('framskrittsfiendtlig',),
'framskrittsfiendtligste': ('framskrittsfiendtlig',),
'framskrittsvennlig': ('framskrittsvennlig',),
'framskrittsvennlige': ('framskrittsvennlig',),
'framskrittsvennligere': ('framskrittsvennlig',),
'framskrittsvennligst': ('framskrittsvennlig',),
'framskrittsvennligste': ('framskrittsvennlig',),
'framskreven': ('framskrive',),
'framskrevet': ('framskrive',),
'framskrevne': ('framskrive',),
'framskrivende': ('framskrive',),
'framskutt': ('framskutt',),
'framskutte': ('framskutt',),
'framskuttere': ('framskutt',),
'framskuttest': ('framskutt',),
'framskutteste': ('framskutt',),
'framskynda': ('framskynde',),
'framskyndede': ('framskynde',),
'framskyndende': ('framskynde',),
'framskyndet': ('framskynde',),
'framskyndete': ('framskynde',),
'framskyndt': ('framskynde',),
'framskyndte': ('framskynde',),
'framskutt': ('framskyte',),
'framskutte': ('framskyte',),
'framskytende': ('framskyte',),
'framspringende': ('framspringende',),
'framstillende': ('framstille',),
'framstilt': ('framstille',),
'framstilte': ('framstille',),
'framstående': ('framstå',),
'framstått': ('framstå',),
'framståtte': ('framstå',),
'framstående': ('framstående',),
'framsynt': ('framsynt',),
'framsynte': ('framsynt',),
'framsyntere': ('framsynt',),
'framsyntest': ('framsynt',),
'framsynteste': ('framsynt',),
'framtidig': ('framtidig',),
'framtidige': ('framtidig',),
'framtidigere': ('framtidig',),
'framtidigst': ('framtidig',),
'framtidigste': ('framtidig',),
'framtidsretta': ('framtidsretta',),
'framtidsrettede': ('framtidsrettet',),
'framtidsrettet': ('framtidsrettet',),
'framtidsrettete': ('framtidsrettet',),
'framtidsrettetere': ('framtidsrettet',),
'framtidsrettetest': ('framtidsrettet',),
'framtidsretteteste': ('framtidsrettet',),
'framtredende': ('framtredende',),
'framvisende': ('framvise',),
'framvist': ('framvise',),
'framviste': ('framvise',),
'franarra': ('franarre',),
'franarrede': ('franarre',),
'franarrende': ('franarre',),
'franarret': ('franarre',),
'franarrete': ('franarre',),
'frank': ('frank',),
'franke': ('frank',),
'frankere': ('frank',),
'frankest': ('frank',),
'frankeste': ('frank',),
'frankt': ('frank',),
'frankerende': ('frankere',),
'frankert': ('frankere',),
'frankerte': ('frankere',),
'frankofil': ('frankofil',),
'frankofile': ('frankofil',),
'frankofilere': ('frankofil',),
'frankofilest': ('frankofil',),
'frankofileste': ('frankofil',),
'frankofilt': ('frankofil',),
'frankoman': ('frankoman',),
'frankomane': ('frankoman',),
'frankomanere': ('frankoman',),
'frankomanest': ('frankoman',),
'frankomaneste': ('frankoman',),
'frankomant': ('frankoman',),
'fransk': ('fransk',),
'franske': ('fransk',),
'franskere': ('fransk',),
'franskest': ('fransk',),
'franskeste': ('fransk',),
'frappant': ('frappant',),
'frappante': ('frappant',),
'frappantere': ('frappant',),
'frappantest': ('frappant',),
'frappanteste': ('frappant',),
'frappantt': ('frappant',),
'frapperende': ('frappere',),
'frappert': ('frappere',),
'frapperte': ('frappere',),
'frapperende': ('frapperende',),
'frarana': ('frarane',),
'fraranede': ('frarane',),
'fraranende': ('frarane',),
'fraranet': ('frarane',),
'fraranete': ('frarane',),
'frarant': ('frarane',),
'frarante': ('frarane',),
'fraregna': ('fraregna',),
'fraregnede': ('fraregnet',),
'fraregnet': ('fraregnet',),
'fraregnete': ('fraregnet',),
'fraregnetere': ('fraregnet',),
'fraregnetest': ('fraregnet',),
'fraregneteste': ('fraregnet',),
'frarekna': ('frarekna',),
'frareknede': ('frareknet',),
'frareknet': ('frareknet',),
'frareknete': ('frareknet',),
'frareknetere': ('frareknet',),
'frareknetest': ('frareknet',),
'frarekneteste': ('frareknet',),
'frarådd': ('frarå',),
'frarådde': ('frarå',),
'frarående': ('frarå',),
'fraråda': ('fraråde',),
'frarådd': ('fraråde',),
'frarådde': ('fraråde',),
'frarådede': ('fraråde',),
'frarådende': ('fraråde',),
'frarådet': ('fraråde',),
'frarådete': ('fraråde',),
'frasefylt': ('frasefylt',),
'frasefylte': ('frasefylt',),
'frasefyltere': ('frasefylt',),
'frasefyltest': ('frasefylt',),
'frasefylteste': ('frasefylt',),
'fraselgende': ('fraselge',),
'frasolgt': ('fraselge',),
'frasolgte': ('fraselge',),
'fraseologisk': ('fraseologisk',),
'fraseologiske': ('fraseologisk',),
'fraseologiskere': ('fraseologisk',),
'fraseologiskest': ('fraseologisk',),
'fraseologiskeste': ('fraseologisk',),
'fraseparert': ('fraseparert',),
'fraseparerte': ('fraseparert',),
'fraseparertere': ('fraseparert',),
'fraseparertest': ('fraseparert',),
'fraseparerteste': ('fraseparert',),
'fraserende': ('frasere',),
'frasert': ('frasere',),
'fraserte': ('frasere',),
'frasagt': ('frasi',),
'frasagte': ('frasi',),
'frasiende': ('frasi',),
'fraskillende': ('fraskille',),
'fraskilt': ('fraskille',),
'fraskilte': ('fraskille',),
'fraskjøta': ('fraskjøte',),
'fraskjøtede': ('fraskjøte',),
'fraskjøtende': ('fraskjøte',),
'fraskjøtet': ('fraskjøte',),
'fraskjøtete': ('fraskjøte',),
'fraskjøtt': ('fraskjøte',),
'fraskjøtte': ('fraskjøte',),
'fraskreven': ('fraskrive',),
'fraskrevet': ('fraskrive',),
'fraskrevne': ('fraskrive',),
'fraskrivende': ('fraskrive',),
'frastjelende': ('frastjele',),
'frastjålen': ('frastjele',),
'frastjålet': ('frastjele',),
'frastjålne': ('frastjele',),
'frastøtende': ('frastøte',),
'frastøtt': ('frastøte',),
'frastøtte': ('frastøte',),
'frastøtende': ('frastøtende',),
'fratakende': ('frata',),
'fratatt': ('frata',),
'fratatte': ('frata',),
'fraterniserende': ('fraternisere',),
'fraternisert': ('fraternisere',),
'fraterniserte': ('fraternisere',),
'fratredende': ('fratre',),
'fratrådt': ('fratre',),
'fratrådte': ('fratre',),
'fraveken': ('fravike',),
'fraveket': ('fravike',),
'fravekne': ('fravike',),
'fravikende': ('fravike',),
'fravikelig': ('fravikelig',),
'fravikelige': ('fravikelig',),
'fravikeligere': ('fravikelig',),
'fravikeligst': ('fravikelig',),
'fravikeligste': ('fravikelig',),
'fravrista': ('fravriste',),
'fravristede': ('fravriste',),
'fravristende': ('fravriste',),
'fravristet': ('fravriste',),
'fravristete': ('fravriste',),
'fraværende': ('fraværende',),
'freda': ('frede',),
'fredede': ('frede',),
'fredende': ('frede',),
'fredet': ('frede',),
'fredete': ('frede',),
'fredelig': ('fredelig',),
'fredelige': ('fredelig',),
'fredeligere': ('fredelig',),
'fredeligst': ('fredelig',),
'fredeligste': ('fredelig',),
'fredeligsinna': ('fredeligsinna',),
'fredeligsinnede': ('fredeligsinnet',),
'fredeligsinnet': ('fredeligsinnet',),
'fredeligsinnete': ('fredeligsinnet',),
'fredeligsinnetere': ('fredeligsinnet',),
'fredeligsinnetest': ('fredeligsinnet',),
'fredeligsinneteste': ('fredeligsinnet',),
'fredfull': ('fredfull',),
'fredfulle': ('fredfull',),
'fredfullere': ('fredfull',),
'fredfullest': ('fredfull',),
'fredfulleste': ('fredfull',),
'fredfullt': ('fredfull',),
'fredhellig': ('fredhellig',),
'fredhellige': ('fredhellig',),
'fredhelligere': ('fredhellig',),
'fredhelligst': ('fredhellig',),
'fredhelligste': ('fredhellig',),
'fredlaus': ('fredlaus',),
'fredlause': ('fredlaus',),
'fredlausere': ('fredlaus',),
'fredlausest': ('fredlaus',),
'fredlauseste': ('fredlaus',),
'fredlaust': ('fredlaus',),
'fredløs': ('fredløs',),
'fredløse': ('fredløs',),
'fredløsere': ('fredløs',),
'fredløsest': ('fredløs',),
'fredløseste': ('fredløs',),
'fredløst': ('fredløs',),
'fredsbevarende': ('fredsbevarende',),
'fredselskende': ('fredselskende',),
'fredsommelig': ('fredsommelig',),
'fredsommelige': ('fredsommelig',),
'fredsommeligere': ('fredsommelig',),
'fredsommeligst': ('fredsommelig',),
'fredsommeligste': ('fredsommelig',),
'fredsæl': ('fredsæl',),
'fredsæle': ('fredsæl',),
'fredsælere': ('fredsæl',),
'fredsælest': ('fredsæl',),
'fredsæleste': ('fredsæl',),
'fredsælt': ('fredsæl',),
'frega': ('frege',),
'fregede': ('frege',),
'fregende': ('frege',),
'freget': ('frege',),
'fregete': ('frege',),
'fregnet': ('fregnet',),
'fregnete': ('fregnet',),
'fregnetere': ('fregnet',),
'fregnetest': ('fregnet',),
'fregneteste': ('fregnet',),
'fregnete': ('fregnete',),
'freidig': ('freidig',),
'freidige': ('freidig',),
'freidigere': ('freidig',),
'freidigst': ('freidig',),
'freidigste': ('freidig',),
'frekk': ('frekk',),
'frekke': ('frekk',),
'frekkere': ('frekk',),
'frekkest': ('frekk',),
'frekkeste': ('frekk',),
'frekt': ('frekk',),
'frekvent': ('frekvent',),
'frekvente': ('frekvent',),
'frekventere': ('frekvent',),
'frekventest': ('frekvent',),
'frekventeste': ('frekvent',),
'frekventerende': ('frekventere',),
'frekventert': ('frekventere',),
'frekventerte': ('frekventere',),
'frelsende': ('frelse',),
'frelst': ('frelse',),
'frelste': ('frelse',),
'frelst': ('frelst',),
'frelste': ('frelst',),
'frelstere': ('frelst',),
'frelstest': ('frelst',),
'frelsteste': ('frelst',),
'fremadretta': ('fremadretta',),
'fremadrettede': ('fremadrettet',),
'fremadrettet': ('fremadrettet',),
'fremadrettete': ('fremadrettet',),
'fremadrettetere': ('fremadrettet',),
'fremadrettetest': ('fremadrettet',),
'fremadretteteste': ('fremadrettet',),
'fremadstormende': ('fremadstormende',),
'fremadstrebende': ('fremadstrebende',),
'fremdaterende': ('fremdatere',),
'fremdatert': ('fremdatere',),
'fremdaterte': ('fremdatere',),
'fremelska': ('fremelske',),
'fremelskede': ('fremelske',),
'fremelskende': ('fremelske',),
'fremelsket': ('fremelske',),
'fremelskete': ('fremelske',),
'fremfaren': ('fremfaren',),
'fremfarent': ('fremfaren',),
'fremfarne': ('fremfaren',),
'fremfarnere': ('fremfaren',),
'fremfarnest': ('fremfaren',),
'fremfarneste': ('fremfaren',),
'fremfus': ('fremfus',),
'fremfuse': ('fremfus',),
'fremfusere': ('fremfus',),
'fremfusest': ('fremfus',),
'fremfuseste': ('fremfus',),
'fremfust': ('fremfus',),
'fremfusende': ('fremfusende',),
'fremførende': ('fremføre',),
'fremført': ('fremføre',),
'fremførte': ('fremføre',),
'fremgangsrik': ('fremgangsrik',),
'fremgangsrike': ('fremgangsrik',),
'fremgangsrikere': ('fremgangsrik',),
'fremgangsrikest': ('fremgangsrik',),
'fremgangsrikeste': ('fremgangsrik',),
'fremgangsrikt': ('fremgangsrik',),
'fremgående': ('fremgå',),
'fremgått': ('fremgå',),
'fremgåtte': ('fremgå',),
'fremherskende': ('fremherskende',),
'fremheva': ('fremheve',),
'fremhevd': ('fremheve',),
'fremhevde': ('fremheve',),
'fremhevede': ('fremheve',),
'fremhevende': ('fremheve',),
'fremhevet': ('fremheve',),
'fremhevete': ('fremheve',),
'fremholdende': ('fremholde',),
'fremholdt': ('fremholde',),
'fremholdte': ('fremholde',),
'fremkallende': ('fremkalle',),
'fremkalt': ('fremkalle',),
'fremkalte': ('fremkalle',),
'fremkasta': ('fremkaste',),
'fremkastede': ('fremkaste',),
'fremkastende': ('fremkaste',),
'fremkastet': ('fremkaste',),
'fremkastete': ('fremkaste',),
'fremkommelig': ('fremkommelig',),
'fremkommelige': ('fremkommelig',),
'fremkommeligere': ('fremkommelig',),
'fremkommeligst': ('fremkommelig',),
'fremkommeligste': ('fremkommelig',),
'fremlagt': ('fremlegge',),
'fremlagte': ('fremlegge',),
'fremleggende': ('fremlegge',),
'fremleid': ('fremleie',),
'fremleide': ('fremleie',),
'fremleiede': ('fremleie',),
'fremleiende': ('fremleie',),
'fremleiet': ('fremleie',),
'fremleiete': ('fremleie',),
'fremlut': ('fremlut',),
'fremlute': ('fremlut',),
'fremlutere': ('fremlut',),
'fremlutest': ('fremlut',),
'fremluteste': ('fremlut',),
'fremlutt': ('fremlut',),
'fremma': ('fremme',),
'fremmede': ('fremme',),
'fremmende': ('fremme',),
'fremmet': ('fremme',),
'fremmete': ('fremme',),
'fremmed': ('fremmed',),
'fremmede': ('fremmed',),
'fremmedere': ('fremmed',),
'fremmedest': ('fremmed',),
'fremmedeste': ('fremmed',),
'fremmed': ('fremmed',),
'fremmede': ('fremmed',),
'fremmedere': ('fremmed',),
'fremmedest': ('fremmed',),
'fremmedeste': ('fremmed',),
'fremmedarta': ('fremmedarta',),
'fremmedarta': ('fremmedarta',),
'fremmedartede': ('fremmedartet',),
'fremmedartet': ('fremmedartet',),
'fremmedartete': ('fremmedartet',),
'fremmedartetere': ('fremmedartet',),
'fremmedartetest': ('fremmedartet',),
'fremmedarteteste': ('fremmedartet',),
'fremmedartede': ('fremmedartet',),
'fremmedartet': ('fremmedartet',),
'fremmedartete': ('fremmedartet',),
'fremmedartetere': ('fremmedartet',),
'fremmedartetest': ('fremmedartet',),
'fremmedarteteste': ('fremmedartet',),
'fremmedgjort': ('fremmedgjøre',),
'fremmedgjorte': ('fremmedgjøre',),
'fremmedgjørende': ('fremmedgjøre',),
'fremmedgjort': ('fremmedgjøre',),
'fremmedgjorte': ('fremmedgjøre',),
'fremmedgjørende': ('fremmedgjøre',),
'fremmedspråklig': ('fremmedspråklig',),
'fremmedspråklige': ('fremmedspråklig',),
'fremmedspråkligere': ('fremmedspråklig',),
'fremmedspråkligst': ('fremmedspråklig',),
'fremmedspråkligste': ('fremmedspråklig',),
'fremmedspråklig': ('fremmedspråklig',),
'fremmedspråklige': ('fremmedspråklig',),
'fremmedspråkligere': ('fremmedspråklig',),
'fremmedspråkligst': ('fremmedspråklig',),
'fremmedspråkligste': ('fremmedspråklig',),
'fremmelig': ('fremmelig',),
'fremmelige': ('fremmelig',),
'fremmeligere': ('fremmelig',),
'fremmeligst': ('fremmelig',),
'fremmeligste': ('fremmelig',),
'fremmend': ('fremmend',),
'fremmende': ('fremmend',),
'fremmendere': ('fremmend',),
'fremmendest': ('fremmend',),
'fremmendeste': ('fremmend',),
'fremmendt': ('fremmend',),
'fremmend': ('fremmend',),
'fremmende': ('fremmend',),
'fremmendere': ('fremmend',),
'fremmendest': ('fremmend',),
'fremmendeste': ('fremmend',),
'fremmendt': ('fremmend',),
'fremmendarta': ('fremmendarta',),
'fremmendarta': ('fremmendarta',),
'fremmendartede': ('fremmendartet',),
'fremmendartet': ('fremmendartet',),
'fremmendartete': ('fremmendartet',),
'fremmendartetere': ('fremmendartet',),
'fremmendartetest': ('fremmendartet',),
'fremmendarteteste': ('fremmendartet',),
'fremmendartede': ('fremmendartet',),
'fremmendartet': ('fremmendartet',),
'fremmendartete': ('fremmendartet',),
'fremmendartetere': ('fremmendartet',),
'fremmendartetest': ('fremmendartet',),
'fremmendarteteste': ('fremmendartet',),
'fremmendgjort': ('fremmendgjøre',),
'fremmendgjorte': ('fremmendgjøre',),
'fremmendgjørende': ('fremmendgjøre',),
'fremmendgjort': ('fremmendgjøre',),
'fremmendgjorte': ('fremmendgjøre',),
'fremmendgjørende': ('fremmendgjøre',),
'fremmendspråklig': ('fremmendspråklig',),
'fremmendspråklige': ('fremmendspråklig',),
'fremmendspråkligere': ('fremmendspråklig',),
'fremmendspråkligst': ('fremmendspråklig',),
'fremmendspråkligste': ('fremmendspråklig',),
'fremmendspråklig': ('fremmendspråklig',),
'fremmendspråklige': ('fremmendspråklig',),
'fremmendspråkligere': ('fremmendspråklig',),
'fremmendspråkligst': ('fremmendspråklig',),
'fremmendspråkligste': ('fremmendspråklig',),
'fremmøtt': ('fremmøtt',),
'fremmøtte': ('fremmøtt',),
'fremmøttere': ('fremmøtt',),
'fremmøttest': ('fremmøtt',),
'fremmøtteste': ('fremmøtt',),
'fremoverbøyd': ('fremoverbøyd',),
'fremoverbøyde': ('fremoverbøyd',),
'fremoverbøydere': ('fremoverbøyd',),
'fremoverbøydest': ('fremoverbøyd',),
'fremoverbøydeste': ('fremoverbøyd',),
'fremoverlut': ('fremoverlut',),
'fremoverlute': ('fremoverlut',),
'fremoverlutere': ('fremoverlut',),
'fremoverlutest': ('fremoverlut',),
'fremoverluteste': ('fremoverlut',),
'fremoverlutt': ('fremoverlut',),
'fremragende': ('fremragende',),
'fremre': ('fremre',),
'fremst': ('fremre',),
'fremste': ('fremre',),
'fremsatt': ('fremsette',),
'fremsatte': ('fremsette',),
'fremsettende': ('fremsette',),
'fremsagt': ('fremsi',),
'fremsagte': ('fremsi',),
'fremsiende': ('fremsi',),
'fremskaffa': ('fremskaffe',),
'fremskaffede': ('fremskaffe',),
'fremskaffende': ('fremskaffe',),
'fremskaffet': ('fremskaffe',),
'fremskaffete': ('fremskaffe',),
'fremskreden': ('fremskreden',),
'fremskredent': ('fremskreden',),
'fremskredne': ('fremskreden',),
'fremskrednere': ('fremskreden',),
'fremskrednest': ('fremskreden',),
'fremskredneste': ('fremskreden',),
'fremskrittsfiendtlig': ('fremskrittsfiendtlig',),
'fremskrittsfiendtlige': ('fremskrittsfiendtlig',),
'fremskrittsfiendtligere': ('fremskrittsfiendtlig',),
'fremskrittsfiendtligst': ('fremskrittsfiendtlig',),
'fremskrittsfiendtligste': ('fremskrittsfiendtlig',),
'fremskrittsvennlig': ('fremskrittsvennlig',),
'fremskrittsvennlige': ('fremskrittsvennlig',),
'fremskrittsvennligere': ('fremskrittsvennlig',),
'fremskrittsvennligst': ('fremskrittsvennlig',),
'fremskrittsvennligste': ('fremskrittsvennlig',),
'fremskreven': ('fremskrive',),
'fremskrevet': ('fremskrive',),
'fremskrevne': ('fremskrive',),
'fremskrivende': ('fremskrive',),
'fremskutt': ('fremskutt',),
'fremskutte': ('fremskutt',),
'fremskuttere': ('fremskutt',),
'fremskuttest': ('fremskutt',),
'fremskutteste': ('fremskutt',),
'fremskynda': ('fremskynde',),
'fremskyndede': ('fremskynde',),
'fremskyndende': ('fremskynde',),
'fremskyndet': ('fremskynde',),
'fremskyndete': ('fremskynde',),
'fremskyndt': ('fremskynde',),
'fremskyndte': ('fremskynde',),
'fremskutt': ('fremskyte',),
'fremskutte': ('fremskyte',),
'fremskytende': ('fremskyte',),
'fremspringende': ('fremspringende',),
'fremstillende': ('fremstille',),
'fremstilt': ('fremstille',),
'fremstilte': ('fremstille',),
'fremstående': ('fremstå',),
'fremstått': ('fremstå',),
'fremståtte': ('fremstå',),
'fremstående': ('fremstående',),
'fremsynt': ('fremsynt',),
'fremsynte': ('fremsynt',),
'fremsyntere': ('fremsynt',),
'fremsyntest': ('fremsynt',),
'fremsynteste': ('fremsynt',),
'fremtidig': ('fremtidig',),
'fremtidige': ('fremtidig',),
'fremtidigere': ('fremtidig',),
'fremtidigst': ('fremtidig',),
'fremtidigste': ('fremtidig',),
'fremtidsretta': ('fremtidsretta',),
'fremtidsrettede': ('fremtidsrettet',),
'fremtidsrettet': ('fremtidsrettet',),
'fremtidsrettete': ('fremtidsrettet',),
'fremtidsrettetere': ('fremtidsrettet',),
'fremtidsrettetest': ('fremtidsrettet',),
'fremtidsretteteste': ('fremtidsrettet',),
'fremtredende': ('fremtredende',),
'fremvisende': ('fremvise',),
'fremvist': ('fremvise',),
'fremviste': ('fremvise',),
'frenetisk': ('frenetisk',),
'frenetiske': ('frenetisk',),
'frenetiskere': ('frenetisk',),
'frenetiskest': ('frenetisk',),
'frenetiskeste': ('frenetisk',),
'fresende': ('frese',),
'frest': ('frese',),
'freste': ('frese',),
'fresende': ('frese',),
'frest': ('frese',),
'freste': ('frese',),
'fresta': ('freste',),
'frestede': ('freste',),
'frestende': ('freste',),
'frestet': ('freste',),
'frestete': ('freste',),
'fretta': ('frette',),
'frettede': ('frette',),
'frettende': ('frette',),
'frettet': ('frette',),
'frettete': ('frette',),
'freudiansk': ('freudiansk',),
'freudianske': ('freudiansk',),
'freudianskere': ('freudiansk',),
'freudianskest': ('freudiansk',),
'freudianskeste': ('freudiansk',),
'freudsk': ('freudsk',),
'freudske': ('freudsk',),
'freudskere': ('freudsk',),
'freudskest': ('freudsk',),
'freudskeste': ('freudsk',),
'fridd': ('fri',),
'fridde': ('fri',),
'friende': ('fri',),
'fridd': ('fri',),
'fridde': ('fri',),
'friende': ('fri',),
'fri': ('fri',),
'frie': ('fri',),
'friere': ('fri',),
'friest': ('fri',),
'frieste': ('fri',),
'fritt': ('fri',),
'fribåren': ('fribåren',),
'fribårent': ('fribåren',),
'fribårne': ('fribåren',),
'fribårnere': ('fribåren',),
'fribårnest': ('fribåren',),
'fribårneste': ('fribåren',),
'frigiende': ('frigi',),
'frigitt': ('frigi',),
'frigitte': ('frigi',),
'frigivende': ('frigi',),
'frigid': ('frigid',),
'frigide': ('frigid',),
'frigidere': ('frigid',),
'frigidest': ('frigid',),
'frigideste': ('frigid',),
'frigjort': ('frigjort',),
'frigjorte': ('frigjort',),
'frigjortere': ('frigjort',),
'frigjortest': ('frigjort',),
'frigjorteste': ('frigjort',),
'frigjort': ('frigjøre',),
'frigjorte': ('frigjøre',),
'frigjørende': ('frigjøre',),
'frigjørende': ('frigjørende',),
'frikativ': ('frikativ',),
'frikative': ('frikativ',),
'frikativere': ('frikativ',),
'frikativest': ('frikativ',),
'frikativeste': ('frikativ',),
'frikativt': ('frikativ',),
'friket': ('friket',),
'frikete': ('friket',),
'friketere': ('friket',),
'friketest': ('friket',),
'friketeste': ('friket',),
'frikete': ('frikete',),
'frikjennende': ('frikjenne',),
'frikjent': ('frikjenne',),
'frikjente': ('frikjenne',),
'frikostig': ('frikostig',),
'frikostige': ('frikostig',),
'frikostigere': ('frikostig',),
'frikostigst': ('frikostig',),
'frikostigste': ('frikostig',),
'friksjonsfri': ('friksjonsfri',),
'friksjonsfrie': ('friksjonsfri',),
'friksjonsfriere': ('friksjonsfri',),
'friksjonsfriest': ('friksjonsfri',),
'friksjonsfrieste': ('friksjonsfri',),
'friksjonsfritt': ('friksjonsfri',),
'frilans': ('frilans',),
'frilansa': ('frilanse',),
'frilansede': ('frilanse',),
'frilansende': ('frilanse',),
'frilanset': ('frilanse',),
'frilansete': ('frilanse',),
'frilista': ('friliste',),
'frilistede': ('friliste',),
'frilistende': ('friliste',),
'frilistet': ('friliste',),
'frilistete': ('friliste',),
'frilynt': ('frilynt',),
'frilynte': ('frilynt',),
'frilyntere': ('frilynt',),
'frilyntest': ('frilynt',),
'frilynteste': ('frilynt',),
'frimodig': ('frimodig',),
'frimodige': ('frimodig',),
'frimodigere': ('frimodig',),
'frimodigst': ('frimodig',),
'frimodigste': ('frimodig',),
'fripostig': ('fripostig',),
'fripostige': ('fripostig',),
'fripostigere': ('fripostig',),
'fripostigst': ('fripostig',),
'fripostigste': ('fripostig',),
'frirådig': ('frirådig',),
'frirådige': ('frirådig',),
'frirådigere': ('frirådig',),
'frirådigst': ('frirådig',),
'frirådigste': ('frirådig',),
'friserende': ('frisere',),
'frisert': ('frisere',),
'friserte': ('frisere',),
'frisinna': ('frisinna',),
'frisinnede': ('frisinnet',),
'frisinnet': ('frisinnet',),
'frisinnete': ('frisinnet',),
'frisinnetere': ('frisinnet',),
'frisinnetest': ('frisinnet',),
'frisinneteste': ('frisinnet',),
'frisisk': ('frisisk',),
'frisiske': ('frisisk',),
'frisiskere': ('frisisk',),
'frisiskest': ('frisisk',),
'frisiskeste': ('frisisk',),
'frisk': ('frisk',),
'friske': ('frisk',),
'friskere': ('frisk',),
'friskest': ('frisk',),
'friskeste': ('frisk',),
'friskt': ('frisk',),
'friska': ('friske',),
'friskede': ('friske',),
'friskende': ('friske',),
'frisket': ('friske',),
'friskete': ('friske',),
'friskfyraktig': ('friskfyraktig',),
'friskfyraktige': ('friskfyraktig',),
'friskfyraktigere': ('friskfyraktig',),
'friskfyraktigst': ('friskfyraktig',),
'friskfyraktigste': ('friskfyraktig',),
'friskmeldende': ('friskmelde',),
'friskmeldt': ('friskmelde',),
'friskmeldte': ('friskmelde',),
'friskna': ('friskne',),
'frisknede': ('friskne',),
'frisknende': ('friskne',),
'frisknet': ('friskne',),
'frisknete': ('friskne',),
'frista': ('friste',),
'fristede': ('friste',),
'fristende': ('friste',),
'fristet': ('friste',),
'fristete': ('friste',),
'frista': ('friste',),
'fristede': ('friste',),
'fristende': ('friste',),
'fristet': ('friste',),
'fristete': ('friste',),
'frista': ('friste',),
'fristede': ('friste',),
'fristende': ('friste',),
'fristet': ('friste',),
'fristete': ('friste',),
'fristende': ('fristende',),
'fritakende': ('frita',),
'fritatt': ('frita',),
'fritatte': ('frita',),
'fritalende': ('fritalende',),
'fritenkersk': ('fritenkersk',),
'fritenkerske': ('fritenkersk',),
'fritenkerskere': ('fritenkersk',),
'fritenkerskest': ('fritenkersk',),
'fritenkerskeste': ('fritenkersk',),
'friterende': ('fritere',),
'fritert': ('fritere',),
'friterte': ('fritere',),
'fritt-talende': ('fritt-talende',),
'frittalende': ('frittalende',),
'fritta': ('fritte',),
'frittede': ('fritte',),
'frittende': ('fritte',),
'frittet': ('fritte',),
'frittete': ('fritte',),
'frittliggende': ('frittliggende',),
'frittstående': ('frittstående',),
'frityrkokt': ('frityrkokt',),
'frityrkokte': ('frityrkokt',),
'frityrkoktere': ('frityrkokt',),
'frityrkoktest': ('frityrkokt',),
'frityrkokteste': ('frityrkokt',),
'frityrsteikt': ('frityrsteikt',),
'frityrsteikte': ('frityrsteikt',),
'frityrsteiktere': ('frityrsteikt',),
'frityrsteiktest': ('frityrsteikt',),
'frityrsteikteste': ('frityrsteikt',),
'frityrstekt': ('frityrstekt',),
'frityrstekte': ('frityrstekt',),
'frityrstektere': ('frityrstekt',),
'frityrstektest': ('frityrstekt',),
'frityrstekteste': ('frityrstekt',),
'frivillig': ('frivillig',),
'frivillige': ('frivillig',),
'frivilligere': ('frivillig',),
'frivilligst': ('frivillig',),
'frivilligste': ('frivillig',),
'frivol': ('frivol',),
'frivole': ('frivol',),
'frivolere': ('frivol',),
'frivolest': ('frivol',),
'frivoleste': ('frivol',),
'frivolt': ('frivol',),
'frodig': ('frodig',),
'frodige': ('frodig',),
'frodigere': ('frodig',),
'frodigst': ('frodig',),
'frodigste': ('frodig',),
'from': ('from',),
'fromme': ('from',),
'frommere': ('from',),
'frommest': ('from',),
'frommeste': ('from',),
'fromt': ('from',),
'fronderende': ('frondere',),
'frondert': ('frondere',),
'fronderte': ('frondere',),
'frontal': ('frontal',),
'frontale': ('frontal',),
'frontalere': ('frontal',),
'frontalest': ('frontal',),
'frontaleste': ('frontal',),
'frontalt': ('frontal',),
'frosne': ('frossen',),
'frosnere': ('frossen',),
'frosnest': ('frossen',),
'frosneste': ('frossen',),
'frossen': ('frossen',),
'frossent': ('frossen',),
'frostlendt': ('frostlendt',),
'frostlendte': ('frostlendt',),
'frostlendtere': ('frostlendt',),
'frostlendtest': ('frostlendt',),
'frostlendteste': ('frostlendt',),
'frostskada': ('frostskada',),
'frostskadd': ('frostskadd',),
'frostskadde': ('frostskadd',),
'frostskaddere': ('frostskadd',),
'frostskaddest': ('frostskadd',),
'frostskaddeste': ('frostskadd',),
'frostskadede': ('frostskadet',),
'frostskadet': ('frostskadet',),
'frostskadete': ('frostskadet',),
'frostskadetere': ('frostskadet',),
'frostskadetest': ('frostskadet',),
'frostskadeteste': ('frostskadet',),
'frotterende': ('frottere',),
'frottert': ('frottere',),
'frotterte': ('frottere',),
'frugal': ('frugal',),
'frugale': ('frugal',),
'frugalere': ('frugal',),
'frugalest': ('frugal',),
'frugaleste': ('frugal',),
'frugalt': ('frugal',),
'fruktbar': ('fruktbar',),
'fruktbare': ('fruktbar',),
'fruktbarere': ('fruktbar',),
'fruktbarest': ('fruktbar',),
'fruktbareste': ('fruktbar',),
'fruktbart': ('fruktbar',),
'fruktbringende': ('fruktbringende',),
'frukta': ('frukte',),
'fruktede': ('frukte',),
'fruktende': ('frukte',),
'fruktet': ('frukte',),
'fruktete': ('frukte',),
'fruktesløs': ('fruktesløs',),
'fruktesløse': ('fruktesløs',),
'fruktesløsere': ('fruktesløs',),
'fruktesløsest': ('fruktesløs',),
'fruktesløseste': ('fruktesløs',),
'fruktesløst': ('fruktesløs',),
'fruktsommelig': ('fruktsommelig',),
'fruktsommelige': ('fruktsommelig',),
'fruktsommeligere': ('fruktsommelig',),
'fruktsommeligst': ('fruktsommelig',),
'fruktsommeligste': ('fruktsommelig',),
'frustrerende': ('frustrere',),
'frustrert': ('frustrere',),
'frustrerte': ('frustrere',),
'fryda': ('fryde',),
'frydede': ('fryde',),
'frydende': ('fryde',),
'frydet': ('fryde',),
'frydete': ('fryde',),
'frydefull': ('frydefull',),
'frydefulle': ('frydefull',),
'frydefullere': ('frydefull',),
'frydefullest': ('frydefull',),
'frydefulleste': ('frydefull',),
'frydefullt': ('frydefull',),
'frygisk': ('frygisk',),
'frygiske': ('frygisk',),
'frygiskere': ('frygisk',),
'frygiskest': ('frygisk',),
'frygiskeste': ('frygisk',),
'fryktblanda': ('fryktblanda',),
'fryktblandede': ('fryktblandet',),
'fryktblandet': ('fryktblandet',),
'fryktblandete': ('fryktblandet',),
'fryktblandetere': ('fryktblandet',),
'fryktblandetest': ('fryktblandet',),
'fryktblandeteste': ('fryktblandet',),
'frykta': ('frykte',),
'fryktede': ('frykte',),
'fryktende': ('frykte',),
'fryktet': ('frykte',),
'fryktete': ('frykte',),
'fryktelig': ('fryktelig',),
'fryktelige': ('fryktelig',),
'frykteligere': ('fryktelig',),
'frykteligst': ('fryktelig',),
'frykteligste': ('fryktelig',),
'fryktinngytende': ('fryktinngytende',),
'fryktlaus': ('fryktlaus',),
'fryktlause': ('fryktlaus',),
'fryktlausere': ('fryktlaus',),
'fryktlausest': ('fryktlaus',),
'fryktlauseste': ('fryktlaus',),
'fryktlaust': ('fryktlaus',),
'fryktløs': ('fryktløs',),
'fryktløse': ('fryktløs',),
'fryktløsere': ('fryktløs',),
'fryktløsest': ('fryktløs',),
'fryktløseste': ('fryktløs',),
'fryktløst': ('fryktløs',),
'fryktsom': ('fryktsom',),
'fryktsomme': ('fryktsom',),
'fryktsommere': ('fryktsom',),
'fryktsomst': ('fryktsom',),
'fryktsomste': ('fryktsom',),
'fryktsomt': ('fryktsom',),
'frynsa': ('frynse',),
'frynsede': ('frynse',),
'frynsende': ('frynse',),
'frynset': ('frynse',),
'frynsete': ('frynse',),
'frynset': ('frynset',),
'frynsete': ('frynset',),
'frynsetere': ('frynset',),
'frynsetest': ('frynset',),
'frynseteste': ('frynset',),
'frynsete': ('frynsete',),
'fråda': ('fråde',),
'frådede': ('fråde',),
'frådende': ('fråde',),
'frådet': ('fråde',),
'frådete': ('fråde',),
'fråssa': ('fråsse',),
'fråssede': ('fråsse',),
'fråssende': ('fråsse',),
'fråsset': ('fråsse',),
'fråssete': ('fråsse',),
'fråtsa': ('fråtse',),
'fråtsede': ('fråtse',),
'fråtsende': ('fråtse',),
'fråtset': ('fråtse',),
'fråtsete': ('fråtse',),
'frødd': ('frø',),
'frødde': ('frø',),
'frøende': ('frø',),
'frøkenaktig': ('frøkenaktig',),
'frøkenaktige': ('frøkenaktig',),
'frøkenaktigere': ('frøkenaktig',),
'frøkenaktigst': ('frøkenaktig',),
'frøkenaktigste': ('frøkenaktig',),
'frøsende': ('frøse',),
'frøst': ('frøse',),
'frøste': ('frøse',),
'frøsen': ('frøsen',),
'frøsent': ('frøsen',),
'frøsne': ('frøsen',),
'frøsnere': ('frøsen',),
'frøsnest': ('frøsen',),
'frøsneste': ('frøsen',),
'fuga': ('fuge',),
'fugede': ('fuge',),
'fugende': ('fuge',),
'fuget': ('fuge',),
'fugete': ('fuge',),
'fuktbestandig': ('fuktbestandig',),
'fuktbestandige': ('fuktbestandig',),
'fuktbestandigere': ('fuktbestandig',),
'fuktbestandigst': ('fuktbestandig',),
'fuktbestandigste': ('fuktbestandig',),
'fukta': ('fukte',),
'fuktede': ('fukte',),
'fuktende': ('fukte',),
'fuktet': ('fukte',),
'fuktete': ('fukte',),
'fuktig': ('fuktig',),
'fuktige': ('fuktig',),
'fuktigere': ('fuktig',),
'fuktigst': ('fuktig',),
'fuktigste': ('fuktig',),
'ful': ('ful',),
'fule': ('ful',),
'fulere': ('ful',),
'fulest': ('ful',),
'fuleste': ('ful',),
'fult': ('ful',),
'full': ('full',),
'fulle': ('full',),
'fullere': ('full',),
'fullest': ('full',),
'fulleste': ('full',),
'fullt': ('full',),
'full-lasta': ('full-lasta',),
'full-lastede': ('full-lastet',),
'full-lastet': ('full-lastet',),
'full-lastete': ('full-lastet',),
'full-lastetere': ('full-lastet',),
'full-lastetest': ('full-lastet',),
'full-lasteteste': ('full-lastet',),
'fullasta': ('fullasta',),
'fullastede': ('fullastet',),
'fullastet': ('fullastet',),
'fullastete': ('fullastet',),
'fullastetere': ('fullastet',),
'fullastetest': ('fullastet',),
'fullasteteste': ('fullastet',),
'fullbefaren': ('fullbefaren',),
'fullbefarent': ('fullbefaren',),
'fullbefarne': ('fullbefaren',),
'fullbefarnere': ('fullbefaren',),
'fullbefarnest': ('fullbefaren',),
'fullbefarneste': ('fullbefaren',),
'fullblods': ('fullblods',),
'fullbragt': ('fullbringe',),
'fullbragte': ('fullbringe',),
'fullbrakt': ('fullbringe',),
'fullbrakte': ('fullbringe',),
'fullbringende': ('fullbringe',),
'fullbyrda': ('fullbyrde',),
'fullbyrdede': ('fullbyrde',),
'fullbyrdende': ('fullbyrde',),
'fullbyrdet': ('fullbyrde',),
'fullbyrdete': ('fullbyrde',),
'fullbåren': ('fullbåren',),
'fullbårent': ('fullbåren',),
'fullbårne': ('fullbåren',),
'fullbårnere': ('fullbåren',),
'fullbårnest': ('fullbåren',),
'fullbårneste': ('fullbåren',),
'fullendende': ('fullende',),
'fullendt': ('fullende',),
'fullendte': ('fullende',),
'fullendt': ('fullendt',),
'fullendte': ('fullendt',),
'fullendtere': ('fullendt',),
'fullendtest': ('fullendt',),
'fullendteste': ('fullendt',),
'fullførende': ('fullføre',),
'fullført': ('fullføre',),
'fullførte': ('fullføre',),
'fullbedre': ('fullgod',),
'fullbest': ('fullgod',),
'fullbeste': ('fullgod',),
'fullgod': ('fullgod',),
'fullgode': ('fullgod',),
'fullgodt': ('fullgod',),
'fullkommen': ('fullkommen',),
'fullkomment': ('fullkommen',),
'fullkomne': ('fullkommen',),
'fullkomnere': ('fullkommen',),
'fullkomnest': ('fullkommen',),
'fullkomneste': ('fullkommen',),
'fullmoden': ('fullmoden',),
'fullmodent': ('fullmoden',),
'fullmodne': ('fullmoden',),
'fullmodnere': ('fullmoden',),
'fullmodnest': ('fullmoden',),
'fullmodneste': ('fullmoden',),
'fullpakka': ('fullpakka',),
'fullpakkede': ('fullpakket',),
'fullpakket': ('fullpakket',),
'fullpakkete': ('fullpakket',),
'fullpakketere': ('fullpakket',),
'fullpakketest': ('fullpakket',),
'fullpakketeste': ('fullpakket',),
'fullrigga': ('fullrigga',),
'fullriggede': ('fullrigget',),
'fullrigget': ('fullrigget',),
'fullriggete': ('fullrigget',),
'fullriggetere': ('fullrigget',),
'fullriggetest': ('fullrigget',),
'fullriggeteste': ('fullrigget',),
'fullrosende': ('fullrose',),
'fullrost': ('fullrose',),
'fullroste': ('fullrose',),
'fullsatt': ('fullsatt',),
'fullsatte': ('fullsatt',),
'fullsattere': ('fullsatt',),
'fullsattest': ('fullsatt',),
'fullsatteste': ('fullsatt',),
'fullstappa': ('fullstappa',),
'fullstappede': ('fullstappet',),
'fullstappet': ('fullstappet',),
'fullstappete': ('fullstappet',),
'fullstappetere': ('fullstappet',),
'fullstappetest': ('fullstappet',),
'fullstappeteste': ('fullstappet',),
'fullstendig': ('fullstendig',),
'fullstendige': ('fullstendig',),
'fullstendigere': ('fullstendig',),
'fullstendigst': ('fullstendig',),
'fullstendigste': ('fullstendig',),
'fulltakka': ('fulltakke',),
'fulltakkede': ('fulltakke',),
'fulltakkende': ('fulltakke',),
'fulltakket': ('fulltakke',),
'fulltakkete': ('fulltakke',),
'fulltallig': ('fulltallig',),
'fulltallige': ('fulltallig',),
'fulltalligere': ('fulltallig',),
'fulltalligst': ('fulltallig',),
'fulltalligste': ('fulltallig',),
'fulltegna': ('fulltegna',),
'fulltegnede': ('fulltegnet',),
'fulltegnet': ('fulltegnet',),
'fulltegnete': ('fulltegnet',),
'fulltegnetere': ('fulltegnet',),
'fulltegnetest': ('fulltegnet',),
'fulltegneteste': ('fulltegnet',),
'fulltonende': ('fulltonende',),
'fullverdig': ('fullverdig',),
'fullverdige': ('fullverdig',),
'fullverdigere': ('fullverdig',),
'fullverdigst': ('fullverdig',),
'fullverdigste': ('fullverdig',),
'fullvoksen': ('fullvoksen',),
'fullvoksent': ('fullvoksen',),
'fullvoksne': ('fullvoksen',),
'fullvoksnere': ('fullvoksen',),
'fullvoksnest': ('fullvoksen',),
'fullvoksneste': ('fullvoksen',),
'fundamental': ('fundamental',),
'fundamentale': ('fundamental',),
'fundamentalere': ('fundamental',),
'fundamentalest': ('fundamental',),
'fundamentaleste': ('fundamental',),
'fundamentalt': ('fundamental',),
'fundamentalistisk': ('fundamentalistisk',),
'fundamentalistiske': ('fundamentalistisk',),
'fundamentalistiskere': ('fundamentalistisk',),
'fundamentalistiskest': ('fundamentalistisk',),
'fundamentalistiskeste': ('fundamentalistisk',),
'fundamenterende': ('fundamentere',),
'fundamentert': ('fundamentere',),
'fundamenterte': ('fundamentere',),
'funderende': ('fundere',),
'fundert': ('fundere',),
'funderte': ('fundere',),
'fungerende': ('fungere',),
'fungert': ('fungere',),
'fungerte': ('fungere',),
'funkla': ('funkle',),
'funklede': ('funkle',),
'funklende': ('funkle',),
'funklet': ('funkle',),
'funklete': ('funkle',),
'funksjonalistisk': ('funksjonalistisk',),
'funksjonalistiske': ('funksjonalistisk',),
'funksjonalistiskere': ('funksjonalistisk',),
'funksjonalistiskest': ('funksjonalistisk',),
'funksjonalistiskeste': ('funksjonalistisk',),
'funksjonell': ('funksjonell',),
'funksjonelle': ('funksjonell',),
'funksjonellere': ('funksjonell',),
'funksjonellest': ('funksjonell',),
'funksjonelleste': ('funksjonell',),
'funksjonelt': ('funksjonell',),
'funksjonerende': ('funksjonere',),
'funksjonert': ('funksjonere',),
'funksjonerte': ('funksjonere',),
'funksjonsdyktig': ('funksjonsdyktig',),
'funksjonsdyktige': ('funksjonsdyktig',),
'funksjonsdyktigere': ('funksjonsdyktig',),
'funksjonsdyktigst': ('funksjonsdyktig',),
'funksjonsdyktigste': ('funksjonsdyktig',),
'funksjonshemma': ('funksjonshemma',),
'funksjonshemmede': ('funksjonshemmet',),
'funksjonshemmet': ('funksjonshemmet',),
'funksjonshemmete': ('funksjonshemmet',),
'funksjonshemmetere': ('funksjonshemmet',),
'funksjonshemmetest': ('funksjonshemmet',),
'funksjonshemmeteste': ('funksjonshemmet',),
'funksjonsriktig': ('funksjonsriktig',),
'funksjonsriktige': ('funksjonsriktig',),
'funksjonsriktigere': ('funksjonsriktig',),
'funksjonsriktigst': ('funksjonsriktig',),
'funksjonsriktigste': ('funksjonsriktig',),
'furasjerende': ('furasjere',),
'furasjert': ('furasjere',),
'furasjerte': ('furasjere',),
'fura': ('fure',),
'furede': ('fure',),
'furende': ('fure',),
'furet': ('fure',),
'furete': ('fure',),
'furt': ('fure',),
'furte': ('fure',),
'furet': ('furet',),
'furete': ('furet',),
'furetere': ('furet',),
'furetest': ('furet',),
'fureteste': ('furet',),
'furete': ('furete',),
'furnerende': ('furnere',),
'furnert': ('furnere',),
'furnerte': ('furnere',),
'furta': ('furte',),
'furtede': ('furte',),
'furtende': ('furte',),
'furtet': ('furte',),
'furtete': ('furte',),
'furten': ('furten',),
'furtent': ('furten',),
'furtne': ('furten',),
'furtnere': ('furten',),
'furtnest': ('furten',),
'furtneste': ('furten',),
'fus': ('fus',),
'fuse': ('fus',),
'fusere': ('fus',),
'fusest': ('fus',),
'fuseste': ('fus',),
'fust': ('fus',),
'fusende': ('fuse',),
'fust': ('fuse',),
'fuste': ('fuse',),
'fusjonerende': ('fusjonere',),
'fusjonert': ('fusjonere',),
'fusjonerte': ('fusjonere',),
'fuska': ('fuske',),
'fuskede': ('fuske',),
'fuskende': ('fuske',),
'fusket': ('fuske',),
'fuskete': ('fuske',),
'futil': ('futil',),
'futile': ('futil',),
'futilere': ('futil',),
'futilest': ('futil',),
'futileste': ('futil',),
'futilt': ('futil',),
'futta': ('futte',),
'futtede': ('futte',),
'futtende': ('futte',),
'futtet': ('futte',),
'futtete': ('futte',),
'futurisk': ('futurisk',),
'futuriske': ('futurisk',),
'futuriskere': ('futurisk',),
'futuriskest': ('futurisk',),
'futuriskeste': ('futurisk',),
'futuristisk': ('futuristisk',),
'futuristiske': ('futuristisk',),
'futuristiskere': ('futuristisk',),
'futuristiskest': ('futuristisk',),
'futuristiskeste': ('futuristisk',),
'fykende': ('fyke',),
'føken': ('fyke',),
'føket': ('fyke',),
'føkne': ('fyke',),
'fykende': ('fykende',),
'fyldig': ('fyldig',),
'fyldige': ('fyldig',),
'fyldigere': ('fyldig',),
'fyldigst': ('fyldig',),
'fyldigste': ('fyldig',),
'fylka': ('fylke',),
'fylkede': ('fylke',),
'fylkende': ('fylke',),
'fylket': ('fylke',),
'fylkete': ('fylke',),
'fylkt': ('fylke',),
'fylkte': ('fylke',),
'fylkeskommunal': ('fylkeskommunal',),
'fylkeskommunale': ('fylkeskommunal',),
'fylkeskommunalere': ('fylkeskommunal',),
'fylkeskommunalest': ('fylkeskommunal',),
'fylkeskommunaleste': ('fylkeskommunal',),
'fylkeskommunalt': ('fylkeskommunal',),
'fylla': ('fylle',),
'fyllede': ('fylle',),
'fyllende': ('fylle',),
'fyllet': ('fylle',),
'fyllete': ('fylle',),
'fyllende': ('fylle',),
'fylt': ('fylle',),
'fylte': ('fylle',),
'fyllekjørende': ('fyllekjøre',),
'fyllekjørt': ('fyllekjøre',),
'fyllekjørte': ('fyllekjøre',),
'fyllesjuk': ('fyllesjuk',),
'fyllesjuke': ('fyllesjuk',),
'fyllesjukere': ('fyllesjuk',),
'fyllesjukest': ('fyllesjuk',),
'fyllesjukeste': ('fyllesjuk',),
'fyllesjukt': ('fyllesjuk',),
'fyllestgjørende': ('fyllestgjørende',),
'fyllesyk': ('fyllesyk',),
'fyllesyke': ('fyllesyk',),
'fyllesykere': ('fyllesyk',),
'fyllesykest': ('fyllesyk',),
'fyllesykeste': ('fyllesyk',),
'fyllesykt': ('fyllesyk',),
'fyndig': ('fyndig',),
'fyndige': ('fyndig',),
'fyndigere': ('fyndig',),
'fyndigst': ('fyndig',),
'fyndigste': ('fyndig',),
'fyrende': ('fyre',),
'fyrt': ('fyre',),
'fyrte': ('fyre',),
'fyrig': ('fyrig',),
'fyrige': ('fyrig',),
'fyrigere': ('fyrig',),
'fyrigst': ('fyrig',),
'fyrigste': ('fyrig',),
'fyrstelig': ('fyrstelig',),
'fyrstelige': ('fyrstelig',),
'fyrsteligere': ('fyrstelig',),
'fyrsteligst': ('fyrstelig',),
'fyrsteligste': ('fyrstelig',),
'fysende': ('fyse',),
'fyst': ('fyse',),
'fyste': ('fyse',),
'fysen': ('fysen',),
'fysent': ('fysen',),
'fysne': ('fysen',),
'fysnere': ('fysen',),
'fysnest': ('fysen',),
'fysneste': ('fysen',),
'fysikalsk': ('fysikalsk',),
'fysikalske': ('fysikalsk',),
'fysikalskere': ('fysikalsk',),
'fysikalskest': ('fysikalsk',),
'fysikalskeste': ('fysikalsk',),
'fysiologisk': ('fysiologisk',),
'fysiologiske': ('fysiologisk',),
'fysiologiskere': ('fysiologisk',),
'fysiologiskest': ('fysiologisk',),
'fysiologiskeste': ('fysiologisk',),
'fysisk': ('fysisk',),
'fysiske': ('fysisk',),
'fysiskere': ('fysisk',),
'fysiskest': ('fysisk',),
'fysiskeste': ('fysisk',),
'fående': ('få',),
'fått': ('få',),
'fåtte': ('få',),
'få': ('få',),
'færre': ('få',),
'færrest': ('få',),
'færreste': ('få',),
'fåfengt': ('fåfengt',),
'fåfengte': ('fåfengt',),
'fåfengtere': ('fåfengt',),
'fåfengtest': ('fåfengt',),
'fåfengteste': ('fåfengt',),
'fåkunnig': ('fåkunnig',),
'fåkunnige': ('fåkunnig',),
'fåkunnigere': ('fåkunnig',),
'fåkunnigst': ('fåkunnig',),
'fåkunnigste': ('fåkunnig',),
'fåment': ('fåment',),
'fåmente': ('fåment',),
'fåmentere': ('fåment',),
'fåmentest': ('fåment',),
'fåmenteste': ('fåment',),
'fåmælt': ('fåmælt',),
'fåmælte': ('fåmælt',),
'fåmæltere': ('fåmælt',),
'fåmæltest': ('fåmælt',),
'fåmælteste': ('fåmælt',),
'fånyttes': ('fånyttes',),
'fåret': ('fåret',),
'fårete': ('fåret',),
'fåretere': ('fåret',),
'fåretest': ('fåret',),
'fåreteste': ('fåret',),
'fårete': ('fårete',),
'fåtallig': ('fåtallig',),
'fåtallige': ('fåtallig',),
'fåtalligere': ('fåtallig',),
'fåtalligst': ('fåtallig',),
'fåtalligste': ('fåtallig',),
'fåtenkt': ('fåtenkt',),
'fåtenkte': ('fåtenkt',),
'fåtenktere': ('fåtenkt',),
'fåtenktest': ('fåtenkt',),
'fåtenkteste': ('fåtenkt',),
'fæl': ('fæl',),
'fæle': ('fæl',),
'fælere': ('fæl',),
'fælest': ('fæl',),
'fæleste': ('fæl',),
'fælt': ('fæl',),
'fælende': ('fæle',),
'fælt': ('fæle',),
'fælte': ('fæle',),
'fælen': ('fælen',),
'fælent': ('fælen',),
'fælne': ('fælen',),
'fælnere': ('fælen',),
'fælnest': ('fælen',),
'fælneste': ('fælen',),
'færre': ('færre',),
'færrest': ('færrest',),
'færreste': ('færrest',),
'færøysk': ('færøysk',),
'færøyske': ('færøysk',),
'færøyskere': ('færøysk',),
'færøyskest': ('færøysk',),
'færøyskeste': ('færøysk',),
'fødd': ('fø',),
'fødde': ('fø',),
'føende': ('fø',),
'fødd': ('føde',),
'fødde': ('føde',),
'fødende': ('føde',),
'født': ('føde',),
'fødte': ('føde',),
'fødd': ('føde',),
'fødde': ('føde',),
'fødende': ('føde',),
'født': ('føde',),
'fødte': ('føde',),
'føderal': ('føderal',),
'føderale': ('føderal',),
'føderalere': ('føderal',),
'føderalest': ('føderal',),
'føderaleste': ('føderal',),
'føderalt': ('føderal',),
'føderativ': ('føderativ',),
'føderative': ('føderativ',),
'føderativere': ('føderativ',),
'føderativest': ('føderativ',),
'føderativeste': ('føderativ',),
'føderativt': ('føderativ',),
'følbar': ('følbar',),
'følbare': ('følbar',),
'følbarere': ('følbar',),
'følbarest': ('følbar',),
'følbareste': ('følbar',),
'følbart': ('følbar',),
'følende': ('føle',),
'følt': ('føle',),
'følte': ('føle',),
'følelig': ('følelig',),
'følelige': ('følelig',),
'føleligere': ('følelig',),
'føleligst': ('følelig',),
'føleligste': ('følelig',),
'følelsesbetona': ('følelsesbetona',),
'følelsesbetonede': ('følelsesbetonet',),
'følelsesbetonet': ('følelsesbetonet',),
'følelsesbetonete': ('følelsesbetonet',),
'følelsesbetonetere': ('følelsesbetonet',),
'følelsesbetonetest': ('følelsesbetonet',),
'følelsesbetoneteste': ('følelsesbetonet',),
'følelsesbetont': ('følelsesbetont',),
'følelsesbetonte': ('følelsesbetont',),
'følelsesbetontere': ('følelsesbetont',),
'følelsesbetontest': ('følelsesbetont',),
'følelsesbetonteste': ('følelsesbetont',),
'følelsesfull': ('følelsesfull',),
'følelsesfulle': ('følelsesfull',),
'følelsesfullere': ('følelsesfull',),
'følelsesfullest': ('følelsesfull',),
'følelsesfulleste': ('følelsesfull',),
'følelsesfullt': ('følelsesfull',),
'følelseskald': ('følelseskald',),
'følelseskalde': ('følelseskald',),
'følelseskaldere': ('følelseskald',),
'følelseskaldest': ('følelseskald',),
'følelseskaldeste': ('følelseskald',),
'følelseskaldt': ('følelseskald',),
'følelseslada': ('følelseslada',),
'følelsesladd': ('følelsesladd',),
'følelsesladde': ('følelsesladd',),
'følelsesladdere': ('følelsesladd',),
'følelsesladdest': ('følelsesladd',),
'følelsesladdeste': ('følelsesladd',),
'følelsesladede': ('følelsesladet',),
'følelsesladet': ('følelsesladet',),
'følelsesladete': ('følelsesladet',),
'følelsesladetere': ('følelsesladet',),
'følelsesladetest': ('følelsesladet',),
'følelsesladeteste': ('følelsesladet',),
'følelseslaus': ('følelseslaus',),
'følelseslause': ('følelseslaus',),
'følelseslausere': ('følelseslaus',),
'følelseslausest': ('følelseslaus',),
'følelseslauseste': ('følelseslaus',),
'følelseslaust': ('følelseslaus',),
'følelsesløs': ('følelsesløs',),
'følelsesløse': ('følelsesløs',),
'følelsesløsere': ('følelsesløs',),
'følelsesløsest': ('følelsesløs',),
'følelsesløseste': ('følelsesløs',),
'følelsesløst': ('følelsesløs',),
'følelsesmessig': ('følelsesmessig',),
'følelsesmessige': ('følelsesmessig',),
'følelsesmessigere': ('følelsesmessig',),
'følelsesmessigst': ('følelsesmessig',),
'følelsesmessigste': ('følelsesmessig',),
'følgende': ('følgende',),
'følgeriktig': ('følgeriktig',),
'følgeriktige': ('følgeriktig',),
'følgeriktigere': ('følgeriktig',),
'følgeriktigst': ('følgeriktig',),
'følgeriktigste': ('følgeriktig',),
'følgende': ('følgje',),
'følgt': ('følgje',),
'følgte': ('følgje',),
'følgende': ('følgje',),
'følgt': ('følgje',),
'følgte': ('følgje',),
'følla': ('følle',),
'føllede': ('følle',),
'føllende': ('følle',),
'føllet': ('følle',),
'føllete': ('følle',),
'følsom': ('følsom',),
'følsomme': ('følsom',),
'følsommere': ('følsom',),
'følsomst': ('følsom',),
'følsomste': ('følsom',),
'følsomt': ('følsom',),
'føna': ('føne',),
'fønede': ('føne',),
'fønende': ('føne',),
'fønet': ('føne',),
'fønete': ('føne',),
'fønt': ('føne',),
'fønte': ('føne',),
'før': ('før',),
'føre': ('før',),
'førere': ('før',),
'førest': ('før',),
'føreste': ('før',),
'ført': ('før',),
'førende': ('føre',),
'ført': ('føre',),
'førte': ('føre',),
'førebels': ('førebels',),
'førebudd': ('førebu',),
'førebudde': ('førebu',),
'førebuende': ('førebu',),
'førekteskapelig': ('førekteskapelig',),
'førekteskapelige': ('førekteskapelig',),
'førekteskapeligere': ('førekteskapelig',),
'førekteskapeligst': ('førekteskapelig',),
'førekteskapeligste': ('førekteskapelig',),
'førhistorisk': ('førhistorisk',),
'førhistoriske': ('førhistorisk',),
'førhistoriskere': ('førhistorisk',),
'førhistoriskest': ('førhistorisk',),
'førhistoriskeste': ('førhistorisk',),
'førkolumbisk': ('førkolumbisk',),
'førkolumbiske': ('førkolumbisk',),
'førkolumbiskere': ('førkolumbisk',),
'førkolumbiskest': ('førkolumbisk',),
'førkolumbiskeste': ('førkolumbisk',),
'førkrigs': ('førkrigs',),
'førlig': ('førlig',),
'førlige': ('førlig',),
'førligere': ('førlig',),
'førligst': ('førlig',),
'førligste': ('førlig',),
'førnevnt': ('førnevnt',),
'førnevnte': ('førnevnt',),
'førnevntere': ('førnevnt',),
'førnevntest': ('førnevnt',),
'førnevnteste': ('førnevnt',),
'første': ('første',),
'førstefødd': ('førstefødd',),
'førstefødde': ('førstefødd',),
'førsteføddere': ('førstefødd',),
'førsteføddest': ('førstefødd',),
'førsteføddeste': ('førstefødd',),
'førstefødt': ('førstefødt',),
'førstefødte': ('førstefødt',),
'førstefødtere': ('førstefødt',),
'førstefødtest': ('førstefødt',),
'førstefødteste': ('førstefødt',),
'førstegangsfødende': ('førstegangsfødende',),
'førstehands': ('førstehands',),
'førstehånds': ('førstehånds',),
'førsteklasses': ('førsteklasses',),
'førsterangs': ('førsterangs',),
'førstkommende': ('førstkommende',),
'førstnevnt': ('førstnevnt',),
'førstnevnte': ('førstnevnt',),
'førstnevntere': ('førstnevnt',),
'førstnevntest': ('førstnevnt',),
'førstnevnteste': ('førstnevnt',),
'førtidspensjonerende': ('førtidspensjonere',),
'førtidspensjonert': ('førtidspensjonere',),
'førtidspensjonerte': ('førtidspensjonere',),
'førtiende': ('førtiende',),
'føydal': ('føydal',),
'føydale': ('føydal',),
'føydalere': ('føydal',),
'føydalest': ('føydal',),
'føydaleste': ('føydal',),
'føydalt': ('føydal',),
'føya': ('føye',),
'føyd': ('føye',),
'føydd': ('føye',),
'føydde': ('føye',),
'føyde': ('føye',),
'føyede': ('føye',),
'føyende': ('føye',),
'føyet': ('føye',),
'føyete': ('føye',),
'føyelig': ('føyelig',),
'føyelige': ('føyelig',),
'føyeligere': ('føyelig',),
'føyeligst': ('føyelig',),
'føyeligste': ('føyelig',),
'føyka': ('føyke',),
'føykede': ('føyke',),
'føykende': ('føyke',),
'føyket': ('føyke',),
'føykete': ('føyke',),
'føykt': ('føyke',),
'føykte': ('føyke',),
'føysende': ('føyse',),
'føyst': ('føyse',),
'føyste': ('føyse',),
'gabonsk': ('gabonsk',),
'gabonske': ('gabonsk',),
'gabonskere': ('gabonsk',),
'gabonskest': ('gabonsk',),
'gabonskeste': ('gabonsk',),
'gaffelforma': ('gaffelforma',),
'gaffelformede': ('gaffelformet',),
'gaffelformet': ('gaffelformet',),
'gaffelformete': ('gaffelformet',),
'gaffelformetere': ('gaffelformet',),
'gaffelformetest': ('gaffelformet',),
'gaffelformeteste': ('gaffelformet',),
'gafla': ('gafle',),
'gaflede': ('gafle',),
'gaflende': ('gafle',),
'gaflet': ('gafle',),
'gaflete': ('gafle',),
'gagna': ('gagne',),
'gagnede': ('gagne',),
'gagnende': ('gagne',),
'gagnet': ('gagne',),
'gagnete': ('gagne',),
'gagnlaus': ('gagnlaus',),
'gagnlause': ('gagnlaus',),
'gagnlausere': ('gagnlaus',),
'gagnlausest': ('gagnlaus',),
'gagnlauseste': ('gagnlaus',),
'gagnlaust': ('gagnlaus',),
'gagnlig': ('gagnlig',),
'gagnlige': ('gagnlig',),
'gagnligere': ('gagnlig',),
'gagnligst': ('gagnlig',),
'gagnligste': ('gagnlig',),
'gagnløs': ('gagnløs',),
'gagnløse': ('gagnløs',),
'gagnløsere': ('gagnløs',),
'gagnløsest': ('gagnløs',),
'gagnløseste': ('gagnløs',),
'gagnløst': ('gagnløs',),
'gagns': ('gagns',),
'gakka': ('gakke',),
'gakkede': ('gakke',),
'gakkende': ('gakke',),
'gakket': ('gakke',),
'gakkete': ('gakke',),
'gal': ('gal',),
'gale': ('gal',),
'galere': ('gal',),
'galest': ('gal',),
'galeste': ('gal',),
'galt': ('gal',),
'galaktisk': ('galaktisk',),
'galaktiske': ('galaktisk',),
'galaktiskere': ('galaktisk',),
'galaktiskest': ('galaktisk',),
'galaktiskeste': ('galaktisk',),
'galant': ('galant',),
'galante': ('galant',),
'galantere': ('galant',),
'galantest': ('galant',),
'galanteste': ('galant',),
'galdra': ('galdre',),
'galdrede': ('galdre',),
'galdrende': ('galdre',),
'galdret': ('galdre',),
'galdrete': ('galdre',),
'galende': ('gale',),
'galt': ('gale',),
'galte': ('gale',),
'galen': ('galen',),
'galent': ('galen',),
'galne': ('galen',),
'galnere': ('galen',),
'galnest': ('galen',),
'galneste': ('galen',),
'galgenhumoristisk': ('galgenhumoristisk',),
'galgenhumoristiske': ('galgenhumoristisk',),
'galgenhumoristiskere': ('galgenhumoristisk',),
'galgenhumoristiskest': ('galgenhumoristisk',),
'galgenhumoristiskeste': ('galgenhumoristisk',),
'galileisk': ('galileisk',),
'galileiske': ('galileisk',),
'galileiskere': ('galileisk',),
'galileiskest': ('galileisk',),
'galileiskeste': ('galileisk',),
'galileisk': ('galileisk',),
'galileiske': ('galileisk',),
'galileiskere': ('galileisk',),
'galileiskest': ('galileisk',),
'galileiskeste': ('galileisk',),
'gallegrøn': ('gallegrøn',),
'gallegrøne': ('gallegrøn',),
'gallegrønere': ('gallegrøn',),
'gallegrønest': ('gallegrøn',),
'gallegrøneste': ('gallegrøn',),
'gallegrønt': ('gallegrøn',),
'gallegrønn': ('gallegrønn',),
'gallegrønne': ('gallegrønn',),
'gallegrønnere': ('gallegrønn',),
'gallegrønnest': ('gallegrønn',),
'gallegrønneste': ('gallegrønn',),
'gallegrønt': ('gallegrønn',),
'gallisk': ('gallisk',),
'galliske': ('gallisk',),
'galliskere': ('gallisk',),
'galliskest': ('gallisk',),
'galliskeste': ('gallisk',),
'galopperende': ('galoppere',),
'galoppert': ('galoppere',),
'galopperte': ('galoppere',),
'galvaniserende': ('galvanisere',),
'galvanisert': ('galvanisere',),
'galvaniserte': ('galvanisere',),
'galvanisk': ('galvanisk',),
'galvaniske': ('galvanisk',),
'galvaniskere': ('galvanisk',),
'galvaniskest': ('galvanisk',),
'galvaniskeste': ('galvanisk',),
'gambisk': ('gambisk',),
'gambiske': ('gambisk',),
'gambiskere': ('gambisk',),
'gambiskest': ('gambisk',),
'gambiskeste': ('gambisk',),
'gambla': ('gamble',),
'gamblede': ('gamble',),
'gamblende': ('gamble',),
'gamblet': ('gamble',),
'gamblete': ('gamble',),
'game': ('game',),
'eldre': ('gammal',),
'eldst': ('gammal',),
'eldste': ('gammal',),
'gamle': ('gammal',),
'gammal': ('gammal',),
'gammalt': ('gammal',),
'gammaldansk': ('gammaldansk',),
'gammaldanske': ('gammaldansk',),
'gammaldanskere': ('gammaldansk',),
'gammaldanskest': ('gammaldansk',),
'gammaldanskeste': ('gammaldansk',),
'gammalkjent': ('gammalkjent',),
'gammalkjente': ('gammalkjent',),
'gammalkjentere': ('gammalkjent',),
'gammalkjentest': ('gammalkjent',),
'gammalkjenteste': ('gammalkjent',),
'gammalmannsaktig': ('gammalmannsaktig',),
'gammalmannsaktige': ('gammalmannsaktig',),
'gammalmannsaktigere': ('gammalmannsaktig',),
'gammalmannsaktigst': ('gammalmannsaktig',),
'gammalmannsaktigste': ('gammalmannsaktig',),
'gammalmodig': ('gammalmodig',),
'gammalmodige': ('gammalmodig',),
'gammalmodigere': ('gammalmodig',),
'gammalmodigst': ('gammalmodig',),
'gammalmodigste': ('gammalmodig',),
'gammalnorsk': ('gammalnorsk',),
'gammalnorske': ('gammalnorsk',),
'gammalnorskere': ('gammalnorsk',),
'gammalnorskest': ('gammalnorsk',),
'gammalnorskeste': ('gammalnorsk',),
'gammalrosa': ('gammalrosa',),
'gammaltestamentlig': ('gammaltestamentlig',),
'gammaltestamentlige': ('gammaltestamentlig',),
'gammaltestamentligere': ('gammaltestamentlig',),
'gammaltestamentligst': ('gammaltestamentlig',),
'gammaltestamentligste': ('gammaltestamentlig',),
'gammalvoren': ('gammalvoren',),
'gammalvorent': ('gammalvoren',),
'gammalvorne': ('gammalvoren',),
'gammalvornere': ('gammalvoren',),
'gammalvornest': ('gammalvoren',),
'gammalvorneste': ('gammalvoren',),
'eldre': ('gammel',),
'eldst': ('gammel',),
'eldste': ('gammel',),
'gamle': ('gammel',),
'gammel': ('gammel',),
'gammelt': ('gammel',),
'gammeldansk': ('gammeldansk',),
'gammeldanske': ('gammeldansk',),
'gammeldanskere': ('gammeldansk',),
'gammeldanskest': ('gammeldansk',),
'gammeldanskeste': ('gammeldansk',),
'gammelkjent': ('gammelkjent',),
'gammelkjente': ('gammelkjent',),
'gammelkjentere': ('gammelkjent',),
'gammelkjentest': ('gammelkjent',),
'gammelkjenteste': ('gammelkjent',),
'gammelmannsaktig': ('gammelmannsaktig',),
'gammelmannsaktige': ('gammelmannsaktig',),
'gammelmannsaktigere': ('gammelmannsaktig',),
'gammelmannsaktigst': ('gammelmannsaktig',),
'gammelmannsaktigste': ('gammelmannsaktig',),
'gammelmodig': ('gammelmodig',),
'gammelmodige': ('gammelmodig',),
'gammelmodigere': ('gammelmodig',),
'gammelmodigst': ('gammelmodig',),
'gammelmodigste': ('gammelmodig',),
'gammelnorsk': ('gammelnorsk',),
'gammelnorske': ('gammelnorsk',),
'gammelnorskere': ('gammelnorsk',),
'gammelnorskest': ('gammelnorsk',),
'gammelnorskeste': ('gammelnorsk',),
'gammelrosa': ('gammelrosa',),
'gammeltestamentlig': ('gammeltestamentlig',),
'gammeltestamentlige': ('gammeltestamentlig',),
'gammeltestamentligere': ('gammeltestamentlig',),
'gammeltestamentligst': ('gammeltestamentlig',),
'gammeltestamentligste': ('gammeltestamentlig',),
'gammelvoren': ('gammelvoren',),
'gammelvorent': ('gammelvoren',),
'gammelvorne': ('gammelvoren',),
'gammelvornere': ('gammelvoren',),
'gammelvornest': ('gammelvoren',),
'gammelvorneste': ('gammelvoren',),
'ganda': ('gande',),
'gandede': ('gande',),
'gandende': ('gande',),
'gandet': ('gande',),
'gandete': ('gande',),
'gana': ('gane',),
'ganede': ('gane',),
'ganende': ('gane',),
'ganet': ('gane',),
'ganete': ('gane',),
'gant': ('gane',),
'gante': ('gane',),
'gangbar': ('gangbar',),
'gangbare': ('gangbar',),
'gangbarere': ('gangbar',),
'gangbarest': ('gangbar',),
'gangbareste': ('gangbar',),
'gangbart': ('gangbar',),
'ganga': ('gange',),
'gangede': ('gange',),
'gangende': ('gange',),
'ganget': ('gange',),
'gangete': ('gange',),
'gangfør': ('gangfør',),
'gangføre': ('gangfør',),
'gangførere': ('gangfør',),
'gangførest': ('gangfør',),
'gangføreste': ('gangfør',),
'gangført': ('gangfør',),
'gangrenøs': ('gangrenøs',),
'gangrenøse': ('gangrenøs',),
'gangrenøsere': ('gangrenøs',),
'gangrenøsest': ('gangrenøs',),
'gangrenøseste': ('gangrenøs',),
'gangrenøst': ('gangrenøs',),
'gangsynt': ('gangsynt',),
'gangsynte': ('gangsynt',),
'gangsyntere': ('gangsynt',),
'gangsyntest': ('gangsynt',),
'gangsynteste': ('gangsynt',),
'ganta': ('gante',),
'gantede': ('gante',),
'gantende': ('gante',),
'gantet': ('gante',),
'gantete': ('gante',),
'gapa': ('gape',),
'gapende': ('gape',),
'gapt': ('gape',),
'gapte': ('gape',),
'gapen': ('gapen',),
'gapent': ('gapen',),
'gapne': ('gapen',),
'gapnere': ('gapen',),
'gapnest': ('gapen',),
'gapneste': ('gapen',),
'gapet': ('gapet',),
'gapete': ('gapet',),
'gapetere': ('gapet',),
'gapetest': ('gapet',),
'gapeteste': ('gapet',),
'gapete': ('gapete',),
'gapskratta': ('gapskratte',),
'gapskrattede': ('gapskratte',),
'gapskrattende': ('gapskratte',),
'gapskrattet': ('gapskratte',),
'gapskrattete': ('gapskratte',),
'garanterende': ('garantere',),
'garantert': ('garantere',),
'garanterte': ('garantere',),
'garderende': ('gardere',),
'gardert': ('gardere',),
'garderte': ('gardere',),
'garna': ('garne',),
'garnede': ('garne',),
'garnende': ('garne',),
'garnet': ('garne',),
'garnete': ('garne',),
'garnerende': ('garnere',),
'garnert': ('garnere',),
'garnerte': ('garnere',),
'garnisonerende': ('garnisonere',),
'garnisonert': ('garnisonere',),
'garnisonerte': ('garnisonere',),
'garpa': ('garpe',),
'garpede': ('garpe',),
'garpende': ('garpe',),
'garpet': ('garpe',),
'garpete': ('garpe',),
'garva': ('garva',),
'garva': ('garve',),
'garvede': ('garve',),
'garvende': ('garve',),
'garvet': ('garve',),
'garvete': ('garve',),
'garvede': ('garvet',),
'garvet': ('garvet',),
'garvete': ('garvet',),
'garvetere': ('garvet',),
'garvetest': ('garvet',),
'garveteste': ('garvet',),
'gasjerende': ('gasjere',),
'gasjert': ('gasjere',),
'gasjerte': ('gasjere',),
'gassa': ('gasse',),
'gassede': ('gasse',),
'gassende': ('gasse',),
'gasset': ('gasse',),
'gassete': ('gasse',),
'gassa': ('gasse',),
'gassede': ('gasse',),
'gassende': ('gasse',),
'gasset': ('gasse',),
'gassete': ('gasse',),
'gassformig': ('gassformig',),
'gassformige': ('gassformig',),
'gassformigere': ('gassformig',),
'gassformigst': ('gassformig',),
'gassformigste': ('gassformig',),
'gassisk': ('gassisk',),
'gassiske': ('gassisk',),
'gassiskere': ('gassisk',),
'gassiskest': ('gassisk',),
'gassiskeste': ('gassisk',),
'gasta': ('gasta',),
'gastrisk': ('gastrisk',),
'gastriske': ('gastrisk',),
'gastriskere': ('gastrisk',),
'gastriskest': ('gastrisk',),
'gastriskeste': ('gastrisk',),
'gastronomisk': ('gastronomisk',),
'gastronomiske': ('gastronomisk',),
'gastronomiskere': ('gastronomisk',),
'gastronomiskest': ('gastronomisk',),
'gastronomiskeste': ('gastronomisk',),
'gauka': ('gauke',),
'gaukede': ('gauke',),
'gaukende': ('gauke',),
'gauket': ('gauke',),
'gaukete': ('gauke',),
'gaula': ('gaule',),
'gaulede': ('gaule',),
'gaulende': ('gaule',),
'gaulet': ('gaule',),
'gaulete': ('gaule',),
'gault': ('gaule',),
'gaulte': ('gaule',),
'gauma': ('gaume',),
'gaumede': ('gaume',),
'gaumende': ('gaume',),
'gaumet': ('gaume',),
'gaumete': ('gaume',),
'gaussisk': ('gaussisk',),
'gaussiske': ('gaussisk',),
'gaussiskere': ('gaussisk',),
'gaussiskest': ('gaussisk',),
'gaussiskeste': ('gaussisk',),
'gaussk': ('gaussk',),
'gausske': ('gaussk',),
'gausskere': ('gaussk',),
'gausskest': ('gaussk',),
'gausskeste': ('gaussk',),
'gavmild': ('gavmild',),
'gavmilde': ('gavmild',),
'gavmildere': ('gavmild',),
'gavmildest': ('gavmild',),
'gavmildeste': ('gavmild',),
'gavmildt': ('gavmild',),
'geberda': ('geberde',),
'geberdede': ('geberde',),
'geberdende': ('geberde',),
'geberdet': ('geberde',),
'geberdete': ('geberde',),
'gebrekkelig': ('gebrekkelig',),
'gebrekkelige': ('gebrekkelig',),
'gebrekkeligere': ('gebrekkelig',),
'gebrekkeligst': ('gebrekkelig',),
'gebrekkeligste': ('gebrekkelig',),
'gebrokken': ('gebrokken',),
'gebrokkent': ('gebrokken',),
'gebrokne': ('gebrokken',),
'gebroknere': ('gebrokken',),
'gebroknest': ('gebrokken',),
'gebrokneste': ('gebrokken',),
'gedigen': ('gedigen',),
'gedigent': ('gedigen',),
'gedigne': ('gedigen',),
'gedignere': ('gedigen',),
'gedignest': ('gedigen',),
'gedigneste': ('gedigen',),
'geil': ('geil',),
'geile': ('geil',),
'geilere': ('geil',),
'geilest': ('geil',),
'geileste': ('geil',),
'geilt': ('geil',),
'geipa': ('geipe',),
'geipede': ('geipe',),
'geipende': ('geipe',),
'geipet': ('geipe',),
'geipete': ('geipe',),
'geipt': ('geipe',),
'geipte': ('geipe',),
'geipet': ('geipet',),
'geipete': ('geipet',),
'geipetere': ('geipet',),
'geipetest': ('geipet',),
'geipeteste': ('geipet',),
'geipete': ('geipete',),
'geistlig': ('geistlig',),
'geistlige': ('geistlig',),
'geistligere': ('geistlig',),
'geistligst': ('geistlig',),
'geistligste': ('geistlig',),
'geitet': ('geitet',),
'geitete': ('geitet',),
'geitetere': ('geitet',),
'geitetest': ('geitet',),
'geiteteste': ('geitet',),
'geitete': ('geitete',),
'geléaktig': ('geléaktig',),
'geléaktige': ('geléaktig',),
'geléaktigere': ('geléaktig',),
'geléaktigst': ('geléaktig',),
'geléaktigste': ('geléaktig',),
'geleida': ('geleide',),
'geleidede': ('geleide',),
'geleidende': ('geleide',),
'geleidet': ('geleide',),
'geleidete': ('geleide',),
'gemeinslig': ('gemeinslig',),
'gemeinslige': ('gemeinslig',),
'gemeinsligere': ('gemeinslig',),
'gemeinsligst': ('gemeinslig',),
'gemeinsligste': ('gemeinslig',),
'gemen': ('gemen',),
'gemene': ('gemen',),
'gemenere': ('gemen',),
'gemenest': ('gemen',),
'gemeneste': ('gemen',),
'gement': ('gemen',),
'gemenslig': ('gemenslig',),
'gemenslige': ('gemenslig',),
'gemensligere': ('gemenslig',),
'gemensligst': ('gemenslig',),
'gemensligste': ('gemenslig',),
'geminerende': ('geminere',),
'geminert': ('geminere',),
'geminerte': ('geminere',),
'gemyttlig': ('gemyttlig',),
'gemyttlige': ('gemyttlig',),
'gemyttligere': ('gemyttlig',),
'gemyttligst': ('gemyttlig',),
'gemyttligste': ('gemyttlig',),
'genealogisk': ('genealogisk',),
'genealogiske': ('genealogisk',),
'genealogiskere': ('genealogisk',),
'genealogiskest': ('genealogisk',),
'genealogiskeste': ('genealogisk',),
'generaliserende': ('generalisere',),
'generalisert': ('generalisere',),
'generaliserte': ('generalisere',),
'generalpreventiv': ('generalpreventiv',),
'generalpreventive': ('generalpreventiv',),
'generalpreventivere': ('generalpreventiv',),
'generalpreventivest': ('generalpreventiv',),
'generalpreventiveste': ('generalpreventiv',),
'generalpreventivt': ('generalpreventiv',),
'generativ': ('generativ',),
'generative': ('generativ',),
'generativere': ('generativ',),
'generativest': ('generativ',),
'generativeste': ('generativ',),
'generativt': ('generativ',),
'generell': ('generell',),
'generelle': ('generell',),
'generellere': ('generell',),
'generellest': ('generell',),
'generelleste': ('generell',),
'generelt': ('generell',),
'genererende': ('generere',),
'generert': ('generere',),
'genererte': ('generere',),
'generisk': ('generisk',),
'generiske': ('generisk',),
'generiskere': ('generisk',),
'generiskest': ('generisk',),
'generiskeste': ('generisk',),
'genetisk': ('genetisk',),
'genetiske': ('genetisk',),
'genetiskere': ('genetisk',),
'genetiskest': ('genetisk',),
'genetiskeste': ('genetisk',),
'genial': ('genial',),
'geniale': ('genial',),
'genialere': ('genial',),
'genialest': ('genial',),
'genialeste': ('genial',),
'genialt': ('genial',),
'genierklærende': ('genierklære',),
'genierklært': ('genierklære',),
'genierklærte': ('genierklære',),
'genital': ('genital',),
'genitale': ('genital',),
'genitalere': ('genital',),
'genitalest': ('genital',),
'genitaleste': ('genital',),
'genitalt': ('genital',),
'genovesisk': ('genovesisk',),
'genovesiske': ('genovesisk',),
'genovesiskere': ('genovesisk',),
'genovesiskest': ('genovesisk',),
'genovesiskeste': ('genovesisk',),
'gentil': ('gentil',),
'gentile': ('gentil',),
'gentilere': ('gentil',),
'gentilest': ('gentil',),
'gentileste': ('gentil',),
'gentilt': ('gentil',),
'genuesisk': ('genuesisk',),
'genuesiske': ('genuesisk',),
'genuesiskere': ('genuesisk',),
'genuesiskest': ('genuesisk',),
'genuesiskeste': ('genuesisk',),
'genuin': ('genuin',),
'genuine': ('genuin',),
'genuinere': ('genuin',),
'genuinest': ('genuin',),
'genuineste': ('genuin',),
'genuint': ('genuin',),
'geodetisk': ('geodetisk',),
'geodetiske': ('geodetisk',),
'geodetiskere': ('geodetisk',),
'geodetiskest': ('geodetisk',),
'geodetiskeste': ('geodetisk',),
'geofysisk': ('geofysisk',),
'geofysiske': ('geofysisk',),
'geofysiskere': ('geofysisk',),
'geofysiskest': ('geofysisk',),
'geofysiskeste': ('geofysisk',),
'geografisk': ('geografisk',),
'geografiske': ('geografisk',),
'geografiskere': ('geografisk',),
'geografiskest': ('geografisk',),
'geografiskeste': ('geografisk',),
'geologisk': ('geologisk',),
'geologiske': ('geologisk',),
'geologiskere': ('geologisk',),
'geologiskest': ('geologisk',),
'geologiskeste': ('geologisk',),
'geometrisk': ('geometrisk',),
'geometriske': ('geometrisk',),
'geometriskere': ('geometrisk',),
'geometriskest': ('geometrisk',),
'geometriskeste': ('geometrisk',),
'georgisk': ('georgisk',),
'georgiske': ('georgisk',),
'georgiskere': ('georgisk',),
'georgiskest': ('georgisk',),
'georgiskeste': ('georgisk',),
'georgistisk': ('georgistisk',),
'georgistiske': ('georgistisk',),
'georgistiskere': ('georgistisk',),
'georgistiskest': ('georgistisk',),
'georgistiskeste': ('georgistisk',),
'geosentrisk': ('geosentrisk',),
'geosentriske': ('geosentrisk',),
'geosentriskere': ('geosentrisk',),
'geosentriskest': ('geosentrisk',),
'geosentriskeste': ('geosentrisk',),
'gererende': ('gerere',),
'gerert': ('gerere',),
'gererte': ('gerere',),
'geriatrisk': ('geriatrisk',),
'geriatriske': ('geriatrisk',),
'geriatriskere': ('geriatrisk',),
'geriatriskest': ('geriatrisk',),
'geriatriskeste': ('geriatrisk',),
'germaniserende': ('germanisere',),
'germanisert': ('germanisere',),
'germaniserte': ('germanisere',),
'germansk': ('germansk',),
'germanske': ('germansk',),
'germanskere': ('germansk',),
'germanskest': ('germansk',),
'germanskeste': ('germansk',),
'geråda': ('geråde',),
'gerådede': ('geråde',),
'gerådende': ('geråde',),
'gerådet': ('geråde',),
'gerådete': ('geråde',),
'geskjeftig': ('geskjeftig',),
'geskjeftige': ('geskjeftig',),
'geskjeftigere': ('geskjeftig',),
'geskjeftigst': ('geskjeftig',),
'geskjeftigste': ('geskjeftig',),
'gestalta': ('gestalte',),
'gestaltede': ('gestalte',),
'gestaltende': ('gestalte',),
'gestaltet': ('gestalte',),
'gestaltete': ('gestalte',),
'gestikulerende': ('gestikulere',),
'gestikulert': ('gestikulere',),
'gestikulerte': ('gestikulere',),
'gesvint': ('gesvint',),
'gesvinte': ('gesvint',),
'gesvintere': ('gesvint',),
'gesvintest': ('gesvint',),
'gesvinteste': ('gesvint',),
'ghanesisk': ('ghanesisk',),
'ghanesiske': ('ghanesisk',),
'ghanesiskere': ('ghanesisk',),
'ghanesiskest': ('ghanesisk',),
'ghanesiskeste': ('ghanesisk',),
'giende': ('gi',),
'gitt': ('gi',),
'gitte': ('gi',),
'givende': ('gi',),
'gidden': ('gidde',),
'giddende': ('gidde',),
'giddet': ('gidde',),
'gidne': ('gidde',),
'giddelaus': ('giddelaus',),
'giddelause': ('giddelaus',),
'giddelausere': ('giddelaus',),
'giddelausest': ('giddelaus',),
'giddelauseste': ('giddelaus',),
'giddelaust': ('giddelaus',),
'giddeløs': ('giddeløs',),
'giddeløse': ('giddeløs',),
'giddeløsere': ('giddeløs',),
'giddeløsest': ('giddeløs',),
'giddeløseste': ('giddeløs',),
'giddeløst': ('giddeløs',),
'gift': ('gift',),
'gifte': ('gift',),
'giftere': ('gift',),
'giftest': ('gift',),
'gifteste': ('gift',),
'gifta': ('gifte',),
'giftede': ('gifte',),
'giftende': ('gifte',),
'giftet': ('gifte',),
'giftete': ('gifte',),
'giftegal': ('giftegal',),
'giftegale': ('giftegal',),
'giftegalere': ('giftegal',),
'giftegalest': ('giftegal',),
'giftegaleste': ('giftegal',),
'giftegalt': ('giftegal',),
'giftgrøn': ('giftgrøn',),
'giftgrøne': ('giftgrøn',),
'giftgrønere': ('giftgrøn',),
'giftgrønest': ('giftgrøn',),
'giftgrøneste': ('giftgrøn',),
'giftgrønt': ('giftgrøn',),
'giftgrønn': ('giftgrønn',),
'giftgrønne': ('giftgrønn',),
'giftgrønnere': ('giftgrønn',),
'giftgrønnest': ('giftgrønn',),
'giftgrønneste': ('giftgrønn',),
'giftgrønt': ('giftgrønn',),
'giftig': ('giftig',),
'giftige': ('giftig',),
'giftigere': ('giftig',),
'giftigst': ('giftig',),
'giftigste': ('giftig',),
'giftiggrøn': ('giftiggrøn',),
'giftiggrøne': ('giftiggrøn',),
'giftiggrønere': ('giftiggrøn',),
'giftiggrønest': ('giftiggrøn',),
'giftiggrøneste': ('giftiggrøn',),
'giftiggrønt': ('giftiggrøn',),
'giftiggrønn': ('giftiggrønn',),
'giftiggrønne': ('giftiggrønn',),
'giftiggrønnere': ('giftiggrønn',),
'giftiggrønnest': ('giftiggrønn',),
'giftiggrønneste': ('giftiggrønn',),
'giftiggrønt': ('giftiggrønn',),
'gigantisk': ('gigantisk',),
'gigantiske': ('gigantisk',),
'gigantiskere': ('gigantisk',),
'gigantiskest': ('gigantisk',),
'gigantiskeste': ('gigantisk',),
'gigga': ('gigge',),
'giggede': ('gigge',),
'giggende': ('gigge',),
'gigget': ('gigge',),
'giggete': ('gigge',),
'giktisk': ('giktisk',),
'giktiske': ('giktisk',),
'giktiskere': ('giktisk',),
'giktiskest': ('giktisk',),
'giktiskeste': ('giktisk',),
'giktsjuk': ('giktsjuk',),
'giktsjuke': ('giktsjuk',),
'giktsjukere': ('giktsjuk',),
'giktsjukest': ('giktsjuk',),
'giktsjukeste': ('giktsjuk',),
'giktsjukt': ('giktsjuk',),
'giktsyk': ('giktsyk',),
'giktsyke': ('giktsyk',),
'giktsykere': ('giktsyk',),
'giktsykest': ('giktsyk',),
'giktsykeste': ('giktsyk',),
'giktsykt': ('giktsyk',),
'gild': ('gild',),
'gilde': ('gild',),
'gildere': ('gild',),
'gildest': ('gild',),
'gildeste': ('gild',),
'gildt': ('gild',),
'gildra': ('gildre',),
'gildrede': ('gildre',),
'gildrende': ('gildre',),
'gildret': ('gildre',),
'gildrete': ('gildre',),
'giljotinerende': ('giljotinere',),
'giljotinert': ('giljotinere',),
'giljotinerte': ('giljotinere',),
'gimpa': ('gimpe',),
'gimpede': ('gimpe',),
'gimpende': ('gimpe',),
'gimpet': ('gimpe',),
'gimpete': ('gimpe',),
'gingival': ('gingival',),
'gingivale': ('gingival',),
'gingivalere': ('gingival',),
'gingivalest': ('gingival',),
'gingivaleste': ('gingival',),
'gingivalt': ('gingival',),
'gipsa': ('gipse',),
'gipsede': ('gipse',),
'gipsende': ('gipse',),
'gipset': ('gipse',),
'gipsete': ('gipse',),
'gipst': ('gipse',),
'gipste': ('gipse',),
'girerende': ('girere',),
'girert': ('girere',),
'girerte': ('girere',),
'gisna': ('gisne',),
'gisnede': ('gisne',),
'gisnende': ('gisne',),
'gisnet': ('gisne',),
'gisnete': ('gisne',),
'gispa': ('gispe',),
'gispede': ('gispe',),
'gispende': ('gispe',),
'gispet': ('gispe',),
'gispete': ('gispe',),
'gissa': ('gisse',),
'gissede': ('gisse',),
'gissende': ('gisse',),
'gisset': ('gisse',),
'gissete': ('gisse',),
'gisne': ('gissen',),
'gisnere': ('gissen',),
'gisnest': ('gissen',),
'gisneste': ('gissen',),
'gissen': ('gissen',),
'gissent': ('gissen',),
'gitra': ('gitre',),
'gitrede': ('gitre',),
'gitrende': ('gitre',),
'gitret': ('gitre',),
'gitrete': ('gitre',),
'givende': ('givende',),
'gjalla': ('gjalle',),
'gjallede': ('gjalle',),
'gjallende': ('gjalle',),
'gjallet': ('gjalle',),
'gjallete': ('gjalle',),
'gjekka': ('gjekke',),
'gjekkede': ('gjekke',),
'gjekkende': ('gjekke',),
'gjekket': ('gjekke',),
'gjekkete': ('gjekke',),
'gjeld': ('gjeld',),
'gjelde': ('gjeld',),
'gjeldere': ('gjeld',),
'gjeldest': ('gjeld',),
'gjeldeste': ('gjeld',),
'gjeldt': ('gjeld',),
'gjeldbunden': ('gjeldbunden',),
'gjeldbundet': ('gjeldbunden',),
'gjeldbundne': ('gjeldbunden',),
'gjeldbundnere': ('gjeldbunden',),
'gjeldbundnest': ('gjeldbunden',),
'gjeldbundneste': ('gjeldbunden',),
'gjeldbundet': ('gjeldbundet',),
'gjeldbundne': ('gjeldbundet',),
'gjeldbundnere': ('gjeldbundet',),
'gjeldbundnest': ('gjeldbundet',),
'gjeldbundneste': ('gjeldbundet',),
'gjelda': ('gjelde',),
'gjeldede': ('gjelde',),
'gjeldende': ('gjelde',),
'gjeldet': ('gjelde',),
'gjeldete': ('gjelde',),
'gjeldt': ('gjelde',),
'gjeldte': ('gjelde',),
'gjeldende': ('gjelde',),
'gjeldt': ('gjelde',),
'gjeldte': ('gjelde',),
'gjeldende': ('gjeldende',),
'gjeldfri': ('gjeldfri',),
'gjeldfrie': ('gjeldfri',),
'gjeldfriere': ('gjeldfri',),
'gjeldfriest': ('gjeldfri',),
'gjeldfrieste': ('gjeldfri',),
'gjeldfritt': ('gjeldfri',),
'gjellende': ('gjelle',),
'gjelt': ('gjelle',),
'gjelte': ('gjelle',),
'gjemmende': ('gjemme',),
'gjemt': ('gjemme',),
'gjemte': ('gjemme',),
'gjenbrukbar': ('gjenbrukbar',),
'gjenbrukbare': ('gjenbrukbar',),
'gjenbrukbarere': ('gjenbrukbar',),
'gjenbrukbarest': ('gjenbrukbar',),
'gjenbrukbareste': ('gjenbrukbar',),
'gjenbrukbart': ('gjenbrukbar',),
'gjenbrukende': ('gjenbruke',),
'gjenbrukt': ('gjenbruke',),
'gjenbrukte': ('gjenbruke',),
'gjendrivelig': ('gjendrivelig',),
'gjendrivelige': ('gjendrivelig',),
'gjendriveligere': ('gjendrivelig',),
'gjendriveligst': ('gjendrivelig',),
'gjendriveligste': ('gjendrivelig',),
'gjenerobra': ('gjenerobre',),
'gjenerobrede': ('gjenerobre',),
'gjenerobrende': ('gjenerobre',),
'gjenerobret': ('gjenerobre',),
'gjenerobrete': ('gjenerobre',),
'gjenforena': ('gjenforene',),
'gjenforenede': ('gjenforene',),
'gjenforenende': ('gjenforene',),
'gjenforenet': ('gjenforene',),
'gjenforenete': ('gjenforene',),
'gjenforent': ('gjenforene',),
'gjenforente': ('gjenforene',),
'gjenforsikret': ('gjenforsikre',),
'gjenforsikrete': ('gjenforsikre',),
'gjenforsikra': ('gjenforsikre',),
'gjenforsikrede': ('gjenforsikre',),
'gjenforsikrende': ('gjenforsikre',),
'gjenga': ('gjenge',),
'gjengede': ('gjenge',),
'gjengende': ('gjenge',),
'gjenget': ('gjenge',),
'gjengete': ('gjenge',),
'gjenget': ('gjenget',),
'gjengete': ('gjenget',),
'gjengetere': ('gjenget',),
'gjengetest': ('gjenget',),
'gjengeteste': ('gjenget',),
'gjengete': ('gjengete',),
'gjengiende': ('gjengi',),
'gjengitt': ('gjengi',),
'gjengitte': ('gjengi',),
'gjengivende': ('gjengi',),
'gjengifta': ('gjengifte',),
'gjengiftede': ('gjengifte',),
'gjengiftende': ('gjengifte',),
'gjengiftet': ('gjengifte',),
'gjengiftete': ('gjengifte',),
'gjengjeldende': ('gjengjelde',),
'gjengjeldt': ('gjengjelde',),
'gjengjeldte': ('gjengjelde',),
'gjenglemt': ('gjenglemt',),
'gjenglemte': ('gjenglemt',),
'gjenglemtere': ('gjenglemt',),
'gjenglemtest': ('gjenglemt',),
'gjenglemteste': ('gjenglemt',),
'gjenglømt': ('gjenglømt',),
'gjenglømte': ('gjenglømt',),
'gjenglømtere': ('gjenglømt',),
'gjenglømtest': ('gjenglømt',),
'gjenglømteste': ('gjenglømt',),
'gjengrodd': ('gjengrodd',),
'gjengrodde': ('gjengrodd',),
'gjengroddere': ('gjengrodd',),
'gjengroddest': ('gjengrodd',),
'gjengroddeste': ('gjengrodd',),
'gjengs': ('gjengs',),
'gjengse': ('gjengs',),
'gjengsere': ('gjengs',),
'gjengsest': ('gjengs',),
'gjengseste': ('gjengs',),
'gjeninnførende': ('gjeninnføre',),
'gjeninnført': ('gjeninnføre',),
'gjeninnførte': ('gjeninnføre',),
'gjeninnsatt': ('gjeninnsette',),
'gjeninnsatte': ('gjeninnsette',),
'gjeninnsettende': ('gjeninnsette',),
'gjeninntakende': ('gjeninnta',),
'gjeninntatt': ('gjeninnta',),
'gjeninntatte': ('gjeninnta',),
'gjenkallende': ('gjenkalle',),
'gjenkalt': ('gjenkalle',),
'gjenkalte': ('gjenkalle',),
'gjenkjennende': ('gjenkjenne',),
'gjenkjent': ('gjenkjenne',),
'gjenkjente': ('gjenkjenne',),
'gjenkjennelig': ('gjenkjennelig',),
'gjenkjennelige': ('gjenkjennelig',),
'gjenkjenneligere': ('gjenkjennelig',),
'gjenkjenneligst': ('gjenkjennelig',),
'gjenkjenneligste': ('gjenkjennelig',),
'gjenlagt': ('gjenlegge',),
'gjenlagte': ('gjenlegge',),
'gjenleggende': ('gjenlegge',),
'gjenlevende': ('gjenlevende',),
'gjenløsende': ('gjenløse',),
'gjenløst': ('gjenløse',),
'gjenløste': ('gjenløse',),
'gjennomarbeida': ('gjennomarbeide',),
'gjennomarbeidd': ('gjennomarbeide',),
'gjennomarbeidde': ('gjennomarbeide',),
'gjennomarbeidede': ('gjennomarbeide',),
'gjennomarbeidende': ('gjennomarbeide',),
'gjennomarbeidet': ('gjennomarbeide',),
'gjennomarbeidete': ('gjennomarbeide',),
'gjennombarka': ('gjennombarka',),
'gjennombarkede': ('gjennombarket',),
'gjennombarket': ('gjennombarket',),
'gjennombarkete': ('gjennombarket',),
'gjennombarketere': ('gjennombarket',),
'gjennombarketest': ('gjennombarket',),
'gjennombarketeste': ('gjennombarket',),
'gjennomblaut': ('gjennomblaut',),
'gjennomblaute': ('gjennomblaut',),
'gjennomblautere': ('gjennomblaut',),
'gjennomblautest': ('gjennomblaut',),
'gjennomblauteste': ('gjennomblaut',),
'gjennomblautt': ('gjennomblaut',),
'gjennombløt': ('gjennombløt',),
'gjennombløte': ('gjennombløt',),
'gjennombløtere': ('gjennombløt',),
'gjennombløtest': ('gjennombløt',),
'gjennombløteste': ('gjennombløt',),
'gjennombløtt': ('gjennombløt',),
'gjennombora': ('gjennombore',),
'gjennomborede': ('gjennombore',),
'gjennomborende': ('gjennombore',),
'gjennomboret': ('gjennombore',),
'gjennomborete': ('gjennombore',),
'gjennomdrøfta': ('gjennomdrøfte',),
'gjennomdrøftede': ('gjennomdrøfte',),
'gjennomdrøftende': ('gjennomdrøfte',),
'gjennomdrøftet': ('gjennomdrøfte',),
'gjennomdrøftete': ('gjennomdrøfte',),
'gjennomfrosne': ('gjennomfrossen',),
'gjennomfrosnere': ('gjennomfrossen',),
'gjennomfrosnest': ('gjennomfrossen',),
'gjennomfrosneste': ('gjennomfrossen',),
'gjennomfrossen': ('gjennomfrossen',),
'gjennomfrosset': ('gjennomfrossen',),
'gjennomfrosne': ('gjennomfrosset',),
'gjennomfrosnere': ('gjennomfrosset',),
'gjennomfrosnest': ('gjennomfrosset',),
'gjennomfrosneste': ('gjennomfrosset',),
'gjennomfrosset': ('gjennomfrosset',),
'gjennomførende': ('gjennomføre',),
'gjennomført': ('gjennomføre',),
'gjennomførte': ('gjennomføre',),
'gjennomførlig': ('gjennomførlig',),
'gjennomførlige': ('gjennomførlig',),
'gjennomførligere': ('gjennomførlig',),
'gjennomførligst': ('gjennomførlig',),
'gjennomførligste': ('gjennomførlig',),
'gjennomført': ('gjennomført',),
'gjennomførte': ('gjennomført',),
'gjennomførtere': ('gjennomført',),
'gjennomførtest': ('gjennomført',),
'gjennomførteste': ('gjennomført',),
'gjennomgripende': ('gjennomgripende',),
'gjennomgående': ('gjennomgå',),
'gjennomgått': ('gjennomgå',),
'gjennomgåtte': ('gjennomgå',),
'gjennomgående': ('gjennomgående',),
'gjennomhulla': ('gjennomhulle',),
'gjennomhullede': ('gjennomhulle',),
'gjennomhullende': ('gjennomhulle',),
'gjennomhullet': ('gjennomhulle',),
'gjennomhullete': ('gjennomhulle',),
'gjennomillustrerende': ('gjennomillustrere',),
'gjennomillustrert': ('gjennomillustrere',),
'gjennomillustrerte': ('gjennomillustrere',),
'gjennomlesende': ('gjennomlese',),
'gjennomlest': ('gjennomlese',),
'gjennomleste': ('gjennomlese',),
'gjennomlevd': ('gjennomleve',),
'gjennomlevde': ('gjennomleve',),
'gjennomlevende': ('gjennomleve',),
'gjennomlufta': ('gjennomlufte',),
'gjennomluftede': ('gjennomlufte',),
'gjennomluftende': ('gjennomlufte',),
'gjennomluftet': ('gjennomlufte',),
'gjennomluftete': ('gjennomlufte',),
'gjennomlysende': ('gjennomlyse',),
'gjennomlyst': ('gjennomlyse',),
'gjennomlyste': ('gjennomlyse',),
'gjennomprøvd': ('gjennomprøve',),
'gjennomprøvde': ('gjennomprøve',),
'gjennomprøvende': ('gjennomprøve',),
'gjennomseende': ('gjennomse',),
'gjennomsett': ('gjennomse',),
'gjennomsette': ('gjennomse',),
'gjennomsiktig': ('gjennomsiktig',),
'gjennomsiktige': ('gjennomsiktig',),
'gjennomsiktigere': ('gjennomsiktig',),
'gjennomsiktigst': ('gjennomsiktig',),
'gjennomsiktigste': ('gjennomsiktig',),
'gjennomskinnelig': ('gjennomskinnelig',),
'gjennomskinnelige': ('gjennomskinnelig',),
'gjennomskinneligere': ('gjennomskinnelig',),
'gjennomskinneligst': ('gjennomskinnelig',),
'gjennomskinneligste': ('gjennomskinnelig',),
'gjennomskua': ('gjennomskue',),
'gjennomskuede': ('gjennomskue',),
'gjennomskuende': ('gjennomskue',),
'gjennomskuet': ('gjennomskue',),
'gjennomskuete': ('gjennomskue',),
'gjennomsnittlig': ('gjennomsnittlig',),
'gjennomsnittlige': ('gjennomsnittlig',),
'gjennomsnittligere': ('gjennomsnittlig',),
'gjennomsnittligst': ('gjennomsnittlig',),
'gjennomsnittligste': ('gjennomsnittlig',),
'gjennomsteikende': ('gjennomsteike',),
'gjennomsteikt': ('gjennomsteike',),
'gjennomsteikte': ('gjennomsteike',),
'gjennomstekende': ('gjennomsteke',),
'gjennomstekt': ('gjennomsteke',),
'gjennomstekte': ('gjennomsteke',),
'gjennomstrømma': ('gjennomstrømme',),
'gjennomstrømmede': ('gjennomstrømme',),
'gjennomstrømmende': ('gjennomstrømme',),
'gjennomstrømmet': ('gjennomstrømme',),
'gjennomstrømmete': ('gjennomstrømme',),
'gjennomstrømt': ('gjennomstrømme',),
'gjennomstrømte': ('gjennomstrømme',),
'gjennomsvett': ('gjennomsvett',),
'gjennomsvette': ('gjennomsvett',),
'gjennomsvettere': ('gjennomsvett',),
'gjennomsvettest': ('gjennomsvett',),
'gjennomsvetteste': ('gjennomsvett',),
'gjennomsyra': ('gjennomsyre',),
'gjennomsyrede': ('gjennomsyre',),
'gjennomsyrende': ('gjennomsyre',),
'gjennomsyret': ('gjennomsyre',),
'gjennomsyrete': ('gjennomsyre',),
'gjennomsyrt': ('gjennomsyre',),
'gjennomsyrte': ('gjennomsyre',),
'gjennomtenkende': ('gjennomtenke',),
'gjennomtenkt': ('gjennomtenke',),
'gjennomtenkte': ('gjennomtenke',),
'gjennomtrengende': ('gjennomtrenge',),
'gjennomtrengt': ('gjennomtrenge',),
'gjennomtrengte': ('gjennomtrenge',),
'gjennomtrengelig': ('gjennomtrengelig',),
'gjennomtrengelige': ('gjennomtrengelig',),
'gjennomtrengeligere': ('gjennomtrengelig',),
'gjennomtrengeligst': ('gjennomtrengelig',),
'gjennomtrengeligste': ('gjennomtrengelig',),
'gjennomtrengende': ('gjennomtrengende',),
'gjennomtråla': ('gjennomtråle',),
'gjennomtrålede': ('gjennomtråle',),
'gjennomtrålende': ('gjennomtråle',),
'gjennomtrålet': ('gjennomtråle',),
'gjennomtrålete': ('gjennomtråle',),
'gjennomtrålt': ('gjennomtråle',),
'gjennomtrålte': ('gjennomtråle',),
'gjennomtørr': ('gjennomtørr',),
'gjennomtørre': ('gjennomtørr',),
'gjennomtørrere': ('gjennomtørr',),
'gjennomtørrest': ('gjennomtørr',),
'gjennomtørreste': ('gjennomtørr',),
'gjennomtørt': ('gjennomtørr',),
'gjennomvarm': ('gjennomvarm',),
'gjennomvarme': ('gjennomvarm',),
'gjennomvarmere': ('gjennomvarm',),
'gjennomvarmest': ('gjennomvarm',),
'gjennomvarmeste': ('gjennomvarm',),
'gjennomvarmt': ('gjennomvarm',),
'gjennomvåt': ('gjennomvåt',),
'gjennomvåte': ('gjennomvåt',),
'gjennomvåtere': ('gjennomvåt',),
'gjennomvåtest': ('gjennomvåt',),
'gjennomvåteste': ('gjennomvåt',),
'gjennomvått': ('gjennomvåt',),
'gjenoppblussa': ('gjenoppblusse',),
'gjenoppblussede': ('gjenoppblusse',),
'gjenoppblussende': ('gjenoppblusse',),
'gjenoppblusset': ('gjenoppblusse',),
'gjenoppblussete': ('gjenoppblusse',),
'gjenoppbygd': ('gjenoppbygge',),
'gjenoppbygde': ('gjenoppbygge',),
'gjenoppbygga': ('gjenoppbygge',),
'gjenoppbyggede': ('gjenoppbygge',),
'gjenoppbyggende': ('gjenoppbygge',),
'gjenoppbygget': ('gjenoppbygge',),
'gjenoppbyggete': ('gjenoppbygge',),
'gjenoppdaga': ('gjenoppdage',),
'gjenoppdagede': ('gjenoppdage',),
'gjenoppdagende': ('gjenoppdage',),
'gjenoppdaget': ('gjenoppdage',),
'gjenoppdagete': ('gjenoppdage',),
'gjenoppfriska': ('gjenoppfriske',),
'gjenoppfriskede': ('gjenoppfriske',),
'gjenoppfriskende': ('gjenoppfriske',),
'gjenoppfrisket': ('gjenoppfriske',),
'gjenoppfriskete': ('gjenoppfriske',),
'gjenopplevd': ('gjenoppleve',),
'gjenopplevde': ('gjenoppleve',),
'gjenopplevende': ('gjenoppleve',),
'gjenoppliva': ('gjenopplive',),
'gjenopplivede': ('gjenopplive',),
'gjenopplivende': ('gjenopplive',),
'gjenopplivet': ('gjenopplive',),
'gjenopplivete': ('gjenopplive',),
'gjenoppretta': ('gjenopprette',),
'gjenopprettede': ('gjenopprette',),
'gjenopprettende': ('gjenopprette',),
'gjenopprettet': ('gjenopprette',),
'gjenopprettete': ('gjenopprette',),
'gjenopptakende': ('gjenoppta',),
'gjenopptatt': ('gjenoppta',),
'gjenopptatte': ('gjenoppta',),
'gjenopptrykka': ('gjenopptrykke',),
'gjenopptrykkede': ('gjenopptrykke',),
'gjenopptrykkende': ('gjenopptrykke',),
'gjenopptrykket': ('gjenopptrykke',),
'gjenopptrykkete': ('gjenopptrykke',),
'gjenopptrykt': ('gjenopptrykke',),
'gjenopptrykte': ('gjenopptrykke',),
'gjenoppvekka': ('gjenoppvekke',),
'gjenoppvekkede': ('gjenoppvekke',),
'gjenoppvekkende': ('gjenoppvekke',),
'gjenoppvekket': ('gjenoppvekke',),
'gjenoppvekkete': ('gjenoppvekke',),
'gjenoppvekt': ('gjenoppvekke',),
'gjenoppvekte': ('gjenoppvekke',),
'gjenreisende': ('gjenreise',),
'gjenreist': ('gjenreise',),
'gjenreiste': ('gjenreise',),
'gjensidig': ('gjensidig',),
'gjensidige': ('gjensidig',),
'gjensidigere': ('gjensidig',),
'gjensidigst': ('gjensidig',),
'gjensidigste': ('gjensidig',),
'gjenskapa': ('gjenskape',),
'gjenskapende': ('gjenskape',),
'gjenskapt': ('gjenskape',),
'gjenskapte': ('gjenskape',),
'gjensnødd': ('gjensnødd',),
'gjensnødde': ('gjensnødd',),
'gjensnøddere': ('gjensnødd',),
'gjensnøddest': ('gjensnødd',),
'gjensnøddeste': ('gjensnødd',),
'gjenspeila': ('gjenspeile',),
'gjenspeilede': ('gjenspeile',),
'gjenspeilende': ('gjenspeile',),
'gjenspeilet': ('gjenspeile',),
'gjenspeilete': ('gjenspeile',),
'gjenspeilt': ('gjenspeile',),
'gjenspeilte': ('gjenspeile',),
'gjenstridig': ('gjenstridig',),
'gjenstridige': ('gjenstridig',),
'gjenstridigere': ('gjenstridig',),
'gjenstridigst': ('gjenstridig',),
'gjenstridigste': ('gjenstridig',),
'gjentakende': ('gjenta',),
'gjentatt': ('gjenta',),
'gjentatte': ('gjenta',),
'gjenvalgt': ('gjenvelge',),
'gjenvalgte': ('gjenvelge',),
'gjenvelgende': ('gjenvelge',),
'gjenvinnbar': ('gjenvinnbar',),
'gjenvinnbare': ('gjenvinnbar',),
'gjenvinnbarere': ('gjenvinnbar',),
'gjenvinnbarest': ('gjenvinnbar',),
'gjenvinnbareste': ('gjenvinnbar',),
'gjenvinnbart': ('gjenvinnbar',),
'gjenværende': ('gjenværende',),
'gjenåpna': ('gjenåpne',),
'gjenåpnede': ('gjenåpne',),
'gjenåpnende': ('gjenåpne',),
'gjenåpnet': ('gjenåpne',),
'gjenåpnete': ('gjenåpne',),
'gjerda': ('gjerde',),
'gjerdede': ('gjerde',),
'gjerdende': ('gjerde',),
'gjerdet': ('gjerde',),
'gjerdete': ('gjerde',),
'gjerdelaus': ('gjerdelaus',),
'gjerdelause': ('gjerdelaus',),
'gjerdelausere': ('gjerdelaus',),
'gjerdelausest': ('gjerdelaus',),
'gjerdelauseste': ('gjerdelaus',),
'gjerdelaust': ('gjerdelaus',),
'gjerdeløs': ('gjerdeløs',),
'gjerdeløse': ('gjerdeløs',),
'gjerdeløsere': ('gjerdeløs',),
'gjerdeløsest': ('gjerdeløs',),
'gjerdeløseste': ('gjerdeløs',),
'gjerdeløst': ('gjerdeløs',),
'gjerrig': ('gjerrig',),
'gjerrige': ('gjerrig',),
'gjerrigere': ('gjerrig',),
'gjerrigst': ('gjerrig',),
'gjerrigste': ('gjerrig',),
'gjespa': ('gjespe',),
'gjespede': ('gjespe',),
'gjespende': ('gjespe',),
'gjespet': ('gjespe',),
'gjespete': ('gjespe',),
'gjesta': ('gjeste',),
'gjestede': ('gjeste',),
'gjestende': ('gjeste',),
'gjestet': ('gjeste',),
'gjestete': ('gjeste',),
'gjestfri': ('gjestfri',),
'gjestfrie': ('gjestfri',),
'gjestfriere': ('gjestfri',),
'gjestfriest': ('gjestfri',),
'gjestfrieste': ('gjestfri',),
'gjestfritt': ('gjestfri',),
'gjestmild': ('gjestmild',),
'gjestmilde': ('gjestmild',),
'gjestmildere': ('gjestmild',),
'gjestmildest': ('gjestmild',),
'gjestmildeste': ('gjestmild',),
'gjestmildt': ('gjestmild',),
'gjetende': ('gjete',),
'gjett': ('gjete',),
'gjette': ('gjete',),
'gjetta': ('gjette',),
'gjettede': ('gjette',),
'gjettende': ('gjette',),
'gjettet': ('gjette',),
'gjettete': ('gjette',),
'gjev': ('gjev',),
'gjeve': ('gjev',),
'gjevere': ('gjev',),
'gjevest': ('gjev',),
'gjeveste': ('gjev',),
'gjevt': ('gjev',),
'gjev': ('gjev',),
'gjeve': ('gjev',),
'gjevere': ('gjev',),
'gjevest': ('gjev',),
'gjeveste': ('gjev',),
'gjevt': ('gjev',),
'gjorda': ('gjorde',),
'gjordede': ('gjorde',),
'gjordende': ('gjorde',),
'gjordet': ('gjorde',),
'gjordete': ('gjorde',),
'gjura': ('gjure',),
'gjurede': ('gjure',),
'gjurende': ('gjure',),
'gjuret': ('gjure',),
'gjurete': ('gjure',),
'gjurt': ('gjure',),
'gjurte': ('gjure',),
'gjæra': ('gjære',),
'gjærede': ('gjære',),
'gjærende': ('gjære',),
'gjæret': ('gjære',),
'gjærete': ('gjære',),
'gjært': ('gjære',),
'gjærte': ('gjære',),
'gjæra': ('gjære',),
'gjærede': ('gjære',),
'gjærende': ('gjære',),
'gjæret': ('gjære',),
'gjærete': ('gjære',),
'gjært': ('gjære',),
'gjærte': ('gjære',),
'gjæv': ('gjæv',),
'gjæve': ('gjæv',),
'gjævere': ('gjæv',),
'gjævest': ('gjæv',),
'gjæveste': ('gjæv',),
'gjævt': ('gjæv',),
'gjæv': ('gjæv',),
'gjæve': ('gjæv',),
'gjævere': ('gjæv',),
'gjævest': ('gjæv',),
'gjæveste': ('gjæv',),
'gjævt': ('gjæv',),
'gjødd': ('gjø',),
'gjødde': ('gjø',),
'gjøende': ('gjø',),
'gjødd': ('gjø',),
'gjødde': ('gjø',),
'gjøende': ('gjø',),
'gjødd': ('gjøde',),
'gjødde': ('gjøde',),
'gjødende': ('gjøde',),
'gjødsla': ('gjødsle',),
'gjødslede': ('gjødsle',),
'gjødslende': ('gjødsle',),
'gjødslet': ('gjødsle',),
'gjødslete': ('gjødsle',),
'gjøgla': ('gjøgle',),
'gjøglede': ('gjøgle',),
'gjøglende': ('gjøgle',),
'gjøglet': ('gjøgle',),
'gjøglete': ('gjøgle',),
'gjølende': ('gjøle',),
'gjølt': ('gjøle',),
'gjølte': ('gjøle',),
'gjølet': ('gjølet',),
'gjølete': ('gjølet',),
'gjøletere': ('gjølet',),
'gjøletest': ('gjølet',),
'gjøleteste': ('gjølet',),
'gjølete': ('gjølete',),
'gjømmende': ('gjømme',),
'gjømt': ('gjømme',),
'gjømte': ('gjømme',),
'gjønende': ('gjøne',),
'gjønt': ('gjøne',),
'gjønte': ('gjøne',),
'gjort': ('gjøre',),
'gjorte': ('gjøre',),
'gjørende': ('gjøre',),
'gjørlig': ('gjørlig',),
'gjørlige': ('gjørlig',),
'gjørligere': ('gjørlig',),
'gjørligst': ('gjørlig',),
'gjørligste': ('gjørlig',),
'gjørma': ('gjørme',),
'gjørmede': ('gjørme',),
'gjørmende': ('gjørme',),
'gjørmet': ('gjørme',),
'gjørmete': ('gjørme',),
'gjørmet': ('gjørmet',),
'gjørmete': ('gjørmet',),
'gjørmetere': ('gjørmet',),
'gjørmetest': ('gjørmet',),
'gjørmeteste': ('gjørmet',),
'gjørmete': ('gjørmete',),
'gladd': ('gla',),
'gladde': ('gla',),
'glaende': ('gla',),
'glad': ('glad',),
'glade': ('glad',),
'gladere': ('glad',),
'gladest': ('glad',),
'gladeste': ('glad',),
'gladlynt': ('gladlynt',),
'gladlynte': ('gladlynt',),
'gladlyntere': ('gladlynt',),
'gladlyntest': ('gladlynt',),
'gladlynteste': ('gladlynt',),
'glafsa': ('glafse',),
'glafsede': ('glafse',),
'glafsende': ('glafse',),
'glafset': ('glafse',),
'glafsete': ('glafse',),
'glamma': ('glamme',),
'glammede': ('glamme',),
'glammende': ('glamme',),
'glammet': ('glamme',),
'glammete': ('glamme',),
'glamoriserende': ('glamorisere',),
'glamorisert': ('glamorisere',),
'glamoriserte': ('glamorisere',),
'glamorøs': ('glamorøs',),
'glamorøse': ('glamorøs',),
'glamorøsere': ('glamorøs',),
'glamorøsest': ('glamorøs',),
'glamorøseste': ('glamorøs',),
'glamorøst': ('glamorøs',),
'glana': ('glane',),
'glanende': ('glane',),
'glant': ('glane',),
'glante': ('glane',),
'glansa': ('glanse',),
'glansede': ('glanse',),
'glansende': ('glanse',),
'glanset': ('glanse',),
'glansete': ('glanse',),
'glasaktig': ('glasaktig',),
'glasaktige': ('glasaktig',),
'glasaktigere': ('glasaktig',),
'glasaktigst': ('glasaktig',),
'glasaktigste': ('glasaktig',),
'glasaktig': ('glasaktig',),
'glasaktige': ('glasaktig',),
'glasaktigere': ('glasaktig',),
'glasaktigst': ('glasaktig',),
'glasaktigste': ('glasaktig',),
'glasblank': ('glasblank',),
'glasblanke': ('glasblank',),
'glasblankere': ('glasblank',),
'glasblankest': ('glasblank',),
'glasblankeste': ('glasblank',),
'glasblankt': ('glasblank',),
'glasblank': ('glasblank',),
'glasblanke': ('glasblank',),
'glasblankere': ('glasblank',),
'glasblankest': ('glasblank',),
'glasblankeste': ('glasblank',),
'glasblankt': ('glasblank',),
'glaserende': ('glasere',),
'glasert': ('glasere',),
'glaserte': ('glasere',),
'glaserende': ('glasere',),
'glasert': ('glasere',),
'glaserte': ('glasere',),
'glashard': ('glashard',),
'glasharde': ('glashard',),
'glashardere': ('glashard',),
'glashardest': ('glashard',),
'glashardeste': ('glashard',),
'glashardt': ('glashard',),
'glashard': ('glashard',),
'glasharde': ('glashard',),
'glashardere': ('glashard',),
'glashardest': ('glashard',),
'glashardeste': ('glashard',),
'glashardt': ('glashard',),
'glasial': ('glasial',),
'glasiale': ('glasial',),
'glasialere': ('glasial',),
'glasialest': ('glasial',),
'glasialeste': ('glasial',),
'glasialt': ('glasial',),
'glasiologisk': ('glasiologisk',),
'glasiologiske': ('glasiologisk',),
'glasiologiskere': ('glasiologisk',),
'glasiologiskest': ('glasiologisk',),
'glasiologiskeste': ('glasiologisk',),
'glasklar': ('glasklar',),
'glasklare': ('glasklar',),
'glasklarere': ('glasklar',),
'glasklarest': ('glasklar',),
'glasklareste': ('glasklar',),
'glasklart': ('glasklar',),
'glasklar': ('glasklar',),
'glasklare': ('glasklar',),
'glasklarere': ('glasklar',),
'glasklarest': ('glasklar',),
'glasklareste': ('glasklar',),
'glasklart': ('glasklar',),
'glassaktig': ('glassaktig',),
'glassaktige': ('glassaktig',),
'glassaktigere': ('glassaktig',),
'glassaktigst': ('glassaktig',),
'glassaktigste': ('glassaktig',),
'glassaktig': ('glassaktig',),
'glassaktige': ('glassaktig',),
'glassaktigere': ('glassaktig',),
'glassaktigst': ('glassaktig',),
'glassaktigste': ('glassaktig',),
'glassblank': ('glassblank',),
'glassblanke': ('glassblank',),
'glassblankere': ('glassblank',),
'glassblankest': ('glassblank',),
'glassblankeste': ('glassblank',),
'glassblankt': ('glassblank',),
'glassblank': ('glassblank',),
'glassblanke': ('glassblank',),
'glassblankere': ('glassblank',),
'glassblankest': ('glassblank',),
'glassblankeste': ('glassblank',),
'glassblankt': ('glassblank',),
'glasserende': ('glassere',),
'glassert': ('glassere',),
'glasserte': ('glassere',),
'glasserende': ('glassere',),
'glassert': ('glassere',),
'glasserte': ('glassere',),
'glasshard': ('glasshard',),
'glassharde': ('glasshard',),
'glasshardere': ('glasshard',),
'glasshardest': ('glasshard',),
'glasshardeste': ('glasshard',),
'glasshardt': ('glasshard',),
'glasshard': ('glasshard',),
'glassharde': ('glasshard',),
'glasshardere': ('glasshard',),
'glasshardest': ('glasshard',),
'glasshardeste': ('glasshard',),
'glasshardt': ('glasshard',),
'glassklar': ('glassklar',),
'glassklare': ('glassklar',),
'glassklarere': ('glassklar',),
'glassklarest': ('glassklar',),
'glassklareste': ('glassklar',),
'glassklart': ('glassklar',),
'glassklar': ('glassklar',),
'glassklare': ('glassklar',),
'glassklarere': ('glassklar',),
'glassklarest': ('glassklar',),
'glassklareste': ('glassklar',),
'glassklart': ('glassklar',),
'glatt': ('glatt',),
'glatte': ('glatt',),
'glattere': ('glatt',),
'glattest': ('glatt',),
'glatteste': ('glatt',),
'glattbarberende': ('glattbarbere',),
'glattbarbert': ('glattbarbere',),
'glattbarberte': ('glattbarbere',),
'glatta': ('glatte',),
'glattede': ('glatte',),
'glattende': ('glatte',),
'glattet': ('glatte',),
'glattete': ('glatte',),
'glatthåra': ('glatthåra',),
'glatthårede': ('glatthåret',),
'glatthåret': ('glatthåret',),
'glatthårete': ('glatthåret',),
'glatthåretere': ('glatthåret',),
'glatthåretest': ('glatthåret',),
'glatthåreteste': ('glatthåret',),
'glattkjemma': ('glattkjemme',),
'glattkjemmede': ('glattkjemme',),
'glattkjemmende': ('glattkjemme',),
'glattkjemmet': ('glattkjemme',),
'glattkjemmete': ('glattkjemme',),
'glattkjemt': ('glattkjemme',),
'glattkjemte': ('glattkjemme',),
'glattløpa': ('glattløpa',),
'glattløpede': ('glattløpet',),
'glattløpet': ('glattløpet',),
'glattløpete': ('glattløpet',),
'glattløpetere': ('glattløpet',),
'glattløpetest': ('glattløpet',),
'glattløpeteste': ('glattløpet',),
'glattstrykende': ('glattstryke',),
'glattstrøken': ('glattstryke',),
'glattstrøket': ('glattstryke',),
'glattstrøkne': ('glattstryke',),
'gledd': ('gle',),
'gledde': ('gle',),
'gleende': ('gle',),
'gledd': ('gle',),
'gledde': ('gle',),
'gleende': ('gle',),
'gleda': ('glede',),
'gledd': ('glede',),
'gledde': ('glede',),
'gledede': ('glede',),
'gledende': ('glede',),
'gledet': ('glede',),
'gledete': ('glede',),
'gleda': ('glede',),
'gledd': ('glede',),
'gledde': ('glede',),
'gledede': ('glede',),
'gledende': ('glede',),
'gledet': ('glede',),
'gledete': ('glede',),
'gledefylt': ('gledefylt',),
'gledefylte': ('gledefylt',),
'gledefyltere': ('gledefylt',),
'gledefyltest': ('gledefylt',),
'gledefylteste': ('gledefylt',),
'gledelaus': ('gledelaus',),
'gledelause': ('gledelaus',),
'gledelausere': ('gledelaus',),
'gledelausest': ('gledelaus',),
'gledelauseste': ('gledelaus',),
'gledelaust': ('gledelaus',),
'gledelig': ('gledelig',),
'gledelige': ('gledelig',),
'gledeligere': ('gledelig',),
'gledeligst': ('gledelig',),
'gledeligste': ('gledelig',),
'gledeløs': ('gledeløs',),
'gledeløse': ('gledeløs',),
'gledeløsere': ('gledeløs',),
'gledeløsest': ('gledeløs',),
'gledeløseste': ('gledeløs',),
'gledeløst': ('gledeløs',),
'glederik': ('glederik',),
'glederike': ('glederik',),
'glederikere': ('glederik',),
'glederikest': ('glederik',),
'glederikeste': ('glederik',),
'glederikt': ('glederik',),
'gledestrålende': ('gledestrålende',),
'glefsa': ('glefse',),
'glefsede': ('glefse',),
'glefsende': ('glefse',),
'glefset': ('glefse',),
'glefsete': ('glefse',),
'glefst': ('glefse',),
'glefste': ('glefse',),
'glemmende': ('glemme',),
'glemt': ('glemme',),
'glemte': ('glemme',),
'glemsk': ('glemsk',),
'glemske': ('glemsk',),
'glemskere': ('glemsk',),
'glemskest': ('glemsk',),
'glemskeste': ('glemsk',),
'glemsom': ('glemsom',),
'glemsomme': ('glemsom',),
'glemsommere': ('glemsom',),
'glemsomst': ('glemsom',),
'glemsomste': ('glemsom',),
'glemsomt': ('glemsom',),
'glepne': ('gleppe',),
'gleppen': ('gleppe',),
'gleppende': ('gleppe',),
'gleppet': ('gleppe',),
'glidd': ('gli',),
'glidde': ('gli',),
'gliende': ('gli',),
'glidd': ('gli',),
'glidde': ('gli',),
'gliende': ('gli',),
'glideflydd': ('glidefly',),
'glideflydde': ('glidefly',),
'glideflyende': ('glidefly',),
'glidefløyen': ('glidefly',),
'glidefløyet': ('glidefly',),
'glidefløyne': ('glidefly',),
'glideflydd': ('glideflyge',),
'glideflydde': ('glideflyge',),
'glideflygende': ('glideflyge',),
'glidefløyen': ('glideflyge',),
'glidefløyet': ('glideflyge',),
'glidefløyne': ('glideflyge',),
'glidende': ('glidende',),
'glimende': ('glime',),
'glimt': ('glime',),
'glimte': ('glime',),
'glimra': ('glimre',),
'glimrede': ('glimre',),
'glimrende': ('glimre',),
'glimret': ('glimre',),
'glimrete': ('glimre',),
'glimrende': ('glimrende',),
'glimta': ('glimte',),
'glimtede': ('glimte',),
'glimtende': ('glimte',),
'glimtet': ('glimte',),
'glimtete': ('glimte',),
'glinsa': ('glinse',),
'glinsede': ('glinse',),
'glinsende': ('glinse',),
'glinset': ('glinse',),
'glinsete': ('glinse',),
'glipende': ('glipe',),
'glipt': ('glipe',),
'glipte': ('glipe',),
'glirende': ('glire',),
'glirt': ('glire',),
'glirte': ('glire',),
'glisende': ('glise',),
'glist': ('glise',),
'gliste': ('glise',),
'glisen': ('glisen',),
'glisent': ('glisen',),
'glisne': ('glisen',),
'glisnere': ('glisen',),
'glisnest': ('glisen',),
'glisneste': ('glisen',),
'glisen': ('glisen',),
'glisent': ('glisen',),
'glisne': ('glisen',),
'glisnere': ('glisen',),
'glisnest': ('glisen',),
'glisneste': ('glisen',),
'glisne': ('glissen',),
'glisnere': ('glissen',),
'glisnest': ('glissen',),
'glisneste': ('glissen',),
'glissen': ('glissen',),
'glissent': ('glissen',),
'glisne': ('glissen',),
'glisnere': ('glissen',),
'glisnest': ('glissen',),
'glisneste': ('glissen',),
'glissen': ('glissen',),
'glissent': ('glissen',),
'glitra': ('glitre',),
'glitrede': ('glitre',),
'glitrende': ('glitre',),
'glitret': ('glitre',),
'glitrete': ('glitre',),
'glitrende': ('glitrende',),
'glitta': ('glitte',),
'glittede': ('glitte',),
'glittende': ('glitte',),
'glittet': ('glitte',),
'glittete': ('glitte',),
'glodd': ('glo',),
'glodde': ('glo',),
'gloende': ('glo',),
'global': ('global',),
'globale': ('global',),
'globalere': ('global',),
'globalest': ('global',),
'globaleste': ('global',),
'globalt': ('global',),
'gloende': ('gloende',),
'glohet': ('glohet',),
'glohete': ('glohet',),
'glohetere': ('glohet',),
'glohetest': ('glohet',),
'gloheteste': ('glohet',),
'glohett': ('glohet',),
'glora': ('glore',),
'glorede': ('glore',),
'glorende': ('glore',),
'gloret': ('glore',),
'glorete': ('glore',),
'glort': ('glore',),
'glorte': ('glore',),
'gloret': ('gloret',),
'glorete': ('gloret',),
'gloretere': ('gloret',),
'gloretest': ('gloret',),
'gloreteste': ('gloret',),
'glorete': ('glorete',),
'glorifiserende': ('glorifisere',),
'glorifisert': ('glorifisere',),
'glorifiserte': ('glorifisere',),
'gloriøs': ('gloriøs',),
'gloriøse': ('gloriøs',),
'gloriøsere': ('gloriøs',),
'gloriøsest': ('gloriøs',),
'gloriøseste': ('gloriøs',),
'gloriøst': ('gloriøs',),
'glorverdig': ('glorverdig',),
'glorverdige': ('glorverdig',),
'glorverdigere': ('glorverdig',),
'glorverdigst': ('glorverdig',),
'glorverdigste': ('glorverdig',),
'glorød': ('glorød',),
'glorøde': ('glorød',),
'glorødere': ('glorød',),
'glorødest': ('glorød',),
'glorødeste': ('glorød',),
'glorødt': ('glorød',),
'glottal': ('glottal',),
'glottale': ('glottal',),
'glottalere': ('glottal',),
'glottalest': ('glottal',),
'glottaleste': ('glottal',),
'glottalt': ('glottal',),
'glovarm': ('glovarm',),
'glovarme': ('glovarm',),
'glovarmere': ('glovarm',),
'glovarmest': ('glovarm',),
'glovarmeste': ('glovarm',),
'glovarmt': ('glovarm',),
'glup': ('glup',),
'glupe': ('glup',),
'glupere': ('glup',),
'glupest': ('glup',),
'glupeste': ('glup',),
'glupt': ('glup',),
'glupende': ('glupende',),
'glupsk': ('glupsk',),
'glupske': ('glupsk',),
'glupskere': ('glupsk',),
'glupskest': ('glupsk',),
'glupskeste': ('glupsk',),
'glutenholdig': ('glutenholdig',),
'glutenholdige': ('glutenholdig',),
'glutenholdigere': ('glutenholdig',),
'glutenholdigst': ('glutenholdig',),
'glutenholdigste': ('glutenholdig',),
'glødd': ('glø',),
'glødde': ('glø',),
'gløende': ('glø',),
'glødd': ('glø',),
'glødde': ('glø',),
'gløende': ('glø',),
'gløda': ('gløde',),
'glødd': ('gløde',),
'glødde': ('gløde',),
'glødede': ('gløde',),
'glødende': ('gløde',),
'glødet': ('gløde',),
'glødete': ('gløde',),
'gløda': ('gløde',),
'glødd': ('gløde',),
'glødde': ('gløde',),
'glødede': ('gløde',),
'glødende': ('gløde',),
'glødet': ('gløde',),
'glødete': ('gløde',),
'glødende': ('glødende',),
'gløgg': ('gløgg',),
'gløgge': ('gløgg',),
'gløggere': ('gløgg',),
'gløggest': ('gløgg',),
'gløggeste': ('gløgg',),
'gløgt': ('gløgg',),
'gløggtenkt': ('gløggtenkt',),
'gløggtenkte': ('gløggtenkt',),
'gløggtenktere': ('gløggtenkt',),
'gløggtenktest': ('gløggtenkt',),
'gløggtenkteste': ('gløggtenkt',),
'glømmende': ('glømme',),
'glømt': ('glømme',),
'glømte': ('glømme',),
'glømsk': ('glømsk',),
'glømske': ('glømsk',),
'glømskere': ('glømsk',),
'glømskest': ('glømsk',),
'glømskeste': ('glømsk',),
'glømsom': ('glømsom',),
'glømsomme': ('glømsom',),
'glømsommere': ('glømsom',),
'glømsomst': ('glømsom',),
'glømsomste': ('glømsom',),
'glømsomt': ('glømsom',),
'gløtta': ('gløtte',),
'gløttede': ('gløtte',),
'gløttende': ('gløtte',),
'gløttet': ('gløtte',),
'gløttete': ('gløtte',),
'gnafsa': ('gnafse',),
'gnafsede': ('gnafse',),
'gnafsende': ('gnafse',),
'gnafset': ('gnafse',),
'gnafsete': ('gnafse',),
'gnafst': ('gnafse',),
'gnafste': ('gnafse',),
'gnagd': ('gnage',),
'gnagde': ('gnage',),
'gnagede': ('gnage',),
'gnagende': ('gnage',),
'gnaget': ('gnage',),
'gnagete': ('gnage',),
'gnaldra': ('gnaldre',),
'gnaldrede': ('gnaldre',),
'gnaldrende': ('gnaldre',),
'gnaldret': ('gnaldre',),
'gnaldrete': ('gnaldre',),
'gneldra': ('gneldre',),
'gneldrede': ('gneldre',),
'gneldrende': ('gneldre',),
'gneldret': ('gneldre',),
'gneldrete': ('gneldre',),
'gnell': ('gnell',),
'gnelle': ('gnell',),
'gnellere': ('gnell',),
'gnellest': ('gnell',),
'gnelleste': ('gnell',),
'gnelt': ('gnell',),
'gnellende': ('gnelle',),
'gnelt': ('gnelle',),
'gnelte': ('gnelle',),
'gnidd': ('gni',),
'gnidde': ('gni',),
'gniende': ('gni',),
'gnidra': ('gnidre',),
'gnidrede': ('gnidre',),
'gnidrende': ('gnidre',),
'gnidret': ('gnidre',),
'gnidrete': ('gnidre',),
'gnidret': ('gnidret',),
'gnidrete': ('gnidret',),
'gnidretere': ('gnidret',),
'gnidretest': ('gnidret',),
'gnidreteste': ('gnidret',),
'gnidrete': ('gnidrete',),
'gnieraktig': ('gnieraktig',),
'gnieraktige': ('gnieraktig',),
'gnieraktigere': ('gnieraktig',),
'gnieraktigst': ('gnieraktig',),
'gnieraktigste': ('gnieraktig',),
'gnika': ('gnike',),
'gnikede': ('gnike',),
'gnikende': ('gnike',),
'gniket': ('gnike',),
'gnikete': ('gnike',),
'gnika': ('gnike',),
'gnikede': ('gnike',),
'gnikende': ('gnike',),
'gniket': ('gnike',),
'gnikete': ('gnike',),
'gniken': ('gniken',),
'gnikent': ('gniken',),
'gnikne': ('gniken',),
'gniknere': ('gniken',),
'gniknest': ('gniken',),
'gnikneste': ('gniken',),
'gnikka': ('gnikke',),
'gnikkede': ('gnikke',),
'gnikkende': ('gnikke',),
'gnikket': ('gnikke',),
'gnikkete': ('gnikke',),
'gnikka': ('gnikke',),
'gnikkede': ('gnikke',),
'gnikkende': ('gnikke',),
'gnikket': ('gnikke',),
'gnikkete': ('gnikke',),
'gniksa': ('gnikse',),
'gniksede': ('gnikse',),
'gniksende': ('gnikse',),
'gnikset': ('gnikse',),
'gniksete': ('gnikse',),
'gnirka': ('gnirke',),
'gnirkede': ('gnirke',),
'gnirkende': ('gnirke',),
'gnirket': ('gnirke',),
'gnirkete': ('gnirke',),
'gnisla': ('gnisle',),
'gnislede': ('gnisle',),
'gnislende': ('gnisle',),
'gnislet': ('gnisle',),
'gnislete': ('gnisle',),
'gnissa': ('gnisse',),
'gnissede': ('gnisse',),
'gnissende': ('gnisse',),
'gnisset': ('gnisse',),
'gnissete': ('gnisse',),
'gnista': ('gniste',),
'gnistede': ('gniste',),
'gnistende': ('gniste',),
'gnistet': ('gniste',),
'gnistete': ('gniste',),
'gnistra': ('gnistre',),
'gnistrede': ('gnistre',),
'gnistrende': ('gnistre',),
'gnistret': ('gnistre',),
'gnistrete': ('gnistre',),
'gnistrende': ('gnistrende',),
'gnomisk': ('gnomisk',),
'gnomiske': ('gnomisk',),
'gnomiskere': ('gnomisk',),
'gnomiskest': ('gnomisk',),
'gnomiskeste': ('gnomisk',),
'gnostisk': ('gnostisk',),
'gnostiske': ('gnostisk',),
'gnostiskere': ('gnostisk',),
'gnostiskest': ('gnostisk',),
'gnostiskeste': ('gnostisk',),
'gnudd': ('gnu',),
'gnudde': ('gnu',),
'gnuende': ('gnu',),
'gnubba': ('gnubbe',),
'gnubbede': ('gnubbe',),
'gnubbende': ('gnubbe',),
'gnubbet': ('gnubbe',),
'gnubbete': ('gnubbe',),
'gnugga': ('gnugge',),
'gnuggede': ('gnugge',),
'gnuggende': ('gnugge',),
'gnugget': ('gnugge',),
'gnuggete': ('gnugge',),
'gnukka': ('gnukke',),
'gnukkede': ('gnukke',),
'gnukkende': ('gnukke',),
'gnukket': ('gnukke',),
'gnukkete': ('gnukke',),
'gnura': ('gnure',),
'gnurede': ('gnure',),
'gnurende': ('gnure',),
'gnuret': ('gnure',),
'gnurete': ('gnure',),
'gnurt': ('gnure',),
'gnurte': ('gnure',),
'gnusla': ('gnusle',),
'gnuslede': ('gnusle',),
'gnuslende': ('gnusle',),
'gnuslet': ('gnusle',),
'gnuslete': ('gnusle',),
'gnussa': ('gnusse',),
'gnussede': ('gnusse',),
'gnussende': ('gnusse',),
'gnusset': ('gnusse',),
'gnussete': ('gnusse',),
'gnydd': ('gny',),
'gnydde': ('gny',),
'gnyende': ('gny',),
'gnålende': ('gnåle',),
'gnålt': ('gnåle',),
'gnålte': ('gnåle',),
'goanesisk': ('goanesisk',),
'goanesiske': ('goanesisk',),
'goanesiskere': ('goanesisk',),
'goanesiskest': ('goanesisk',),
'goanesiskeste': ('goanesisk',),
'bedre': ('god',),
'best': ('god',),
'beste': ('god',),
'god': ('god',),
'gode': ('god',),
'godt': ('god',),
'godarta': ('godarta',),
'godartede': ('godartet',),
'godartet': ('godartet',),
'godartete': ('godartet',),
'godartetere': ('godartet',),
'godartetest': ('godartet',),
'godarteteste': ('godartet',),
'godfjottet': ('godfjottet',),
'godfjottete': ('godfjottet',),
'godfjottetere': ('godfjottet',),
'godfjottetest': ('godfjottet',),
'godfjotteteste': ('godfjottet',),
'godfjottete': ('godfjottete',),
'godgjort': ('godgjøre',),
'godgjorte': ('godgjøre',),
'godgjørende': ('godgjøre',),
'godgjørende': ('godgjørende',),
'godhjerta': ('godhjerta',),
'godhjertede': ('godhjertet',),
'godhjertet': ('godhjertet',),
'godhjertete': ('godhjertet',),
'godhjertetere': ('godhjertet',),
'godhjertetest': ('godhjertet',),
'godhjerteteste': ('godhjertet',),
'godkjennende': ('godkjenne',),
'godkjent': ('godkjenne',),
'godkjente': ('godkjenne',),
'godkjent': ('godkjent',),
'godkjente': ('godkjent',),
'godkjentere': ('godkjent',),
'godkjentest': ('godkjent',),
'godkjenteste': ('godkjent',),
'godlynt': ('godlynt',),
'godlynte': ('godlynt',),
'godlyntere': ('godlynt',),
'godlyntest': ('godlynt',),
'godlynteste': ('godlynt',),
'godmodig': ('godmodig',),
'godmodige': ('godmodig',),
'godmodigere': ('godmodig',),
'godmodigst': ('godmodig',),
'godmodigste': ('godmodig',),
'godskreven': ('godskrive',),
'godskrevet': ('godskrive',),
'godskrevne': ('godskrive',),
'godskrivende': ('godskrive',),
'godslig': ('godslig',),
'godslige': ('godslig',),
'godsligere': ('godslig',),
'godsligst': ('godslig',),
'godsligste': ('godslig',),
'godsnakka': ('godsnakke',),
'godsnakkede': ('godsnakke',),
'godsnakkende': ('godsnakke',),
'godsnakket': ('godsnakke',),
'godsnakkete': ('godsnakke',),
'godtakende': ('godta',),
'godtatt': ('godta',),
'godtatte': ('godta',),
'godta': ('godte',),
'godtede': ('godte',),
'godtende': ('godte',),
'godtet': ('godte',),
'godtete': ('godte',),
'godtekkelig': ('godtekkelig',),
'godtekkelige': ('godtekkelig',),
'godtekkeligere': ('godtekkelig',),
'godtekkeligst': ('godtekkelig',),
'godtekkeligste': ('godtekkelig',),
'godtgjort': ('godtgjøre',),
'godtgjorte': ('godtgjøre',),
'godtgjørende': ('godtgjøre',),
'godtkjøps': ('godtkjøps',),
'godtroende': ('godtroende',),
'godtruen': ('godtruen',),
'godtruene': ('godtruen',),
'godtruenere': ('godtruen',),
'godtruenest': ('godtruen',),
'godtrueneste': ('godtruen',),
'godtruent': ('godtruen',),
'godtrune': ('godtruen',),
'godtrunere': ('godtruen',),
'godtrunest': ('godtruen',),
'godtruneste': ('godtruen',),
'godtruende': ('godtruende',),
'godvillig': ('godvillig',),
'godvillige': ('godvillig',),
'godvilligere': ('godvillig',),
'godvilligst': ('godvillig',),
'godvilligste': ('godvillig',),
'gold': ('gold',),
'golde': ('gold',),
'goldere': ('gold',),
'goldest': ('gold',),
'goldeste': ('gold',),
'goldt': ('gold',),
'gomla': ('gomle',),
'gomlede': ('gomle',),
'gomlende': ('gomle',),
'gomlet': ('gomle',),
'gomlete': ('gomle',),
'gordisk': ('gordisk',),
'gordiske': ('gordisk',),
'gordiskere': ('gordisk',),
'gordiskest': ('gordisk',),
'gordiskeste': ('gordisk',),
'gotisk': ('gotisk',),
'gotiske': ('gotisk',),
'gotiskere': ('gotisk',),
'gotiskest': ('gotisk',),
'gotiskeste': ('gotisk',),
'gotlandsk': ('gotlandsk',),
'gotlandske': ('gotlandsk',),
'gotlandskere': ('gotlandsk',),
'gotlandskest': ('gotlandsk',),
'gotlandskeste': ('gotlandsk',),
'gova': ('gove',),
'govede': ('gove',),
'govende': ('gove',),
'govet': ('gove',),
'govete': ('gove',),
'gra': ('gra',),
'grae': ('gra',),
'graere': ('gra',),
'graest': ('gra',),
'graeste': ('gra',),
'grabba': ('grabbe',),
'grabbede': ('grabbe',),
'grabbende': ('grabbe',),
'grabbet': ('grabbe',),
'grabbete': ('grabbe',),
'gradbøya': ('gradbøye',),
'gradbøyd': ('gradbøye',),
'gradbøyde': ('gradbøye',),
'gradbøyede': ('gradbøye',),
'gradbøyende': ('gradbøye',),
'gradbøyet': ('gradbøye',),
'gradbøyete': ('gradbøye',),
'grada': ('grade',),
'gradede': ('grade',),
'gradende': ('grade',),
'gradet': ('grade',),
'gradete': ('grade',),
'graderende': ('gradere',),
'gradert': ('gradere',),
'graderte': ('gradere',),
'gradual': ('gradual',),
'graduale': ('gradual',),
'gradualere': ('gradual',),
'gradualest': ('gradual',),
'gradualeste': ('gradual',),
'gradualt': ('gradual',),
'graduell': ('graduell',),
'graduelle': ('graduell',),
'graduellere': ('graduell',),
'graduellest': ('graduell',),
'graduelleste': ('graduell',),
'graduelt': ('graduell',),
'graduerende': ('graduere',),
'graduert': ('graduere',),
'graduerte': ('graduere',),
'grafisk': ('grafisk',),
'grafiske': ('grafisk',),
'grafiskere': ('grafisk',),
'grafiskest': ('grafisk',),
'grafiskeste': ('grafisk',),
'grafologisk': ('grafologisk',),
'grafologiske': ('grafologisk',),
'grafologiskere': ('grafologisk',),
'grafologiskest': ('grafologisk',),
'grafologiskeste': ('grafologisk',),
'grafsa': ('grafse',),
'grafsede': ('grafse',),
'grafsende': ('grafse',),
'grafset': ('grafse',),
'grafsete': ('grafse',),
'grafsen': ('grafsen',),
'grafsent': ('grafsen',),
'grafsne': ('grafsen',),
'grafsnere': ('grafsen',),
'grafsnest': ('grafsen',),
'grafsneste': ('grafsen',),
'gram': ('gram',),
'gramme': ('gram',),
'grammere': ('gram',),
'grammest': ('gram',),
'grammeste': ('gram',),
'gramt': ('gram',),
'grammatikalsk': ('grammatikalsk',),
'grammatikalske': ('grammatikalsk',),
'grammatikalskere': ('grammatikalsk',),
'grammatikalskest': ('grammatikalsk',),
'grammatikalskeste': ('grammatikalsk',),
'grammatisk': ('grammatisk',),
'grammatiske': ('grammatisk',),
'grammatiskere': ('grammatisk',),
'grammatiskest': ('grammatisk',),
'grammatiskeste': ('grammatisk',),
'gramnegativ': ('gramnegativ',),
'gramnegative': ('gramnegativ',),
'gramnegativere': ('gramnegativ',),
'gramnegativest': ('gramnegativ',),
'gramnegativeste': ('gramnegativ',),
'gramnegativt': ('gramnegativ',),
'grampositiv': ('grampositiv',),
'grampositive': ('grampositiv',),
'grampositivere': ('grampositiv',),
'grampositivest': ('grampositiv',),
'grampositiveste': ('grampositiv',),
'grampositivt': ('grampositiv',),
'gramsa': ('gramse',),
'gramsede': ('gramse',),
'gramsende': ('gramse',),
'gramset': ('gramse',),
'gramsete': ('gramse',),
'grand': ('grand',),
'grandios': ('grandios',),
'grandiose': ('grandios',),
'grandiosere': ('grandios',),
'grandiosest': ('grandios',),
'grandioseste': ('grandios',),
'grandiost': ('grandios',),
'granittisk': ('granittisk',),
'granittiske': ('granittisk',),
'granittiskere': ('granittisk',),
'granittiskest': ('granittisk',),
'granittiskeste': ('granittisk',),
'grann': ('grann',),
'granne': ('grann',),
'grannere': ('grann',),
'grannest': ('grann',),
'granneste': ('grann',),
'grant': ('grann',),
'grannmælt': ('grannmælt',),
'grannmælte': ('grannmælt',),
'grannmæltere': ('grannmælt',),
'grannmæltest': ('grannmælt',),
'grannmælteste': ('grannmælt',),
'grannvokst': ('grannvokst',),
'grannvokste': ('grannvokst',),
'grannvokstere': ('grannvokst',),
'grannvokstest': ('grannvokst',),
'grannvoksteste': ('grannvokst',),
'granska': ('granske',),
'granskede': ('granske',),
'granskende': ('granske',),
'gransket': ('granske',),
'granskete': ('granske',),
'granulerende': ('granulere',),
'granulert': ('granulere',),
'granulerte': ('granulere',),
'grasa': ('grase',),
'grasede': ('grase',),
'grasende': ('grase',),
'graset': ('grase',),
'grasete': ('grase',),
'grasgrodd': ('grasgrodd',),
'grasgrodde': ('grasgrodd',),
'grasgroddere': ('grasgrodd',),
'grasgroddest': ('grasgrodd',),
'grasgroddeste': ('grasgrodd',),
'grasil': ('grasil',),
'grasile': ('grasil',),
'grasilere': ('grasil',),
'grasilest': ('grasil',),
'grasileste': ('grasil',),
'grasilt': ('grasil',),
'grasiøs': ('grasiøs',),
'grasiøse': ('grasiøs',),
'grasiøsere': ('grasiøs',),
'grasiøsest': ('grasiøs',),
'grasiøseste': ('grasiøs',),
'grasiøst': ('grasiøs',),
'graskledd': ('graskledd',),
'graskledde': ('graskledd',),
'graskleddere': ('graskledd',),
'graskleddest': ('graskledd',),
'graskleddeste': ('graskledd',),
'grasserende': ('grassere',),
'grassert': ('grassere',),
'grasserte': ('grassere',),
'gratinerende': ('gratinere',),
'gratinert': ('gratinere',),
'gratinerte': ('gratinere',),
'gratis': ('gratis',),
'gratulerende': ('gratulere',),
'gratulert': ('gratulere',),
'gratulerte': ('gratulere',),
'grautaktig': ('grautaktig',),
'grautaktige': ('grautaktig',),
'grautaktigere': ('grautaktig',),
'grautaktigst': ('grautaktig',),
'grautaktigste': ('grautaktig',),
'grauten': ('grauten',),
'grautent': ('grauten',),
'grautne': ('grauten',),
'grautnere': ('grauten',),
'grautnest': ('grauten',),
'grautneste': ('grauten',),
'grautet': ('grautet',),
'grautete': ('grautet',),
'grautetere': ('grautet',),
'grautetest': ('grautet',),
'grauteteste': ('grautet',),
'grautete': ('grautete',),
'gravalvorlig': ('gravalvorlig',),
'gravalvorlige': ('gravalvorlig',),
'gravalvorligere': ('gravalvorlig',),
'gravalvorligst': ('gravalvorlig',),
'gravalvorligste': ('gravalvorlig',),
'grava': ('grave',),
'gravd': ('grave',),
'gravde': ('grave',),
'gravede': ('grave',),
'gravende': ('grave',),
'gravet': ('grave',),
'gravete': ('grave',),
'gravd': ('grave',),
'gravde': ('grave',),
'gravende': ('grave',),
'graverende': ('gravere',),
'gravert': ('gravere',),
'graverte': ('gravere',),
'graverende': ('graverende',),
'gravid': ('gravid',),
'gravide': ('gravid',),
'gravidere': ('gravid',),
'gravidest': ('gravid',),
'gravideste': ('gravid',),
'graviterende': ('gravitere',),
'gravitert': ('gravitere',),
'graviterte': ('gravitere',),
'gravitetisk': ('gravitetisk',),
'gravitetiske': ('gravitetisk',),
'gravitetiskere': ('gravitetisk',),
'gravitetiskest': ('gravitetisk',),
'gravitetiskeste': ('gravitetisk',),
'gravlagt': ('gravlegge',),
'gravlagte': ('gravlegge',),
'gravleggende': ('gravlegge',),
'gredd': ('gre',),
'gredde': ('gre',),
'greende': ('gre',),
'gregoriansk': ('gregoriansk',),
'gregorianske': ('gregoriansk',),
'gregorianskere': ('gregoriansk',),
'gregorianskest': ('gregoriansk',),
'gregorianskeste': ('gregoriansk',),
'grei': ('grei',),
'greie': ('grei',),
'greiere': ('grei',),
'greiest': ('grei',),
'greieste': ('grei',),
'greit': ('grei',),
'greitt': ('grei',),
'greid': ('greie',),
'greidd': ('greie',),
'greidde': ('greie',),
'greide': ('greie',),
'greiende': ('greie',),
'greid': ('greie',),
'greidd': ('greie',),
'greidde': ('greie',),
'greide': ('greie',),
'greiende': ('greie',),
'greina': ('greine',),
'greinede': ('greine',),
'greinende': ('greine',),
'greinet': ('greine',),
'greinete': ('greine',),
'greint': ('greine',),
'greinte': ('greine',),
'greinet': ('greinet',),
'greinete': ('greinet',),
'greinetere': ('greinet',),
'greinetest': ('greinet',),
'greineteste': ('greinet',),
'greinete': ('greinete',),
'grell': ('grell',),
'grelle': ('grell',),
'grellere': ('grell',),
'grellest': ('grell',),
'grelleste': ('grell',),
'grelt': ('grell',),
'gremma': ('gremme',),
'gremmede': ('gremme',),
'gremmende': ('gremme',),
'gremmet': ('gremme',),
'gremmete': ('gremme',),
'gremt': ('gremme',),
'gremte': ('gremme',),
'grenadisk': ('grenadisk',),
'grenadiske': ('grenadisk',),
'grenadiskere': ('grenadisk',),
'grenadiskest': ('grenadisk',),
'grenadiskeste': ('grenadisk',),
'grena': ('grene',),
'grenede': ('grene',),
'grenende': ('grene',),
'grenet': ('grene',),
'grenete': ('grene',),
'grent': ('grene',),
'grente': ('grene',),
'grenet': ('grenet',),
'grenete': ('grenet',),
'grenetere': ('grenet',),
'grenetest': ('grenet',),
'greneteste': ('grenet',),
'grenete': ('grenete',),
'grensa': ('grense',),
'grensede': ('grense',),
'grensende': ('grense',),
'grenset': ('grense',),
'grensete': ('grense',),
'grenselaus': ('grenselaus',),
'grenselause': ('grenselaus',),
'grenselausere': ('grenselaus',),
'grenselausest': ('grenselaus',),
'grenselauseste': ('grenselaus',),
'grenselaust': ('grenselaus',),
'grenseløs': ('grenseløs',),
'grenseløse': ('grenseløs',),
'grenseløsere': ('grenseløs',),
'grenseløsest': ('grenseløs',),
'grenseløseste': ('grenseløs',),
'grenseløst': ('grenseløs',),
'grepa': ('grepa',),
'grepen': ('grepen',),
'grepet': ('grepen',),
'grepne': ('grepen',),
'grepnere': ('grepen',),
'grepnest': ('grepen',),
'grepneste': ('grepen',),
'grepet': ('grepet',),
'grepne': ('grepet',),
'grepnere': ('grepet',),
'grepnest': ('grepet',),
'grepneste': ('grepet',),
'gresk': ('gresk',),
'greske': ('gresk',),
'greskere': ('gresk',),
'greskest': ('gresk',),
'greskeste': ('gresk',),
'gresk-katolsk': ('gresk-katolsk',),
'gresk-katolske': ('gresk-katolsk',),
'gresk-katolskere': ('gresk-katolsk',),
'gresk-katolskest': ('gresk-katolsk',),
'gresk-katolskeste': ('gresk-katolsk',),
'gresk-ortodoks': ('gresk-ortodoks',),
'gresk-ortodokse': ('gresk-ortodoks',),
'gresk-ortodoksere': ('gresk-ortodoks',),
'gresk-ortodoksest': ('gresk-ortodoks',),
'gresk-ortodokseste': ('gresk-ortodoks',),
'gresk-ortodokst': ('gresk-ortodoks',),
'gresk-romersk': ('gresk-romersk',),
'gresk-romerske': ('gresk-romersk',),
'gresk-romerskere': ('gresk-romersk',),
'gresk-romerskest': ('gresk-romersk',),
'gresk-romerskeste': ('gresk-romersk',),
'gressa': ('gresse',),
'gressede': ('gresse',),
'gressende': ('gresse',),
'gresset': ('gresse',),
'gressete': ('gresse',),
'gresselig': ('gresselig',),
'gresselige': ('gresselig',),
'gresseligere': ('gresselig',),
'gresseligst': ('gresselig',),
'gresseligste': ('gresselig',),
'gressgrodd': ('gressgrodd',),
'gressgrodde': ('gressgrodd',),
'gressgroddere': ('gressgrodd',),
'gressgroddest': ('gressgrodd',),
'gressgroddeste': ('gressgrodd',),
'gresskledd': ('gresskledd',),
'gresskledde': ('gresskledd',),
'gresskleddere': ('gresskledd',),
'gresskleddest': ('gresskledd',),
'gresskleddeste': ('gresskledd',),
'gretne': ('gretten',),
'gretnere': ('gretten',),
'gretnest': ('gretten',),
'gretneste': ('gretten',),
'gretten': ('gretten',),
'grettent': ('gretten',),
'grevelig': ('grevelig',),
'grevelige': ('grevelig',),
'greveligere': ('grevelig',),
'greveligst': ('grevelig',),
'greveligste': ('grevelig',),
'griljerende': ('griljere',),
'griljert': ('griljere',),
'griljerte': ('griljere',),
'grilla': ('grille',),
'grillede': ('grille',),
'grillende': ('grille',),
'grillet': ('grille',),
'grillete': ('grille',),
'grillsteikt': ('grillsteikt',),
'grillsteikte': ('grillsteikt',),
'grillsteiktere': ('grillsteikt',),
'grillsteiktest': ('grillsteikt',),
'grillsteikteste': ('grillsteikt',),
'grillstekt': ('grillstekt',),
'grillstekte': ('grillstekt',),
'grillstektere': ('grillstekt',),
'grillstektest': ('grillstekt',),
'grillstekteste': ('grillstekt',),
'grim': ('grim',),
'grimme': ('grim',),
'grimmere': ('grim',),
'grimmest': ('grim',),
'grimmeste': ('grim',),
'grimt': ('grim',),
'grima': ('grime',),
'grimede': ('grime',),
'grimende': ('grime',),
'grimet': ('grime',),
'grimete': ('grime',),
'grimet': ('grimet',),
'grimete': ('grimet',),
'grimetere': ('grimet',),
'grimetest': ('grimet',),
'grimeteste': ('grimet',),
'grimete': ('grimete',),
'grinaktig': ('grinaktig',),
'grinaktige': ('grinaktig',),
'grinaktigere': ('grinaktig',),
'grinaktigst': ('grinaktig',),
'grinaktigste': ('grinaktig',),
'grinende': ('grine',),
'grint': ('grine',),
'grinte': ('grine',),
'grinet': ('grinet',),
'grinete': ('grinet',),
'grinetere': ('grinet',),
'grinetest': ('grinet',),
'grineteste': ('grinet',),
'grinete': ('grinete',),
'grepen': ('gripe',),
'grepet': ('gripe',),
'grepne': ('gripe',),
'gripende': ('gripe',),
'gripende': ('gripende',),
'grisa': ('grise',),
'grisede': ('grise',),
'grisende': ('grise',),
'griset': ('grise',),
'grisete': ('grise',),
'grist': ('grise',),
'griste': ('grise',),
'griset': ('griset',),
'grisete': ('griset',),
'grisetere': ('griset',),
'grisetest': ('griset',),
'griseteste': ('griset',),
'grisete': ('grisete',),
'grisgrendt': ('grisgrendt',),
'grisgrendte': ('grisgrendt',),
'grisgrendtere': ('grisgrendt',),
'grisgrendtest': ('grisgrendt',),
'grisgrendteste': ('grisgrendt',),
'grisk': ('grisk',),
'griske': ('grisk',),
'griskere': ('grisk',),
'griskest': ('grisk',),
'griskeste': ('grisk',),
'griskt': ('grisk',),
'grisla': ('grisle',),
'grislede': ('grisle',),
'grislende': ('grisle',),
'grislet': ('grisle',),
'grislete': ('grisle',),
'grisna': ('grisne',),
'grisnede': ('grisne',),
'grisnende': ('grisne',),
'grisnet': ('grisne',),
'grisnete': ('grisne',),
'grisne': ('grissen',),
'grisnere': ('grissen',),
'grisnest': ('grissen',),
'grisneste': ('grissen',),
'grissen': ('grissen',),
'grissent': ('grissen',),
'grissgrendt': ('grissgrendt',),
'grissgrendte': ('grissgrendt',),
'grissgrendtere': ('grissgrendt',),
'grissgrendtest': ('grissgrendt',),
'grissgrendteste': ('grissgrendt',),
'grisøyd': ('grisøyd',),
'grisøyde': ('grisøyd',),
'grisøydere': ('grisøyd',),
'grisøydest': ('grisøyd',),
'grisøydeste': ('grisøyd',),
'grodd': ('gro',),
'grodde': ('gro',),
'groende': ('gro',),
'groggy': ('groggy',),
'grom': ('grom',),
'gromme': ('grom',),
'grommere': ('grom',),
'grommest': ('grom',),
'grommeste': ('grom',),
'gromt': ('grom',),
'gropa': ('grope',),
'gropede': ('grope',),
'gropende': ('grope',),
'gropet': ('grope',),
'gropete': ('grope',),
'grotesk': ('grotesk',),
'groteske': ('grotesk',),
'groteskere': ('grotesk',),
'groteskest': ('grotesk',),
'groteskeste': ('grotesk',),
'grov': ('grov',),
'grove': ('grov',),
'grovere': ('grov',),
'grovest': ('grov',),
'groveste': ('grov',),
'grovt': ('grov',),
'grøvst': ('grov',),
'grøvste': ('grov',),
'grovbarka': ('grovbarka',),
'grovbarkede': ('grovbarket',),
'grovbarket': ('grovbarket',),
'grovbarkete': ('grovbarket',),
'grovbarketere': ('grovbarket',),
'grovbarketest': ('grovbarket',),
'grovbarketeste': ('grovbarket',),
'grovbygd': ('grovbygd',),
'grovbygde': ('grovbygd',),
'grovbygdere': ('grovbygd',),
'grovbygdest': ('grovbygd',),
'grovbygdeste': ('grovbygd',),
'grovdimensjonert': ('grovdimensjonert',),
'grovdimensjonerte': ('grovdimensjonert',),
'grovdimensjonertere': ('grovdimensjonert',),
'grovdimensjonertest': ('grovdimensjonert',),
'grovdimensjonerteste': ('grovdimensjonert',),
'grovhakka': ('grovhakke',),
'grovhakkede': ('grovhakke',),
'grovhakkende': ('grovhakke',),
'grovhakket': ('grovhakke',),
'grovhakkete': ('grovhakke',),
'grovkorna': ('grovkorna',),
'grovkornede': ('grovkornet',),
'grovkornet': ('grovkornet',),
'grovkornete': ('grovkornet',),
'grovkornetere': ('grovkornet',),
'grovkornetest': ('grovkornet',),
'grovkorneteste': ('grovkornet',),
'grovmalende': ('grovmale',),
'grovmalt': ('grovmale',),
'grovmalte': ('grovmale',),
'grovmælt': ('grovmælt',),
'grovmælte': ('grovmælt',),
'grovmæltere': ('grovmælt',),
'grovmæltest': ('grovmælt',),
'grovmælteste': ('grovmælt',),
'grovsikta': ('grovsikte',),
'grovsiktede': ('grovsikte',),
'grovsiktende': ('grovsikte',),
'grovsiktet': ('grovsikte',),
'grovsiktete': ('grovsikte',),
'grovskåret': ('grovskåret',),
'grovskårne': ('grovskåret',),
'grovskårnere': ('grovskåret',),
'grovskårnest': ('grovskåret',),
'grovskårneste': ('grovskåret',),
'grovsorterende': ('grovsortere',),
'grovsortert': ('grovsortere',),
'grovsorterte': ('grovsortere',),
'grovtalt': ('grovtelle',),
'grovtalte': ('grovtelle',),
'grovtella': ('grovtelle',),
'grovtellede': ('grovtelle',),
'grovtellende': ('grovtelle',),
'grovtellet': ('grovtelle',),
'grovtellete': ('grovtelle',),
'grovtelt': ('grovtelle',),
'grovtelte': ('grovtelle',),
'grubla': ('gruble',),
'grublede': ('gruble',),
'grublende': ('gruble',),
'grublet': ('gruble',),
'grublete': ('gruble',),
'grua': ('grue',),
'grudd': ('grue',),
'grudde': ('grue',),
'gruede': ('grue',),
'gruende': ('grue',),
'gruet': ('grue',),
'gruete': ('grue',),
'gruelig': ('gruelig',),
'gruelige': ('gruelig',),
'grueligere': ('gruelig',),
'grueligst': ('gruelig',),
'grueligste': ('gruelig',),
'grufull': ('grufull',),
'grufulle': ('grufull',),
'grufullere': ('grufull',),
'grufullest': ('grufull',),
'grufulleste': ('grufull',),
'grufullt': ('grufull',),
'gruggen': ('gruggen',),
'gruggent': ('gruggen',),
'grugne': ('gruggen',),
'grugnere': ('gruggen',),
'grugnest': ('gruggen',),
'grugneste': ('gruggen',),
'grugget': ('grugget',),
'gruggete': ('grugget',),
'gruggetere': ('grugget',),
'gruggetest': ('grugget',),
'gruggeteste': ('grugget',),
'gruggete': ('gruggete',),
'grum': ('grum',),
'grumme': ('grum',),
'grummere': ('grum',),
'grummest': ('grum',),
'grummeste': ('grum',),
'grumt': ('grum',),
'grumsa': ('grumse',),
'grumsede': ('grumse',),
'grumsende': ('grumse',),
'grumset': ('grumse',),
'grumsete': ('grumse',),
'grumset': ('grumset',),
'grumsete': ('grumset',),
'grumsetere': ('grumset',),
'grumsetest': ('grumset',),
'grumseteste': ('grumset',),
'grumsete': ('grumsete',),
'grunderende': ('grundere',),
'grundert': ('grundere',),
'grunderte': ('grundere',),
'grundig': ('grundig',),
'grundige': ('grundig',),
'grundigere': ('grundig',),
'grundigst': ('grundig',),
'grundigste': ('grundig',),
'grundtvigiansk': ('grundtvigiansk',),
'grundtvigianske': ('grundtvigiansk',),
'grundtvigianskere': ('grundtvigiansk',),
'grundtvigianskest': ('grundtvigiansk',),
'grundtvigianskeste': ('grundtvigiansk',),
'grunn': ('grunn',),
'grunne': ('grunn',),
'grunnere': ('grunn',),
'grunnest': ('grunn',),
'grunneste': ('grunn',),
'grunt': ('grunn',),
'grunna': ('grunne',),
'grunnede': ('grunne',),
'grunnende': ('grunne',),
'grunnet': ('grunne',),
'grunnete': ('grunne',),
'grunna': ('grunne',),
'grunnede': ('grunne',),
'grunnende': ('grunne',),
'grunnet': ('grunne',),
'grunnete': ('grunne',),
'grunna': ('grunne',),
'grunnede': ('grunne',),
'grunnende': ('grunne',),
'grunnet': ('grunne',),
'grunnete': ('grunne',),
'grunnfalsk': ('grunnfalsk',),
'grunnfalske': ('grunnfalsk',),
'grunnfalskere': ('grunnfalsk',),
'grunnfalskest': ('grunnfalsk',),
'grunnfalskeste': ('grunnfalsk',),
'grunnfalskt': ('grunnfalsk',),
'grunnfast': ('grunnfast',),
'grunnfaste': ('grunnfast',),
'grunnfastere': ('grunnfast',),
'grunnfastest': ('grunnfast',),
'grunnfasteste': ('grunnfast',),
'grunnfesta': ('grunnfesta',),
'grunnfesta': ('grunnfeste',),
'grunnfestede': ('grunnfeste',),
'grunnfestende': ('grunnfeste',),
'grunnfestet': ('grunnfeste',),
'grunnfestete': ('grunnfeste',),
'grunnfestede': ('grunnfestet',),
'grunnfestet': ('grunnfestet',),
'grunnfestete': ('grunnfestet',),
'grunnfestetere': ('grunnfestet',),
'grunnfestetest': ('grunnfestet',),
'grunnfesteteste': ('grunnfestet',),
'grunngiende': ('grunngi',),
'grunngitt': ('grunngi',),
'grunngitte': ('grunngi',),
'grunngivende': ('grunngi',),
'grunnlaus': ('grunnlaus',),
'grunnlause': ('grunnlaus',),
'grunnlausere': ('grunnlaus',),
'grunnlausest': ('grunnlaus',),
'grunnlauseste': ('grunnlaus',),
'grunnlaust': ('grunnlaus',),
'grunnlagt': ('grunnlegge',),
'grunnlagte': ('grunnlegge',),
'grunnleggende': ('grunnlegge',),
'grunnleggende': ('grunnleggende',),
'grunnlovfesta': ('grunnlovfesta',),
'grunnlovfestede': ('grunnlovfestet',),
'grunnlovfestet': ('grunnlovfestet',),
'grunnlovfestete': ('grunnlovfestet',),
'grunnlovfestetere': ('grunnlovfestet',),
'grunnlovfestetest': ('grunnlovfestet',),
'grunnlovfesteteste': ('grunnlovfestet',),
'grunnlovgivende': ('grunnlovgivende',),
'grunnlovlig': ('grunnlovlig',),
'grunnlovlige': ('grunnlovlig',),
'grunnlovligere': ('grunnlovlig',),
'grunnlovligst': ('grunnlovlig',),
'grunnlovligste': ('grunnlovlig',),
'grunnlovsstridig': ('grunnlovsstridig',),
'grunnlovsstridige': ('grunnlovsstridig',),
'grunnlovsstridigere': ('grunnlovsstridig',),
'grunnlovsstridigst': ('grunnlovsstridig',),
'grunnlovsstridigste': ('grunnlovsstridig',),
'grunnløs': ('grunnløs',),
'grunnløse': ('grunnløs',),
'grunnløsere': ('grunnløs',),
'grunnløsest': ('grunnløs',),
'grunnløseste': ('grunnløs',),
'grunnløst': ('grunnløs',),
'grunnrik': ('grunnrik',),
'grunnrike': ('grunnrik',),
'grunnrikere': ('grunnrik',),
'grunnrikest': ('grunnrik',),
'grunnrikeste': ('grunnrik',),
'grunnrikt': ('grunnrik',),
'grunnsatt': ('grunnsette',),
'grunnsatte': ('grunnsette',),
'grunnsettende': ('grunnsette',),
'grunnsolid': ('grunnsolid',),
'grunnsolide': ('grunnsolid',),
'grunnsolidere': ('grunnsolid',),
'grunnsolidest': ('grunnsolid',),
'grunnsolideste': ('grunnsolid',),
'grunnstøtende': ('grunnstøte',),
'grunnstøtt': ('grunnstøte',),
'grunnstøtte': ('grunnstøte',),
'gruntgående': ('gruntgående',),
'grupperende': ('gruppere',),
'gruppert': ('gruppere',),
'grupperte': ('gruppere',),
'grusa': ('gruse',),
'grusede': ('gruse',),
'grusende': ('gruse',),
'gruset': ('gruse',),
'grusete': ('gruse',),
'gruselig': ('gruselig',),
'gruselige': ('gruselig',),
'gruseligere': ('gruselig',),
'gruseligst': ('gruselig',),
'gruseligste': ('gruselig',),
'gruset': ('gruset',),
'grusete': ('gruset',),
'grusetere': ('gruset',),
'grusetest': ('gruset',),
'gruseteste': ('gruset',),
'grusete': ('grusete',),
'grusisk': ('grusisk',),
'grusiske': ('grusisk',),
'grusiskere': ('grusisk',),
'grusiskest': ('grusisk',),
'grusiskeste': ('grusisk',),
'gruslagt': ('gruslegge',),
'gruslagte': ('gruslegge',),
'grusleggende': ('gruslegge',),
'grusom': ('grusom',),
'grusomme': ('grusom',),
'grusommere': ('grusom',),
'grusomst': ('grusom',),
'grusomste': ('grusom',),
'grusomt': ('grusom',),
'grydd': ('gry',),
'grydde': ('gry',),
'gryende': ('gry',),
'grynende': ('gryne',),
'grynt': ('gryne',),
'grynte': ('gryne',),
'grynet': ('grynet',),
'grynete': ('grynet',),
'grynetere': ('grynet',),
'grynetest': ('grynet',),
'gryneteste': ('grynet',),
'grynete': ('grynete',),
'grynta': ('grynte',),
'gryntede': ('grynte',),
'gryntende': ('grynte',),
'gryntet': ('grynte',),
'gryntete': ('grynte',),
'gryteferdig': ('gryteferdig',),
'gryteferdige': ('gryteferdig',),
'gryteferdigere': ('gryteferdig',),
'gryteferdigst': ('gryteferdig',),
'gryteferdigste': ('gryteferdig',),
'grytidlig': ('grytidlig',),
'grytidlige': ('grytidlig',),
'grytidligere': ('grytidlig',),
'grytidligst': ('grytidlig',),
'grytidligste': ('grytidlig',),
'grå': ('grå',),
'gråe': ('grå',),
'gråere': ('grå',),
'gråest': ('grå',),
'gråeste': ('grå',),
'grått': ('grå',),
'gråaktig': ('gråaktig',),
'gråaktige': ('gråaktig',),
'gråaktigere': ('gråaktig',),
'gråaktigst': ('gråaktig',),
'gråaktigste': ('gråaktig',),
'grådig': ('grådig',),
'grådige': ('grådig',),
'grådigere': ('grådig',),
'grådigst': ('grådig',),
'grådigste': ('grådig',),
'gråhåra': ('gråhåra',),
'gråhårede': ('gråhåret',),
'gråhåret': ('gråhåret',),
'gråhårete': ('gråhåret',),
'gråhåretere': ('gråhåret',),
'gråhåretest': ('gråhåret',),
'gråhåreteste': ('gråhåret',),
'gråkald': ('gråkald',),
'gråkalde': ('gråkald',),
'gråkaldere': ('gråkald',),
'gråkaldest': ('gråkald',),
'gråkaldeste': ('gråkald',),
'gråkaldt': ('gråkald',),
'grålende': ('gråle',),
'grålt': ('gråle',),
'grålte': ('gråle',),
'grålig': ('grålig',),
'grålige': ('grålig',),
'gråligere': ('grålig',),
'gråligst': ('grålig',),
'gråligste': ('grålig',),
'gråna': ('gråne',),
'grånede': ('gråne',),
'grånende': ('gråne',),
'grånet': ('gråne',),
'grånete': ('gråne',),
'gråskitne': ('gråskitten',),
'gråskitnere': ('gråskitten',),
'gråskitnest': ('gråskitten',),
'gråskitneste': ('gråskitten',),
'gråskitten': ('gråskitten',),
'gråskittent': ('gråskitten',),
'gråtblanda': ('gråtblanda',),
'gråtblandede': ('gråtblandet',),
'gråtblandet': ('gråtblandet',),
'gråtblandete': ('gråtblandet',),
'gråtblandetere': ('gråtblandet',),
'gråtblandetest': ('gråtblandet',),
'gråtblandeteste': ('gråtblandet',),
'gråtende': ('gråte',),
'grått': ('gråte',),
'gråtte': ('gråte',),
'gråteferdig': ('gråteferdig',),
'gråteferdige': ('gråteferdig',),
'gråteferdigere': ('gråteferdig',),
'gråteferdigst': ('gråteferdig',),
'gråteferdigste': ('gråteferdig',),
'gråtkvalt': ('gråtkvalt',),
'gråtkvalte': ('gråtkvalt',),
'gråtkvaltere': ('gråtkvalt',),
'gråtkvaltest': ('gråtkvalt',),
'gråtkvalteste': ('gråtkvalt',),
'gråøyd': ('gråøyd',),
'gråøyde': ('gråøyd',),
'gråøydere': ('gråøyd',),
'gråøydest': ('gråøyd',),
'gråøydeste': ('gråøyd',),
'grødd': ('grø',),
'grødde': ('grø',),
'grøende': ('grø',),
'grødd': ('grø',),
'grødde': ('grø',),
'grøende': ('grø',),
'grødd': ('grøde',),
'grødde': ('grøde',),
'grødende': ('grøde',),
'grødd': ('grøde',),
'grødde': ('grøde',),
'grødende': ('grøde',),
'grødefull': ('grødefull',),
'grødefulle': ('grødefull',),
'grødefullere': ('grødefull',),
'grødefullest': ('grødefull',),
'grødefulleste': ('grødefull',),
'grødefullt': ('grødefull',),
'grøderik': ('grøderik',),
'grøderike': ('grøderik',),
'grøderikere': ('grøderik',),
'grøderikest': ('grøderik',),
'grøderikeste': ('grøderik',),
'grøderikt': ('grøderik',),
'grøfta': ('grøfte',),
'grøftede': ('grøfte',),
'grøftende': ('grøfte',),
'grøftet': ('grøfte',),
'grøftete': ('grøfte',),
'grøn': ('grøn',),
'grøne': ('grøn',),
'grønere': ('grøn',),
'grønest': ('grøn',),
'grøneste': ('grøn',),
'grønt': ('grøn',),
'grøn': ('grøn',),
'grøne': ('grøn',),
'grønere': ('grøn',),
'grønest': ('grøn',),
'grøneste': ('grøn',),
'grønt': ('grøn',),
'grønaktig': ('grønaktig',),
'grønaktige': ('grønaktig',),
'grønaktigere': ('grønaktig',),
'grønaktigst': ('grønaktig',),
'grønaktigste': ('grønaktig',),
'grønaktig': ('grønaktig',),
'grønaktige': ('grønaktig',),
'grønaktigere': ('grønaktig',),
'grønaktigst': ('grønaktig',),
'grønaktigste': ('grønaktig',),
'grønka': ('grønke',),
'grønkede': ('grønke',),
'grønkende': ('grønke',),
'grønket': ('grønke',),
'grønkete': ('grønke',),
'grønlandsk': ('grønlandsk',),
'grønlandske': ('grønlandsk',),
'grønlandskere': ('grønlandsk',),
'grønlandskest': ('grønlandsk',),
'grønlandskeste': ('grønlandsk',),
'grønlig': ('grønlig',),
'grønlige': ('grønlig',),
'grønligere': ('grønlig',),
'grønligst': ('grønlig',),
'grønligste': ('grønlig',),
'grønlig': ('grønlig',),
'grønlige': ('grønlig',),
'grønligere': ('grønlig',),
'grønligst': ('grønlig',),
'grønligste': ('grønlig',),
'grønn': ('grønn',),
'grønne': ('grønn',),
'grønnere': ('grønn',),
'grønnest': ('grønn',),
'grønneste': ('grønn',),
'grønt': ('grønn',),
'grønn': ('grønn',),
'grønne': ('grønn',),
'grønnere': ('grønn',),
'grønnest': ('grønn',),
'grønneste': ('grønn',),
'grønt': ('grønn',),
'grønnaktig': ('grønnaktig',),
'grønnaktige': ('grønnaktig',),
'grønnaktigere': ('grønnaktig',),
'grønnaktigst': ('grønnaktig',),
'grønnaktigste': ('grønnaktig',),
'grønnaktig': ('grønnaktig',),
'grønnaktige': ('grønnaktig',),
'grønnaktigere': ('grønnaktig',),
'grønnaktigst': ('grønnaktig',),
'grønnaktigste': ('grønnaktig',),
'grønnlig': ('grønnlig',),
'grønnlige': ('grønnlig',),
'grønnligere': ('grønnlig',),
'grønnligst': ('grønnlig',),
'grønnligste': ('grønnlig',),
'grønnlig': ('grønnlig',),
'grønnlige': ('grønnlig',),
'grønnligere': ('grønnlig',),
'grønnligst': ('grønnlig',),
'grønnligste': ('grønnlig',),
'grønska': ('grønske',),
'grønskede': ('grønske',),
'grønskende': ('grønske',),
'grønsket': ('grønske',),
'grønskete': ('grønske',),
'grønsket': ('grønsket',),
'grønskete': ('grønsket',),
'grønsketere': ('grønsket',),
'grønsketest': ('grønsket',),
'grønsketeste': ('grønsket',),
'grønskete': ('grønskete',),
'grøppa': ('grøppe',),
'grøppede': ('grøppe',),
'grøppende': ('grøppe',),
'grøppet': ('grøppe',),
'grøppete': ('grøppe',),
'grøpt': ('grøppe',),
'grøpte': ('grøppe',),
'grøssa': ('grøsse',),
'grøssede': ('grøsse',),
'grøssende': ('grøsse',),
'grøsset': ('grøsse',),
'grøssete': ('grøsse',),
'grøst': ('grøsse',),
'grøste': ('grøsse',),
'grøtaktig': ('grøtaktig',),
'grøtaktige': ('grøtaktig',),
'grøtaktigere': ('grøtaktig',),
'grøtaktigst': ('grøtaktig',),
'grøtaktigste': ('grøtaktig',),
'grøtet': ('grøtet',),
'grøtete': ('grøtet',),
'grøtetere': ('grøtet',),
'grøtetest': ('grøtet',),
'grøteteste': ('grøtet',),
'grøtete': ('grøtete',),
'guatemalansk': ('guatemalansk',),
'guatemalanske': ('guatemalansk',),
'guatemalanskere': ('guatemalansk',),
'guatemalanskest': ('guatemalansk',),
'guatemalanskeste': ('guatemalansk',),
'gudbenåda': ('gudbenåda',),
'gudbenådede': ('gudbenådet',),
'gudbenådet': ('gudbenådet',),
'gudbenådete': ('gudbenådet',),
'gudbenådetere': ('gudbenådet',),
'gudbenådetest': ('gudbenådet',),
'gudbenådeteste': ('gudbenådet',),
'gudbrandsdalsk': ('gudbrandsdalsk',),
'gudbrandsdalske': ('gudbrandsdalsk',),
'gudbrandsdalskere': ('gudbrandsdalsk',),
'gudbrandsdalskest': ('gudbrandsdalsk',),
'gudbrandsdalskeste': ('gudbrandsdalsk',),
'guddommelig': ('guddommelig',),
'guddommelige': ('guddommelig',),
'guddommeligere': ('guddommelig',),
'guddommeligst': ('guddommelig',),
'guddommeligste': ('guddommelig',),
'gudelig': ('gudelig',),
'gudelige': ('gudelig',),
'gudeligere': ('gudelig',),
'gudeligst': ('gudelig',),
'gudeligste': ('gudelig',),
'gudfryktig': ('gudfryktig',),
'gudfryktige': ('gudfryktig',),
'gudfryktigere': ('gudfryktig',),
'gudfryktigst': ('gudfryktig',),
'gudfryktigste': ('gudfryktig',),
'gudgitt': ('gudgitt',),
'gudgitte': ('gudgitt',),
'gudgittere': ('gudgitt',),
'gudgittest': ('gudgitt',),
'gudgitteste': ('gudgitt',),
'gudhengiven': ('gudhengiven',),
'gudhengivent': ('gudhengiven',),
'gudhengivne': ('gudhengiven',),
'gudhengivnere': ('gudhengiven',),
'gudhengivnest': ('gudhengiven',),
'gudhengivneste': ('gudhengiven',),
'gudlaus': ('gudlaus',),
'gudlause': ('gudlaus',),
'gudlausere': ('gudlaus',),
'gudlausest': ('gudlaus',),
'gudlauseste': ('gudlaus',),
'gudlaust': ('gudlaus',),
'gudløs': ('gudløs',),
'gudløse': ('gudløs',),
'gudløsere': ('gudløs',),
'gudløsest': ('gudløs',),
'gudløseste': ('gudløs',),
'gudløst': ('gudløs',),
'gudnådslig': ('gudnådslig',),
'gudnådslige': ('gudnådslig',),
'gudnådsligere': ('gudnådslig',),
'gudnådsligst': ('gudnådslig',),
'gudnådsligste': ('gudnådslig',),
'gudsbespottelig': ('gudsbespottelig',),
'gudsbespottelige': ('gudsbespottelig',),
'gudsbespotteligere': ('gudsbespottelig',),
'gudsbespotteligst': ('gudsbespottelig',),
'gudsbespotteligste': ('gudsbespottelig',),
'gudsendt': ('gudsendt',),
'gudsendte': ('gudsendt',),
'gudsendtere': ('gudsendt',),
'gudsendtest': ('gudsendt',),
'gudsendteste': ('gudsendt',),
'gudsens': ('gudsens',),
'gudsforlatt': ('gudsforlatt',),
'gudsforlatte': ('gudsforlatt',),
'gudsforlattere': ('gudsforlatt',),
'gudsforlattest': ('gudsforlatt',),
'gudsforlatteste': ('gudsforlatt',),
'gudsjammerlig': ('gudsjammerlig',),
'gudsjammerlige': ('gudsjammerlig',),
'gudsjammerligere': ('gudsjammerlig',),
'gudsjammerligst': ('gudsjammerlig',),
'gudsjammerligste': ('gudsjammerlig',),
'gudskapt': ('gudskapt',),
'gudskapte': ('gudskapt',),
'gudskaptere': ('gudskapt',),
'gudskaptest': ('gudskapt',),
'gudskapteste': ('gudskapt',),
'gudstjenstlig': ('gudstjenstlig',),
'gudstjenstlige': ('gudstjenstlig',),
'gudstjenstligere': ('gudstjenstlig',),
'gudstjenstligst': ('gudstjenstlig',),
'gudstjenstligste': ('gudstjenstlig',),
'guffen': ('guffen',),
'guffent': ('guffen',),
'gufne': ('guffen',),
'gufnere': ('guffen',),
'gufnest': ('guffen',),
'gufneste': ('guffen',),
'gufsa': ('gufse',),
'gufsede': ('gufse',),
'gufsende': ('gufse',),
'gufset': ('gufse',),
'gufsete': ('gufse',),
'guida': ('guide',),
'guidede': ('guide',),
'guidende': ('guide',),
'guidet': ('guide',),
'guidete': ('guide',),
'guineansk': ('guineansk',),
'guineanske': ('guineansk',),
'guineanskere': ('guineansk',),
'guineanskest': ('guineansk',),
'guineanskeste': ('guineansk',),
'gul': ('gul',),
'gule': ('gul',),
'gulere': ('gul',),
'gulest': ('gul',),
'guleste': ('gul',),
'gult': ('gul',),
'gulblakk': ('gulblakk',),
'gulblakke': ('gulblakk',),
'gulblakkere': ('gulblakk',),
'gulblakkest': ('gulblakk',),
'gulblakkeste': ('gulblakk',),
'gulblakt': ('gulblakk',),
'gula': ('gule',),
'gulede': ('gule',),
'gulende': ('gule',),
'gulet': ('gule',),
'gulete': ('gule',),
'gulka': ('gulke',),
'gulkede': ('gulke',),
'gulkende': ('gulke',),
'gulket': ('gulke',),
'gulkete': ('gulke',),
'gullblank': ('gullblank',),
'gullblanke': ('gullblank',),
'gullblankere': ('gullblank',),
'gullblankest': ('gullblank',),
'gullblankeste': ('gullblank',),
'gullblankt': ('gullblank',),
'gullkanta': ('gullkanta',),
'gullkantede': ('gullkantet',),
'gullkantet': ('gullkantet',),
'gullkantete': ('gullkantet',),
'gullkantetere': ('gullkantet',),
'gullkantetest': ('gullkantet',),
'gullkanteteste': ('gullkantet',),
'gullslått': ('gullslått',),
'gullslåtte': ('gullslått',),
'gullslåttere': ('gullslått',),
'gullslåttest': ('gullslått',),
'gullslåtteste': ('gullslått',),
'gulmoden': ('gulmoden',),
'gulmodent': ('gulmoden',),
'gulmodne': ('gulmoden',),
'gulmodnere': ('gulmoden',),
'gulmodnest': ('gulmoden',),
'gulmodneste': ('gulmoden',),
'gulna': ('gulne',),
'gulnede': ('gulne',),
'gulnende': ('gulne',),
'gulnet': ('gulne',),
'gulnete': ('gulne',),
'gulpa': ('gulpe',),
'gulpede': ('gulpe',),
'gulpende': ('gulpe',),
'gulpet': ('gulpe',),
'gulpete': ('gulpe',),
'gulrotfarga': ('gulrotfarga',),
'gulrotfargede': ('gulrotfarget',),
'gulrotfarget': ('gulrotfarget',),
'gulrotfargete': ('gulrotfarget',),
'gulrotfargetere': ('gulrotfarget',),
'gulrotfargetest': ('gulrotfarget',),
'gulrotfargeteste': ('gulrotfarget',),
'gummierende': ('gummiere',),
'gummiert': ('gummiere',),
'gummierte': ('gummiere',),
'gunstig': ('gunstig',),
'gunstige': ('gunstig',),
'gunstigere': ('gunstig',),
'gunstigst': ('gunstig',),
'gunstigste': ('gunstig',),
'gurgla': ('gurgle',),
'gurglede': ('gurgle',),
'gurglende': ('gurgle',),
'gurglet': ('gurgle',),
'gurglete': ('gurgle',),
'gurpa': ('gurpe',),
'gurpede': ('gurpe',),
'gurpende': ('gurpe',),
'gurpet': ('gurpe',),
'gurpete': ('gurpe',),
'gursegrøn': ('gursegrøn',),
'gursegrøne': ('gursegrøn',),
'gursegrønere': ('gursegrøn',),
'gursegrønest': ('gursegrøn',),
'gursegrøneste': ('gursegrøn',),
'gursegrønt': ('gursegrøn',),
'gursegrønn': ('gursegrønn',),
'gursegrønne': ('gursegrønn',),
'gursegrønnere': ('gursegrønn',),
'gursegrønnest': ('gursegrønn',),
'gursegrønneste': ('gursegrønn',),
'gursegrønt': ('gursegrønn',),
'gursegul': ('gursegul',),
'gursegule': ('gursegul',),
'gursegulere': ('gursegul',),
'gursegulest': ('gursegul',),
'gurseguleste': ('gursegul',),
'gursegult': ('gursegul',),
'gusta': ('guste',),
'gustede': ('guste',),
'gustende': ('guste',),
'gustet': ('guste',),
'gustete': ('guste',),
'gusten': ('gusten',),
'gustent': ('gusten',),
'gustne': ('gusten',),
'gustnere': ('gusten',),
'gustnest': ('gusten',),
'gustneste': ('gusten',),
'guterende': ('gutere',),
'gutert': ('gutere',),
'guterte': ('gutere',),
'guttaktig': ('guttaktig',),
'guttaktige': ('guttaktig',),
'guttaktigere': ('guttaktig',),
'guttaktigst': ('guttaktig',),
'guttaktigste': ('guttaktig',),
'gutteaktig': ('gutteaktig',),
'gutteaktige': ('gutteaktig',),
'gutteaktigere': ('gutteaktig',),
'gutteaktigst': ('gutteaktig',),
'gutteaktigste': ('gutteaktig',),
'guttegal': ('guttegal',),
'guttegale': ('guttegal',),
'guttegalere': ('guttegal',),
'guttegalest': ('guttegal',),
'guttegaleste': ('guttegal',),
'guttegalt': ('guttegal',),
'guttural': ('guttural',),
'gutturale': ('guttural',),
'gutturalere': ('guttural',),
'gutturalest': ('guttural',),
'gutturaleste': ('guttural',),
'gutturalt': ('guttural',),
'guyansk': ('guyansk',),
'guyanske': ('guyansk',),
'guyanskere': ('guyansk',),
'guyanskest': ('guyansk',),
'guyanskeste': ('guyansk',),
'gyldig': ('gyldig',),
'gyldige': ('gyldig',),
'gyldigere': ('gyldig',),
'gyldigst': ('gyldig',),
'gyldigste': ('gyldig',),
'gylla': ('gylle',),
'gyllede': ('gylle',),
'gyllende': ('gylle',),
'gyllet': ('gylle',),
'gyllete': ('gylle',),
'gylt': ('gylle',),
'gylte': ('gylle',),
'gyllen': ('gyllen',),
'gyllent': ('gyllen',),
'gylne': ('gyllen',),
'gylnere': ('gyllen',),
'gylnest': ('gyllen',),
'gylneste': ('gyllen',),
'gyllenblank': ('gyllenblank',),
'gyllenblanke': ('gyllenblank',),
'gyllenblankere': ('gyllenblank',),
'gyllenblankest': ('gyllenblank',),
'gyllenblankeste': ('gyllenblank',),
'gyllenblankt': ('gyllenblank',),
'gyllenbrun': ('gyllenbrun',),
'gyllenbrune': ('gyllenbrun',),
'gyllenbrunere': ('gyllenbrun',),
'gyllenbrunest': ('gyllenbrun',),
'gyllenbruneste': ('gyllenbrun',),
'gyllenbrunt': ('gyllenbrun',),
'gymnasial': ('gymnasial',),
'gymnasiale': ('gymnasial',),
'gymnasialere': ('gymnasial',),
'gymnasialest': ('gymnasial',),
'gymnasialeste': ('gymnasial',),
'gymnasialt': ('gymnasial',),
'gymnastiserende': ('gymnastisere',),
'gymnastisert': ('gymnastisere',),
'gymnastiserte': ('gymnastisere',),
'gymnastisk': ('gymnastisk',),
'gymnastiske': ('gymnastisk',),
'gymnastiskere': ('gymnastisk',),
'gymnastiskest': ('gymnastisk',),
'gymnastiskeste': ('gymnastisk',),
'gynekologisk': ('gynekologisk',),
'gynekologiske': ('gynekologisk',),
'gynekologiskere': ('gynekologisk',),
'gynekologiskest': ('gynekologisk',),
'gynekologiskeste': ('gynekologisk',),
'gynga': ('gynge',),
'gyngede': ('gynge',),
'gyngende': ('gynge',),
'gynget': ('gynge',),
'gyngete': ('gynge',),
'gysende': ('gyse',),
'gyss': ('gyse',),
'gysse': ('gyse',),
'gyst': ('gyse',),
'gyste': ('gyse',),
'gyselig': ('gyselig',),
'gyselige': ('gyselig',),
'gyseligere': ('gyselig',),
'gyseligst': ('gyselig',),
'gyseligste': ('gyselig',),
'gytende': ('gyte',),
'gytt': ('gyte',),
'gytte': ('gyte',),
'gyteferdig': ('gyteferdig',),
'gyteferdige': ('gyteferdig',),
'gyteferdigere': ('gyteferdig',),
'gyteferdigst': ('gyteferdig',),
'gyteferdigste': ('gyteferdig',),
'gjøven': ('gyve',),
'gjøvet': ('gyve',),
'gjøvne': ('gyve',),
'gyvd': ('gyve',),
'gyvde': ('gyve',),
'gyvende': ('gyve',),
'gående': ('gå',),
'gått': ('gå',),
'gåtte': ('gå',),
'gåen': ('gåen',),
'gåent': ('gåen',),
'gået': ('gåen',),
'gåne': ('gåen',),
'gånere': ('gåen',),
'gånest': ('gåen',),
'gåneste': ('gåen',),
'gående': ('gående',),
'gåra': ('gåre',),
'gårede': ('gåre',),
'gårende': ('gåre',),
'gåret': ('gåre',),
'gårete': ('gåre',),
'gåtefull': ('gåtefull',),
'gåtefulle': ('gåtefull',),
'gåtefullere': ('gåtefull',),
'gåtefullest': ('gåtefull',),
'gåtefulleste': ('gåtefull',),
'gåtefullt': ('gåtefull',),
'gælisk': ('gælisk',),
'gæliske': ('gælisk',),
'gæliskere': ('gælisk',),
'gæliskest': ('gælisk',),
'gæliskeste': ('gælisk',),
'gørr': ('gørr',),
'gørre': ('gørr',),
'gørrere': ('gørr',),
'gørrest': ('gørr',),
'gørreste': ('gørr',),
'gørrkjedelig': ('gørrkjedelig',),
'gørrkjedelige': ('gørrkjedelig',),
'gørrkjedeligere': ('gørrkjedelig',),
'gørrkjedeligst': ('gørrkjedelig',),
'gørrkjedeligste': ('gørrkjedelig',),
'gørrlei': ('gørrlei',),
'gørrleie': ('gørrlei',),
'gørrleiere': ('gørrlei',),
'gørrleiest': ('gørrlei',),
'gørrleieste': ('gørrlei',),
'gørrleit': ('gørrlei',),
'gøy': ('gøy',),
'gøye': ('gøy',),
'gøyere': ('gøy',),
'gøyest': ('gøy',),
'gøyeste': ('gøy',),
'gøyal': ('gøyal',),
'gøyale': ('gøyal',),
'gøyalere': ('gøyal',),
'gøyalest': ('gøyal',),
'gøyaleste': ('gøyal',),
'gøyalt': ('gøyal',),
'gøysende': ('gøyse',),
'gøyst': ('gøyse',),
'gøyste': ('gøyse',),
'haende': ('ha',),
'ha-stemt': ('ha-stemt',),
'ha-stemte': ('ha-stemt',),
'ha-stemtere': ('ha-stemt',),
'ha-stemtest': ('ha-stemt',),
'ha-stemteste': ('ha-stemt',),
'habil': ('habil',),
'habile': ('habil',),
'habilere': ('habil',),
'habilest': ('habil',),
'habileste': ('habil',),
'habilt': ('habil',),
'habiliterende': ('habilitere',),
'habilitert': ('habilitere',),
'habiliterte': ('habilitere',),
'habituell': ('habituell',),
'habituelle': ('habituell',),
'habituellere': ('habituell',),
'habituellest': ('habituell',),
'habituelleste': ('habituell',),
'habituelt': ('habituell',),
'habsburgisk': ('habsburgisk',),
'habsburgiske': ('habsburgisk',),
'habsburgiskere': ('habsburgisk',),
'habsburgiskest': ('habsburgisk',),
'habsburgiskeste': ('habsburgisk',),
'habsburgsk': ('habsburgsk',),
'habsburgske': ('habsburgsk',),
'habsburgskere': ('habsburgsk',),
'habsburgskest': ('habsburgsk',),
'habsburgskeste': ('habsburgsk',),
'hag': ('hag',),
'hage': ('hag',),
'hagere': ('hag',),
'hagest': ('hag',),
'hageste': ('hag',),
'hagt': ('hag',),
'haglblanda': ('haglblanda',),
'haglblandede': ('haglblandet',),
'haglblandet': ('haglblandet',),
'haglblandete': ('haglblandet',),
'haglblandetere': ('haglblandet',),
'haglblandetest': ('haglblandet',),
'haglblandeteste': ('haglblandet',),
'hagla': ('hagle',),
'haglede': ('hagle',),
'haglende': ('hagle',),
'haglet': ('hagle',),
'haglete': ('hagle',),
'haika': ('haike',),
'haikede': ('haike',),
'haikende': ('haike',),
'haiket': ('haike',),
'haikete': ('haike',),
'haitiansk': ('haitiansk',),
'haitianske': ('haitiansk',),
'haitianskere': ('haitiansk',),
'haitianskest': ('haitiansk',),
'haitianskeste': ('haitiansk',),
'haitisk': ('haitisk',),
'haitiske': ('haitisk',),
'haitiskere': ('haitisk',),
'haitiskest': ('haitisk',),
'haitiskeste': ('haitisk',),
'haka': ('hake',),
'hakede': ('hake',),
'hakende': ('hake',),
'haket': ('hake',),
'hakete': ('hake',),
'hakt': ('hake',),
'hakte': ('hake',),
'hakka': ('hakke',),
'hakkede': ('hakke',),
'hakkende': ('hakke',),
'hakket': ('hakke',),
'hakkete': ('hakke',),
'hakket': ('hakket',),
'hakkete': ('hakket',),
'hakketere': ('hakket',),
'hakketest': ('hakket',),
'hakketeste': ('hakket',),
'hakkete': ('hakkete',),
'hala': ('hale',),
'halede': ('hale',),
'halende': ('hale',),
'halet': ('hale',),
'halete': ('hale',),
'halt': ('hale',),
'halte': ('hale',),
'halelaus': ('halelaus',),
'halelause': ('halelaus',),
'halelausere': ('halelaus',),
'halelausest': ('halelaus',),
'halelauseste': ('halelaus',),
'halelaust': ('halelaus',),
'haleløs': ('haleløs',),
'haleløse': ('haleløs',),
'haleløsere': ('haleløs',),
'haleløsest': ('haleløs',),
'haleløseste': ('haleløs',),
'haleløst': ('haleløs',),
'hall': ('hall',),
'halle': ('hall',),
'hallere': ('hall',),
'hallest': ('hall',),
'halleste': ('hall',),
'halt': ('hall',),
'halla': ('halle',),
'hallede': ('halle',),
'hallende': ('halle',),
'hallet': ('halle',),
'hallete': ('halle',),
'hallusinatorisk': ('hallusinatorisk',),
'hallusinatoriske': ('hallusinatorisk',),
'hallusinatoriskere': ('hallusinatorisk',),
'hallusinatoriskest': ('hallusinatorisk',),
'hallusinatoriskeste': ('hallusinatorisk',),
'hallusinerende': ('hallusinere',),
'hallusinert': ('hallusinere',),
'hallusinerte': ('hallusinere',),
'hallusinogen': ('hallusinogen',),
'hallusinogene': ('hallusinogen',),
'hallusinogenere': ('hallusinogen',),
'hallusinogenest': ('hallusinogen',),
'hallusinogeneste': ('hallusinogen',),
'hallusinogent': ('hallusinogen',),
'halofil': ('halofil',),
'halofile': ('halofil',),
'halofilere': ('halofil',),
'halofilest': ('halofil',),
'halofileste': ('halofil',),
'halofilt': ('halofil',),
'halsbrekkende': ('halsbrekkende',),
'halsa': ('halse',),
'halsede': ('halse',),
'halsende': ('halse',),
'halset': ('halse',),
'halsete': ('halse',),
'halslaus': ('halslaus',),
'halslause': ('halslaus',),
'halslausere': ('halslaus',),
'halslausest': ('halslaus',),
'halslauseste': ('halslaus',),
'halslaust': ('halslaus',),
'halsløs': ('halsløs',),
'halsløse': ('halsløs',),
'halsløsere': ('halsløs',),
'halsløsest': ('halsløs',),
'halsløseste': ('halsløs',),
'halsløst': ('halsløs',),
'halsstarrig': ('halsstarrig',),
'halsstarrige': ('halsstarrig',),
'halsstarrigere': ('halsstarrig',),
'halsstarrigst': ('halsstarrig',),
'halsstarrigste': ('halsstarrig',),
'halt': ('halt',),
'halte': ('halt',),
'haltere': ('halt',),
'haltest': ('halt',),
'halteste': ('halt',),
'halta': ('halte',),
'haltede': ('halte',),
'haltende': ('halte',),
'haltet': ('halte',),
'haltete': ('halte',),
'halv': ('halv',),
'halve': ('halv',),
'halvere': ('halv',),
'halvest': ('halv',),
'halveste': ('halv',),
'halvt': ('halv',),
'halvautomatisk': ('halvautomatisk',),
'halvautomatiske': ('halvautomatisk',),
'halvautomatiskere': ('halvautomatisk',),
'halvautomatiskest': ('halvautomatisk',),
'halvautomatiskeste': ('halvautomatisk',),
'halvblind': ('halvblind',),
'halvblinde': ('halvblind',),
'halvblindere': ('halvblind',),
'halvblindest': ('halvblind',),
'halvblindeste': ('halvblind',),
'halvblindt': ('halvblind',),
'halvblods': ('halvblods',),
'halvdaud': ('halvdaud',),
'halvdaude': ('halvdaud',),
'halvdaudere': ('halvdaud',),
'halvdaudest': ('halvdaud',),
'halvdaudeste': ('halvdaud',),
'halvdaudt': ('halvdaud',),
'halvdokumentarisk': ('halvdokumentarisk',),
'halvdokumentariske': ('halvdokumentarisk',),
'halvdokumentariskere': ('halvdokumentarisk',),
'halvdokumentariskest': ('halvdokumentarisk',),
'halvdokumentariskeste': ('halvdokumentarisk',),
'halvdød': ('halvdød',),
'halvdøde': ('halvdød',),
'halvdødere': ('halvdød',),
'halvdødest': ('halvdød',),
'halvdødeste': ('halvdød',),
'halvdødt': ('halvdød',),
'halva': ('halve',),
'halvede': ('halve',),
'halvende': ('halve',),
'halvet': ('halve',),
'halvete': ('halve',),
'halverende': ('halvere',),
'halvert': ('halvere',),
'halverte': ('halvere',),
'halvferdig': ('halvferdig',),
'halvferdige': ('halvferdig',),
'halvferdigere': ('halvferdig',),
'halvferdigst': ('halvferdig',),
'halvferdigste': ('halvferdig',),
'halvfet': ('halvfet',),
'halvfete': ('halvfet',),
'halvfetere': ('halvfet',),
'halvfetest': ('halvfet',),
'halvfeteste': ('halvfet',),
'halvfett': ('halvfet',),
'halvfordøya': ('halvfordøya',),
'halvfordøyd': ('halvfordøyd',),
'halvfordøyde': ('halvfordøyd',),
'halvfordøydere': ('halvfordøyd',),
'halvfordøydest': ('halvfordøyd',),
'halvfordøydeste': ('halvfordøyd',),
'halvfordøyede': ('halvfordøyet',),
'halvfordøyet': ('halvfordøyet',),
'halvfordøyete': ('halvfordøyet',),
'halvfordøyetere': ('halvfordøyet',),
'halvfordøyetest': ('halvfordøyet',),
'halvfordøyeteste': ('halvfordøyet',),
'halvfull': ('halvfull',),
'halvfulle': ('halvfull',),
'halvfullere': ('halvfull',),
'halvfullest': ('halvfull',),
'halvfulleste': ('halvfull',),
'halvfullt': ('halvfull',),
'halvgal': ('halvgal',),
'halvgale': ('halvgal',),
'halvgalere': ('halvgal',),
'halvgalest': ('halvgal',),
'halvgaleste': ('halvgal',),
'halvgalt': ('halvgal',),
'halveldre': ('halvgammel',),
'halveldst': ('halvgammel',),
'halveldste': ('halvgammel',),
'halvgamle': ('halvgammel',),
'halvgammel': ('halvgammel',),
'halvgammelt': ('halvgammel',),
'halvgarderende': ('halvgardere',),
'halvgardert': ('halvgardere',),
'halvgarderte': ('halvgardere',),
'halvgjort': ('halvgjort',),
'halvgjorte': ('halvgjort',),
'halvgjortere': ('halvgjort',),
'halvgjortest': ('halvgjort',),
'halvgjorteste': ('halvgjort',),
'halvbedre': ('halvgod',),
'halvbest': ('halvgod',),
'halvbeste': ('halvgod',),
'halvgod': ('halvgod',),
'halvgode': ('halvgod',),
'halvgodt': ('halvgod',),
'halvgått': ('halvgått',),
'halvgåtte': ('halvgått',),
'halvgåttere': ('halvgått',),
'halvgåttest': ('halvgått',),
'halvgåtteste': ('halvgått',),
'halvhjerta': ('halvhjerta',),
'halvhjertede': ('halvhjertet',),
'halvhjertet': ('halvhjertet',),
'halvhjertete': ('halvhjertet',),
'halvhjertetere': ('halvhjertet',),
'halvhjertetest': ('halvhjertet',),
'halvhjerteteste': ('halvhjertet',),
'halvhøg': ('halvhøg',),
'halvhøge': ('halvhøg',),
'halvhøgere': ('halvhøg',),
'halvhøgest': ('halvhøg',),
'halvhøgeste': ('halvhøg',),
'halvhøgre': ('halvhøg',),
'halvhøgst': ('halvhøg',),
'halvhøgste': ('halvhøg',),
'halvhøgt': ('halvhøg',),
'halvhøy': ('halvhøy',),
'halvhøye': ('halvhøy',),
'halvhøyere': ('halvhøy',),
'halvhøyest': ('halvhøy',),
'halvhøyeste': ('halvhøy',),
'halvhøyt': ('halvhøy',),
'halvklarende': ('halvklare',),
'halvklart': ('halvklare',),
'halvklarte': ('halvklare',),
'halvkvedede': ('halvkvedet',),
'halvkvedet': ('halvkvedet',),
'halvkvedete': ('halvkvedet',),
'halvkvedetere': ('halvkvedet',),
'halvkvedetest': ('halvkvedet',),
'halvkvedeteste': ('halvkvedet',),
'halvmett': ('halvmett',),
'halvmette': ('halvmett',),
'halvmettere': ('halvmett',),
'halvmettest': ('halvmett',),
'halvmetteste': ('halvmett',),
'halvmoden': ('halvmoden',),
'halvmodent': ('halvmoden',),
'halvmodne': ('halvmoden',),
'halvmodnere': ('halvmoden',),
'halvmodnest': ('halvmoden',),
'halvmodneste': ('halvmoden',),
'halvnaken': ('halvnaken',),
'halvnakent': ('halvnaken',),
'halvnakne': ('halvnaken',),
'halvnaknere': ('halvnaken',),
'halvnaknest': ('halvnaken',),
'halvnakneste': ('halvnaken',),
'halvsoven': ('halvsove',),
'halvsovende': ('halvsove',),
'halvsovet': ('halvsove',),
'halvsovne': ('halvsove',),
'halvstudert': ('halvstudert',),
'halvstuderte': ('halvstudert',),
'halvstudertere': ('halvstudert',),
'halvstudertest': ('halvstudert',),
'halvstuderteste': ('halvstudert',),
'halvsåla': ('halvsåle',),
'halvsålede': ('halvsåle',),
'halvsålende': ('halvsåle',),
'halvsålet': ('halvsåle',),
'halvsålete': ('halvsåle',),
'halvsålt': ('halvsåle',),
'halvsålte': ('halvsåle',),
'halvtoms': ('halvtoms',),
'halvtredje': ('halvtredje',),
'halvtullet': ('halvtullet',),
'halvtullete': ('halvtullet',),
'halvtulletere': ('halvtullet',),
'halvtulletest': ('halvtullet',),
'halvtulleteste': ('halvtullet',),
'halvtullete': ('halvtullete',),
'halvtårs': ('halvtårs',),
'halvtørr': ('halvtørr',),
'halvtørre': ('halvtørr',),
'halvtørrere': ('halvtørr',),
'halvtørrest': ('halvtørr',),
'halvtørreste': ('halvtørr',),
'halvtørt': ('halvtørr',),
'halvvoksen': ('halvvoksen',),
'halvvoksent': ('halvvoksen',),
'halvvoksne': ('halvvoksen',),
'halvvoksnere': ('halvvoksen',),
'halvvoksnest': ('halvvoksen',),
'halvvoksneste': ('halvvoksen',),
'halvårig': ('halvårig',),
'halvårige': ('halvårig',),
'halvårigere': ('halvårig',),
'halvårigst': ('halvårig',),
'halvårigste': ('halvårig',),
'halvårlig': ('halvårlig',),
'halvårlige': ('halvårlig',),
'halvårligere': ('halvårlig',),
'halvårligst': ('halvårlig',),
'halvårligste': ('halvårlig',),
'hamburgsk': ('hamburgsk',),
'hamburgske': ('hamburgsk',),
'hamburgskere': ('hamburgsk',),
'hamburgskest': ('hamburgsk',),
'hamburgskeste': ('hamburgsk',),
'hamittisk': ('hamittisk',),
'hamittiske': ('hamittisk',),
'hamittiskere': ('hamittisk',),
'hamittiskest': ('hamittisk',),
'hamittiskeste': ('hamittisk',),
'hamla': ('hamle',),
'hamlede': ('hamle',),
'hamlende': ('hamle',),
'hamlet': ('hamle',),
'hamlete': ('hamle',),
'hamla': ('hamle',),
'hamlede': ('hamle',),
'hamlende': ('hamle',),
'hamlet': ('hamle',),
'hamlete': ('hamle',),
'hamna': ('hamne',),
'hamnede': ('hamne',),
'hamnende': ('hamne',),
'hamnet': ('hamne',),
'hamnete': ('hamne',),
'hamna': ('hamne',),
'hamnede': ('hamne',),
'hamnende': ('hamne',),
'hamnet': ('hamne',),
'hamnete': ('hamne',),
'hamna': ('hamne',),
'hamnede': ('hamne',),
'hamnende': ('hamne',),
'hamnet': ('hamne',),
'hamnete': ('hamne',),
'hamra': ('hamre',),
'hamrede': ('hamre',),
'hamrende': ('hamre',),
'hamret': ('hamre',),
'hamrete': ('hamre',),
'hamsa': ('hamse',),
'hamsede': ('hamse',),
'hamsende': ('hamse',),
'hamset': ('hamse',),
'hamsete': ('hamse',),
'hamstra': ('hamstre',),
'hamstrede': ('hamstre',),
'hamstrende': ('hamstre',),
'hamstret': ('hamstre',),
'hamstrete': ('hamstre',),
'handdrevet': ('handdrevet',),
'handdrevne': ('handdrevet',),
'handdrevnere': ('handdrevet',),
'handdrevnest': ('handdrevet',),
'handdrevneste': ('handdrevet',),
'handelspolitisk': ('handelspolitisk',),
'handelspolitiske': ('handelspolitisk',),
'handelspolitiskere': ('handelspolitisk',),
'handelspolitiskest': ('handelspolitisk',),
'handelspolitiskeste': ('handelspolitisk',),
'handfallen': ('handfallen',),
'handfallent': ('handfallen',),
'handfalne': ('handfallen',),
'handfalnere': ('handfallen',),
'handfalnest': ('handfallen',),
'handfalneste': ('handfallen',),
'handfarende': ('handfare',),
'handfart': ('handfare',),
'handfarte': ('handfare',),
'handfast': ('handfast',),
'handfaste': ('handfast',),
'handfastere': ('handfast',),
'handfastest': ('handfast',),
'handfasteste': ('handfast',),
'handgangen': ('handgangen',),
'handgangent': ('handgangen',),
'handgangne': ('handgangen',),
'handgangnere': ('handgangen',),
'handgangnest': ('handgangen',),
'handgangneste': ('handgangen',),
'handgiende': ('handgi',),
'handgitt': ('handgi',),
'handgitte': ('handgi',),
'handgivende': ('handgi',),
'handgripelig': ('handgripelig',),
'handgripelige': ('handgripelig',),
'handgripeligere': ('handgripelig',),
'handgripeligst': ('handgripelig',),
'handgripeligste': ('handgripelig',),
'handhelsende': ('handhelse',),
'handhelst': ('handhelse',),
'handhelste': ('handhelse',),
'handheva': ('handheve',),
'handhevd': ('handheve',),
'handhevde': ('handheve',),
'handhevede': ('handheve',),
'handhevende': ('handheve',),
'handhevet': ('handheve',),
'handhevete': ('handheve',),
'handhilsende': ('handhilse',),
'handhilst': ('handhilse',),
'handhilste': ('handhilse',),
'handhilsende': ('handhilse',),
'handhilst': ('handhilse',),
'handhilste': ('handhilse',),
'handikappa': ('handikappe',),
'handikappede': ('handikappe',),
'handikappende': ('handikappe',),
'handikappet': ('handikappe',),
'handikappete': ('handikappe',),
'handlaga': ('handlaga',),
'handlagd': ('handlagd',),
'handlagde': ('handlagd',),
'handlagdere': ('handlagd',),
'handlagdest': ('handlagd',),
'handlagdeste': ('handlagd',),
'handlagede': ('handlaget',),
'handlaget': ('handlaget',),
'handlagete': ('handlaget',),
'handlagetere': ('handlaget',),
'handlagetest': ('handlaget',),
'handlageteste': ('handlaget',),
'handla': ('handle',),
'handlede': ('handle',),
'handlende': ('handle',),
'handlet': ('handle',),
'handlete': ('handle',),
'handledyktig': ('handledyktig',),
'handledyktige': ('handledyktig',),
'handledyktigere': ('handledyktig',),
'handledyktigst': ('handledyktig',),
'handledyktigste': ('handledyktig',),
'handlekraftig': ('handlekraftig',),
'handlekraftige': ('handlekraftig',),
'handlekraftigere': ('handlekraftig',),
'handlekraftigst': ('handlekraftig',),
'handlekraftigste': ('handlekraftig',),
'handlingslamma': ('handlingslamma',),
'handlingslammede': ('handlingslammet',),
'handlingslammet': ('handlingslammet',),
'handlingslammete': ('handlingslammet',),
'handlingslammetere': ('handlingslammet',),
'handlingslammetest': ('handlingslammet',),
'handlingslammeteste': ('handlingslammet',),
'handlingsmetta': ('handlingsmetta',),
'handlingsmettede': ('handlingsmettet',),
'handlingsmettet': ('handlingsmettet',),
'handlingsmettete': ('handlingsmettet',),
'handlingsmettetere': ('handlingsmettet',),
'handlingsmettetest': ('handlingsmettet',),
'handlingsmetteteste': ('handlingsmettet',),
'handnerva': ('handnerva',),
'handnervede': ('handnervet',),
'handnervet': ('handnervet',),
'handnervete': ('handnervet',),
'handnervetere': ('handnervet',),
'handnervetest': ('handnervet',),
'handnerveteste': ('handnervet',),
'handplukka': ('handplukke',),
'handplukkede': ('handplukke',),
'handplukkende': ('handplukke',),
'handplukket': ('handplukke',),
'handplukkete': ('handplukke',),
'handsama': ('handsame',),
'handsamede': ('handsame',),
'handsamende': ('handsame',),
'handsamet': ('handsame',),
'handsamete': ('handsame',),
'handsa': ('handse',),
'handsede': ('handse',),
'handsende': ('handse',),
'handset': ('handse',),
'handsete': ('handse',),
'handskreven': ('handskreven',),
'handskrevet': ('handskreven',),
'handskrevne': ('handskreven',),
'handskrevnere': ('handskreven',),
'handskrevnest': ('handskreven',),
'handskrevneste': ('handskreven',),
'handskrevet': ('handskrevet',),
'handskrevne': ('handskrevet',),
'handskrevnere': ('handskrevet',),
'handskrevnest': ('handskrevet',),
'handskrevneste': ('handskrevet',),
'handskåren': ('handskåren',),
'handskåret': ('handskåren',),
'handskårne': ('handskåren',),
'handskårnere': ('handskåren',),
'handskårnest': ('handskåren',),
'handskårneste': ('handskåren',),
'handskåret': ('handskåret',),
'handskårne': ('handskåret',),
'handskårnere': ('handskåret',),
'handskårnest': ('handskåret',),
'handskårneste': ('handskåret',),
'handstående': ('handstående',),
'handterende': ('handtere',),
'handtert': ('handtere',),
'handterte': ('handtere',),
'handterlig': ('handterlig',),
'handterlige': ('handterlig',),
'handterligere': ('handterlig',),
'handterligst': ('handterlig',),
'handterligste': ('handterlig',),
'handvarm': ('handvarm',),
'handvarme': ('handvarm',),
'handvarmere': ('handvarm',),
'handvarmest': ('handvarm',),
'handvarmeste': ('handvarm',),
'handvarmt': ('handvarm',),
'handverksmessig': ('handverksmessig',),
'handverksmessige': ('handverksmessig',),
'handverksmessigere': ('handverksmessig',),
'handverksmessigst': ('handverksmessig',),
'handverksmessigste': ('handverksmessig',),
'hangla': ('hangle',),
'hanglede': ('hangle',),
'hanglende': ('hangle',),
'hanglet': ('hangle',),
'hanglete': ('hangle',),
'hanglet': ('hanglet',),
'hanglete': ('hanglet',),
'hangletere': ('hanglet',),
'hangletest': ('hanglet',),
'hangleteste': ('hanglet',),
'hanglete': ('hanglete',),
'hankelaus': ('hankelaus',),
'hankelause': ('hankelaus',),
'hankelausere': ('hankelaus',),
'hankelausest': ('hankelaus',),
'hankelauseste': ('hankelaus',),
'hankelaust': ('hankelaus',),
'hankeløs': ('hankeløs',),
'hankeløse': ('hankeløs',),
'hankeløsere': ('hankeløs',),
'hankeløsest': ('hankeløs',),
'hankeløseste': ('hankeløs',),
'hankeløst': ('hankeløs',),
'hanlig': ('hanlig',),
'hanlige': ('hanlig',),
'hanligere': ('hanlig',),
'hanligst': ('hanlig',),
'hanligste': ('hanlig',),
'hannlig': ('hannlig',),
'hannlige': ('hannlig',),
'hannligere': ('hannlig',),
'hannligst': ('hannlig',),
'hannligste': ('hannlig',),
'hanseatisk': ('hanseatisk',),
'hanseatiske': ('hanseatisk',),
'hanseatiskere': ('hanseatisk',),
'hanseatiskest': ('hanseatisk',),
'hanseatiskeste': ('hanseatisk',),
'haploid': ('haploid',),
'haploide': ('haploid',),
'haploidere': ('haploid',),
'haploidest': ('haploid',),
'haploideste': ('haploid',),
'hard': ('hard',),
'harde': ('hard',),
'hardere': ('hard',),
'hardest': ('hard',),
'hardeste': ('hard',),
'hardt': ('hard',),
'hardbalen': ('hardbalen',),
'hardbalent': ('hardbalen',),
'hardbalne': ('hardbalen',),
'hardbalnere': ('hardbalen',),
'hardbalnest': ('hardbalen',),
'hardbalneste': ('hardbalen',),
'hardbarkede': ('hardbarket',),
'hardbarket': ('hardbarket',),
'hardbarkete': ('hardbarket',),
'hardbarketere': ('hardbarket',),
'hardbarketest': ('hardbarket',),
'hardbarketeste': ('hardbarket',),
'hardfrosne': ('hardfrossen',),
'hardfrosnere': ('hardfrossen',),
'hardfrosnest': ('hardfrossen',),
'hardfrosneste': ('hardfrossen',),
'hardfrossen': ('hardfrossen',),
'hardfrosset': ('hardfrossen',),
'hardfrosne': ('hardfrosset',),
'hardfrosnere': ('hardfrosset',),
'hardfrosnest': ('hardfrosset',),
'hardfrosneste': ('hardfrosset',),
'hardfrosset': ('hardfrosset',),
'hardfør': ('hardfør',),
'hardføre': ('hardfør',),
'hardførere': ('hardfør',),
'hardførest': ('hardfør',),
'hardføreste': ('hardfør',),
'hardført': ('hardfør',),
'hardhendt': ('hardhendt',),
'hardhendte': ('hardhendt',),
'hardhendtere': ('hardhendt',),
'hardhendtest': ('hardhendt',),
'hardhendteste': ('hardhendt',),
'hardhjerta': ('hardhjerta',),
'hardhjertede': ('hardhjertet',),
'hardhjertet': ('hardhjertet',),
'hardhjertete': ('hardhjertet',),
'hardhjertetere': ('hardhjertet',),
'hardhjertetest': ('hardhjertet',),
'hardhjerteteste': ('hardhjertet',),
'hardhuda': ('hardhuda',),
'hardhudede': ('hardhudet',),
'hardhudet': ('hardhudet',),
'hardhudete': ('hardhudet',),
'hardhudetere': ('hardhudet',),
'hardhudetest': ('hardhudet',),
'hardhudeteste': ('hardhudet',),
'hardkokende': ('hardkoke',),
'hardkokt': ('hardkoke',),
'hardkokte': ('hardkoke',),
'hardlynt': ('hardlynt',),
'hardlynte': ('hardlynt',),
'hardlyntere': ('hardlynt',),
'hardlyntest': ('hardlynt',),
'hardlynteste': ('hardlynt',),
'hardnakka': ('hardnakka',),
'hardnakkede': ('hardnakket',),
'hardnakket': ('hardnakket',),
'hardnakkete': ('hardnakket',),
'hardnakketere': ('hardnakket',),
'hardnakketest': ('hardnakket',),
'hardnakketeste': ('hardnakket',),
'hardna': ('hardne',),
'hardnede': ('hardne',),
'hardnende': ('hardne',),
'hardnet': ('hardne',),
'hardnete': ('hardne',),
'hardstappa': ('hardstappa',),
'hardstappede': ('hardstappet',),
'hardstappet': ('hardstappet',),
'hardstappete': ('hardstappet',),
'hardstappetere': ('hardstappet',),
'hardstappetest': ('hardstappet',),
'hardstappeteste': ('hardstappet',),
'hardtrampa': ('hardtrampe',),
'hardtrampede': ('hardtrampe',),
'hardtrampende': ('hardtrampe',),
'hardtrampet': ('hardtrampe',),
'hardtrampete': ('hardtrampe',),
'hardtrena': ('hardtrene',),
'hardtrenede': ('hardtrene',),
'hardtrenende': ('hardtrene',),
'hardtrenet': ('hardtrene',),
'hardtrenete': ('hardtrene',),
'hardtrent': ('hardtrene',),
'hardtrente': ('hardtrene',),
'haremynt': ('haremynt',),
'haremynte': ('haremynt',),
'haremyntere': ('haremynt',),
'haremyntest': ('haremynt',),
'haremynteste': ('haremynt',),
'harka': ('harke',),
'harkede': ('harke',),
'harkende': ('harke',),
'harket': ('harke',),
'harkete': ('harke',),
'harm': ('harm',),
'harme': ('harm',),
'harmere': ('harm',),
'harmest': ('harm',),
'harmeste': ('harm',),
'harmt': ('harm',),
'harmdirrende': ('harmdirrende',),
'harma': ('harme',),
'harmede': ('harme',),
'harmende': ('harme',),
'harmet': ('harme',),
'harmete': ('harme',),
'harmelig': ('harmelig',),
'harmelige': ('harmelig',),
'harmeligere': ('harmelig',),
'harmeligst': ('harmelig',),
'harmeligste': ('harmelig',),
'harmfull': ('harmfull',),
'harmfulle': ('harmfull',),
'harmfullere': ('harmfull',),
'harmfullest': ('harmfull',),
'harmfulleste': ('harmfull',),
'harmfullt': ('harmfull',),
'harmlaus': ('harmlaus',),
'harmlause': ('harmlaus',),
'harmlausere': ('harmlaus',),
'harmlausest': ('harmlaus',),
'harmlauseste': ('harmlaus',),
'harmlaust': ('harmlaus',),
'harmløs': ('harmløs',),
'harmløse': ('harmløs',),
'harmløsere': ('harmløs',),
'harmløsest': ('harmløs',),
'harmløseste': ('harmløs',),
'harmløst': ('harmløs',),
'harmonerende': ('harmonere',),
'harmonert': ('harmonere',),
'harmonerte': ('harmonere',),
'harmoniserende': ('harmonisere',),
'harmonisert': ('harmonisere',),
'harmoniserte': ('harmonisere',),
'harmonisk': ('harmonisk',),
'harmoniske': ('harmonisk',),
'harmoniskere': ('harmonisk',),
'harmoniskest': ('harmonisk',),
'harmoniskeste': ('harmonisk',),
'harpa': ('harpe',),
'harpede': ('harpe',),
'harpende': ('harpe',),
'harpet': ('harpe',),
'harpete': ('harpe',),
'harpeserende': ('harpesere',),
'harpesert': ('harpesere',),
'harpeserte': ('harpesere',),
'harpunerende': ('harpunere',),
'harpunert': ('harpunere',),
'harpunerte': ('harpunere',),
'harselerende': ('harselere',),
'harselert': ('harselere',),
'harselerte': ('harselere',),
'harsk': ('harsk',),
'harske': ('harsk',),
'harskere': ('harsk',),
'harskest': ('harsk',),
'harskeste': ('harsk',),
'harskt': ('harsk',),
'harska': ('harske',),
'harskede': ('harske',),
'harskende': ('harske',),
'harsket': ('harske',),
'harskete': ('harske',),
'harskna': ('harskne',),
'harsknede': ('harskne',),
'harsknende': ('harskne',),
'harsknet': ('harskne',),
'harsknete': ('harskne',),
'harva': ('harve',),
'harvede': ('harve',),
'harvende': ('harve',),
'harvet': ('harve',),
'harvete': ('harve',),
'harva': ('harve',),
'harvede': ('harve',),
'harvende': ('harve',),
'harvet': ('harve',),
'harvete': ('harve',),
'hasardiøs': ('hasardiøs',),
'hasardiøse': ('hasardiøs',),
'hasardiøsere': ('hasardiøs',),
'hasardiøsest': ('hasardiøs',),
'hasardiøseste': ('hasardiøs',),
'hasardiøst': ('hasardiøs',),
'haspa': ('haspe',),
'haspede': ('haspe',),
'haspende': ('haspe',),
'haspet': ('haspe',),
'haspete': ('haspe',),
'haspla': ('hasple',),
'hasplede': ('hasple',),
'hasplende': ('hasple',),
'hasplet': ('hasple',),
'hasplete': ('hasple',),
'hasta': ('haste',),
'hastede': ('haste',),
'hastende': ('haste',),
'hastet': ('haste',),
'hastete': ('haste',),
'hastig': ('hastig',),
'hastige': ('hastig',),
'hastigere': ('hastig',),
'hastigst': ('hastig',),
'hastigste': ('hastig',),
'hata': ('hate',),
'hatede': ('hate',),
'hatende': ('hate',),
'hatet': ('hate',),
'hatete': ('hate',),
'hatefull': ('hatefull',),
'hatefulle': ('hatefull',),
'hatefullere': ('hatefull',),
'hatefullest': ('hatefull',),
'hatefulleste': ('hatefull',),
'hatefullt': ('hatefull',),
'hatig': ('hatig',),
'hatige': ('hatig',),
'hatigere': ('hatig',),
'hatigst': ('hatig',),
'hatigste': ('hatig',),
'hatsk': ('hatsk',),
'hatske': ('hatsk',),
'hatskere': ('hatsk',),
'hatskest': ('hatsk',),
'hatskeste': ('hatsk',),
'hauga': ('hauge',),
'haugede': ('hauge',),
'haugende': ('hauge',),
'hauget': ('hauge',),
'haugete': ('hauge',),
'hauget': ('hauget',),
'haugete': ('hauget',),
'haugetere': ('hauget',),
'haugetest': ('hauget',),
'haugeteste': ('hauget',),
'haugete': ('haugete',),
'haugiansk': ('haugiansk',),
'haugianske': ('haugiansk',),
'haugianskere': ('haugiansk',),
'haugianskest': ('haugiansk',),
'haugianskeste': ('haugiansk',),
'hauglagt': ('hauglegge',),
'hauglagte': ('hauglegge',),
'haugleggende': ('hauglegge',),
'haugtakende': ('haugta',),
'haugtatt': ('haugta',),
'haugtatte': ('haugta',),
'hauka': ('hauke',),
'haukede': ('hauke',),
'haukende': ('hauke',),
'hauket': ('hauke',),
'haukete': ('hauke',),
'haussa': ('hausse',),
'haussede': ('hausse',),
'haussende': ('hausse',),
'hausset': ('hausse',),
'haussete': ('hausse',),
'havannesisk': ('havannesisk',),
'havannesiske': ('havannesisk',),
'havannesiskere': ('havannesisk',),
'havannesiskest': ('havannesisk',),
'havannesiskeste': ('havannesisk',),
'havarerende': ('havarere',),
'havarert': ('havarere',),
'havarerte': ('havarere',),
'havesjuk': ('havesjuk',),
'havesjuke': ('havesjuk',),
'havesjukere': ('havesjuk',),
'havesjukest': ('havesjuk',),
'havesjukeste': ('havesjuk',),
'havesjukt': ('havesjuk',),
'havesyk': ('havesyk',),
'havesyke': ('havesyk',),
'havesykere': ('havesyk',),
'havesykest': ('havesyk',),
'havesykeste': ('havesyk',),
'havesykt': ('havesyk',),
'havgående': ('havgående',),
'havna': ('havne',),
'havnede': ('havne',),
'havnende': ('havne',),
'havnet': ('havne',),
'havnete': ('havne',),
'havna': ('havne',),
'havnede': ('havne',),
'havnende': ('havne',),
'havnet': ('havne',),
'havnete': ('havne',),
'havna': ('havne',),
'havnede': ('havne',),
'havnende': ('havne',),
'havnet': ('havne',),
'havnete': ('havne',),
'havsalt': ('havsalt',),
'havsalte': ('havsalt',),
'havsaltere': ('havsalt',),
'havsaltest': ('havsalt',),
'havsalteste': ('havsalt',),
'hawaiisk': ('hawaiisk',),
'hawaiiske': ('hawaiisk',),
'hawaiiskere': ('hawaiisk',),
'hawaiiskest': ('hawaiisk',),
'hawaiiskeste': ('hawaiisk',),
'hawaisk': ('hawaisk',),
'hawaiske': ('hawaisk',),
'hawaiskere': ('hawaisk',),
'hawaiskest': ('hawaisk',),
'hawaiskeste': ('hawaisk',),
'heada': ('heade',),
'headede': ('heade',),
'headende': ('heade',),
'headet': ('heade',),
'headete': ('heade',),
'hebraisk': ('hebraisk',),
'hebraiske': ('hebraisk',),
'hebraiskere': ('hebraisk',),
'hebraiskest': ('hebraisk',),
'hebraiskeste': ('hebraisk',),
'hebridisk': ('hebridisk',),
'hebridiske': ('hebridisk',),
'hebridiskere': ('hebridisk',),
'hebridiskest': ('hebridisk',),
'hebridiskeste': ('hebridisk',),
'hedensk': ('hedensk',),
'hedenske': ('hedensk',),
'hedenskere': ('hedensk',),
'hedenskest': ('hedensk',),
'hedenskeste': ('hedensk',),
'hederlig': ('hederlig',),
'hederlige': ('hederlig',),
'hederligere': ('hederlig',),
'hederligst': ('hederlig',),
'hederligste': ('hederlig',),
'hederskrona': ('hederskrona',),
'hederskronede': ('hederskronet',),
'hederskronet': ('hederskronet',),
'hederskronete': ('hederskronet',),
'hederskronetere': ('hederskronet',),
'hederskronetest': ('hederskronet',),
'hederskroneteste': ('hederskronet',),
'hederskront': ('hederskront',),
'hederskronte': ('hederskront',),
'hederskrontere': ('hederskront',),
'hederskrontest': ('hederskront',),
'hederskronteste': ('hederskront',),
'hedningkristen': ('hedningkristen',),
'hedningkristent': ('hedningkristen',),
'hedningkristne': ('hedningkristen',),
'hedningkristnere': ('hedningkristen',),
'hedningkristnest': ('hedningkristen',),
'hedningkristneste': ('hedningkristen',),
'hedonistisk': ('hedonistisk',),
'hedonistiske': ('hedonistisk',),
'hedonistiskere': ('hedonistisk',),
'hedonistiskest': ('hedonistisk',),
'hedonistiskeste': ('hedonistisk',),
'hedra': ('hedre',),
'hedrede': ('hedre',),
'hedrende': ('hedre',),
'hedret': ('hedre',),
'hedrete': ('hedre',),
'hefta': ('hefte',),
'heftede': ('hefte',),
'heftende': ('hefte',),
'heftet': ('hefte',),
'heftete': ('hefte',),
'heftig': ('heftig',),
'heftige': ('heftig',),
'heftigere': ('heftig',),
'heftigst': ('heftig',),
'heftigste': ('heftig',),
'hegda': ('hegde',),
'hegdede': ('hegde',),
'hegdende': ('hegde',),
'hegdet': ('hegde',),
'hegdete': ('hegde',),
'hegeliansk': ('hegeliansk',),
'hegelianske': ('hegeliansk',),
'hegelianskere': ('hegeliansk',),
'hegelianskest': ('hegeliansk',),
'hegelianskeste': ('hegeliansk',),
'hegelsk': ('hegelsk',),
'hegelske': ('hegelsk',),
'hegelskere': ('hegelsk',),
'hegelskest': ('hegelsk',),
'hegelskeste': ('hegelsk',),
'hegna': ('hegne',),
'hegnede': ('hegne',),
'hegnende': ('hegne',),
'hegnet': ('hegne',),
'hegnete': ('hegne',),
'heidundrende': ('heidundrende',),
'heia': ('heie',),
'heiede': ('heie',),
'heiende': ('heie',),
'heiet': ('heie',),
'heiete': ('heie',),
'heil': ('heil',),
'heile': ('heil',),
'heilere': ('heil',),
'heilest': ('heil',),
'heileste': ('heil',),
'heilt': ('heil',),
'heilaftens': ('heilaftens',),
'heilautomatisk': ('heilautomatisk',),
'heilautomatiske': ('heilautomatisk',),
'heilautomatiskere': ('heilautomatisk',),
'heilautomatiskest': ('heilautomatisk',),
'heilautomatiskeste': ('heilautomatisk',),
'heildekkende': ('heildekkende',),
'heilfet': ('heilfet',),
'heilfete': ('heilfet',),
'heilfetere': ('heilfet',),
'heilfetest': ('heilfet',),
'heilfeteste': ('heilfet',),
'heilfett': ('heilfet',),
'heilfrelst': ('heilfrelst',),
'heilfrelste': ('heilfrelst',),
'heilfrelstere': ('heilfrelst',),
'heilfrelstest': ('heilfrelst',),
'heilfrelsteste': ('heilfrelst',),
'heilgarderende': ('heilgardere',),
'heilgardert': ('heilgardere',),
'heilgarderte': ('heilgardere',),
'heilhetlig': ('heilhetlig',),
'heilhetlige': ('heilhetlig',),
'heilhetligere': ('heilhetlig',),
'heilhetligst': ('heilhetlig',),
'heilhetligste': ('heilhetlig',),
'heilhjerta': ('heilhjerta',),
'heilhjertede': ('heilhjertet',),
'heilhjertet': ('heilhjertet',),
'heilhjertete': ('heilhjertet',),
'heilhjertetere': ('heilhjertet',),
'heilhjertetest': ('heilhjertet',),
'heilhjerteteste': ('heilhjertet',),
'heilhuga': ('heilhuga',),
'heilkontinuerlig': ('heilkontinuerlig',),
'heilkontinuerlige': ('heilkontinuerlig',),
'heilkontinuerligere': ('heilkontinuerlig',),
'heilkontinuerligst': ('heilkontinuerlig',),
'heilkontinuerligste': ('heilkontinuerlig',),
'heilnorsk': ('heilnorsk',),
'heilnorske': ('heilnorsk',),
'heilnorskere': ('heilnorsk',),
'heilnorskest': ('heilnorsk',),
'heilnorskeste': ('heilnorsk',),
'heilnorsk': ('heilnorsk',),
'heilnorske': ('heilnorsk',),
'heilnorskere': ('heilnorsk',),
'heilnorskest': ('heilnorsk',),
'heilnorskeste': ('heilnorsk',),
'heilskinna': ('heilskinna',),
'heilskinnede': ('heilskinnet',),
'heilskinnet': ('heilskinnet',),
'heilskinnete': ('heilskinnet',),
'heilskinnetere': ('heilskinnet',),
'heilskinnetest': ('heilskinnet',),
'heilskinneteste': ('heilskinnet',),
'heilskåren': ('heilskåren',),
'heilskåret': ('heilskåren',),
'heilskårne': ('heilskåren',),
'heilskårnere': ('heilskåren',),
'heilskårnest': ('heilskåren',),
'heilskårneste': ('heilskåren',),
'heilskåret': ('heilskåret',),
'heilskårne': ('heilskåret',),
'heilskårnere': ('heilskåret',),
'heilskårnest': ('heilskåret',),
'heilskårneste': ('heilskåret',),
'heilstaut': ('heilstaut',),
'heilstaute': ('heilstaut',),
'heilstautere': ('heilstaut',),
'heilstautest': ('heilstaut',),
'heilstauteste': ('heilstaut',),
'heilsteikende': ('heilsteike',),
'heilsteikt': ('heilsteike',),
'heilsteikte': ('heilsteike',),
'heilstekende': ('heilsteke',),
'heilstekt': ('heilsteke',),
'heilstekte': ('heilsteke',),
'heilstøpende': ('heilstøpe',),
'heilstøpt': ('heilstøpe',),
'heilstøpte': ('heilstøpe',),
'heilstøypende': ('heilstøype',),
'heilstøypt': ('heilstøype',),
'heilstøypte': ('heilstøype',),
'heilsvart': ('heilsvart',),
'heilsvarte': ('heilsvart',),
'heilsvartere': ('heilsvart',),
'heilsvartest': ('heilsvart',),
'heilsvarteste': ('heilsvart',),
'heilsynkroniserende': ('heilsynkronisere',),
'heilsynkronisert': ('heilsynkronisere',),
'heilsynkroniserte': ('heilsynkronisere',),
'heiltallig': ('heiltallig',),
'heiltallige': ('heiltallig',),
'heiltalligere': ('heiltallig',),
'heiltalligst': ('heiltallig',),
'heiltalligste': ('heiltallig',),
'heiltidsansatt': ('heiltidsansatt',),
'heiltidsansatte': ('heiltidsansatt',),
'heiltidsansattere': ('heiltidsansatt',),
'heiltidsansattest': ('heiltidsansatt',),
'heiltidsansatteste': ('heiltidsansatt',),
'heiltres': ('heiltres',),
'heiltrukket': ('heiltrukket',),
'heiltrukne': ('heiltrukket',),
'heiltruknere': ('heiltrukket',),
'heiltruknest': ('heiltrukket',),
'heiltrukneste': ('heiltrukket',),
'heilårig': ('heilårig',),
'heilårige': ('heilårig',),
'heilårigere': ('heilårig',),
'heilårigst': ('heilårig',),
'heilårigste': ('heilårig',),
'heilårs': ('heilårs',),
'heimattkommen': ('heimattkommen',),
'heimattkomment': ('heimattkommen',),
'heimattkommet': ('heimattkommen',),
'heimattkomne': ('heimattkommen',),
'heimattkomnere': ('heimattkommen',),
'heimattkomnest': ('heimattkommen',),
'heimattkomneste': ('heimattkommen',),
'heimattkommet': ('heimattkommet',),
'heimattkomne': ('heimattkommet',),
'heimattkomnere': ('heimattkommet',),
'heimattkomnest': ('heimattkommet',),
'heimattkomneste': ('heimattkommet',),
'heima': ('heime',),
'heimede': ('heime',),
'heimende': ('heime',),
'heimet': ('heime',),
'heimete': ('heime',),
'heimearbeidende': ('heimearbeidende',),
'heimeavla': ('heimeavla',),
'heimeavlede': ('heimeavlet',),
'heimeavlet': ('heimeavlet',),
'heimeavlete': ('heimeavlet',),
'heimeavletere': ('heimeavlet',),
'heimeavletest': ('heimeavlet',),
'heimeavleteste': ('heimeavlet',),
'heimebakt': ('heimebakt',),
'heimebakte': ('heimebakt',),
'heimebaktere': ('heimebakt',),
'heimebaktest': ('heimebakt',),
'heimebakteste': ('heimebakt',),
'heimegjort': ('heimegjort',),
'heimegjorte': ('heimegjort',),
'heimegjortere': ('heimegjort',),
'heimegjortest': ('heimegjort',),
'heimegjorteste': ('heimegjort',),
'heimehørende': ('heimehørende',),
'heimekjent': ('heimekjent',),
'heimekjente': ('heimekjent',),
'heimekjentere': ('heimekjent',),
'heimekjentest': ('heimekjent',),
'heimekjenteste': ('heimekjent',),
'heimekjær': ('heimekjær',),
'heimekjære': ('heimekjær',),
'heimekjærere': ('heimekjær',),
'heimekjærest': ('heimekjær',),
'heimekjæreste': ('heimekjær',),
'heimekjært': ('heimekjær',),
'heimekoselig': ('heimekoselig',),
'heimekoselige': ('heimekoselig',),
'heimekoseligere': ('heimekoselig',),
'heimekoseligst': ('heimekoselig',),
'heimekoseligste': ('heimekoselig',),
'heimelaga': ('heimelaga',),
'heimelagd': ('heimelagd',),
'heimelagde': ('heimelagd',),
'heimelagdere': ('heimelagd',),
'heimelagdest': ('heimelagd',),
'heimelagdeste': ('heimelagd',),
'heimelagede': ('heimelaget',),
'heimelaget': ('heimelaget',),
'heimelagete': ('heimelaget',),
'heimelagetere': ('heimelaget',),
'heimelagetest': ('heimelaget',),
'heimelageteste': ('heimelaget',),
'heimestrikka': ('heimestrikka',),
'heimestrikkede': ('heimestrikket',),
'heimestrikket': ('heimestrikket',),
'heimestrikkete': ('heimestrikket',),
'heimestrikketere': ('heimestrikket',),
'heimestrikketest': ('heimestrikket',),
'heimestrikketeste': ('heimestrikket',),
'heimevant': ('heimevant',),
'heimevante': ('heimevant',),
'heimevantere': ('heimevant',),
'heimevantest': ('heimevant',),
'heimevanteste': ('heimevant',),
'heimeværende': ('heimeværende',),
'heimfallende': ('heimfalle',),
'heimfalt': ('heimfalle',),
'heimfalte': ('heimfalle',),
'heimfallen': ('heimfallen',),
'heimfallent': ('heimfallen',),
'heimfalne': ('heimfallen',),
'heimfalnere': ('heimfallen',),
'heimfalnest': ('heimfallen',),
'heimfalneste': ('heimfallen',),
'heimfesta': ('heimfeste',),
'heimfestede': ('heimfeste',),
'heimfestende': ('heimfeste',),
'heimfestet': ('heimfeste',),
'heimfestete': ('heimfeste',),
'heimfus': ('heimfus',),
'heimfuse': ('heimfus',),
'heimfusere': ('heimfus',),
'heimfusest': ('heimfus',),
'heimfuseste': ('heimfus',),
'heimfust': ('heimfus',),
'heimførende': ('heimføre',),
'heimført': ('heimføre',),
'heimførte': ('heimføre',),
'heimhuga': ('heimhuga',),
'heimkallende': ('heimkalle',),
'heimkalt': ('heimkalle',),
'heimkalte': ('heimkalle',),
'heimkommet': ('heimkommet',),
'heimkomne': ('heimkommet',),
'heimkomnere': ('heimkommet',),
'heimkomnest': ('heimkommet',),
'heimkomneste': ('heimkommet',),
'heimlaus': ('heimlaus',),
'heimlause': ('heimlaus',),
'heimlausere': ('heimlaus',),
'heimlausest': ('heimlaus',),
'heimlauseste': ('heimlaus',),
'heimlaust': ('heimlaus',),
'heimla': ('heimle',),
'heimlede': ('heimle',),
'heimlende': ('heimle',),
'heimlet': ('heimle',),
'heimlete': ('heimle',),
'heimlig': ('heimlig',),
'heimlige': ('heimlig',),
'heimligere': ('heimlig',),
'heimligst': ('heimlig',),
'heimligste': ('heimlig',),
'heimløs': ('heimløs',),
'heimløse': ('heimløs',),
'heimløsere': ('heimløs',),
'heimløsest': ('heimløs',),
'heimløseste': ('heimløs',),
'heimløst': ('heimløs',),
'heimsendende': ('heimsende',),
'heimsendt': ('heimsende',),
'heimsendte': ('heimsende',),
'heimsøkende': ('heimsøke',),
'heimsøkt': ('heimsøke',),
'heimsøkte': ('heimsøke',),
'heimvendt': ('heimvendt',),
'heimvendte': ('heimvendt',),
'heimvendtere': ('heimvendt',),
'heimvendtest': ('heimvendt',),
'heimvendteste': ('heimvendt',),
'heinende': ('heine',),
'heint': ('heine',),
'heinte': ('heine',),
'heisende': ('heise',),
'heist': ('heise',),
'heiste': ('heise',),
'heisende': ('heise',),
'heist': ('heise',),
'heiste': ('heise',),
'heit': ('heit',),
'heite': ('heit',),
'heitere': ('heit',),
'heitest': ('heit',),
'heiteste': ('heit',),
'heitt': ('heit',),
'hett': ('heit',),
'heitna': ('heitne',),
'heitnede': ('heitne',),
'heitnende': ('heitne',),
'heitnet': ('heitne',),
'heitnete': ('heitne',),
'hekka': ('hekke',),
'hekkede': ('hekke',),
'hekkende': ('hekke',),
'hekket': ('hekke',),
'hekkete': ('hekke',),
'hekla': ('hekle',),
'heklede': ('hekle',),
'heklende': ('hekle',),
'heklet': ('hekle',),
'heklete': ('hekle',),
'hekla': ('hekle',),
'heklede': ('hekle',),
'heklende': ('hekle',),
'heklet': ('hekle',),
'heklete': ('hekle',),
'heksa': ('hekse',),
'heksede': ('hekse',),
'heksende': ('hekse',),
'hekset': ('hekse',),
'heksete': ('hekse',),
'hekta': ('hekte',),
'hektede': ('hekte',),
'hektende': ('hekte',),
'hektet': ('hekte',),
'hektete': ('hekte',),
'hektisk': ('hektisk',),
'hektiske': ('hektisk',),
'hektiskere': ('hektisk',),
'hektiskest': ('hektisk',),
'hektiskeste': ('hektisk',),
'hektograferende': ('hektografere',),
'hektografert': ('hektografere',),
'hektograferte': ('hektografere',),
'hel': ('hel',),
'hele': ('hel',),
'helere': ('hel',),
'helest': ('hel',),
'heleste': ('hel',),
'helt': ('hel',),
'helaftens': ('helaftens',),
'helautomatisk': ('helautomatisk',),
'helautomatiske': ('helautomatisk',),
'helautomatiskere': ('helautomatisk',),
'helautomatiskest': ('helautomatisk',),
'helautomatiskeste': ('helautomatisk',),
'helbreda': ('helbrede',),
'helbredede': ('helbrede',),
'helbredende': ('helbrede',),
'helbredet': ('helbrede',),
'helbredete': ('helbrede',),
'helbredelig': ('helbredelig',),
'helbredelige': ('helbredelig',),
'helbredeligere': ('helbredelig',),
'helbredeligst': ('helbredelig',),
'helbredeligste': ('helbredelig',),
'helda': ('helde',),
'heldede': ('helde',),
'heldende': ('helde',),
'heldet': ('helde',),
'heldete': ('helde',),
'heldekkende': ('heldekkende',),
'heldig': ('heldig',),
'heldige': ('heldig',),
'heldigere': ('heldig',),
'heldigst': ('heldig',),
'heldigste': ('heldig',),
'helfet': ('helfet',),
'helfete': ('helfet',),
'helfetere': ('helfet',),
'helfetest': ('helfet',),
'helfeteste': ('helfet',),
'helfett': ('helfet',),
'helfrelst': ('helfrelst',),
'helfrelste': ('helfrelst',),
'helfrelstere': ('helfrelst',),
'helfrelstest': ('helfrelst',),
'helfrelsteste': ('helfrelst',),
'helgarderende': ('helgardere',),
'helgardert': ('helgardere',),
'helgarderte': ('helgardere',),
'helhetlig': ('helhetlig',),
'helhetlige': ('helhetlig',),
'helhetligere': ('helhetlig',),
'helhetligst': ('helhetlig',),
'helhetligste': ('helhetlig',),
'helhjerta': ('helhjerta',),
'helhjertede': ('helhjertet',),
'helhjertet': ('helhjertet',),
'helhjertete': ('helhjertet',),
'helhjertetere': ('helhjertet',),
'helhjertetest': ('helhjertet',),
'helhjerteteste': ('helhjertet',),
'heliosentrisk': ('heliosentrisk',),
'heliosentriske': ('heliosentrisk',),
'heliosentriskere': ('heliosentrisk',),
'heliosentriskest': ('heliosentrisk',),
'heliosentriskeste': ('heliosentrisk',),
'helkontinuerlig': ('helkontinuerlig',),
'helkontinuerlige': ('helkontinuerlig',),
'helkontinuerligere': ('helkontinuerlig',),
'helkontinuerligst': ('helkontinuerlig',),
'helkontinuerligste': ('helkontinuerlig',),
'hella': ('helle',),
'hellede': ('helle',),
'hellende': ('helle',),
'hellet': ('helle',),
'hellete': ('helle',),
'helt': ('helle',),
'helte': ('helle',),
'hellelagt': ('hellelegge',),
'hellelagte': ('hellelegge',),
'helleleggende': ('hellelegge',),
'hellenistisk': ('hellenistisk',),
'hellenistiske': ('hellenistisk',),
'hellenistiskere': ('hellenistisk',),
'hellenistiskest': ('hellenistisk',),
'hellenistiskeste': ('hellenistisk',),
'hellensk': ('hellensk',),
'hellenske': ('hellensk',),
'hellenskere': ('hellensk',),
'hellenskest': ('hellensk',),
'hellenskeste': ('hellensk',),
'hellig': ('hellig',),
'hellige': ('hellig',),
'helligere': ('hellig',),
'helligst': ('hellig',),
'helligste': ('hellig',),
'helliga': ('hellige',),
'helligede': ('hellige',),
'helligende': ('hellige',),
'helliget': ('hellige',),
'helligete': ('hellige',),
'helligholdende': ('helligholde',),
'helligholdt': ('helligholde',),
'helligholdte': ('helligholde',),
'helnorsk': ('helnorsk',),
'helnorske': ('helnorsk',),
'helnorskere': ('helnorsk',),
'helnorskest': ('helnorsk',),
'helnorskeste': ('helnorsk',),
'helsende': ('helse',),
'helst': ('helse',),
'helste': ('helse',),
'helsende': ('helse',),
'helst': ('helse',),
'helste': ('helse',),
'helsebringende': ('helsebringende',),
'helsebrutt': ('helsebrutt',),
'helsebrutte': ('helsebrutt',),
'helsebruttere': ('helsebrutt',),
'helsebruttest': ('helsebrutt',),
'helsebrutteste': ('helsebrutt',),
'helsefarlig': ('helsefarlig',),
'helsefarlige': ('helsefarlig',),
'helsefarligere': ('helsefarlig',),
'helsefarligst': ('helsefarlig',),
'helsefarligste': ('helsefarlig',),
'helselaus': ('helselaus',),
'helselause': ('helselaus',),
'helselausere': ('helselaus',),
'helselausest': ('helselaus',),
'helselauseste': ('helselaus',),
'helselaust': ('helselaus',),
'helseløs': ('helseløs',),
'helseløse': ('helseløs',),
'helseløsere': ('helseløs',),
'helseløsest': ('helseløs',),
'helseløseste': ('helseløs',),
'helseløst': ('helseløs',),
'helseslående': ('helseslå',),
'helseslått': ('helseslå',),
'helseslåtte': ('helseslå',),
'helsikes': ('helsikes',),
'helskinna': ('helskinna',),
'helskinnede': ('helskinnet',),
'helskinnet': ('helskinnet',),
'helskinnete': ('helskinnet',),
'helskinnetere': ('helskinnet',),
'helskinnetest': ('helskinnet',),
'helskinneteste': ('helskinnet',),
'helskåren': ('helskåren',),
'helskåret': ('helskåren',),
'helskårne': ('helskåren',),
'helskårnere': ('helskåren',),
'helskårnest': ('helskåren',),
'helskårneste': ('helskåren',),
'helskåret': ('helskåret',),
'helskårne': ('helskåret',),
'helskårnere': ('helskåret',),
'helskårnest': ('helskåret',),
'helskårneste': ('helskåret',),
'helstaut': ('helstaut',),
'helstaute': ('helstaut',),
'helstautere': ('helstaut',),
'helstautest': ('helstaut',),
'helstauteste': ('helstaut',),
'helsteikende': ('helsteike',),
'helsteikt': ('helsteike',),
'helsteikte': ('helsteike',),
'helstekende': ('helsteke',),
'helstekt': ('helsteke',),
'helstekte': ('helsteke',),
'helstøpende': ('helstøpe',),
'helstøpt': ('helstøpe',),
'helstøpte': ('helstøpe',),
'helstøypende': ('helstøype',),
'helstøypt': ('helstøype',),
'helstøypte': ('helstøype',),
'helsvart': ('helsvart',),
'helsvarte': ('helsvart',),
'helsvartere': ('helsvart',),
'helsvartest': ('helsvart',),
'helsvarteste': ('helsvart',),
'helsynkroniserende': ('helsynkronisere',),
'helsynkronisert': ('helsynkronisere',),
'helsynkroniserte': ('helsynkronisere',),
'heltallig': ('heltallig',),
'heltallige': ('heltallig',),
'heltalligere': ('heltallig',),
'heltalligst': ('heltallig',),
'heltalligste': ('heltallig',),
'heltemodig': ('heltemodig',),
'heltemodige': ('heltemodig',),
'heltemodigere': ('heltemodig',),
'heltemodigst': ('heltemodig',),
'heltemodigste': ('heltemodig',),
'heltidsansatt': ('heltidsansatt',),
'heltidsansatte': ('heltidsansatt',),
'heltidsansattere': ('heltidsansatt',),
'heltidsansattest': ('heltidsansatt',),
'heltidsansatteste': ('heltidsansatt',),
'heltres': ('heltres',),
'heltrukket': ('heltrukket',),
'heltrukne': ('heltrukket',),
'heltruknere': ('heltrukket',),
'heltruknest': ('heltrukket',),
'heltrukneste': ('heltrukket',),
'helvetes': ('helvetes',),
'helårig': ('helårig',),
'helårige': ('helårig',),
'helårigere': ('helårig',),
'helårigst': ('helårig',),
'helårigste': ('helårig',),
'helårs': ('helårs',),
'hematologisk': ('hematologisk',),
'hematologiske': ('hematologisk',),
'hematologiskere': ('hematologisk',),
'hematologiskest': ('hematologisk',),
'hematologiskeste': ('hematologisk',),
'hemisfærisk': ('hemisfærisk',),
'hemisfæriske': ('hemisfærisk',),
'hemisfæriskere': ('hemisfærisk',),
'hemisfæriskest': ('hemisfærisk',),
'hemisfæriskeste': ('hemisfærisk',),
'hemma': ('hemme',),
'hemmede': ('hemme',),
'hemmende': ('hemme',),
'hemmet': ('hemme',),
'hemmete': ('hemme',),
'hemmelig': ('hemmelig',),
'hemmelige': ('hemmelig',),
'hemmeligere': ('hemmelig',),
'hemmeligst': ('hemmelig',),
'hemmeligste': ('hemmelig',),
'hemmelighetsfull': ('hemmelighetsfull',),
'hemmelighetsfulle': ('hemmelighetsfull',),
'hemmelighetsfullere': ('hemmelighetsfull',),
'hemmelighetsfullest': ('hemmelighetsfull',),
'hemmelighetsfulleste': ('hemmelighetsfull',),
'hemmelighetsfullt': ('hemmelighetsfull',),
'hemmeligholdende': ('hemmeligholde',),
'hemmeligholdt': ('hemmeligholde',),
'hemmeligholdte': ('hemmeligholde',),
'hemmeligstempla': ('hemmeligstemple',),
'hemmeligstemplede': ('hemmeligstemple',),
'hemmeligstemplende': ('hemmeligstemple',),
'hemmeligstemplet': ('hemmeligstemple',),
'hemmeligstemplete': ('hemmeligstemple',),
'hemningslaus': ('hemningslaus',),
'hemningslause': ('hemningslaus',),
'hemningslausere': ('hemningslaus',),
'hemningslausest': ('hemningslaus',),
'hemningslauseste': ('hemningslaus',),
'hemningslaust': ('hemningslaus',),
'hemningsløs': ('hemningsløs',),
'hemningsløse': ('hemningsløs',),
'hemningsløsere': ('hemningsløs',),
'hemningsløsest': ('hemningsløs',),
'hemningsløseste': ('hemningsløs',),
'hemningsløst': ('hemningsløs',),
'hendende': ('hende',),
'hendt': ('hende',),
'hendte': ('hende',),
'hende': ('hende',),
'hendelig': ('hendelig',),
'hendelige': ('hendelig',),
'hendeligere': ('hendelig',),
'hendeligst': ('hendelig',),
'hendeligste': ('hendelig',),
'hendig': ('hendig',),
'hendige': ('hendig',),
'hendigere': ('hendig',),
'hendigst': ('hendig',),
'hendigste': ('hendig',),
'hendt': ('hendt',),
'hendte': ('hendt',),
'hendtere': ('hendt',),
'hendtest': ('hendt',),
'hendteste': ('hendt',),
'hendøende': ('hendøende',),
'henfallen': ('henfallen',),
'henfallent': ('henfallen',),
'henfalne': ('henfallen',),
'henfalnere': ('henfallen',),
'henfalnest': ('henfallen',),
'henfalneste': ('henfallen',),
'henfaren': ('henfaren',),
'henfarent': ('henfaren',),
'henfarne': ('henfaren',),
'henfarnere': ('henfaren',),
'henfarnest': ('henfaren',),
'henfarneste': ('henfaren',),
'henførende': ('henføre',),
'henført': ('henføre',),
'henførte': ('henføre',),
'hengebratt': ('hengebratt',),
'hengebratte': ('hengebratt',),
'hengebrattere': ('hengebratt',),
'hengebrattest': ('hengebratt',),
'hengebratteste': ('hengebratt',),
'hengeskuldra': ('hengeskuldra',),
'hengeskuldrede': ('hengeskuldret',),
'hengeskuldret': ('hengeskuldret',),
'hengeskuldrete': ('hengeskuldret',),
'hengeskuldretere': ('hengeskuldret',),
'hengeskuldretest': ('hengeskuldret',),
'hengeskuldreteste': ('hengeskuldret',),
'hengiende': ('hengi',),
'hengitt': ('hengi',),
'hengitte': ('hengi',),
'hengivende': ('hengi',),
'hengiven': ('hengiven',),
'hengivent': ('hengiven',),
'hengivne': ('hengiven',),
'hengivnere': ('hengiven',),
'hengivnest': ('hengiven',),
'hengivneste': ('hengiven',),
'hengsla': ('hengsle',),
'hengslede': ('hengsle',),
'hengslende': ('hengsle',),
'hengslet': ('hengsle',),
'hengslete': ('hengsle',),
'hengslet': ('hengslet',),
'hengslete': ('hengslet',),
'hengsletere': ('hengslet',),
'hengsletest': ('hengslet',),
'hengsleteste': ('hengslet',),
'hengslete': ('hengslete',),
'henholdende': ('henholde',),
'henholdt': ('henholde',),
'henholdte': ('henholde',),
'henhørende': ('henhøre',),
'henhørt': ('henhøre',),
'henhørte': ('henhøre',),
'henkasta': ('henkaste',),
'henkastede': ('henkaste',),
'henkastende': ('henkaste',),
'henkastet': ('henkaste',),
'henkastete': ('henkaste',),
'henleda': ('henlede',),
'henledede': ('henlede',),
'henledende': ('henlede',),
'henledet': ('henlede',),
'henledete': ('henlede',),
'henlagt': ('henlegge',),
'henlagte': ('henlegge',),
'henleggende': ('henlegge',),
'hennafarga': ('hennafarga',),
'hennafargede': ('hennafarget',),
'hennafarget': ('hennafarget',),
'hennafargete': ('hennafarget',),
'hennafargetere': ('hennafarget',),
'hennafargetest': ('hennafarget',),
'hennafargeteste': ('hennafarget',),
'henrekna': ('henrekne',),
'henreknede': ('henrekne',),
'henreknende': ('henrekne',),
'henreknet': ('henrekne',),
'henreknete': ('henrekne',),
'henretta': ('henrette',),
'henrettede': ('henrette',),
'henrettende': ('henrette',),
'henrettet': ('henrette',),
'henrettete': ('henrette',),
'henrivende': ('henrivende',),
'henrykka': ('henrykke',),
'henrykkede': ('henrykke',),
'henrykkende': ('henrykke',),
'henrykket': ('henrykke',),
'henrykkete': ('henrykke',),
'henrykt': ('henrykke',),
'henrykte': ('henrykke',),
'henrykt': ('henrykt',),
'henrykte': ('henrykt',),
'henryktere': ('henrykt',),
'henryktest': ('henrykt',),
'henrykteste': ('henrykt',),
'hensatt': ('hensette',),
'hensatte': ('hensette',),
'hensettende': ('hensette',),
'hensiktsmessig': ('hensiktsmessig',),
'hensiktsmessige': ('hensiktsmessig',),
'hensiktsmessigere': ('hensiktsmessig',),
'hensiktsmessigst': ('hensiktsmessig',),
'hensiktsmessigste': ('hensiktsmessig',),
'hensiktssvarende': ('hensiktssvarende',),
'henskutt': ('henskyte',),
'henskutte': ('henskyte',),
'henskytende': ('henskyte',),
'henslengt': ('henslengt',),
'henslengte': ('henslengt',),
'henslengtere': ('henslengt',),
'henslengtest': ('henslengt',),
'henslengteste': ('henslengt',),
'henslepende': ('henslepe',),
'henslept': ('henslepe',),
'henslepte': ('henslepe',),
'henspillende': ('henspille',),
'henspilt': ('henspille',),
'henspilte': ('henspille',),
'henstillende': ('henstille',),
'henstilt': ('henstille',),
'henstilte': ('henstille',),
'henstrakt': ('henstrakt',),
'henstrakte': ('henstrakt',),
'henstraktere': ('henstrakt',),
'henstraktest': ('henstrakt',),
'henstrakteste': ('henstrakt',),
'hensynsfull': ('hensynsfull',),
'hensynsfulle': ('hensynsfull',),
'hensynsfullere': ('hensynsfull',),
'hensynsfullest': ('hensynsfull',),
'hensynsfulleste': ('hensynsfull',),
'hensynsfullt': ('hensynsfull',),
'hensynslaus': ('hensynslaus',),
'hensynslause': ('hensynslaus',),
'hensynslausere': ('hensynslaus',),
'hensynslausest': ('hensynslaus',),
'hensynslauseste': ('hensynslaus',),
'hensynslaust': ('hensynslaus',),
'hensynsløs': ('hensynsløs',),
'hensynsløse': ('hensynsløs',),
'hensynsløsere': ('hensynsløs',),
'hensynsløsest': ('hensynsløs',),
'hensynsløseste': ('hensynsløs',),
'hensynsløst': ('hensynsløs',),
'henta': ('hente',),
'hentede': ('hente',),
'hentende': ('hente',),
'hentet': ('hente',),
'hentete': ('hente',),
'hentyda': ('hentyde',),
'hentydede': ('hentyde',),
'hentydende': ('hentyde',),
'hentydet': ('hentyde',),
'hentydete': ('hentyde',),
'henvendende': ('henvende',),
'henvendt': ('henvende',),
'henvendte': ('henvende',),
'henvisende': ('henvise',),
'henvist': ('henvise',),
'henviste': ('henvise',),
'heppa': ('heppe',),
'heppede': ('heppe',),
'heppende': ('heppe',),
'heppet': ('heppe',),
'heppete': ('heppe',),
'hepne': ('heppen',),
'hepnere': ('heppen',),
'hepnest': ('heppen',),
'hepneste': ('heppen',),
'heppen': ('heppen',),
'heppent': ('heppen',),
'heraldisk': ('heraldisk',),
'heraldiske': ('heraldisk',),
'heraldiskere': ('heraldisk',),
'heraldiskest': ('heraldisk',),
'heraldiskeste': ('heraldisk',),
'herda': ('herde',),
'herdede': ('herde',),
'herdende': ('herde',),
'herdet': ('herde',),
'herdete': ('herde',),
'herdebrei': ('herdebrei',),
'herdebreie': ('herdebrei',),
'herdebreiere': ('herdebrei',),
'herdebreiest': ('herdebrei',),
'herdebreieste': ('herdebrei',),
'herdebreit': ('herdebrei',),
'herdig': ('herdig',),
'herdige': ('herdig',),
'herdigere': ('herdig',),
'herdigst': ('herdig',),
'herdigste': ('herdig',),
'herdna': ('herdne',),
'herdnede': ('herdne',),
'herdnende': ('herdne',),
'herdnet': ('herdne',),
'herdnete': ('herdne',),
'hereditær': ('hereditær',),
'hereditære': ('hereditær',),
'hereditærere': ('hereditær',),
'hereditærest': ('hereditær',),
'hereditæreste': ('hereditær',),
'hereditært': ('hereditær',),
'heretisk': ('heretisk',),
'heretiske': ('heretisk',),
'heretiskere': ('heretisk',),
'heretiskest': ('heretisk',),
'heretiskeste': ('heretisk',),
'herja': ('herje',),
'herjede': ('herje',),
'herjende': ('herje',),
'herjet': ('herje',),
'herjete': ('herje',),
'herkulisk': ('herkulisk',),
'herkuliske': ('herkulisk',),
'herkuliskere': ('herkulisk',),
'herkuliskest': ('herkulisk',),
'herkuliskeste': ('herkulisk',),
'herlig': ('herlig',),
'herlige': ('herlig',),
'herligere': ('herlig',),
'herligst': ('herlig',),
'herligste': ('herlig',),
'herliggjort': ('herliggjøre',),
'herliggjorte': ('herliggjøre',),
'herliggjørende': ('herliggjøre',),
'hermafrodittisk': ('hermafrodittisk',),
'hermafrodittiske': ('hermafrodittisk',),
'hermafrodittiskere': ('hermafrodittisk',),
'hermafrodittiskest': ('hermafrodittisk',),
'hermafrodittiskeste': ('hermafrodittisk',),
'herma': ('herme',),
'hermede': ('herme',),
'hermende': ('herme',),
'hermet': ('herme',),
'hermete': ('herme',),
'hermt': ('herme',),
'hermte': ('herme',),
'hermeneutisk': ('hermeneutisk',),
'hermeneutiske': ('hermeneutisk',),
'hermeneutiskere': ('hermeneutisk',),
'hermeneutiskest': ('hermeneutisk',),
'hermeneutiskeste': ('hermeneutisk',),
'hermetiserende': ('hermetisere',),
'hermetisert': ('hermetisere',),
'hermetiserte': ('hermetisere',),
'hermetisk': ('hermetisk',),
'hermetiske': ('hermetisk',),
'hermetiskere': ('hermetisk',),
'hermetiskest': ('hermetisk',),
'hermetiskeste': ('hermetisk',),
'heroiserende': ('heroisere',),
'heroisert': ('heroisere',),
'heroiserte': ('heroisere',),
'heroisk': ('heroisk',),
'heroiske': ('heroisk',),
'heroiskere': ('heroisk',),
'heroiskest': ('heroisk',),
'heroiskeste': ('heroisk',),
'herostratisk': ('herostratisk',),
'herostratiske': ('herostratisk',),
'herostratiskere': ('herostratisk',),
'herostratiskest': ('herostratisk',),
'herostratiskeste': ('herostratisk',),
'herrelaus': ('herrelaus',),
'herrelause': ('herrelaus',),
'herrelausere': ('herrelaus',),
'herrelausest': ('herrelaus',),
'herrelauseste': ('herrelaus',),
'herrelaust': ('herrelaus',),
'herreløs': ('herreløs',),
'herreløse': ('herreløs',),
'herreløsere': ('herreløs',),
'herreløsest': ('herreløs',),
'herreløseste': ('herreløs',),
'herreløst': ('herreløs',),
'herrnhutisk': ('herrnhutisk',),
'herrnhutiske': ('herrnhutisk',),
'herrnhutiskere': ('herrnhutisk',),
'herrnhutiskest': ('herrnhutisk',),
'herrnhutiskeste': ('herrnhutisk',),
'hersa': ('herse',),
'hersede': ('herse',),
'hersende': ('herse',),
'herset': ('herse',),
'hersete': ('herse',),
'herskapelig': ('herskapelig',),
'herskapelige': ('herskapelig',),
'herskapeligere': ('herskapelig',),
'herskapeligst': ('herskapelig',),
'herskapeligste': ('herskapelig',),
'herska': ('herske',),
'herskede': ('herske',),
'herskende': ('herske',),
'hersket': ('herske',),
'herskete': ('herske',),
'herskesjuk': ('herskesjuk',),
'herskesjuke': ('herskesjuk',),
'herskesjukere': ('herskesjuk',),
'herskesjukest': ('herskesjuk',),
'herskesjukeste': ('herskesjuk',),
'herskesjukt': ('herskesjuk',),
'herskesyk': ('herskesyk',),
'herskesyke': ('herskesyk',),
'herskesykere': ('herskesyk',),
'herskesykest': ('herskesyk',),
'herskesykeste': ('herskesyk',),
'herskesykt': ('herskesyk',),
'herværende': ('herværende',),
'hes': ('hes',),
'hese': ('hes',),
'hesere': ('hes',),
'hesest': ('hes',),
'heseste': ('hes',),
'hest': ('hes',),
'heseblesende': ('heseblesende',),
'hesja': ('hesje',),
'hesjede': ('hesje',),
'hesjende': ('hesje',),
'hesjet': ('hesje',),
'hesjete': ('hesje',),
'heslig': ('heslig',),
'heslige': ('heslig',),
'hesligere': ('heslig',),
'hesligst': ('heslig',),
'hesligste': ('heslig',),
'hespa': ('hespe',),
'hespede': ('hespe',),
'hespende': ('hespe',),
'hespet': ('hespe',),
'hespete': ('hespe',),
'hespla': ('hesple',),
'hesplede': ('hesple',),
'hesplende': ('hesple',),
'hesplet': ('hesple',),
'hesplete': ('hesple',),
'hestedum': ('hestedum',),
'hestedumme': ('hestedum',),
'hestedummere': ('hestedum',),
'hestedummest': ('hestedum',),
'hestedummeste': ('hestedum',),
'hestedumt': ('hestedum',),
'hestegal': ('hestegal',),
'hestegale': ('hestegal',),
'hestegalere': ('hestegal',),
'hestegalest': ('hestegal',),
'hestegaleste': ('hestegal',),
'hestegalt': ('hestegal',),
'hestehandla': ('hestehandle',),
'hestehandlede': ('hestehandle',),
'hestehandlende': ('hestehandle',),
'hestehandlet': ('hestehandle',),
'hestehandlete': ('hestehandle',),
'hestgal': ('hestgal',),
'hestgale': ('hestgal',),
'hestgalere': ('hestgal',),
'hestgalest': ('hestgal',),
'hestgaleste': ('hestgal',),
'hestgalt': ('hestgal',),
'het': ('het',),
'hete': ('het',),
'hetere': ('het',),
'hetest': ('het',),
'heteste': ('het',),
'hett': ('het',),
'heta': ('hete',),
'hetede': ('hete',),
'hetende': ('hete',),
'hetet': ('hete',),
'hetete': ('hete',),
'hetende': ('hete',),
'hett': ('hete',),
'hette': ('hete',),
'heterodoks': ('heterodoks',),
'heterodokse': ('heterodoks',),
'heterodoksere': ('heterodoks',),
'heterodoksest': ('heterodoks',),
'heterodokseste': ('heterodoks',),
'heterodokst': ('heterodoks',),
'heterofil': ('heterofil',),
'heterofile': ('heterofil',),
'heterofilere': ('heterofil',),
'heterofilest': ('heterofil',),
'heterofileste': ('heterofil',),
'heterofilt': ('heterofil',),
'heterogen': ('heterogen',),
'heterogene': ('heterogen',),
'heterogenere': ('heterogen',),
'heterogenest': ('heterogen',),
'heterogeneste': ('heterogen',),
'heterogent': ('heterogen',),
'heteromorf': ('heteromorf',),
'heteromorfe': ('heteromorf',),
'heteromorfere': ('heteromorf',),
'heteromorfest': ('heteromorf',),
'heteromorfeste': ('heteromorf',),
'heteromorft': ('heteromorf',),
'heteroseksuell': ('heteroseksuell',),
'heteroseksuelle': ('heteroseksuell',),
'heteroseksuellere': ('heteroseksuell',),
'heteroseksuellest': ('heteroseksuell',),
'heteroseksuelleste': ('heteroseksuell',),
'heteroseksuelt': ('heteroseksuell',),
'hetna': ('hetne',),
'hetnede': ('hetne',),
'hetnende': ('hetne',),
'hetnet': ('hetne',),
'hetnete': ('hetne',),
'hetsa': ('hetse',),
'hetsede': ('hetse',),
'hetsende': ('hetse',),
'hetset': ('hetse',),
'hetsete': ('hetse',),
'hettittisk': ('hettittisk',),
'hettittiske': ('hettittisk',),
'hettittiskere': ('hettittisk',),
'hettittiskest': ('hettittisk',),
'hettittiskeste': ('hettittisk',),
'heuristisk': ('heuristisk',),
'heuristiske': ('heuristisk',),
'heuristiskere': ('heuristisk',),
'heuristiskest': ('heuristisk',),
'heuristiskeste': ('heuristisk',),
'hevbar': ('hevbar',),
'hevbare': ('hevbar',),
'hevbarere': ('hevbar',),
'hevbarest': ('hevbar',),
'hevbareste': ('hevbar',),
'hevbart': ('hevbar',),
'hevda': ('hevde',),
'hevdede': ('hevde',),
'hevdende': ('hevde',),
'hevdet': ('hevde',),
'hevdete': ('hevde',),
'hevdvunne': ('hevdvunnen',),
'hevdvunnen': ('hevdvunnen',),
'hevdvunnere': ('hevdvunnen',),
'hevdvunnest': ('hevdvunnen',),
'hevdvunneste': ('hevdvunnen',),
'hevdvunnet': ('hevdvunnen',),
'hevdvunne': ('hevdvunnet',),
'hevdvunnere': ('hevdvunnet',),
'hevdvunnest': ('hevdvunnet',),
'hevdvunneste': ('hevdvunnet',),
'hevdvunnet': ('hevdvunnet',),
'heva': ('heve',),
'hevd': ('heve',),
'hevde': ('heve',),
'hevede': ('heve',),
'hevende': ('heve',),
'hevet': ('heve',),
'hevete': ('heve',),
'hevla': ('hevle',),
'hevlede': ('hevle',),
'hevlende': ('hevle',),
'hevlet': ('hevle',),
'hevlete': ('hevle',),
'hevna': ('hevne',),
'hevnede': ('hevne',),
'hevnende': ('hevne',),
'hevnet': ('hevne',),
'hevnete': ('hevne',),
'hevngjerrig': ('hevngjerrig',),
'hevngjerrige': ('hevngjerrig',),
'hevngjerrigere': ('hevngjerrig',),
'hevngjerrigst': ('hevngjerrig',),
'hevngjerrigste': ('hevngjerrig',),
'hia': ('hie',),
'hiede': ('hie',),
'hiende': ('hie',),
'hiet': ('hie',),
'hiete': ('hie',),
'hierarkisk': ('hierarkisk',),
'hierarkiske': ('hierarkisk',),
'hierarkiskere': ('hierarkisk',),
'hierarkiskest': ('hierarkisk',),
'hierarkiskeste': ('hierarkisk',),
'hieratisk': ('hieratisk',),
'hieratiske': ('hieratisk',),
'hieratiskere': ('hieratisk',),
'hieratiskest': ('hieratisk',),
'hieratiskeste': ('hieratisk',),
'hieroglyfisk': ('hieroglyfisk',),
'hieroglyfiske': ('hieroglyfisk',),
'hieroglyfiskere': ('hieroglyfisk',),
'hieroglyfiskest': ('hieroglyfisk',),
'hieroglyfiskeste': ('hieroglyfisk',),
'higa': ('hige',),
'higede': ('hige',),
'higende': ('hige',),
'higet': ('hige',),
'higete': ('hige',),
'hikka': ('hikke',),
'hikkede': ('hikke',),
'hikkende': ('hikke',),
'hikket': ('hikke',),
'hikkete': ('hikke',),
'hiksta': ('hikste',),
'hikstede': ('hikste',),
'hikstende': ('hikste',),
'hikstet': ('hikste',),
'hikstete': ('hikste',),
'hikstegråtende': ('hikstegråte',),
'hikstegrått': ('hikstegråte',),
'hikstegråtte': ('hikstegråte',),
'hilda': ('hilde',),
'hildede': ('hilde',),
'hildende': ('hilde',),
'hildet': ('hilde',),
'hildete': ('hilde',),
'hildra': ('hildre',),
'hildrede': ('hildre',),
'hildrende': ('hildre',),
'hildret': ('hildre',),
'hildrete': ('hildre',),
'hilsende': ('hilse',),
'hilst': ('hilse',),
'hilste': ('hilse',),
'hilsende': ('hilse',),
'hilst': ('hilse',),
'hilste': ('hilse',),
'himla': ('himle',),
'himlede': ('himle',),
'himlende': ('himle',),
'himlet': ('himle',),
'himlete': ('himle',),
'himla': ('himle',),
'himlede': ('himle',),
'himlende': ('himle',),
'himlet': ('himle',),
'himlete': ('himle',),
'himmelblå': ('himmelblå',),
'himmelblåe': ('himmelblå',),
'himmelblåere': ('himmelblå',),
'himmelblåest': ('himmelblå',),
'himmelblåeste': ('himmelblå',),
'himmelblått': ('himmelblå',),
'himmelfallen': ('himmelfallen',),
'himmelfallent': ('himmelfallen',),
'himmelfalne': ('himmelfallen',),
'himmelfalnere': ('himmelfallen',),
'himmelfalnest': ('himmelfallen',),
'himmelfalneste': ('himmelfallen',),
'himmelhenrykt': ('himmelhenrykt',),
'himmelhenrykte': ('himmelhenrykt',),
'himmelhenryktere': ('himmelhenrykt',),
'himmelhenryktest': ('himmelhenrykt',),
'himmelhenrykteste': ('himmelhenrykt',),
'himmelhøg': ('himmelhøg',),
'himmelhøge': ('himmelhøg',),
'himmelhøgere': ('himmelhøg',),
'himmelhøgest': ('himmelhøg',),
'himmelhøgeste': ('himmelhøg',),
'himmelhøgre': ('himmelhøg',),
'himmelhøgst': ('himmelhøg',),
'himmelhøgste': ('himmelhøg',),
'himmelhøgt': ('himmelhøg',),
'himmelhøy': ('himmelhøy',),
'himmelhøye': ('himmelhøy',),
'himmelhøyere': ('himmelhøy',),
'himmelhøyest': ('himmelhøy',),
'himmelhøyeste': ('himmelhøy',),
'himmelhøyt': ('himmelhøy',),
'himmelropende': ('himmelropende',),
'himmelsk': ('himmelsk',),
'himmelske': ('himmelsk',),
'himmelskere': ('himmelsk',),
'himmelskest': ('himmelsk',),
'himmelskeste': ('himmelsk',),
'himmelstormende': ('himmelstormende',),
'himmelvid': ('himmelvid',),
'himmelvide': ('himmelvid',),
'himmelvidere': ('himmelvid',),
'himmelvidest': ('himmelvid',),
'himmelvideste': ('himmelvid',),
'himmelvidt': ('himmelvid',),
'hindra': ('hindre',),
'hindrede': ('hindre',),
'hindrende': ('hindre',),
'hindret': ('hindre',),
'hindrete': ('hindre',),
'hinduisk': ('hinduisk',),
'hinduiske': ('hinduisk',),
'hinduiskere': ('hinduisk',),
'hinduiskest': ('hinduisk',),
'hinduiskeste': ('hinduisk',),
'hinduistisk': ('hinduistisk',),
'hinduistiske': ('hinduistisk',),
'hinduistiskere': ('hinduistisk',),
'hinduistiskest': ('hinduistisk',),
'hinduistiskeste': ('hinduistisk',),
'hindustansk': ('hindustansk',),
'hindustanske': ('hindustansk',),
'hindustanskere': ('hindustansk',),
'hindustanskest': ('hindustansk',),
'hindustanskeste': ('hindustansk',),
'hingstegal': ('hingstegal',),
'hingstegale': ('hingstegal',),
'hingstegalere': ('hingstegal',),
'hingstegalest': ('hingstegal',),
'hingstegaleste': ('hingstegal',),
'hingstegalt': ('hingstegal',),
'hingstgal': ('hingstgal',),
'hingstgale': ('hingstgal',),
'hingstgalere': ('hingstgal',),
'hingstgalest': ('hingstgal',),
'hingstgaleste': ('hingstgal',),
'hingstgalt': ('hingstgal',),
'hinka': ('hinke',),
'hinkede': ('hinke',),
'hinkende': ('hinke',),
'hinket': ('hinke',),
'hinkete': ('hinke',),
'hinnet': ('hinnet',),
'hinnete': ('hinnet',),
'hinnetere': ('hinnet',),
'hinnetest': ('hinnet',),
'hinneteste': ('hinnet',),
'hinnete': ('hinnete',),
'hinsidig': ('hinsidig',),
'hinsidige': ('hinsidig',),
'hinsidigere': ('hinsidig',),
'hinsidigst': ('hinsidig',),
'hinsidigste': ('hinsidig',),
'hipa': ('hipe',),
'hipede': ('hipe',),
'hipende': ('hipe',),
'hipet': ('hipe',),
'hipete': ('hipe',),
'hipt': ('hipe',),
'hipte': ('hipe',),
'hipp': ('hipp',),
'hippe': ('hipp',),
'hippere': ('hipp',),
'hippest': ('hipp',),
'hippeste': ('hipp',),
'hipt': ('hipp',),
'hipne': ('hippen',),
'hipnere': ('hippen',),
'hipnest': ('hippen',),
'hipneste': ('hippen',),
'hippen': ('hippen',),
'hippent': ('hippen',),
'hirende': ('hire',),
'hirt': ('hire',),
'hirte': ('hire',),
'hiren': ('hiren',),
'hirent': ('hiren',),
'hirne': ('hiren',),
'hirnere': ('hiren',),
'hirnest': ('hiren',),
'hirneste': ('hiren',),
'hissa': ('hisse',),
'hissede': ('hisse',),
'hissende': ('hisse',),
'hisset': ('hisse',),
'hissete': ('hisse',),
'hissig': ('hissig',),
'hissige': ('hissig',),
'hissigere': ('hissig',),
'hissigst': ('hissig',),
'hissigste': ('hissig',),
'historiografisk': ('historiografisk',),
'historiografiske': ('historiografisk',),
'historiografiskere': ('historiografisk',),
'historiografiskest': ('historiografisk',),
'historiografiskeste': ('historiografisk',),
'historisk': ('historisk',),
'historiske': ('historisk',),
'historiskere': ('historisk',),
'historiskest': ('historisk',),
'historiskeste': ('historisk',),
'hithørende': ('hithørende',),
'hitre': ('hitre',),
'hitterst': ('hitre',),
'hitterste': ('hitre',),
'hitsatt': ('hitsette',),
'hitsatte': ('hitsette',),
'hitsettende': ('hitsette',),
'hitta': ('hitte',),
'hittede': ('hitte',),
'hittende': ('hitte',),
'hittet': ('hitte',),
'hittete': ('hitte',),
'hitterst': ('hitterst',),
'hitterste': ('hitterst',),
'hivd': ('hive',),
'hivde': ('hive',),
'hivende': ('hive',),
'hjelpende': ('hjelpe',),
'hjulpen': ('hjelpe',),
'hjulpet': ('hjelpe',),
'hjulpne': ('hjelpe',),
'hjelpelaus': ('hjelpelaus',),
'hjelpelause': ('hjelpelaus',),
'hjelpelausere': ('hjelpelaus',),
'hjelpelausest': ('hjelpelaus',),
'hjelpelauseste': ('hjelpelaus',),
'hjelpelaust': ('hjelpelaus',),
'hjelpeløs': ('hjelpeløs',),
'hjelpeløse': ('hjelpeløs',),
'hjelpeløsere': ('hjelpeløs',),
'hjelpeløsest': ('hjelpeløs',),
'hjelpeløseste': ('hjelpeløs',),
'hjelpeløst': ('hjelpeløs',),
'hjelpetrengende': ('hjelpetrengende',),
'hjelpsom': ('hjelpsom',),
'hjelpsomme': ('hjelpsom',),
'hjelpsommere': ('hjelpsom',),
'hjelpsomst': ('hjelpsom',),
'hjelpsomste': ('hjelpsom',),
'hjelpsomt': ('hjelpsom',),
'hjemfallende': ('hjemfalle',),
'hjemfalt': ('hjemfalle',),
'hjemfalte': ('hjemfalle',),
'hjemfallen': ('hjemfallen',),
'hjemfallent': ('hjemfallen',),
'hjemfalne': ('hjemfallen',),
'hjemfalnere': ('hjemfallen',),
'hjemfalnest': ('hjemfallen',),
'hjemfalneste': ('hjemfallen',),
'hjemfesta': ('hjemfeste',),
'hjemfestede': ('hjemfeste',),
'hjemfestende': ('hjemfeste',),
'hjemfestet': ('hjemfeste',),
'hjemfestete': ('hjemfeste',),
'hjemførende': ('hjemføre',),
'hjemført': ('hjemføre',),
'hjemførte': ('hjemføre',),
'hjemkallende': ('hjemkalle',),
'hjemkalt': ('hjemkalle',),
'hjemkalte': ('hjemkalle',),
'hjemkommet': ('hjemkommet',),
'hjemkomne': ('hjemkommet',),
'hjemkomnere': ('hjemkommet',),
'hjemkomnest': ('hjemkommet',),
'hjemkomneste': ('hjemkommet',),
'hjemlaus': ('hjemlaus',),
'hjemlause': ('hjemlaus',),
'hjemlausere': ('hjemlaus',),
'hjemlausest': ('hjemlaus',),
'hjemlauseste': ('hjemlaus',),
'hjemlaust': ('hjemlaus',),
'hjemla': ('hjemle',),
'hjemlede': ('hjemle',),
'hjemlende': ('hjemle',),
'hjemlet': ('hjemle',),
'hjemlete': ('hjemle',),
'hjemlig': ('hjemlig',),
'hjemlige': ('hjemlig',),
'hjemligere': ('hjemlig',),
'hjemligst': ('hjemlig',),
'hjemligste': ('hjemlig',),
'hjemløs': ('hjemløs',),
'hjemløse': ('hjemløs',),
'hjemløsere': ('hjemløs',),
'hjemløsest': ('hjemløs',),
'hjemløseste': ('hjemløs',),
'hjemløst': ('hjemløs',),
'hjemmearbeidende': ('hjemmearbeidende',),
'hjemmeavla': ('hjemmeavla',),
'hjemmeavlede': ('hjemmeavlet',),
'hjemmeavlet': ('hjemmeavlet',),
'hjemmeavlete': ('hjemmeavlet',),
'hjemmeavletere': ('hjemmeavlet',),
'hjemmeavletest': ('hjemmeavlet',),
'hjemmeavleteste': ('hjemmeavlet',),
'hjemmegjort': ('hjemmegjort',),
'hjemmegjorte': ('hjemmegjort',),
'hjemmegjortere': ('hjemmegjort',),
'hjemmegjortest': ('hjemmegjort',),
'hjemmegjorteste': ('hjemmegjort',),
'hjemmehørende': ('hjemmehørende',),
'hjemmekjent': ('hjemmekjent',),
'hjemmekjente': ('hjemmekjent',),
'hjemmekjentere': ('hjemmekjent',),
'hjemmekjentest': ('hjemmekjent',),
'hjemmekjenteste': ('hjemmekjent',),
'hjemmekjær': ('hjemmekjær',),
'hjemmekjære': ('hjemmekjær',),
'hjemmekjærere': ('hjemmekjær',),
'hjemmekjærest': ('hjemmekjær',),
'hjemmekjæreste': ('hjemmekjær',),
'hjemmekjært': ('hjemmekjær',),
'hjemmekoselig': ('hjemmekoselig',),
'hjemmekoselige': ('hjemmekoselig',),
'hjemmekoseligere': ('hjemmekoselig',),
'hjemmekoseligst': ('hjemmekoselig',),
'hjemmekoseligste': ('hjemmekoselig',),
'hjemmelaga': ('hjemmelaga',),
'hjemmelagd': ('hjemmelagd',),
'hjemmelagde': ('hjemmelagd',),
'hjemmelagdere': ('hjemmelagd',),
'hjemmelagdest': ('hjemmelagd',),
'hjemmelagdeste': ('hjemmelagd',),
'hjemmelagede': ('hjemmelaget',),
'hjemmelaget': ('hjemmelaget',),
'hjemmelagete': ('hjemmelaget',),
'hjemmelagetere': ('hjemmelaget',),
'hjemmelagetest': ('hjemmelaget',),
'hjemmelageteste': ('hjemmelaget',),
'hjemmestrikka': ('hjemmestrikka',),
'hjemmestrikkede': ('hjemmestrikket',),
'hjemmestrikket': ('hjemmestrikket',),
'hjemmestrikkete': ('hjemmestrikket',),
'hjemmestrikketere': ('hjemmestrikket',),
'hjemmestrikketest': ('hjemmestrikket',),
'hjemmestrikketeste': ('hjemmestrikket',),
'hjemmevant': ('hjemmevant',),
'hjemmevante': ('hjemmevant',),
'hjemmevantere': ('hjemmevant',),
'hjemmevantest': ('hjemmevant',),
'hjemmevanteste': ('hjemmevant',),
'hjemmeværende': ('hjemmeværende',),
'hjemsendende': ('hjemsende',),
'hjemsendt': ('hjemsende',),
'hjemsendte': ('hjemsende',),
'hjemstavnsberettiga': ('hjemstavnsberettiga',),
'hjemstavnsberettigede': ('hjemstavnsberettiget',),
'hjemstavnsberettiget': ('hjemstavnsberettiget',),
'hjemstavnsberettigete': ('hjemstavnsberettiget',),
'hjemstavnsberettigetere': ('hjemstavnsberettiget',),
'hjemstavnsberettigetest': ('hjemstavnsberettiget',),
'hjemstavnsberettigeteste': ('hjemstavnsberettiget',),
'hjemsøkende': ('hjemsøke',),
'hjemsøkt': ('hjemsøke',),
'hjemsøkte': ('hjemsøke',),
'hjemvendt': ('hjemvendt',),
'hjemvendte': ('hjemvendt',),
'hjemvendtere': ('hjemvendt',),
'hjemvendtest': ('hjemvendt',),
'hjemvendteste': ('hjemvendt',),
'hjernedød': ('hjernedød',),
'hjernedøde': ('hjernedød',),
'hjernedødere': ('hjernedød',),
'hjernedødest': ('hjernedød',),
'hjernedødeste': ('hjernedød',),
'hjernedødt': ('hjernedød',),
'hjernevaska': ('hjernevaske',),
'hjernevaskede': ('hjernevaske',),
'hjernevaskende': ('hjernevaske',),
'hjernevasket': ('hjernevaske',),
'hjernevaskete': ('hjernevaske',),
'hjerta': ('hjerta',),
'hjerteforma': ('hjerteforma',),
'hjerteformede': ('hjerteformet',),
'hjerteformet': ('hjerteformet',),
'hjerteformete': ('hjerteformet',),
'hjerteformetere': ('hjerteformet',),
'hjerteformetest': ('hjerteformet',),
'hjerteformeteste': ('hjerteformet',),
'hjertebedre': ('hjertegod',),
'hjertebest': ('hjertegod',),
'hjertebeste': ('hjertegod',),
'hjertegod': ('hjertegod',),
'hjertegode': ('hjertegod',),
'hjertegodt': ('hjertegod',),
'hjertelaus': ('hjertelaus',),
'hjertelause': ('hjertelaus',),
'hjertelausere': ('hjertelaus',),
'hjertelausest': ('hjertelaus',),
'hjertelauseste': ('hjertelaus',),
'hjertelaust': ('hjertelaus',),
'hjertelig': ('hjertelig',),
'hjertelige': ('hjertelig',),
'hjerteligere': ('hjertelig',),
'hjerteligst': ('hjertelig',),
'hjerteligste': ('hjertelig',),
'hjerteløs': ('hjerteløs',),
'hjerteløse': ('hjerteløs',),
'hjerteløsere': ('hjerteløs',),
'hjerteløsest': ('hjerteløs',),
'hjerteløseste': ('hjerteløs',),
'hjerteløst': ('hjerteløs',),
'hjertens': ('hjertens',),
'hjerterå': ('hjerterå',),
'hjerteråe': ('hjerterå',),
'hjerteråere': ('hjerterå',),
'hjerteråest': ('hjerterå',),
'hjerteråeste': ('hjerterå',),
'hjerterått': ('hjerterå',),
'hjerteskjærende': ('hjerteskjærende',),
'hjertevarm': ('hjertevarm',),
'hjertevarme': ('hjertevarm',),
'hjertevarmere': ('hjertevarm',),
'hjertevarmest': ('hjertevarm',),
'hjertevarmeste': ('hjertevarm',),
'hjertevarmt': ('hjertevarm',),
'hjonslig': ('hjonslig',),
'hjonslige': ('hjonslig',),
'hjonsligere': ('hjonslig',),
'hjonsligst': ('hjonslig',),
'hjonsligste': ('hjonslig',),
'hjulbeint': ('hjulbeint',),
'hjulbeinte': ('hjulbeint',),
'hjulbeintere': ('hjulbeint',),
'hjulbeintest': ('hjulbeint',),
'hjulbeinteste': ('hjulbeint',),
'hjulbent': ('hjulbent',),
'hjulbente': ('hjulbent',),
'hjulbentere': ('hjulbent',),
'hjulbentest': ('hjulbent',),
'hjulbenteste': ('hjulbent',),
'hjulpen': ('hjulpen',),
'hjulpent': ('hjulpen',),
'hjulpne': ('hjulpen',),
'hjulpnere': ('hjulpen',),
'hjulpnest': ('hjulpen',),
'hjulpneste': ('hjulpen',),
'hodegal': ('hodegal',),
'hodegale': ('hodegal',),
'hodegalere': ('hodegal',),
'hodegalest': ('hodegal',),
'hodegaleste': ('hodegal',),
'hodegalt': ('hodegal',),
'hodegalen': ('hodegalen',),
'hodegalent': ('hodegalen',),
'hodegalne': ('hodegalen',),
'hodegalnere': ('hodegalen',),
'hodegalnest': ('hodegalen',),
'hodegalneste': ('hodegalen',),
'hoderystende': ('hoderystende',),
'hofferda': ('hofferde',),
'hofferdede': ('hofferde',),
'hofferdende': ('hofferde',),
'hofferdet': ('hofferde',),
'hofferdete': ('hofferde',),
'hofferdig': ('hofferdig',),
'hofferdige': ('hofferdig',),
'hofferdigere': ('hofferdig',),
'hofferdigst': ('hofferdig',),
'hofferdigste': ('hofferdig',),
'hoggbratt': ('hoggbratt',),
'hoggbratte': ('hoggbratt',),
'hoggbrattere': ('hoggbratt',),
'hoggbrattest': ('hoggbratt',),
'hoggbratteste': ('hoggbratt',),
'hogstmoden': ('hogstmoden',),
'hogstmodent': ('hogstmoden',),
'hogstmodne': ('hogstmoden',),
'hogstmodnere': ('hogstmoden',),
'hogstmodnest': ('hogstmoden',),
'hogstmodneste': ('hogstmoden',),
'hoia': ('hoie',),
'hoiede': ('hoie',),
'hoiende': ('hoie',),
'hoiet': ('hoie',),
'hoiete': ('hoie',),
'hol': ('hol',),
'hole': ('hol',),
'holere': ('hol',),
'holest': ('hol',),
'holeste': ('hol',),
'holt': ('hol',),
'holdbar': ('holdbar',),
'holdbare': ('holdbar',),
'holdbarere': ('holdbar',),
'holdbarest': ('holdbar',),
'holdbareste': ('holdbar',),
'holdbart': ('holdbar',),
'holdende': ('holde',),
'holdt': ('holde',),
'holdte': ('holde',),
'holden': ('holden',),
'holdent': ('holden',),
'holdne': ('holden',),
'holdnere': ('holden',),
'holdnest': ('holden',),
'holdneste': ('holden',),
'holdningslaus': ('holdningslaus',),
'holdningslause': ('holdningslaus',),
'holdningslausere': ('holdningslaus',),
'holdningslausest': ('holdningslaus',),
'holdningslauseste': ('holdningslaus',),
'holdningslaust': ('holdningslaus',),
'holdningsløs': ('holdningsløs',),
'holdningsløse': ('holdningsløs',),
'holdningsløsere': ('holdningsløs',),
'holdningsløsest': ('holdningsløs',),
'holdningsløseste': ('holdningsløs',),
'holdningsløst': ('holdningsløs',),
'holdningsskapende': ('holdningsskapende',),
'holende': ('hole',),
'holt': ('hole',),
'holte': ('hole',),
'holet': ('holet',),
'holete': ('holet',),
'holetere': ('holet',),
'holetest': ('holet',),
'holeteste': ('holet',),
'holete': ('holete',),
'holka': ('holke',),
'holkede': ('holke',),
'holkende': ('holke',),
'holket': ('holke',),
'holkete': ('holke',),
'holkinna': ('holkinna',),
'holkinnede': ('holkinnet',),
'holkinnet': ('holkinnet',),
'holkinnete': ('holkinnet',),
'holkinnetere': ('holkinnet',),
'holkinnetest': ('holkinnet',),
'holkinneteste': ('holkinnet',),
'hollandsk': ('hollandsk',),
'hollandske': ('hollandsk',),
'hollandskere': ('hollandsk',),
'hollandskest': ('hollandsk',),
'hollandskeste': ('hollandsk',),
'holna': ('holne',),
'holnede': ('holne',),
'holnende': ('holne',),
'holnet': ('holne',),
'holnete': ('holne',),
'holograf': ('holograf',),
'holografe': ('holograf',),
'holografere': ('holograf',),
'holografest': ('holograf',),
'holografeste': ('holograf',),
'holograft': ('holograf',),
'holografisk': ('holografisk',),
'holografiske': ('holografisk',),
'holografiskere': ('holografisk',),
'holografiskest': ('holografisk',),
'holografiskeste': ('holografisk',),
'holsteinsk': ('holsteinsk',),
'holsteinske': ('holsteinsk',),
'holsteinskere': ('holsteinsk',),
'holsteinskest': ('holsteinsk',),
'holsteinskeste': ('holsteinsk',),
'holøyd': ('holøyd',),
'holøyde': ('holøyd',),
'holøydere': ('holøyd',),
'holøydest': ('holøyd',),
'holøydeste': ('holøyd',),
'homerisk': ('homerisk',),
'homeriske': ('homerisk',),
'homeriskere': ('homerisk',),
'homeriskest': ('homerisk',),
'homeriskeste': ('homerisk',),
'homiletisk': ('homiletisk',),
'homiletiske': ('homiletisk',),
'homiletiskere': ('homiletisk',),
'homiletiskest': ('homiletisk',),
'homiletiskeste': ('homiletisk',),
'homma': ('homme',),
'hommede': ('homme',),
'hommende': ('homme',),
'hommet': ('homme',),
'hommete': ('homme',),
'homo': ('homo',),
'homofil': ('homofil',),
'homofile': ('homofil',),
'homofilere': ('homofil',),
'homofilest': ('homofil',),
'homofileste': ('homofil',),
'homofilt': ('homofil',),
'homofon': ('homofon',),
'homofone': ('homofon',),
'homofonere': ('homofon',),
'homofonest': ('homofon',),
'homofoneste': ('homofon',),
'homofont': ('homofon',),
'homogen': ('homogen',),
'homogene': ('homogen',),
'homogenere': ('homogen',),
'homogenest': ('homogen',),
'homogeneste': ('homogen',),
'homogent': ('homogen',),
'homogeniserende': ('homogenisere',),
'homogenisert': ('homogenisere',),
'homogeniserte': ('homogenisere',),
'homonym': ('homonym',),
'homonyme': ('homonym',),
'homonymere': ('homonym',),
'homonymest': ('homonym',),
'homonymeste': ('homonym',),
'homonymt': ('homonym',),
'homoseksuell': ('homoseksuell',),
'homoseksuelle': ('homoseksuell',),
'homoseksuellere': ('homoseksuell',),
'homoseksuellest': ('homoseksuell',),
'homoseksuelleste': ('homoseksuell',),
'homoseksuelt': ('homoseksuell',),
'homøopatisk': ('homøopatisk',),
'homøopatiske': ('homøopatisk',),
'homøopatiskere': ('homøopatisk',),
'homøopatiskest': ('homøopatisk',),
'homøopatiskeste': ('homøopatisk',),
'honduransk': ('honduransk',),
'honduranske': ('honduransk',),
'honduranskere': ('honduransk',),
'honduranskest': ('honduransk',),
'honduranskeste': ('honduransk',),
'honnett': ('honnett',),
'honnette': ('honnett',),
'honnettere': ('honnett',),
'honnettest': ('honnett',),
'honnetteste': ('honnett',),
'honninggjømmende': ('honninggjømme',),
'honninggjømt': ('honninggjømme',),
'honninggjømte': ('honninggjømme',),
'honningsøt': ('honningsøt',),
'honningsøte': ('honningsøt',),
'honningsøtere': ('honningsøt',),
'honningsøtest': ('honningsøt',),
'honningsøteste': ('honningsøt',),
'honningsøtt': ('honningsøt',),
'honorabel': ('honorabel',),
'honorabelt': ('honorabel',),
'honorable': ('honorabel',),
'honorablere': ('honorabel',),
'honorablest': ('honorabel',),
'honorableste': ('honorabel',),
'honorerende': ('honorere',),
'honorert': ('honorere',),
'honorerte': ('honorere',),
'honorær': ('honorær',),
'honorære': ('honorær',),
'honorærere': ('honorær',),
'honorærest': ('honorær',),
'honoræreste': ('honorær',),
'honorært': ('honorær',),
'hopa': ('hope',),
'hopede': ('hope',),
'hopende': ('hope',),
'hopet': ('hope',),
'hopete': ('hope',),
'hopa': ('hope',),
'hopede': ('hope',),
'hopende': ('hope',),
'hopet': ('hope',),
'hopete': ('hope',),
'hoppa': ('hoppe',),
'hoppede': ('hoppe',),
'hoppende': ('hoppe',),
'hoppet': ('hoppe',),
'hoppete': ('hoppe',),
'hora': ('hore',),
'horede': ('hore',),
'horende': ('hore',),
'horet': ('hore',),
'horete': ('hore',),
'hort': ('hore',),
'horte': ('hore',),
'horisontal': ('horisontal',),
'horisontale': ('horisontal',),
'horisontalere': ('horisontal',),
'horisontalest': ('horisontal',),
'horisontaleste': ('horisontal',),
'horisontalt': ('horisontal',),
'horisontaldelt': ('horisontaldelt',),
'horisontaldelte': ('horisontaldelt',),
'horisontaldeltere': ('horisontaldelt',),
'horisontaldeltest': ('horisontaldelt',),
'horisontaldelteste': ('horisontaldelt',),
'hormonal': ('hormonal',),
'hormonale': ('hormonal',),
'hormonalere': ('hormonal',),
'hormonalest': ('hormonal',),
'hormonaleste': ('hormonal',),
'hormonalt': ('hormonal',),
'hormonell': ('hormonell',),
'hormonelle': ('hormonell',),
'hormonellere': ('hormonell',),
'hormonellest': ('hormonell',),
'hormonelleste': ('hormonell',),
'hormonelt': ('hormonell',),
'hornet': ('hornet',),
'hornete': ('hornet',),
'hornetere': ('hornet',),
'hornetest': ('hornet',),
'horneteste': ('hornet',),
'hornete': ('hornete',),
'horribel': ('horribel',),
'horribelt': ('horribel',),
'horrible': ('horribel',),
'horriblere': ('horribel',),
'horriblest': ('horribel',),
'horribleste': ('horribel',),
'horsa': ('horse',),
'horsede': ('horse',),
'horsende': ('horse',),
'horset': ('horse',),
'horsete': ('horse',),
'hosliggende': ('hosliggende',),
'hospitaliserende': ('hospitalisere',),
'hospitalisert': ('hospitalisere',),
'hospitaliserte': ('hospitalisere',),
'hospiterende': ('hospitere',),
'hospitert': ('hospitere',),
'hospiterte': ('hospitere',),
'hosstående': ('hosstående',),
'hosta': ('hoste',),
'hostede': ('hoste',),
'hostende': ('hoste',),
'hostet': ('hoste',),
'hostete': ('hoste',),
'hota': ('hote',),
'hotede': ('hote',),
'hotende': ('hote',),
'hotet': ('hote',),
'hotete': ('hote',),
'hottentottisk': ('hottentottisk',),
'hottentottiske': ('hottentottisk',),
'hottentottiskere': ('hottentottisk',),
'hottentottiskest': ('hottentottisk',),
'hottentottiskeste': ('hottentottisk',),
'hovedsakelig': ('hovedsakelig',),
'hovedsakelige': ('hovedsakelig',),
'hovedsakeligere': ('hovedsakelig',),
'hovedsakeligst': ('hovedsakelig',),
'hovedsakeligste': ('hovedsakelig',),
'hoven': ('hoven',),
'hovent': ('hoven',),
'hovne': ('hoven',),
'hovnere': ('hoven',),
'hovnest': ('hoven',),
'hovneste': ('hoven',),
'hoverende': ('hovere',),
'hovert': ('hovere',),
'hoverte': ('hovere',),
'hovmestererende': ('hovmesterere',),
'hovmesterert': ('hovmesterere',),
'hovmestererte': ('hovmesterere',),
'hovmoda': ('hovmode',),
'hovmodede': ('hovmode',),
'hovmodende': ('hovmode',),
'hovmodet': ('hovmode',),
'hovmodete': ('hovmode',),
'hovmodig': ('hovmodig',),
'hovmodige': ('hovmodig',),
'hovmodigere': ('hovmodig',),
'hovmodigst': ('hovmodig',),
'hovmodigste': ('hovmodig',),
'hovna': ('hovne',),
'hovnede': ('hovne',),
'hovnende': ('hovne',),
'hovnet': ('hovne',),
'hovnete': ('hovne',),
'hudfletta': ('hudflette',),
'hudflettede': ('hudflette',),
'hudflettende': ('hudflette',),
'hudflettet': ('hudflette',),
'hudflettete': ('hudflette',),
'hudlaus': ('hudlaus',),
'hudlause': ('hudlaus',),
'hudlausere': ('hudlaus',),
'hudlausest': ('hudlaus',),
'hudlauseste': ('hudlaus',),
'hudlaust': ('hudlaus',),
'hudløs': ('hudløs',),
'hudløse': ('hudløs',),
'hudløsere': ('hudløs',),
'hudløsest': ('hudløs',),
'hudløseste': ('hudløs',),
'hudløst': ('hudløs',),
'hudstrykende': ('hudstryke',),
'hudstrøken': ('hudstryke',),
'hudstrøket': ('hudstryke',),
'hudstrøkne': ('hudstryke',),
'huegæren': ('huegæren',),
'huegærent': ('huegæren',),
'huegærne': ('huegæren',),
'huegærnere': ('huegæren',),
'huegærnest': ('huegæren',),
'huegærneste': ('huegæren',),
'hufsa': ('hufse',),
'hufsede': ('hufse',),
'hufsende': ('hufse',),
'hufset': ('hufse',),
'hufsete': ('hufse',),
'huga': ('huga',),
'hugal': ('hugal',),
'hugale': ('hugal',),
'hugalere': ('hugal',),
'hugalest': ('hugal',),
'hugaleste': ('hugal',),
'hugalt': ('hugal',),
'huga': ('huge',),
'hugede': ('huge',),
'hugende': ('huge',),
'huget': ('huge',),
'hugete': ('huge',),
'hugheil': ('hugheil',),
'hugheile': ('hugheil',),
'hugheilere': ('hugheil',),
'hugheilest': ('hugheil',),
'hugheileste': ('hugheil',),
'hugheilt': ('hugheil',),
'hugnadsam': ('hugnadsam',),
'hugnadsame': ('hugnadsam',),
'hugnadsamere': ('hugnadsam',),
'hugnadsamest': ('hugnadsam',),
'hugnadsameste': ('hugnadsam',),
'hugnadsamt': ('hugnadsam',),
'hugsa': ('hugse',),
'hugsede': ('hugse',),
'hugsende': ('hugse',),
'hugset': ('hugse',),
'hugsete': ('hugse',),
'hugstmoden': ('hugstmoden',),
'hugstmodent': ('hugstmoden',),
'hugstmodne': ('hugstmoden',),
'hugstmodnere': ('hugstmoden',),
'hugstmodnest': ('hugstmoden',),
'hugstmodneste': ('hugstmoden',),
'hugsvala': ('hugsvale',),
'hugsvalede': ('hugsvale',),
'hugsvalende': ('hugsvale',),
'hugsvalet': ('hugsvale',),
'hugsvalete': ('hugsvale',),
'hugsvalt': ('hugsvale',),
'hugsvalte': ('hugsvale',),
'hugtakende': ('hugta',),
'hugtatt': ('hugta',),
'hugtatte': ('hugta',),
'hugæren': ('hugæren',),
'hugærent': ('hugæren',),
'hugærne': ('hugæren',),
'hugærnere': ('hugæren',),
'hugærnest': ('hugæren',),
'hugærneste': ('hugæren',),
'huia': ('huie',),
'huiede': ('huie',),
'huiende': ('huie',),
'huiet': ('huie',),
'huiete': ('huie',),
'huka': ('huke',),
'hukede': ('huke',),
'hukende': ('huke',),
'huket': ('huke',),
'hukete': ('huke',),
'hukt': ('huke',),
'hukte': ('huke',),
'huka': ('huke',),
'hukede': ('huke',),
'hukende': ('huke',),
'huket': ('huke',),
'hukete': ('huke',),
'hukt': ('huke',),
'hukte': ('huke',),
'hukra': ('hukre',),
'hukrede': ('hukre',),
'hukrende': ('hukre',),
'hukret': ('hukre',),
'hukrete': ('hukre',),
'huksittende': ('huksittende',),
'hul': ('hul',),
'hule': ('hul',),
'hulere': ('hul',),
'hulest': ('hul',),
'huleste': ('hul',),
'hult': ('hul',),
'hulbrysta': ('hulbrysta',),
'hulbrystede': ('hulbrystet',),
'hulbrystet': ('hulbrystet',),
'hulbrystete': ('hulbrystet',),
'hulbrystetere': ('hulbrystet',),
'hulbrystetest': ('hulbrystet',),
'hulbrysteteste': ('hulbrystet',),
'huldren': ('huldren',),
'huldrene': ('huldren',),
'huldrenere': ('huldren',),
'huldrenest': ('huldren',),
'huldreneste': ('huldren',),
'huldrent': ('huldren',),
'huldrne': ('huldren',),
'huldrnere': ('huldren',),
'huldrnest': ('huldren',),
'huldrneste': ('huldren',),
'hula': ('hule',),
'hulede': ('hule',),
'hulende': ('hule',),
'hulet': ('hule',),
'hulete': ('hule',),
'hult': ('hule',),
'hulte': ('hule',),
'hulka': ('hulke',),
'hulkede': ('hulke',),
'hulkende': ('hulke',),
'hulket': ('hulke',),
'hulkete': ('hulke',),
'hulkinna': ('hulkinna',),
'hulkinnede': ('hulkinnet',),
'hulkinnet': ('hulkinnet',),
'hulkinnete': ('hulkinnet',),
'hulkinnetere': ('hulkinnet',),
'hulkinnetest': ('hulkinnet',),
'hulkinneteste': ('hulkinnet',),
'hull': ('hull',),
'hulle': ('hull',),
'hullere': ('hull',),
'hullest': ('hull',),
'hulleste': ('hull',),
'hult': ('hull',),
'hulla': ('hulle',),
'hullede': ('hulle',),
'hullende': ('hulle',),
'hullet': ('hulle',),
'hullete': ('hulle',),
'hullet': ('hullet',),
'hullete': ('hullet',),
'hulletere': ('hullet',),
'hulletest': ('hullet',),
'hulleteste': ('hullet',),
'hullete': ('hullete',),
'huløyd': ('huløyd',),
'huløyde': ('huløyd',),
'huløydere': ('huløyd',),
'huløydest': ('huløyd',),
'huløydeste': ('huløyd',),
'human': ('human',),
'humane': ('human',),
'humanere': ('human',),
'humanest': ('human',),
'humaneste': ('human',),
'humant': ('human',),
'humanetisk': ('humanetisk',),
'humanetiske': ('humanetisk',),
'humanetiskere': ('humanetisk',),
'humanetiskest': ('humanetisk',),
'humanetiskeste': ('humanetisk',),
'humaniserende': ('humanisere',),
'humanisert': ('humanisere',),
'humaniserte': ('humanisere',),
'humanistisk': ('humanistisk',),
'humanistiske': ('humanistisk',),
'humanistiskere': ('humanistisk',),
'humanistiskest': ('humanistisk',),
'humanistiskeste': ('humanistisk',),
'humanitær': ('humanitær',),
'humanitære': ('humanitær',),
'humanitærere': ('humanitær',),
'humanitærest': ('humanitær',),
'humanitæreste': ('humanitær',),
'humanitært': ('humanitær',),
'humid': ('humid',),
'humide': ('humid',),
'humidere': ('humid',),
'humidest': ('humid',),
'humideste': ('humid',),
'humoral': ('humoral',),
'humorale': ('humoral',),
'humoralere': ('humoral',),
'humoralest': ('humoral',),
'humoraleste': ('humoral',),
'humoralt': ('humoral',),
'humoristisk': ('humoristisk',),
'humoristiske': ('humoristisk',),
'humoristiskere': ('humoristisk',),
'humoristiskest': ('humoristisk',),
'humoristiskeste': ('humoristisk',),
'humpa': ('humpe',),
'humpede': ('humpe',),
'humpende': ('humpe',),
'humpet': ('humpe',),
'humpete': ('humpe',),
'humpet': ('humpet',),
'humpete': ('humpet',),
'humpetere': ('humpet',),
'humpetest': ('humpet',),
'humpeteste': ('humpet',),
'humpete': ('humpete',),
'humra': ('humre',),
'humrede': ('humre',),
'humrende': ('humre',),
'humret': ('humre',),
'humrete': ('humre',),
'humørfylt': ('humørfylt',),
'humørfylte': ('humørfylt',),
'humørfyltere': ('humørfylt',),
'humørfyltest': ('humørfylt',),
'humørfylteste': ('humørfylt',),
'humørsjuk': ('humørsjuk',),
'humørsjuke': ('humørsjuk',),
'humørsjukere': ('humørsjuk',),
'humørsjukest': ('humørsjuk',),
'humørsjukeste': ('humørsjuk',),
'humørsjukt': ('humørsjuk',),
'humørsyk': ('humørsyk',),
'humørsyke': ('humørsyk',),
'humørsykere': ('humørsyk',),
'humørsykest': ('humørsyk',),
'humørsykeste': ('humørsyk',),
'humørsykt': ('humørsyk',),
'hundekald': ('hundekald',),
'hundekalde': ('hundekald',),
'hundekaldere': ('hundekald',),
'hundekaldest': ('hundekald',),
'hundekaldeste': ('hundekald',),
'hundekaldt': ('hundekald',),
'hundeldre': ('hundgammal',),
'hundeldst': ('hundgammal',),
'hundeldste': ('hundgammal',),
'hundgamle': ('hundgammal',),
'hundgammal': ('hundgammal',),
'hundgammalt': ('hundgammal',),
'hundeldre': ('hundgammel',),
'hundeldst': ('hundgammel',),
'hundeldste': ('hundgammel',),
'hundgamle': ('hundgammel',),
'hundgammel': ('hundgammel',),
'hundgammelt': ('hundgammel',),
'hundjaga': ('hundjage',),
'hundjagd': ('hundjage',),
'hundjagde': ('hundjage',),
'hundjagede': ('hundjage',),
'hundjagende': ('hundjage',),
'hundjaget': ('hundjage',),
'hundjagete': ('hundjage',),
'hundrede': ('hundrede',),
'hundretalls': ('hundretalls',),
'hundretals': ('hundretals',),
'hundreårig': ('hundreårig',),
'hundreårige': ('hundreårig',),
'hundreårigere': ('hundreårig',),
'hundreårigst': ('hundreårig',),
'hundreårigste': ('hundreårig',),
'hundreårs': ('hundreårs',),
'hundsa': ('hundse',),
'hundsede': ('hundse',),
'hundsende': ('hundse',),
'hundset': ('hundse',),
'hundsete': ('hundse',),
'hundsk': ('hundsk',),
'hundske': ('hundsk',),
'hundskere': ('hundsk',),
'hundskest': ('hundsk',),
'hundskeste': ('hundsk',),
'hungerramma': ('hungerramma',),
'hungerrammede': ('hungerrammet',),
'hungerrammet': ('hungerrammet',),
'hungerrammete': ('hungerrammet',),
'hungerrammetere': ('hungerrammet',),
'hungerrammetest': ('hungerrammet',),
'hungerrammeteste': ('hungerrammet',),
'hungra': ('hungre',),
'hungrede': ('hungre',),
'hungrende': ('hungre',),
'hungret': ('hungre',),
'hungrete': ('hungre',),
'hungrig': ('hungrig',),
'hungrige': ('hungrig',),
'hungrigere': ('hungrig',),
'hungrigst': ('hungrig',),
'hungrigste': ('hungrig',),
'hunisk': ('hunisk',),
'huniske': ('hunisk',),
'huniskere': ('hunisk',),
'huniskest': ('hunisk',),
'huniskeste': ('hunisk',),
'hunlig': ('hunlig',),
'hunlige': ('hunlig',),
'hunligere': ('hunlig',),
'hunligst': ('hunlig',),
'hunligste': ('hunlig',),
'hunnlig': ('hunnlig',),
'hunnlige': ('hunnlig',),
'hunnligere': ('hunnlig',),
'hunnligst': ('hunnlig',),
'hunnligste': ('hunnlig',),
'hurpa': ('hurpe',),
'hurpede': ('hurpe',),
'hurpende': ('hurpe',),
'hurpet': ('hurpe',),
'hurpete': ('hurpe',),
'hurpet': ('hurpet',),
'hurpete': ('hurpet',),
'hurpetere': ('hurpet',),
'hurpetest': ('hurpet',),
'hurpeteste': ('hurpet',),
'hurpete': ('hurpete',),
'hurra': ('hurre',),
'hurrede': ('hurre',),
'hurrende': ('hurre',),
'hurret': ('hurre',),
'hurrete': ('hurre',),
'hurtig': ('hurtig',),
'hurtige': ('hurtig',),
'hurtigere': ('hurtig',),
'hurtigst': ('hurtig',),
'hurtigste': ('hurtig',),
'hurtigarbeidende': ('hurtigarbeidende',),
'hurtiggående': ('hurtiggående',),
'husbankfinansierende': ('husbankfinansiere',),
'husbankfinansiert': ('husbankfinansiere',),
'husbankfinansierte': ('husbankfinansiere',),
'husa': ('huse',),
'husede': ('huse',),
'husende': ('huse',),
'huset': ('huse',),
'husete': ('huse',),
'hust': ('huse',),
'huste': ('huse',),
'huserende': ('husere',),
'husert': ('husere',),
'huserte': ('husere',),
'husholdende': ('husholde',),
'husholdt': ('husholde',),
'husholdte': ('husholde',),
'husholderende': ('husholdere',),
'husholdert': ('husholdere',),
'husholderte': ('husholdere',),
'husholdererende': ('husholderere',),
'husholderert': ('husholderere',),
'husholdererte': ('husholderere',),
'husittisk': ('husittisk',),
'husittiske': ('husittisk',),
'husittiskere': ('husittisk',),
'husittiskest': ('husittisk',),
'husittiskeste': ('husittisk',),
'huskald': ('huskald',),
'huskalde': ('huskald',),
'huskaldere': ('huskald',),
'huskaldest': ('huskald',),
'huskaldeste': ('huskald',),
'huskaldt': ('huskald',),
'huska': ('huske',),
'huskede': ('huske',),
'huskende': ('huske',),
'husket': ('huske',),
'huskete': ('huske',),
'huska': ('huske',),
'huskede': ('huske',),
'huskende': ('huske',),
'husket': ('huske',),
'huskete': ('huske',),
'huslaus': ('huslaus',),
'huslause': ('huslaus',),
'huslausere': ('huslaus',),
'huslausest': ('huslaus',),
'huslauseste': ('huslaus',),
'huslaust': ('huslaus',),
'huslaus': ('huslaus',),
'huslause': ('huslaus',),
'huslausere': ('huslaus',),
'huslausest': ('huslaus',),
'huslauseste': ('huslaus',),
'huslaust': ('huslaus',),
'huslig': ('huslig',),
'huslige': ('huslig',),
'husligere': ('huslig',),
'husligst': ('huslig',),
'husligste': ('huslig',),
'husløs': ('husløs',),
'husløse': ('husløs',),
'husløsere': ('husløs',),
'husløsest': ('husløs',),
'husløseste': ('husløs',),
'husløst': ('husløs',),
'hussøkende': ('hussøkende',),
'hustra': ('hustre',),
'hustrede': ('hustre',),
'hustrende': ('hustre',),
'hustret': ('hustre',),
'hustrete': ('hustre',),
'hustren': ('hustren',),
'hustrene': ('hustren',),
'hustrenere': ('hustren',),
'hustrenest': ('hustren',),
'hustreneste': ('hustren',),
'hustrent': ('hustren',),
'hustrne': ('hustren',),
'hustrnere': ('hustren',),
'hustrnest': ('hustren',),
'hustrneste': ('hustren',),
'hustrig': ('hustrig',),
'hustrige': ('hustrig',),
'hustrigere': ('hustrig',),
'hustrigst': ('hustrig',),
'hustrigste': ('hustrig',),
'husvalende': ('husvale',),
'husvalt': ('husvale',),
'husvalte': ('husvale',),
'husvarm': ('husvarm',),
'husvarme': ('husvarm',),
'husvarmere': ('husvarm',),
'husvarmest': ('husvarm',),
'husvarmeste': ('husvarm',),
'husvarmt': ('husvarm',),
'husvill': ('husvill',),
'husville': ('husvill',),
'husvillere': ('husvill',),
'husvillest': ('husvill',),
'husvilleste': ('husvill',),
'husvilt': ('husvill',),
'huta': ('hute',),
'hutede': ('hute',),
'hutende': ('hute',),
'hutet': ('hute',),
'hutete': ('hute',),
'hutra': ('hutre',),
'hutrede': ('hutre',),
'hutrende': ('hutre',),
'hutret': ('hutre',),
'hutrete': ('hutre',),
'hvass': ('hvass',),
'hvasse': ('hvass',),
'hvassere': ('hvass',),
'hvassest': ('hvass',),
'hvasseste': ('hvass',),
'hvast': ('hvass',),
'hvassøyd': ('hvassøyd',),
'hvassøyde': ('hvassøyd',),
'hvassøydere': ('hvassøyd',),
'hvassøydest': ('hvassøyd',),
'hvassøydeste': ('hvassøyd',),
'hvelva': ('hvelve',),
'hvelvede': ('hvelve',),
'hvelvende': ('hvelve',),
'hvelvet': ('hvelve',),
'hvelvete': ('hvelve',),
'hverdagslig': ('hverdagslig',),
'hverdagslige': ('hverdagslig',),
'hverdagsligere': ('hverdagslig',),
'hverdagsligst': ('hverdagslig',),
'hverdagsligste': ('hverdagslig',),
'hvesende': ('hvese',),
'hvest': ('hvese',),
'hveste': ('hvese',),
'hvessa': ('hvesse',),
'hvessede': ('hvesse',),
'hvessende': ('hvesse',),
'hvesset': ('hvesse',),
'hvessete': ('hvesse',),
'hvest': ('hvesse',),
'hveste': ('hvesse',),
'hvilende': ('hvile',),
'hvilt': ('hvile',),
'hvilte': ('hvile',),
'hvilelaus': ('hvilelaus',),
'hvilelause': ('hvilelaus',),
'hvilelausere': ('hvilelaus',),
'hvilelausest': ('hvilelaus',),
'hvilelauseste': ('hvilelaus',),
'hvilelaust': ('hvilelaus',),
'hvileløs': ('hvileløs',),
'hvileløse': ('hvileløs',),
'hvileløsere': ('hvileløs',),
'hvileløsest': ('hvileløs',),
'hvileløseste': ('hvileløs',),
'hvileløst': ('hvileløs',),
'hvinende': ('hvine',),
'hvint': ('hvine',),
'hvinte': ('hvine',),
'hviska': ('hviske',),
'hviskede': ('hviske',),
'hviskende': ('hviske',),
'hvisket': ('hviske',),
'hviskete': ('hviske',),
'hviska': ('hviske',),
'hviskede': ('hviske',),
'hviskende': ('hviske',),
'hvisket': ('hviske',),
'hviskete': ('hviske',),
'hvit': ('hvit',),
'hvite': ('hvit',),
'hvitere': ('hvit',),
'hvitest': ('hvit',),
'hviteste': ('hvit',),
'hvitt': ('hvit',),
'hvitbleik': ('hvitbleik',),
'hvitbleike': ('hvitbleik',),
'hvitbleikere': ('hvitbleik',),
'hvitbleikest': ('hvitbleik',),
'hvitbleikeste': ('hvitbleik',),
'hvitbleikt': ('hvitbleik',),
'hvitblek': ('hvitblek',),
'hvitbleke': ('hvitblek',),
'hvitblekere': ('hvitblek',),
'hvitblekest': ('hvitblek',),
'hvitblekeste': ('hvitblek',),
'hvitblekt': ('hvitblek',),
'hviterussisk': ('hviterussisk',),
'hviterussiske': ('hviterussisk',),
'hviterussiskere': ('hviterussisk',),
'hviterussiskest': ('hviterussisk',),
'hviterussiskeste': ('hviterussisk',),
'hvitglødende': ('hvitglødende',),
'hvithåra': ('hvithåra',),
'hvithårede': ('hvithåret',),
'hvithåret': ('hvithåret',),
'hvithårete': ('hvithåret',),
'hvithåretere': ('hvithåret',),
'hvithåretest': ('hvithåret',),
'hvithåreteste': ('hvithåret',),
'hvitkalka': ('hvitkalke',),
'hvitkalkede': ('hvitkalke',),
'hvitkalkende': ('hvitkalke',),
'hvitkalket': ('hvitkalke',),
'hvitkalkete': ('hvitkalke',),
'hvitkledd': ('hvitkledd',),
'hvitkledde': ('hvitkledd',),
'hvitkleddere': ('hvitkledd',),
'hvitkleddest': ('hvitkledd',),
'hvitkleddeste': ('hvitkledd',),
'hvitlett': ('hvitlett',),
'hvitlette': ('hvitlett',),
'hvitlettere': ('hvitlett',),
'hvitlettest': ('hvitlett',),
'hvitletteste': ('hvitlett',),
'hvitna': ('hvitne',),
'hvitnede': ('hvitne',),
'hvitnende': ('hvitne',),
'hvitnet': ('hvitne',),
'hvitnete': ('hvitne',),
'hvitta': ('hvitte',),
'hvittede': ('hvitte',),
'hvittende': ('hvitte',),
'hvittet': ('hvitte',),
'hvittete': ('hvitte',),
'hvitvaska': ('hvitvaske',),
'hvitvaskede': ('hvitvaske',),
'hvitvaskende': ('hvitvaske',),
'hvitvasket': ('hvitvaske',),
'hvitvaskete': ('hvitvaske',),
'hybrid': ('hybrid',),
'hybride': ('hybrid',),
'hybridere': ('hybrid',),
'hybridest': ('hybrid',),
'hybrideste': ('hybrid',),
'hydraulisk': ('hydraulisk',),
'hydrauliske': ('hydraulisk',),
'hydrauliskere': ('hydraulisk',),
'hydrauliskest': ('hydraulisk',),
'hydrauliskeste': ('hydraulisk',),
'hydroelektrisk': ('hydroelektrisk',),
'hydroelektriske': ('hydroelektrisk',),
'hydroelektriskere': ('hydroelektrisk',),
'hydroelektriskest': ('hydroelektrisk',),
'hydroelektriskeste': ('hydroelektrisk',),
'hydrofil': ('hydrofil',),
'hydrofile': ('hydrofil',),
'hydrofilere': ('hydrofil',),
'hydrofilest': ('hydrofil',),
'hydrofileste': ('hydrofil',),
'hydrofilt': ('hydrofil',),
'hydrofob': ('hydrofob',),
'hydrofobe': ('hydrofob',),
'hydrofobere': ('hydrofob',),
'hydrofobest': ('hydrofob',),
'hydrofobeste': ('hydrofob',),
'hydrofobt': ('hydrofob',),
'hydroteknisk': ('hydroteknisk',),
'hydrotekniske': ('hydroteknisk',),
'hydrotekniskere': ('hydroteknisk',),
'hydrotekniskest': ('hydroteknisk',),
'hydrotekniskeste': ('hydroteknisk',),
'hyet': ('hyet',),
'hyete': ('hyet',),
'hyetere': ('hyet',),
'hyetest': ('hyet',),
'hyeteste': ('hyet',),
'hyete': ('hyete',),
'hygd': ('hygge',),
'hygde': ('hygge',),
'hygga': ('hygge',),
'hyggede': ('hygge',),
'hyggende': ('hygge',),
'hygget': ('hygge',),
'hyggete': ('hygge',),
'hyggelig': ('hyggelig',),
'hyggelige': ('hyggelig',),
'hyggeligere': ('hyggelig',),
'hyggeligst': ('hyggelig',),
'hyggeligste': ('hyggelig',),
'hygienisk': ('hygienisk',),
'hygieniske': ('hygienisk',),
'hygieniskere': ('hygienisk',),
'hygieniskest': ('hygienisk',),
'hygieniskeste': ('hygienisk',),
'hygroskopisk': ('hygroskopisk',),
'hygroskopiske': ('hygroskopisk',),
'hygroskopiskere': ('hygroskopisk',),
'hygroskopiskest': ('hygroskopisk',),
'hygroskopiskeste': ('hygroskopisk',),
'hykkelsk': ('hykkelsk',),
'hykkelske': ('hykkelsk',),
'hykkelskere': ('hykkelsk',),
'hykkelskest': ('hykkelsk',),
'hykkelskeste': ('hykkelsk',),
'hykla': ('hykle',),
'hyklede': ('hykle',),
'hyklende': ('hykle',),
'hyklet': ('hykle',),
'hyklete': ('hykle',),
'hyklersk': ('hyklersk',),
'hyklerske': ('hyklersk',),
'hyklerskere': ('hyklersk',),
'hyklerskest': ('hyklersk',),
'hyklerskeste': ('hyklersk',),
'hylende': ('hyle',),
'hylt': ('hyle',),
'hylte': ('hyle',),
'hylla': ('hylle',),
'hyllede': ('hylle',),
'hyllende': ('hylle',),
'hyllet': ('hylle',),
'hyllete': ('hylle',),
'hylla': ('hylle',),
'hyllede': ('hylle',),
'hyllende': ('hylle',),
'hyllet': ('hylle',),
'hyllete': ('hylle',),
'hyperaktiv': ('hyperaktiv',),
'hyperaktive': ('hyperaktiv',),
'hyperaktivere': ('hyperaktiv',),
'hyperaktivest': ('hyperaktiv',),
'hyperaktiveste': ('hyperaktiv',),
'hyperaktivt': ('hyperaktiv',),
'hyperaktuell': ('hyperaktuell',),
'hyperaktuelle': ('hyperaktuell',),
'hyperaktuellere': ('hyperaktuell',),
'hyperaktuellest': ('hyperaktuell',),
'hyperaktuelleste': ('hyperaktuell',),
'hyperaktuelt': ('hyperaktuell',),
'hyperbolsk': ('hyperbolsk',),
'hyperbolske': ('hyperbolsk',),
'hyperbolskere': ('hyperbolsk',),
'hyperbolskest': ('hyperbolsk',),
'hyperbolskeste': ('hyperbolsk',),
'hyperelegant': ('hyperelegant',),
'hyperelegante': ('hyperelegant',),
'hyperelegantere': ('hyperelegant',),
'hyperelegantest': ('hyperelegant',),
'hypereleganteste': ('hyperelegant',),
'hyperkorrekt': ('hyperkorrekt',),
'hyperkorrekte': ('hyperkorrekt',),
'hyperkorrektere': ('hyperkorrekt',),
'hyperkorrektest': ('hyperkorrekt',),
'hyperkorrekteste': ('hyperkorrekt',),
'hypermoderne': ('hypermoderne',),
'hypersonisk': ('hypersonisk',),
'hypersoniske': ('hypersonisk',),
'hypersoniskere': ('hypersonisk',),
'hypersoniskest': ('hypersonisk',),
'hypersoniskeste': ('hypersonisk',),
'hypnotiserende': ('hypnotisere',),
'hypnotisert': ('hypnotisere',),
'hypnotiserte': ('hypnotisere',),
'hypnotisk': ('hypnotisk',),
'hypnotiske': ('hypnotisk',),
'hypnotiskere': ('hypnotisk',),
'hypnotiskest': ('hypnotisk',),
'hypnotiskeste': ('hypnotisk',),
'hypokonder': ('hypokonder',),
'hypokondert': ('hypokonder',),
'hypokondre': ('hypokonder',),
'hypokondrere': ('hypokonder',),
'hypokondrest': ('hypokonder',),
'hypokondreste': ('hypokonder',),
'hypokondrisk': ('hypokondrisk',),
'hypokondriske': ('hypokondrisk',),
'hypokondriskere': ('hypokondrisk',),
'hypokondriskest': ('hypokondrisk',),
'hypokondriskeste': ('hypokondrisk',),
'hypotaktisk': ('hypotaktisk',),
'hypotaktiske': ('hypotaktisk',),
'hypotaktiskere': ('hypotaktisk',),
'hypotaktiskest': ('hypotaktisk',),
'hypotaktiskeste': ('hypotaktisk',),
'hypotetisk': ('hypotetisk',),
'hypotetiske': ('hypotetisk',),
'hypotetiskere': ('hypotetisk',),
'hypotetiskest': ('hypotetisk',),
'hypotetiskeste': ('hypotetisk',),
'hypp': ('hypp',),
'hyppe': ('hypp',),
'hyppere': ('hypp',),
'hyppest': ('hypp',),
'hyppeste': ('hypp',),
'hypt': ('hypp',),
'hyppa': ('hyppe',),
'hyppede': ('hyppe',),
'hyppende': ('hyppe',),
'hyppet': ('hyppe',),
'hyppete': ('hyppe',),
'hyppig': ('hyppig',),
'hyppige': ('hyppig',),
'hyppigere': ('hyppig',),
'hyppigst': ('hyppig',),
'hyppigste': ('hyppig',),
'hyra': ('hyre',),
'hyrede': ('hyre',),
'hyrende': ('hyre',),
'hyret': ('hyre',),
'hyrete': ('hyre',),
'hyrt': ('hyre',),
'hyrte': ('hyre',),
'hyra': ('hyre',),
'hyrede': ('hyre',),
'hyrende': ('hyre',),
'hyret': ('hyre',),
'hyrete': ('hyre',),
'hyrt': ('hyre',),
'hyrte': ('hyre',),
'hysja': ('hysje',),
'hysjede': ('hysje',),
'hysjende': ('hysje',),
'hysjet': ('hysje',),
'hysjete': ('hysje',),
'hyssa': ('hysse',),
'hyssede': ('hysse',),
'hyssende': ('hysse',),
'hysset': ('hysse',),
'hyssete': ('hysse',),
'hysterisk': ('hysterisk',),
'hysteriske': ('hysterisk',),
'hysteriskere': ('hysterisk',),
'hysteriskest': ('hysterisk',),
'hysteriskeste': ('hysterisk',),
'hytta': ('hytte',),
'hyttede': ('hytte',),
'hyttende': ('hytte',),
'hyttet': ('hytte',),
'hyttete': ('hytte',),
'hytta': ('hytte',),
'hyttede': ('hytte',),
'hyttende': ('hytte',),
'hyttet': ('hytte',),
'hyttete': ('hytte',),
'hål': ('hål',),
'håle': ('hål',),
'hålere': ('hål',),
'hålest': ('hål',),
'håleste': ('hål',),
'hålt': ('hål',),
'hålket': ('hålket',),
'hålkete': ('hålket',),
'hålketere': ('hålket',),
'hålketest': ('hålket',),
'hålketeste': ('hålket',),
'hålkete': ('hålkete',),
'hånddrevet': ('hånddrevet',),
'hånddrevne': ('hånddrevet',),
'hånddrevnere': ('hånddrevet',),
'hånddrevnest': ('hånddrevet',),
'hånddrevneste': ('hånddrevet',),
'håndfallen': ('håndfallen',),
'håndfallent': ('håndfallen',),
'håndfalne': ('håndfallen',),
'håndfalnere': ('håndfallen',),
'håndfalnest': ('håndfallen',),
'håndfalneste': ('håndfallen',),
'håndfast': ('håndfast',),
'håndfaste': ('håndfast',),
'håndfastere': ('håndfast',),
'håndfastest': ('håndfast',),
'håndfasteste': ('håndfast',),
'håndgangen': ('håndgangen',),
'håndgangent': ('håndgangen',),
'håndgangne': ('håndgangen',),
'håndgangnere': ('håndgangen',),
'håndgangnest': ('håndgangen',),
'håndgangneste': ('håndgangen',),
'håndgiende': ('håndgi',),
'håndgitt': ('håndgi',),
'håndgitte': ('håndgi',),
'håndgivende': ('håndgi',),
'håndgripelig': ('håndgripelig',),
'håndgripelige': ('håndgripelig',),
'håndgripeligere': ('håndgripelig',),
'håndgripeligst': ('håndgripelig',),
'håndgripeligste': ('håndgripelig',),
'håndheva': ('håndheve',),
'håndhevd': ('håndheve',),
'håndhevde': ('håndheve',),
'håndhevede': ('håndheve',),
'håndhevende': ('håndheve',),
'håndhevet': ('håndheve',),
'håndhevete': ('håndheve',),
'håndhilsende': ('håndhilse',),
'håndhilst': ('håndhilse',),
'håndhilste': ('håndhilse',),
'håndhilsende': ('håndhilse',),
'håndhilst': ('håndhilse',),
'håndhilste': ('håndhilse',),
'håndlaga': ('håndlaga',),
'håndlagd': ('håndlagd',),
'håndlagde': ('håndlagd',),
'håndlagdere': ('håndlagd',),
'håndlagdest': ('håndlagd',),
'håndlagdeste': ('håndlagd',),
'håndlagede': ('håndlaget',),
'håndlaget': ('håndlaget',),
'håndlagete': ('håndlaget',),
'håndlagetere': ('håndlaget',),
'håndlagetest': ('håndlaget',),
'håndlageteste': ('håndlaget',),
'håndnerva': ('håndnerva',),
'håndnervede': ('håndnervet',),
'håndnervet': ('håndnervet',),
'håndnervete': ('håndnervet',),
'håndnervetere': ('håndnervet',),
'håndnervetest': ('håndnervet',),
'håndnerveteste': ('håndnervet',),
'håndplukka': ('håndplukke',),
'håndplukkede': ('håndplukke',),
'håndplukkende': ('håndplukke',),
'håndplukket': ('håndplukke',),
'håndplukkete': ('håndplukke',),
'håndskreven': ('håndskreven',),
'håndskrevet': ('håndskreven',),
'håndskrevne': ('håndskreven',),
'håndskrevnere': ('håndskreven',),
'håndskrevnest': ('håndskreven',),
'håndskrevneste': ('håndskreven',),
'håndskrevet': ('håndskrevet',),
'håndskrevne': ('håndskrevet',),
'håndskrevnere': ('håndskrevet',),
'håndskrevnest': ('håndskrevet',),
'håndskrevneste': ('håndskrevet',),
'håndskåren': ('håndskåren',),
'håndskåret': ('håndskåren',),
'håndskårne': ('håndskåren',),
'håndskårnere': ('håndskåren',),
'håndskårnest': ('håndskåren',),
'håndskårneste': ('håndskåren',),
'håndskåret': ('håndskåret',),
'håndskårne': ('håndskåret',),
'håndskårnere': ('håndskåret',),
'håndskårnest': ('håndskåret',),
'håndskårneste': ('håndskåret',),
'håndstående': ('håndstående',),
'håndterende': ('håndtere',),
'håndtert': ('håndtere',),
'håndterte': ('håndtere',),
'håndterlig': ('håndterlig',),
'håndterlige': ('håndterlig',),
'håndterligere': ('håndterlig',),
'håndterligst': ('håndterlig',),
'håndterligste': ('håndterlig',),
'håndvarm': ('håndvarm',),
'håndvarme': ('håndvarm',),
'håndvarmere': ('håndvarm',),
'håndvarmest': ('håndvarm',),
'håndvarmeste': ('håndvarm',),
'håndvarmt': ('håndvarm',),
'håndverksmessig': ('håndverksmessig',),
'håndverksmessige': ('håndverksmessig',),
'håndverksmessigere': ('håndverksmessig',),
'håndverksmessigst': ('håndverksmessig',),
'håndverksmessigste': ('håndverksmessig',),
'håna': ('håne',),
'hånede': ('håne',),
'hånende': ('håne',),
'hånet': ('håne',),
'hånete': ('håne',),
'hånt': ('håne',),
'hånte': ('håne',),
'hånflirende': ('hånflire',),
'hånflirt': ('hånflire',),
'hånflirte': ('hånflire',),
'hånledd': ('hånle',),
'hånledde': ('hånle',),
'hånleende': ('hånle',),
'hånlig': ('hånlig',),
'hånlige': ('hånlig',),
'hånligere': ('hånlig',),
'hånligst': ('hånlig',),
'hånligste': ('hånlig',),
'hånsk': ('hånsk',),
'hånske': ('hånsk',),
'hånskere': ('hånsk',),
'hånskest': ('hånsk',),
'hånskeste': ('hånsk',),
'håpa': ('håpe',),
'håpede': ('håpe',),
'håpende': ('håpe',),
'håpet': ('håpe',),
'håpete': ('håpe',),
'håpt': ('håpe',),
'håpte': ('håpe',),
'håpefull': ('håpefull',),
'håpefulle': ('håpefull',),
'håpefullere': ('håpefull',),
'håpefullest': ('håpefull',),
'håpefulleste': ('håpefull',),
'håpefullt': ('håpefull',),
'håplaus': ('håplaus',),
'håplause': ('håplaus',),
'håplausere': ('håplaus',),
'håplausest': ('håplaus',),
'håplauseste': ('håplaus',),
'håplaust': ('håplaus',),
'håpløs': ('håpløs',),
'håpløse': ('håpløs',),
'håpløsere': ('håpløs',),
'håpløsest': ('håpløs',),
'håpløseste': ('håpløs',),
'håpløst': ('håpløs',),
'håret': ('håret',),
'hårete': ('håret',),
'håretere': ('håret',),
'håretest': ('håret',),
'håreteste': ('håret',),
'hårete': ('hårete',),
'hårfager': ('hårfager',),
'hårfagert': ('hårfager',),
'hårfagre': ('hårfager',),
'hårfagrere': ('hårfager',),
'hårfagrest': ('hårfager',),
'hårfagreste': ('hårfager',),
'hårfin': ('hårfin',),
'hårfine': ('hårfin',),
'hårfinere': ('hårfin',),
'hårfinest': ('hårfin',),
'hårfineste': ('hårfin',),
'hårfint': ('hårfin',),
'hårreisende': ('hårreisende',),
'hårsår': ('hårsår',),
'hårsåre': ('hårsår',),
'hårsårere': ('hårsår',),
'hårsårest': ('hårsår',),
'hårsåreste': ('hårsår',),
'hårsårt': ('hårsår',),
'hås': ('hås',),
'håse': ('hås',),
'håsere': ('hås',),
'håsest': ('hås',),
'håseste': ('hås',),
'håst': ('hås',),
'håva': ('håve',),
'håvede': ('håve',),
'håvende': ('håve',),
'håvet': ('håve',),
'håvete': ('håve',),
'hæla': ('hæle',),
'hælede': ('hæle',),
'hælende': ('hæle',),
'hælet': ('hæle',),
'hælete': ('hæle',),
'hælt': ('hæle',),
'hælte': ('hæle',),
'hælsparka': ('hælsparke',),
'hælsparkede': ('hælsparke',),
'hælsparkende': ('hælsparke',),
'hælsparket': ('hælsparke',),
'hælsparkete': ('hælsparke',),
'hærkledd': ('hærkledd',),
'hærkledde': ('hærkledd',),
'hærkleddere': ('hærkledd',),
'hærkleddest': ('hærkledd',),
'hærkleddeste': ('hærkledd',),
'hærtakende': ('hærta',),
'hærtatt': ('hærta',),
'hærtatte': ('hærta',),
'høflig': ('høflig',),
'høflige': ('høflig',),
'høfligere': ('høflig',),
'høfligst': ('høflig',),
'høfligste': ('høflig',),
'høg': ('høg',),
'høge': ('høg',),
'høgere': ('høg',),
'høgest': ('høg',),
'høgeste': ('høg',),
'høgre': ('høg',),
'høgst': ('høg',),
'høgste': ('høg',),
'høgt': ('høg',),
'høgborgerlig': ('høgborgerlig',),
'høgborgerlige': ('høgborgerlig',),
'høgborgerligere': ('høgborgerlig',),
'høgborgerligst': ('høgborgerlig',),
'høgborgerligste': ('høgborgerlig',),
'høgereliggende': ('høgereliggende',),
'høgerestående': ('høgerestående',),
'høgfrekvent': ('høgfrekvent',),
'høgfrekvente': ('høgfrekvent',),
'høgfrekventere': ('høgfrekvent',),
'høgfrekventest': ('høgfrekvent',),
'høgfrekventeste': ('høgfrekvent',),
'høggravid': ('høggravid',),
'høggravide': ('høggravid',),
'høggravidere': ('høggravid',),
'høggravidest': ('høggravid',),
'høggravideste': ('høggravid',),
'høghalsede': ('høghalset',),
'høghalset': ('høghalset',),
'høghalsete': ('høghalset',),
'høghalsetere': ('høghalset',),
'høghalsetest': ('høghalset',),
'høghalseteste': ('høghalset',),
'høghælt': ('høghælt',),
'høghælte': ('høghælt',),
'høghæltere': ('høghælt',),
'høghæltest': ('høghælt',),
'høghælteste': ('høghælt',),
'høgkirkelig': ('høgkirkelig',),
'høgkirkelige': ('høgkirkelig',),
'høgkirkeligere': ('høgkirkelig',),
'høgkirkeligst': ('høgkirkelig',),
'høgkirkeligste': ('høgkirkelig',),
'høglofta': ('høglofta',),
'høgloftede': ('høgloftet',),
'høgloftet': ('høgloftet',),
'høgloftete': ('høgloftet',),
'høgloftetere': ('høgloftet',),
'høgloftetest': ('høgloftet',),
'høglofteteste': ('høgloftet',),
'høglys': ('høglys',),
'høglyse': ('høglys',),
'høglysere': ('høglys',),
'høglysest': ('høglys',),
'høglyseste': ('høglys',),
'høglyst': ('høglys',),
'høglytt': ('høglytt',),
'høglytte': ('høglytt',),
'høglyttere': ('høglytt',),
'høglyttest': ('høglytt',),
'høglytteste': ('høglytt',),
'høgmælt': ('høgmælt',),
'høgmælte': ('høgmælt',),
'høgmæltere': ('høgmælt',),
'høgmæltest': ('høgmælt',),
'høgmælteste': ('høgmælt',),
'høgre': ('høgre',),
'høgrehendt': ('høgrehendt',),
'høgrehendte': ('høgrehendt',),
'høgrehendtere': ('høgrehendt',),
'høgrehendtest': ('høgrehendt',),
'høgrehendteste': ('høgrehendt',),
'høgrehengsla': ('høgrehengsla',),
'høgrehengslede': ('høgrehengslet',),
'høgrehengslet': ('høgrehengslet',),
'høgrehengslete': ('høgrehengslet',),
'høgrehengsletere': ('høgrehengslet',),
'høgrehengsletest': ('høgrehengslet',),
'høgrehengsleteste': ('høgrehengslet',),
'høgreliggende': ('høgreliggende',),
'høgreorientert': ('høgreorientert',),
'høgreorienterte': ('høgreorientert',),
'høgreorientertere': ('høgreorientert',),
'høgreorientertest': ('høgreorientert',),
'høgreorienterteste': ('høgreorientert',),
'høgrestående': ('høgrestående',),
'høgrevridd': ('høgrevridd',),
'høgrevridde': ('høgrevridd',),
'høgrevriddere': ('høgrevridd',),
'høgrevriddest': ('høgrevridd',),
'høgrevriddeste': ('høgrevridd',),
'høgrygga': ('høgrygga',),
'høgryggede': ('høgrygget',),
'høgrygget': ('høgrygget',),
'høgryggete': ('høgrygget',),
'høgryggetere': ('høgrygget',),
'høgryggetest': ('høgrygget',),
'høgryggeteste': ('høgrygget',),
'høgrøsta': ('høgrøsta',),
'høgrøstede': ('høgrøstet',),
'høgrøstet': ('høgrøstet',),
'høgrøstete': ('høgrøstet',),
'høgrøstetere': ('høgrøstet',),
'høgrøstetest': ('høgrøstet',),
'høgrøsteteste': ('høgrøstet',),
'høgspent': ('høgspent',),
'høgspente': ('høgspent',),
'høgspentere': ('høgspent',),
'høgspentest': ('høgspent',),
'høgspenteste': ('høgspent',),
'høgstemt': ('høgstemt',),
'høgstemte': ('høgstemt',),
'høgstemtere': ('høgstemt',),
'høgstemtest': ('høgstemt',),
'høgstemteste': ('høgstemt',),
'høgtflygende': ('høgtflygende',),
'høgtidelig': ('høgtidelig',),
'høgtidelige': ('høgtidelig',),
'høgtideligere': ('høgtidelig',),
'høgtideligst': ('høgtidelig',),
'høgtideligste': ('høgtidelig',),
'høgtidsfull': ('høgtidsfull',),
'høgtidsfulle': ('høgtidsfull',),
'høgtidsfullere': ('høgtidsfull',),
'høgtidsfullest': ('høgtidsfull',),
'høgtidsfulleste': ('høgtidsfull',),
'høgtidsfullt': ('høgtidsfull',),
'høgtidsfull': ('høgtidsfull',),
'høgtidsfulle': ('høgtidsfull',),
'høgtidsfullere': ('høgtidsfull',),
'høgtidsfullest': ('høgtidsfull',),
'høgtidsfulleste': ('høgtidsfull',),
'høgtidsfullt': ('høgtidsfull',),
'høgtliggende': ('høgtliggende',),
'høgtlønna': ('høgtlønna',),
'høgtlønnede': ('høgtlønnet',),
'høgtlønnet': ('høgtlønnet',),
'høgtlønnete': ('høgtlønnet',),
'høgtlønnetere': ('høgtlønnet',),
'høgtlønnetest': ('høgtlønnet',),
'høgtlønneteste': ('høgtlønnet',),
'høgtlønt': ('høgtlønt',),
'høgtlønte': ('høgtlønt',),
'høgtløntere': ('høgtlønt',),
'høgtløntest': ('høgtlønt',),
'høgtlønteste': ('høgtlønt',),
'høgtstående': ('høgtstående',),
'høgtsvevende': ('høgtsvevende',),
'høgtysk': ('høgtysk',),
'høgtyske': ('høgtysk',),
'høgtyskere': ('høgtysk',),
'høgtyskest': ('høgtysk',),
'høgtyskeste': ('høgtysk',),
'høgvelbåren': ('høgvelbåren',),
'høgvelbårent': ('høgvelbåren',),
'høgvelbårne': ('høgvelbåren',),
'høgvelbårnere': ('høgvelbåren',),
'høgvelbårnest': ('høgvelbåren',),
'høgvelbårneste': ('høgvelbåren',),
'høgverdig': ('høgverdig',),
'høgverdige': ('høgverdig',),
'høgverdigere': ('høgverdig',),
'høgverdigst': ('høgverdig',),
'høgverdigste': ('høgverdig',),
'høgvokst': ('høgvokst',),
'høgvokste': ('høgvokst',),
'høgvokstere': ('høgvokst',),
'høgvokstest': ('høgvokst',),
'høgvoksteste': ('høgvokst',),
'høgætta': ('høgætta',),
'høgættede': ('høgættet',),
'høgættet': ('høgættet',),
'høgættete': ('høgættet',),
'høgættetere': ('høgættet',),
'høgættetest': ('høgættet',),
'høgætteteste': ('høgættet',),
'høkeraktig': ('høkeraktig',),
'høkeraktige': ('høkeraktig',),
'høkeraktigere': ('høkeraktig',),
'høkeraktigst': ('høkeraktig',),
'høkeraktigste': ('høkeraktig',),
'høkra': ('høkre',),
'høkrede': ('høkre',),
'høkrende': ('høkre',),
'høkret': ('høkre',),
'høkrete': ('høkre',),
'hølja': ('hølje',),
'høljede': ('hølje',),
'høljende': ('hølje',),
'høljet': ('hølje',),
'høljete': ('hølje',),
'høljeregna': ('høljeregne',),
'høljeregnede': ('høljeregne',),
'høljeregnende': ('høljeregne',),
'høljeregnet': ('høljeregne',),
'høljeregnete': ('høljeregne',),
'høljeregnt': ('høljeregne',),
'høljeregnte': ('høljeregne',),
'høljregna': ('høljregne',),
'høljregnede': ('høljregne',),
'høljregnende': ('høljregne',),
'høljregnet': ('høljregne',),
'høljregnete': ('høljregne',),
'høljregnt': ('høljregne',),
'høljregnte': ('høljregne',),
'hørbar': ('hørbar',),
'hørbare': ('hørbar',),
'hørbarere': ('hørbar',),
'hørbarest': ('hørbar',),
'hørbareste': ('hørbar',),
'hørbart': ('hørbar',),
'hørende': ('høre',),
'hørt': ('høre',),
'hørte': ('høre',),
'hørlig': ('hørlig',),
'hørlige': ('hørlig',),
'hørligere': ('hørlig',),
'hørligst': ('hørlig',),
'hørligste': ('hørlig',),
'hørselshemma': ('hørselshemma',),
'hørselshemmede': ('hørselshemmet',),
'hørselshemmet': ('hørselshemmet',),
'hørselshemmete': ('hørselshemmet',),
'hørselshemmetere': ('hørselshemmet',),
'hørselshemmetest': ('hørselshemmet',),
'hørselshemmeteste': ('hørselshemmet',),
'hørselssvekka': ('hørselssvekka',),
'hørselssvekket': ('hørselssvekket',),
'hørselssvekkete': ('hørselssvekket',),
'hørselssvekketere': ('hørselssvekket',),
'hørselssvekketest': ('hørselssvekket',),
'hørselssvekketeste': ('hørselssvekket',),
'høstbær': ('høstbær',),
'høstbære': ('høstbær',),
'høstbærere': ('høstbær',),
'høstbærest': ('høstbær',),
'høstbæreste': ('høstbær',),
'høstbært': ('høstbær',),
'høsta': ('høste',),
'høstede': ('høste',),
'høstende': ('høste',),
'høstet': ('høste',),
'høstete': ('høste',),
'høstlig': ('høstlig',),
'høstlige': ('høstlig',),
'høstligere': ('høstlig',),
'høstligst': ('høstlig',),
'høstligste': ('høstlig',),
'høvd': ('høve',),
'høvde': ('høve',),
'høvende': ('høve',),
'høvelig': ('høvelig',),
'høvelige': ('høvelig',),
'høveligere': ('høvelig',),
'høveligst': ('høvelig',),
'høveligste': ('høvelig',),
'høvisk': ('høvisk',),
'høviske': ('høvisk',),
'høviskere': ('høvisk',),
'høviskest': ('høvisk',),
'høviskeste': ('høvisk',),
'høvla': ('høvle',),
'høvlede': ('høvle',),
'høvlende': ('høvle',),
'høvlet': ('høvle',),
'høvlete': ('høvle',),
'høy': ('høy',),
'høye': ('høy',),
'høyere': ('høy',),
'høyest': ('høy',),
'høyeste': ('høy',),
'høyt': ('høy',),
'høyborgerlig': ('høyborgerlig',),
'høyborgerlige': ('høyborgerlig',),
'høyborgerligere': ('høyborgerlig',),
'høyborgerligst': ('høyborgerlig',),
'høyborgerligste': ('høyborgerlig',),
'høya': ('høye',),
'høyede': ('høye',),
'høyende': ('høye',),
'høyet': ('høye',),
'høyete': ('høye',),
'høyereliggende': ('høyereliggende',),
'høyerestående': ('høyerestående',),
'høyfrekvent': ('høyfrekvent',),
'høyfrekvente': ('høyfrekvent',),
'høyfrekventere': ('høyfrekvent',),
'høyfrekventest': ('høyfrekvent',),
'høyfrekventeste': ('høyfrekvent',),
'høygravid': ('høygravid',),
'høygravide': ('høygravid',),
'høygravidere': ('høygravid',),
'høygravidest': ('høygravid',),
'høygravideste': ('høygravid',),
'høyhalsede': ('høyhalset',),
'høyhalset': ('høyhalset',),
'høyhalsete': ('høyhalset',),
'høyhalsetere': ('høyhalset',),
'høyhalsetest': ('høyhalset',),
'høyhalseteste': ('høyhalset',),
'høyhælt': ('høyhælt',),
'høyhælte': ('høyhælt',),
'høyhæltere': ('høyhælt',),
'høyhæltest': ('høyhælt',),
'høyhælteste': ('høyhælt',),
'høykirkelig': ('høykirkelig',),
'høykirkelige': ('høykirkelig',),
'høykirkeligere': ('høykirkelig',),
'høykirkeligst': ('høykirkelig',),
'høykirkeligste': ('høykirkelig',),
'høylofta': ('høylofta',),
'høyloftede': ('høyloftet',),
'høyloftet': ('høyloftet',),
'høyloftete': ('høyloftet',),
'høyloftetere': ('høyloftet',),
'høyloftetest': ('høyloftet',),
'høylofteteste': ('høyloftet',),
'høylys': ('høylys',),
'høylyse': ('høylys',),
'høylysere': ('høylys',),
'høylysest': ('høylys',),
'høylyseste': ('høylys',),
'høylyst': ('høylys',),
'høylytt': ('høylytt',),
'høylytte': ('høylytt',),
'høylyttere': ('høylytt',),
'høylyttest': ('høylytt',),
'høylytteste': ('høylytt',),
'høymælt': ('høymælt',),
'høymælte': ('høymælt',),
'høymæltere': ('høymælt',),
'høymæltest': ('høymælt',),
'høymælteste': ('høymælt',),
'høyna': ('høyne',),
'høynede': ('høyne',),
'høynende': ('høyne',),
'høynet': ('høyne',),
'høynete': ('høyne',),
'høyre': ('høyre',),
'høyrehendt': ('høyrehendt',),
'høyrehendte': ('høyrehendt',),
'høyrehendtere': ('høyrehendt',),
'høyrehendtest': ('høyrehendt',),
'høyrehendteste': ('høyrehendt',),
'høyrehengsla': ('høyrehengsla',),
'høyrehengslede': ('høyrehengslet',),
'høyrehengslet': ('høyrehengslet',),
'høyrehengslete': ('høyrehengslet',),
'høyrehengsletere': ('høyrehengslet',),
'høyrehengsletest': ('høyrehengslet',),
'høyrehengsleteste': ('høyrehengslet',),
'høyreorientert': ('høyreorientert',),
'høyreorienterte': ('høyreorientert',),
'høyreorientertere': ('høyreorientert',),
'høyreorientertest': ('høyreorientert',),
'høyreorienterteste': ('høyreorientert',),
'høyrevridd': ('høyrevridd',),
'høyrevridde': ('høyrevridd',),
'høyrevriddere': ('høyrevridd',),
'høyrevriddest': ('høyrevridd',),
'høyrevriddeste': ('høyrevridd',),
'høyrygga': ('høyrygga',),
'høyryggede': ('høyrygget',),
'høyrygget': ('høyrygget',),
'høyryggete': ('høyrygget',),
'høyryggetere': ('høyrygget',),
'høyryggetest': ('høyrygget',),
'høyryggeteste': ('høyrygget',),
'høyrøsta': ('høyrøsta',),
'høyrøstede': ('høyrøstet',),
'høyrøstet': ('høyrøstet',),
'høyrøstete': ('høyrøstet',),
'høyrøstetere': ('høyrøstet',),
'høyrøstetest': ('høyrøstet',),
'høyrøsteteste': ('høyrøstet',),
'høyspent': ('høyspent',),
'høyspente': ('høyspent',),
'høyspentere': ('høyspent',),
'høyspentest': ('høyspent',),
'høyspenteste': ('høyspent',),
'høystbydende': ('høystbydende',),
'høystemt': ('høystemt',),
'høystemte': ('høystemt',),
'høystemtere': ('høystemt',),
'høystemtest': ('høystemt',),
'høystemteste': ('høystemt',),
'høystærede': ('høystæret',),
'høystæret': ('høystæret',),
'høystærete': ('høystæret',),
'høystæretere': ('høystæret',),
'høystæretest': ('høystæret',),
'høystæreteste': ('høystæret',),
'høytflygende': ('høytflygende',),
'høytidelig': ('høytidelig',),
'høytidelige': ('høytidelig',),
'høytideligere': ('høytidelig',),
'høytideligst': ('høytidelig',),
'høytideligste': ('høytidelig',),
'høytidsfull': ('høytidsfull',),
'høytidsfulle': ('høytidsfull',),
'høytidsfullere': ('høytidsfull',),
'høytidsfullest': ('høytidsfull',),
'høytidsfulleste': ('høytidsfull',),
'høytidsfullt': ('høytidsfull',),
'høytidsfull': ('høytidsfull',),
'høytidsfulle': ('høytidsfull',),
'høytidsfullere': ('høytidsfull',),
'høytidsfullest': ('høytidsfull',),
'høytidsfulleste': ('høytidsfull',),
'høytidsfullt': ('høytidsfull',),
'høytliggende': ('høytliggende',),
'høytlønt': ('høytlønt',),
'høytlønte': ('høytlønt',),
'høytløntere': ('høytlønt',),
'høytløntest': ('høytlønt',),
'høytlønteste': ('høytlønt',),
'høytlønt': ('høytlønt',),
'høytlønte': ('høytlønt',),
'høytløntere': ('høytlønt',),
'høytløntest': ('høytlønt',),
'høytlønteste': ('høytlønt',),
'høytstående': ('høytstående',),
'høytsvevende': ('høytsvevende',),
'høyttravende': ('høyttravende',),
'høytysk': ('høytysk',),
'høytyske': ('høytysk',),
'høytyskere': ('høytysk',),
'høytyskest': ('høytysk',),
'høytyskeste': ('høytysk',),
'høyvelbåren': ('høyvelbåren',),
'høyvelbårent': ('høyvelbåren',),
'høyvelbårne': ('høyvelbåren',),
'høyvelbårnere': ('høyvelbåren',),
'høyvelbårnest': ('høyvelbåren',),
'høyvelbårneste': ('høyvelbåren',),
'høyverdig': ('høyverdig',),
'høyverdige': ('høyverdig',),
'høyverdigere': ('høyverdig',),
'høyverdigst': ('høyverdig',),
'høyverdigste': ('høyverdig',),
'høyvokst': ('høyvokst',),
'høyvokste': ('høyvokst',),
'høyvokstere': ('høyvokst',),
'høyvokstest': ('høyvokst',),
'høyvoksteste': ('høyvokst',),
'høyætta': ('høyætta',),
'høyættede': ('høyættet',),
'høyættet': ('høyættet',),
'høyættete': ('høyættet',),
'høyættetere': ('høyættet',),
'høyættetest': ('høyættet',),
'høyætteteste': ('høyættet',),
'iakttakende': ('iaktta',),
'iakttatt': ('iaktta',),
'iakttatte': ('iaktta',),
'iatrogen': ('iatrogen',),
'iatrogene': ('iatrogen',),
'iatrogenere': ('iatrogen',),
'iatrogenest': ('iatrogen',),
'iatrogeneste': ('iatrogen',),
'iatrogent': ('iatrogen',),
'iberegna': ('iberegne',),
'iberegnede': ('iberegne',),
'iberegnende': ('iberegne',),
'iberegnet': ('iberegne',),
'iberegnete': ('iberegne',),
'iberisk': ('iberisk',),
'iberiske': ('iberisk',),
'iberiskere': ('iberisk',),
'iberiskest': ('iberisk',),
'iberiskeste': ('iberisk',),
'iblanda': ('iblande',),
'iblandede': ('iblande',),
'iblandende': ('iblande',),
'iblandet': ('iblande',),
'iblandete': ('iblande',),
'iboende': ('iboende',),
'ibsensk': ('ibsensk',),
'ibsenske': ('ibsensk',),
'ibsenskere': ('ibsensk',),
'ibsenskest': ('ibsensk',),
'ibsenskeste': ('ibsensk',),
'ibuende': ('ibuende',),
'idéhistorisk': ('idéhistorisk',),
'idéhistoriske': ('idéhistorisk',),
'idéhistoriskere': ('idéhistorisk',),
'idéhistoriskest': ('idéhistorisk',),
'idéhistoriskeste': ('idéhistorisk',),
'idélaus': ('idélaus',),
'idélause': ('idélaus',),
'idélausere': ('idélaus',),
'idélausest': ('idélaus',),
'idélauseste': ('idélaus',),
'idélaust': ('idélaus',),
'idéløs': ('idéløs',),
'idéløse': ('idéløs',),
'idéløsere': ('idéløs',),
'idéløsest': ('idéløs',),
'idéløseste': ('idéløs',),
'idéløst': ('idéløs',),
'idérik': ('idérik',),
'idérike': ('idérik',),
'idérikere': ('idérik',),
'idérikest': ('idérik',),
'idérikeste': ('idérik',),
'idérikt': ('idérik',),
'ideal': ('ideal',),
'ideale': ('ideal',),
'idealere': ('ideal',),
'idealest': ('ideal',),
'idealeste': ('ideal',),
'idealt': ('ideal',),
'idealiserende': ('idealisere',),
'idealisert': ('idealisere',),
'idealiserte': ('idealisere',),
'idealistisk': ('idealistisk',),
'idealistiske': ('idealistisk',),
'idealistiskere': ('idealistisk',),
'idealistiskest': ('idealistisk',),
'idealistiskeste': ('idealistisk',),
'ideell': ('ideell',),
'ideelle': ('ideell',),
'ideellere': ('ideell',),
'ideellest': ('ideell',),
'ideelleste': ('ideell',),
'ideelt': ('ideell',),
'idel': ('idel',),
'idelig': ('idelig',),
'idelige': ('idelig',),
'ideligere': ('idelig',),
'ideligst': ('idelig',),
'ideligste': ('idelig',),
'identifiserende': ('identifisere',),
'identifisert': ('identifisere',),
'identifiserte': ('identifisere',),
'identisk': ('identisk',),
'identiske': ('identisk',),
'identiskere': ('identisk',),
'identiskest': ('identisk',),
'identiskeste': ('identisk',),
'ideografisk': ('ideografisk',),
'ideografiske': ('ideografisk',),
'ideografiskere': ('ideografisk',),
'ideografiskest': ('ideografisk',),
'ideografiskeste': ('ideografisk',),
'ideologiserende': ('ideologisere',),
'ideologisert': ('ideologisere',),
'ideologiserte': ('ideologisere',),
'ideologisk': ('ideologisk',),
'ideologiske': ('ideologisk',),
'ideologiskere': ('ideologisk',),
'ideologiskest': ('ideologisk',),
'ideologiskeste': ('ideologisk',),
'idig': ('idig',),
'idige': ('idig',),
'idigere': ('idig',),
'idigst': ('idig',),
'idigste': ('idig',),
'idiomatisk': ('idiomatisk',),
'idiomatiske': ('idiomatisk',),
'idiomatiskere': ('idiomatisk',),
'idiomatiskest': ('idiomatisk',),
'idiomatiskeste': ('idiomatisk',),
'idiosynkratisk': ('idiosynkratisk',),
'idiosynkratiske': ('idiosynkratisk',),
'idiosynkratiskere': ('idiosynkratisk',),
'idiosynkratiskest': ('idiosynkratisk',),
'idiosynkratiskeste': ('idiosynkratisk',),
'idiotisk': ('idiotisk',),
'idiotiske': ('idiotisk',),
'idiotiskere': ('idiotisk',),
'idiotiskest': ('idiotisk',),
'idiotiskeste': ('idiotisk',),
'idiotsikker': ('idiotsikker',),
'idiotsikkert': ('idiotsikker',),
'idiotsikre': ('idiotsikker',),
'idiotsikrere': ('idiotsikker',),
'idiotsikrest': ('idiotsikker',),
'idiotsikreste': ('idiotsikker',),
'idka': ('idke',),
'idkede': ('idke',),
'idkende': ('idke',),
'idket': ('idke',),
'idkete': ('idke',),
'idrettslig': ('idrettslig',),
'idrettslige': ('idrettslig',),
'idrettsligere': ('idrettslig',),
'idrettsligst': ('idrettslig',),
'idrettsligste': ('idrettslig',),
'idylliserende': ('idyllisere',),
'idyllisert': ('idyllisere',),
'idylliserte': ('idyllisere',),
'idyllisk': ('idyllisk',),
'idylliske': ('idyllisk',),
'idylliskere': ('idyllisk',),
'idylliskest': ('idyllisk',),
'idylliskeste': ('idyllisk',),
'idømmende': ('idømme',),
'idømt': ('idømme',),
'idømte': ('idømme',),
'iførende': ('iføre',),
'iført': ('iføre',),
'iførte': ('iføre',),
'igangsatt': ('igangsette',),
'igangsatte': ('igangsette',),
'igangsettende': ('igangsette',),
'igangværende': ('igangværende',),
'ignorerende': ('ignorere',),
'ignorert': ('ignorere',),
'ignorerte': ('ignorere',),
'ihelfrosne': ('ihelfrosset',),
'ihelfrosnere': ('ihelfrosset',),
'ihelfrosnest': ('ihelfrosset',),
'ihelfrosneste': ('ihelfrosset',),
'ihelfrosset': ('ihelfrosset',),
'iherdig': ('iherdig',),
'iherdige': ('iherdig',),
'iherdigere': ('iherdig',),
'iherdigst': ('iherdig',),
'iherdigste': ('iherdig',),
'ihjelfrosne': ('ihjelfrosset',),
'ihjelfrosnere': ('ihjelfrosset',),
'ihjelfrosnest': ('ihjelfrosset',),
'ihjelfrosneste': ('ihjelfrosset',),
'ihjelfrosset': ('ihjelfrosset',),
'ihjelkjørt': ('ihjelkjørt',),
'ihjelkjørte': ('ihjelkjørt',),
'ihjelkjørtere': ('ihjelkjørt',),
'ihjelkjørtest': ('ihjelkjørt',),
'ihjelkjørteste': ('ihjelkjørt',),
'ihopfletta': ('ihopfletta',),
'ihopflettede': ('ihopflettet',),
'ihopflettet': ('ihopflettet',),
'ihopflettete': ('ihopflettet',),
'ihopflettetere': ('ihopflettet',),
'ihopflettetest': ('ihopflettet',),
'ihopfletteteste': ('ihopflettet',),
'ihopklemt': ('ihopklemt',),
'ihopklemte': ('ihopklemt',),
'ihopklemtere': ('ihopklemt',),
'ihopklemtest': ('ihopklemt',),
'ihopklemteste': ('ihopklemt',),
'ihopkrøkt': ('ihopkrøkt',),
'ihopkrøkte': ('ihopkrøkt',),
'ihopkrøktere': ('ihopkrøkt',),
'ihopkrøktest': ('ihopkrøkt',),
'ihopkrøkteste': ('ihopkrøkt',),
'ihuga': ('ihuga',),
'ihukommen': ('ihukomme',),
'ihukommende': ('ihukomme',),
'ihukommet': ('ihukomme',),
'ihukomne': ('ihukomme',),
'ikke-ledende': ('ikke-ledende',),
'ikke-stridende': ('ikke-stridende',),
'ikledd': ('ikle',),
'ikledde': ('ikle',),
'ikleende': ('ikle',),
'ikonisk': ('ikonisk',),
'ikoniske': ('ikonisk',),
'ikoniskere': ('ikonisk',),
'ikoniskest': ('ikonisk',),
'ikoniskeste': ('ikonisk',),
'ilanddrevet': ('ilanddrevet',),
'ilanddrevne': ('ilanddrevet',),
'ilanddrevnere': ('ilanddrevet',),
'ilanddrevnest': ('ilanddrevet',),
'ilanddrevneste': ('ilanddrevet',),
'ilandførende': ('ilandføre',),
'ilandført': ('ilandføre',),
'ilandførte': ('ilandføre',),
'ilda': ('ilde',),
'ildede': ('ilde',),
'ildende': ('ilde',),
'ildet': ('ilde',),
'ildete': ('ilde',),
'ilda': ('ilde',),
'ildede': ('ilde',),
'ildende': ('ilde',),
'ildet': ('ilde',),
'ildete': ('ilde',),
'ildfast': ('ildfast',),
'ildfaste': ('ildfast',),
'ildfastere': ('ildfast',),
'ildfastest': ('ildfast',),
'ildfasteste': ('ildfast',),
'ildfast': ('ildfast',),
'ildfaste': ('ildfast',),
'ildfastere': ('ildfast',),
'ildfastest': ('ildfast',),
'ildfasteste': ('ildfast',),
'ildfull': ('ildfull',),
'ildfulle': ('ildfull',),
'ildfullere': ('ildfull',),
'ildfullest': ('ildfull',),
'ildfulleste': ('ildfull',),
'ildfullt': ('ildfull',),
'ildfull': ('ildfull',),
'ildfulle': ('ildfull',),
'ildfullere': ('ildfull',),
'ildfullest': ('ildfull',),
'ildfulleste': ('ildfull',),
'ildfullt': ('ildfull',),
'ildna': ('ildne',),
'ildnede': ('ildne',),
'ildnende': ('ildne',),
'ildnet': ('ildne',),
'ildnete': ('ildne',),
'ildnende': ('ildnende',),
'ildrød': ('ildrød',),
'ildrøde': ('ildrød',),
'ildrødere': ('ildrød',),
'ildrødest': ('ildrød',),
'ildrødeste': ('ildrød',),
'ildrødt': ('ildrød',),
'ildrød': ('ildrød',),
'ildrøde': ('ildrød',),
'ildrødere': ('ildrød',),
'ildrødest': ('ildrød',),
'ildrødeste': ('ildrød',),
'ildrødt': ('ildrød',),
'ildrød': ('ildrød',),
'ildrøde': ('ildrød',),
'ildrødere': ('ildrød',),
'ildrødest': ('ildrød',),
'ildrødeste': ('ildrød',),
'ildrødt': ('ildrød',),
'ildsfarlig': ('ildsfarlig',),
'ildsfarlige': ('ildsfarlig',),
'ildsfarligere': ('ildsfarlig',),
'ildsfarligst': ('ildsfarlig',),
'ildsfarligste': ('ildsfarlig',),
'ildsfarlig': ('ildsfarlig',),
'ildsfarlige': ('ildsfarlig',),
'ildsfarligere': ('ildsfarlig',),
'ildsfarligst': ('ildsfarlig',),
'ildsfarligste': ('ildsfarlig',),
'ildsikker': ('ildsikker',),
'ildsikkert': ('ildsikker',),
'ildsikre': ('ildsikker',),
'ildsikrere': ('ildsikker',),
'ildsikrest': ('ildsikker',),
'ildsikreste': ('ildsikker',),
'ildsikker': ('ildsikker',),
'ildsikkert': ('ildsikker',),
'ildsikre': ('ildsikker',),
'ildsikrere': ('ildsikker',),
'ildsikrest': ('ildsikker',),
'ildsikreste': ('ildsikker',),
'ildsprutende': ('ildsprutende',),
'ildsprutende': ('ildsprutende',),
'ilende': ('ile',),
'ilt': ('ile',),
'ilte': ('ile',),
'ilagt': ('ilegge',),
'ilagte': ('ilegge',),
'ileggende': ('ilegge',),
'iligna': ('iligne',),
'ilignede': ('iligne',),
'ilignende': ('iligne',),
'ilignet': ('iligne',),
'ilignete': ('iligne',),
'ilikna': ('ilikne',),
'iliknede': ('ilikne',),
'iliknende': ('ilikne',),
'iliknet': ('ilikne',),
'iliknete': ('ilikne',),
'ill': ('ill',),
'ille': ('ill',),
'illere': ('ill',),
'illest': ('ill',),
'illeste': ('ill',),
'ilt': ('ill',),
'ille': ('ille',),
'verre': ('ille',),
'verst': ('ille',),
'verste': ('ille',),
'illegal': ('illegal',),
'illegale': ('illegal',),
'illegalere': ('illegal',),
'illegalest': ('illegal',),
'illegaleste': ('illegal',),
'illegalt': ('illegal',),
'illegitim': ('illegitim',),
'illegitime': ('illegitim',),
'illegitimere': ('illegitim',),
'illegitimest': ('illegitim',),
'illegitimeste': ('illegitim',),
'illegitimt': ('illegitim',),
'illeluktende': ('illeluktende',),
'illevarslende': ('illevarslende',),
'illgjeten': ('illgjeten',),
'illgjetent': ('illgjeten',),
'illgjetne': ('illgjeten',),
'illgjetnere': ('illgjeten',),
'illgjetnest': ('illgjeten',),
'illgjetneste': ('illgjeten',),
'illgjødd': ('illgjø',),
'illgjødde': ('illgjø',),
'illgjøende': ('illgjø',),
'illhervelig': ('illhervelig',),
'illhervelige': ('illhervelig',),
'illherveligere': ('illhervelig',),
'illherveligst': ('illhervelig',),
'illherveligste': ('illhervelig',),
'illhuia': ('illhuie',),
'illhuiede': ('illhuie',),
'illhuiende': ('illhuie',),
'illhuiet': ('illhuie',),
'illhuiete': ('illhuie',),
'illiberal': ('illiberal',),
'illiberale': ('illiberal',),
'illiberalere': ('illiberal',),
'illiberalest': ('illiberal',),
'illiberaleste': ('illiberal',),
'illiberalt': ('illiberal',),
'illojal': ('illojal',),
'illojale': ('illojal',),
'illojalere': ('illojal',),
'illojalest': ('illojal',),
'illojaleste': ('illojal',),
'illojalt': ('illojal',),
'illrød': ('illrød',),
'illrøde': ('illrød',),
'illrødere': ('illrød',),
'illrødest': ('illrød',),
'illrødeste': ('illrød',),
'illrødt': ('illrød',),
'illsinna': ('illsinna',),
'illsint': ('illsint',),
'illsinte': ('illsint',),
'illsintere': ('illsint',),
'illsintest': ('illsint',),
'illsinteste': ('illsint',),
'illskreken': ('illskrike',),
'illskreket': ('illskrike',),
'illskrekne': ('illskrike',),
'illskrikende': ('illskrike',),
'illsvien': ('illsvien',),
'illsviene': ('illsvien',),
'illsvienere': ('illsvien',),
'illsvienest': ('illsvien',),
'illsvieneste': ('illsvien',),
'illsvient': ('illsvien',),
'illuderende': ('illudere',),
'illudert': ('illudere',),
'illuderte': ('illudere',),
'illuminerende': ('illuminere',),
'illuminert': ('illuminere',),
'illuminerte': ('illuminere',),
'illusjonær': ('illusjonær',),
'illusjonære': ('illusjonær',),
'illusjonærere': ('illusjonær',),
'illusjonærest': ('illusjonær',),
'illusjonæreste': ('illusjonær',),
'illusjonært': ('illusjonær',),
'illusorisk': ('illusorisk',),
'illusoriske': ('illusorisk',),
'illusoriskere': ('illusorisk',),
'illusoriskest': ('illusorisk',),
'illusoriskeste': ('illusorisk',),
'illustrativ': ('illustrativ',),
'illustrative': ('illustrativ',),
'illustrativere': ('illustrativ',),
'illustrativest': ('illustrativ',),
'illustrativeste': ('illustrativ',),
'illustrativt': ('illustrativ',),
'illustre': ('illustre',),
'illustrerende': ('illustrere',),
'illustrert': ('illustrere',),
'illustrerte': ('illustrere',),
'ilsk': ('ilsk',),
'ilske': ('ilsk',),
'ilskere': ('ilsk',),
'ilskest': ('ilsk',),
'ilskeste': ('ilsk',),
'ilska': ('ilske',),
'ilskede': ('ilske',),
'ilskende': ('ilske',),
'ilsket': ('ilske',),
'ilskete': ('ilske',),
'ilsken': ('ilsken',),
'ilskent': ('ilsken',),
'ilskne': ('ilsken',),
'ilsknere': ('ilsken',),
'ilsknest': ('ilsken',),
'ilskneste': ('ilsken',),
'ilskna': ('ilskne',),
'ilsknede': ('ilskne',),
'ilsknende': ('ilskne',),
'ilsknet': ('ilskne',),
'ilsknete': ('ilskne',),
'ilsom': ('ilsom',),
'ilsomme': ('ilsom',),
'ilsommere': ('ilsom',),
'ilsomst': ('ilsom',),
'ilsomste': ('ilsom',),
'ilsomt': ('ilsom',),
'ilter': ('ilter',),
'iltert': ('ilter',),
'iltre': ('ilter',),
'iltrere': ('ilter',),
'iltrest': ('ilter',),
'iltreste': ('ilter',),
'imaginal': ('imaginal',),
'imaginale': ('imaginal',),
'imaginalere': ('imaginal',),
'imaginalest': ('imaginal',),
'imaginaleste': ('imaginal',),
'imaginalt': ('imaginal',),
'imaginerende': ('imaginere',),
'imaginert': ('imaginere',),
'imaginerte': ('imaginere',),
'imaginær': ('imaginær',),
'imaginære': ('imaginær',),
'imaginærere': ('imaginær',),
'imaginærest': ('imaginær',),
'imaginæreste': ('imaginær',),
'imaginært': ('imaginær',),
'imbesill': ('imbesill',),
'imbesille': ('imbesill',),
'imbesillere': ('imbesill',),
'imbesillest': ('imbesill',),
'imbesilleste': ('imbesill',),
'imbesilt': ('imbesill',),
'imiterende': ('imitere',),
'imitert': ('imitere',),
'imiterte': ('imitere',),
'immanent': ('immanent',),
'immanente': ('immanent',),
'immanentere': ('immanent',),
'immanentest': ('immanent',),
'immanenteste': ('immanent',),
'immateriell': ('immateriell',),
'immaterielle': ('immateriell',),
'immateriellere': ('immateriell',),
'immateriellest': ('immateriell',),
'immaterielleste': ('immateriell',),
'immaterielt': ('immateriell',),
'immatrikulerende': ('immatrikulere',),
'immatrikulert': ('immatrikulere',),
'immatrikulerte': ('immatrikulere',),
'immigrerende': ('immigrere',),
'immigrert': ('immigrere',),
'immigrerte': ('immigrere',),
'immobil': ('immobil',),
'immobile': ('immobil',),
'immobilere': ('immobil',),
'immobilest': ('immobil',),
'immobileste': ('immobil',),
'immobilt': ('immobil',),
'immortaliserende': ('immortalisere',),
'immortalisert': ('immortalisere',),
'immortaliserte': ('immortalisere',),
'immortell': ('immortell',),
'immortelle': ('immortell',),
'immortellere': ('immortell',),
'immortellest': ('immortell',),
'immortelleste': ('immortell',),
'immortelt': ('immortell',),
'immun': ('immun',),
'immune': ('immun',),
'immunere': ('immun',),
'immunest': ('immun',),
'immuneste': ('immun',),
'immunt': ('immun',),
'immuniserende': ('immunisere',),
'immunisert': ('immunisere',),
'immuniserte': ('immunisere',),
'immunologisk': ('immunologisk',),
'immunologiske': ('immunologisk',),
'immunologiskere': ('immunologisk',),
'immunologiskest': ('immunologisk',),
'immunologiskeste': ('immunologisk',),
'impenetrabel': ('impenetrabel',),
'impenetrabelt': ('impenetrabel',),
'impenetrable': ('impenetrabel',),
'impenetrablere': ('impenetrabel',),
'impenetrablest': ('impenetrabel',),
'impenetrableste': ('impenetrabel',),
'imperativ': ('imperativ',),
'imperative': ('imperativ',),
'imperativere': ('imperativ',),
'imperativest': ('imperativ',),
'imperativeste': ('imperativ',),
'imperativt': ('imperativ',),
'imperativisk': ('imperativisk',),
'imperativiske': ('imperativisk',),
'imperativiskere': ('imperativisk',),
'imperativiskest': ('imperativisk',),
'imperativiskeste': ('imperativisk',),
'imperfektiv': ('imperfektiv',),
'imperfektive': ('imperfektiv',),
'imperfektivere': ('imperfektiv',),
'imperfektivest': ('imperfektiv',),
'imperfektiveste': ('imperfektiv',),
'imperfektivt': ('imperfektiv',),
'imperial': ('imperial',),
'imperiale': ('imperial',),
'imperialere': ('imperial',),
'imperialest': ('imperial',),
'imperialeste': ('imperial',),
'imperialt': ('imperial',),
'imperialistisk': ('imperialistisk',),
'imperialistiske': ('imperialistisk',),
'imperialistiskere': ('imperialistisk',),
'imperialistiskest': ('imperialistisk',),
'imperialistiskeste': ('imperialistisk',),
'impermeabel': ('impermeabel',),
'impermeabelt': ('impermeabel',),
'impermeable': ('impermeabel',),
'impermeablere': ('impermeabel',),
'impermeablest': ('impermeabel',),
'impermeableste': ('impermeabel',),
'impertinent': ('impertinent',),
'impertinente': ('impertinent',),
'impertinentere': ('impertinent',),
'impertinentest': ('impertinent',),
'impertinenteste': ('impertinent',),
'implanterende': ('implantere',),
'implantert': ('implantere',),
'implanterte': ('implantere',),
'implementerende': ('implementere',),
'implementert': ('implementere',),
'implementerte': ('implementere',),
'impliserende': ('implisere',),
'implisert': ('implisere',),
'impliserte': ('implisere',),
'implisitt': ('implisitt',),
'implisitte': ('implisitt',),
'implisittere': ('implisitt',),
'implisittest': ('implisitt',),
'implisitteste': ('implisitt',),
'imploderende': ('implodere',),
'implodert': ('implodere',),
'imploderte': ('implodere',),
'implosjonssikker': ('implosjonssikker',),
'implosjonssikkert': ('implosjonssikker',),
'implosjonssikre': ('implosjonssikker',),
'implosjonssikrere': ('implosjonssikker',),
'implosjonssikrest': ('implosjonssikker',),
'implosjonssikreste': ('implosjonssikker',),
'imponerende': ('imponere',),
'imponert': ('imponere',),
'imponerte': ('imponere',),
'importerende': ('importere',),
'importert': ('importere',),
'importerte': ('importere',),
'imposant': ('imposant',),
'imposante': ('imposant',),
'imposantere': ('imposant',),
'imposantest': ('imposant',),
'imposanteste': ('imposant',),
'impotent': ('impotent',),
'impotente': ('impotent',),
'impotentere': ('impotent',),
'impotentest': ('impotent',),
'impotenteste': ('impotent',),
'impregnerende': ('impregnere',),
'impregnert': ('impregnere',),
'impregnerte': ('impregnere',),
'impresjonistisk': ('impresjonistisk',),
'impresjonistiske': ('impresjonistisk',),
'impresjonistiskere': ('impresjonistisk',),
'impresjonistiskest': ('impresjonistisk',),
'impresjonistiskeste': ('impresjonistisk',),
'improviserende': ('improvisere',),
'improvisert': ('improvisere',),
'improviserte': ('improvisere',),
'impulsiv': ('impulsiv',),
'impulsive': ('impulsiv',),
'impulsivere': ('impulsiv',),
'impulsivest': ('impulsiv',),
'impulsiveste': ('impulsiv',),
'impulsivt': ('impulsiv',),
'imøtegående': ('imøtegå',),
'imøtegått': ('imøtegå',),
'imøtegåtte': ('imøtegå',),
'imøteseende': ('imøtese',),
'imøtesett': ('imøtese',),
'imøtesette': ('imøtese',),
'in': ('in',),
'inadekvat': ('inadekvat',),
'inadekvate': ('inadekvat',),
'inadekvatere': ('inadekvat',),
'inadekvatest': ('inadekvat',),
'inadekvateste': ('inadekvat',),
'inaktiv': ('inaktiv',),
'inaktive': ('inaktiv',),
'inaktivere': ('inaktiv',),
'inaktivest': ('inaktiv',),
'inaktiveste': ('inaktiv',),
'inaktivt': ('inaktiv',),
'inaktiverende': ('inaktivere',),
'inaktivert': ('inaktivere',),
'inaktiverte': ('inaktivere',),
'inappellabel': ('inappellabel',),
'inappellabelt': ('inappellabel',),
'inappellable': ('inappellabel',),
'inappellablere': ('inappellabel',),
'inappellablest': ('inappellabel',),
'inappellableste': ('inappellabel',),
'inaugurerende': ('inaugurere',),
'inaugurert': ('inaugurere',),
'inaugurerte': ('inaugurere',),
'incestuøs': ('incestuøs',),
'incestuøse': ('incestuøs',),
'incestuøsere': ('incestuøs',),
'incestuøsest': ('incestuøs',),
'incestuøseste': ('incestuøs',),
'incestuøst': ('incestuøs',),
'inciterende': ('incitere',),
'incitert': ('incitere',),
'inciterte': ('incitere',),
'inderlig': ('inderlig',),
'inderlige': ('inderlig',),
'inderligere': ('inderlig',),
'inderligst': ('inderlig',),
'inderligste': ('inderlig',),
'indiansk': ('indiansk',),
'indianske': ('indiansk',),
'indianskere': ('indiansk',),
'indianskest': ('indiansk',),
'indianskeste': ('indiansk',),
'indifferent': ('indifferent',),
'indifferente': ('indifferent',),
'indifferentere': ('indifferent',),
'indifferentest': ('indifferent',),
'indifferenteste': ('indifferent',),
'indignert': ('indignert',),
'indignerte': ('indignert',),
'indignertere': ('indignert',),
'indignertest': ('indignert',),
'indignerteste': ('indignert',),
'indigoblå': ('indigoblå',),
'indigoblåe': ('indigoblå',),
'indigoblåere': ('indigoblå',),
'indigoblåest': ('indigoblå',),
'indigoblåeste': ('indigoblå',),
'indigoblått': ('indigoblå',),
'indikativisk': ('indikativisk',),
'indikativiske': ('indikativisk',),
'indikativiskere': ('indikativisk',),
'indikativiskest': ('indikativisk',),
'indikativiskeste': ('indikativisk',),
'indikerende': ('indikere',),
'indikert': ('indikere',),
'indikerte': ('indikere',),
'indirekte': ('indirekte',),
'indisk': ('indisk',),
'indiske': ('indisk',),
'indiskere': ('indisk',),
'indiskest': ('indisk',),
'indiskeste': ('indisk',),
'indiskre': ('indiskre',),
'indiskree': ('indiskre',),
'indiskreere': ('indiskre',),
'indiskreest': ('indiskre',),
'indiskreeste': ('indiskre',),
'indiskutabel': ('indiskutabel',),
'indiskutabelt': ('indiskutabel',),
'indiskutable': ('indiskutabel',),
'indiskutablere': ('indiskutabel',),
'indiskutablest': ('indiskutabel',),
'indiskutableste': ('indiskutabel',),
'indisponert': ('indisponert',),
'indisponerte': ('indisponert',),
'indisponertere': ('indisponert',),
'indisponertest': ('indisponert',),
'indisponerteste': ('indisponert',),
'indisponibel': ('indisponibel',),
'indisponibelt': ('indisponibel',),
'indisponible': ('indisponibel',),
'indisponiblere': ('indisponibel',),
'indisponiblest': ('indisponibel',),
'indisponibleste': ('indisponibel',),
'individualiserende': ('individualisere',),
'individualisert': ('individualisere',),
'individualiserte': ('individualisere',),
'individualistisk': ('individualistisk',),
'individualistiske': ('individualistisk',),
'individualistiskere': ('individualistisk',),
'individualistiskest': ('individualistisk',),
'individualistiskeste': ('individualistisk',),
'individualpreventiv': ('individualpreventiv',),
'individualpreventive': ('individualpreventiv',),
'individualpreventivere': ('individualpreventiv',),
'individualpreventivest': ('individualpreventiv',),
'individualpreventiveste': ('individualpreventiv',),
'individualpreventivt': ('individualpreventiv',),
'individuell': ('individuell',),
'individuelle': ('individuell',),
'individuellere': ('individuell',),
'individuellest': ('individuell',),
'individuelleste': ('individuell',),
'individuelt': ('individuell',),
'indoarisk': ('indoarisk',),
'indoariske': ('indoarisk',),
'indoariskere': ('indoarisk',),
'indoariskest': ('indoarisk',),
'indoariskeste': ('indoarisk',),
'indoeuropeisk': ('indoeuropeisk',),
'indoeuropeiske': ('indoeuropeisk',),
'indoeuropeiskere': ('indoeuropeisk',),
'indoeuropeiskest': ('indoeuropeisk',),
'indoeuropeiskeste': ('indoeuropeisk',),
'indoiransk': ('indoiransk',),
'indoiranske': ('indoiransk',),
'indoiranskere': ('indoiransk',),
'indoiranskest': ('indoiransk',),
'indoiranskeste': ('indoiransk',),
'indoiransk': ('indoiransk',),
'indoiranske': ('indoiransk',),
'indoiranskere': ('indoiransk',),
'indoiranskest': ('indoiransk',),
'indoiranskeste': ('indoiransk',),
'indokinesisk': ('indokinesisk',),
'indokinesiske': ('indokinesisk',),
'indokinesiskere': ('indokinesisk',),
'indokinesiskest': ('indokinesisk',),
'indokinesiskeste': ('indokinesisk',),
'indoktrinerende': ('indoktrinere',),
'indoktrinert': ('indoktrinere',),
'indoktrinerte': ('indoktrinere',),
'indolent': ('indolent',),
'indolente': ('indolent',),
'indolentere': ('indolent',),
'indolentest': ('indolent',),
'indolenteste': ('indolent',),
'indonesisk': ('indonesisk',),
'indonesiske': ('indonesisk',),
'indonesiskere': ('indonesisk',),
'indonesiskest': ('indonesisk',),
'indonesiskeste': ('indonesisk',),
'indre': ('indre',),
'innerst': ('indre',),
'innerste': ('indre',),
'inst': ('indre',),
'inste': ('indre',),
'indremedisinsk': ('indremedisinsk',),
'indremedisinske': ('indremedisinsk',),
'indremedisinskere': ('indremedisinsk',),
'indremedisinskest': ('indremedisinsk',),
'indremedisinskeste': ('indremedisinsk',),
'indrepolitisk': ('indrepolitisk',),
'indrepolitiske': ('indrepolitisk',),
'indrepolitiskere': ('indrepolitisk',),
'indrepolitiskest': ('indrepolitisk',),
'indrepolitiskeste': ('indrepolitisk',),
'indresekretorisk': ('indresekretorisk',),
'indresekretoriske': ('indresekretorisk',),
'indresekretoriskere': ('indresekretorisk',),
'indresekretoriskest': ('indresekretorisk',),
'indresekretoriskeste': ('indresekretorisk',),
'induktiv': ('induktiv',),
'induktive': ('induktiv',),
'induktivere': ('induktiv',),
'induktivest': ('induktiv',),
'induktiveste': ('induktiv',),
'induktivt': ('induktiv',),
'induserende': ('indusere',),
'indusert': ('indusere',),
'induserte': ('indusere',),
'industrialiserende': ('industrialisere',),
'industrialisert': ('industrialisere',),
'industrialiserte': ('industrialisere',),
'industriell': ('industriell',),
'industrielle': ('industriell',),
'industriellere': ('industriell',),
'industriellest': ('industriell',),
'industrielleste': ('industriell',),
'industrielt': ('industriell',),
'ineffektiv': ('ineffektiv',),
'ineffektive': ('ineffektiv',),
'ineffektivere': ('ineffektiv',),
'ineffektivest': ('ineffektiv',),
'ineffektiveste': ('ineffektiv',),
'ineffektivt': ('ineffektiv',),
'inert': ('inert',),
'inerte': ('inert',),
'inertere': ('inert',),
'inertest': ('inert',),
'inerteste': ('inert',),
'infam': ('infam',),
'infame': ('infam',),
'infamere': ('infam',),
'infamest': ('infam',),
'infameste': ('infam',),
'infamt': ('infam',),
'infamerende': ('infamere',),
'infamert': ('infamere',),
'infamerte': ('infamere',),
'infantil': ('infantil',),
'infantile': ('infantil',),
'infantilere': ('infantil',),
'infantilest': ('infantil',),
'infantileste': ('infantil',),
'infantilt': ('infantil',),
'infantiliserende': ('infantilisere',),
'infantilisert': ('infantilisere',),
'infantiliserte': ('infantilisere',),
'infeksiøs': ('infeksiøs',),
'infeksiøse': ('infeksiøs',),
'infeksiøsere': ('infeksiøs',),
'infeksiøsest': ('infeksiøs',),
'infeksiøseste': ('infeksiøs',),
'infeksiøst': ('infeksiøs',),
'inferiør': ('inferiør',),
'inferiøre': ('inferiør',),
'inferiørere': ('inferiør',),
'inferiørest': ('inferiør',),
'inferiøreste': ('inferiør',),
'inferiørt': ('inferiør',),
'infernalsk': ('infernalsk',),
'infernalske': ('infernalsk',),
'infernalskere': ('infernalsk',),
'infernalskest': ('infernalsk',),
'infernalskeste': ('infernalsk',),
'infiltrerende': ('infiltrere',),
'infiltrert': ('infiltrere',),
'infiltrerte': ('infiltrere',),
'infinitt': ('infinitt',),
'infinitte': ('infinitt',),
'infinittere': ('infinitt',),
'infinittest': ('infinitt',),
'infinitteste': ('infinitt',),
'infiserende': ('infisere',),
'infisert': ('infisere',),
'infiserte': ('infisere',),
'inflammatorisk': ('inflammatorisk',),
'inflammatoriske': ('inflammatorisk',),
'inflammatoriskere': ('inflammatorisk',),
'inflammatoriskest': ('inflammatorisk',),
'inflammatoriskeste': ('inflammatorisk',),
'inflammerende': ('inflammere',),
'inflammert': ('inflammere',),
'inflammerte': ('inflammere',),
'inflasjonistisk': ('inflasjonistisk',),
'inflasjonistiske': ('inflasjonistisk',),
'inflasjonistiskere': ('inflasjonistisk',),
'inflasjonistiskest': ('inflasjonistisk',),
'inflasjonistiskeste': ('inflasjonistisk',),
'inflasjonsdrivende': ('inflasjonsdrivende',),
'inflaterende': ('inflatere',),
'inflatert': ('inflatere',),
'inflaterte': ('inflatere',),
'inflatorisk': ('inflatorisk',),
'inflatoriske': ('inflatorisk',),
'inflatoriskere': ('inflatorisk',),
'inflatoriskest': ('inflatorisk',),
'inflatoriskeste': ('inflatorisk',),
'influerende': ('influere',),
'influert': ('influere',),
'influerte': ('influere',),
'informativ': ('informativ',),
'informative': ('informativ',),
'informativere': ('informativ',),
'informativest': ('informativ',),
'informativeste': ('informativ',),
'informativt': ('informativ',),
'informerende': ('informere',),
'informert': ('informere',),
'informerte': ('informere',),
'infrarød': ('infrarød',),
'infrarøde': ('infrarød',),
'infrarødere': ('infrarød',),
'infrarødest': ('infrarød',),
'infrarødeste': ('infrarød',),
'infrarødt': ('infrarød',),
'inhabil': ('inhabil',),
'inhabile': ('inhabil',),
'inhabilere': ('inhabil',),
'inhabilest': ('inhabil',),
'inhabileste': ('inhabil',),
'inhabilt': ('inhabil',),
'inhalerende': ('inhalere',),
'inhalert': ('inhalere',),
'inhalerte': ('inhalere',),
'inherent': ('inherent',),
'inherente': ('inherent',),
'inherentere': ('inherent',),
'inherentest': ('inherent',),
'inherenteste': ('inherent',),
'inhererende': ('inherere',),
'inherert': ('inherere',),
'inhererte': ('inherere',),
'inhiberende': ('inhibere',),
'inhibert': ('inhibere',),
'inhiberte': ('inhibere',),
'inhibitorisk': ('inhibitorisk',),
'inhibitoriske': ('inhibitorisk',),
'inhibitoriskere': ('inhibitorisk',),
'inhibitoriskest': ('inhibitorisk',),
'inhibitoriskeste': ('inhibitorisk',),
'inhuman': ('inhuman',),
'inhumane': ('inhuman',),
'inhumanere': ('inhuman',),
'inhumanest': ('inhuman',),
'inhumaneste': ('inhuman',),
'inhumant': ('inhuman',),
'initial': ('initial',),
'initiale': ('initial',),
'initialere': ('initial',),
'initialest': ('initial',),
'initialeste': ('initial',),
'initialt': ('initial',),
'initiativlaus': ('initiativlaus',),
'initiativlause': ('initiativlaus',),
'initiativlausere': ('initiativlaus',),
'initiativlausest': ('initiativlaus',),
'initiativlauseste': ('initiativlaus',),
'initiativlaust': ('initiativlaus',),
'initiativløs': ('initiativløs',),
'initiativløse': ('initiativløs',),
'initiativløsere': ('initiativløs',),
'initiativløsest': ('initiativløs',),
'initiativløseste': ('initiativløs',),
'initiativløst': ('initiativløs',),
'initiativrik': ('initiativrik',),
'initiativrike': ('initiativrik',),
'initiativrikere': ('initiativrik',),
'initiativrikest': ('initiativrik',),
'initiativrikeste': ('initiativrik',),
'initiativrikt': ('initiativrik',),
'initierende': ('initiere',),
'initiert': ('initiere',),
'initierte': ('initiere',),
'injiserende': ('injisere',),
'injisert': ('injisere',),
'injiserte': ('injisere',),
'injurierende': ('injuriere',),
'injuriert': ('injuriere',),
'injurierte': ('injuriere',),
'inkapabel': ('inkapabel',),
'inkapabelt': ('inkapabel',),
'inkapable': ('inkapabel',),
'inkapablere': ('inkapabel',),
'inkapablest': ('inkapabel',),
'inkapableste': ('inkapabel',),
'inkarnerende': ('inkarnere',),
'inkarnert': ('inkarnere',),
'inkarnerte': ('inkarnere',),
'inklinerende': ('inklinere',),
'inklinert': ('inklinere',),
'inklinerte': ('inklinere',),
'inkluderende': ('inkludere',),
'inkludert': ('inkludere',),
'inkluderte': ('inkludere',),
'inklusiv': ('inklusiv',),
'inklusive': ('inklusiv',),
'inklusivere': ('inklusiv',),
'inklusivest': ('inklusiv',),
'inklusiveste': ('inklusiv',),
'inklusivt': ('inklusiv',),
'inkoativ': ('inkoativ',),
'inkoative': ('inkoativ',),
'inkoativere': ('inkoativ',),
'inkoativest': ('inkoativ',),
'inkoativeste': ('inkoativ',),
'inkoativt': ('inkoativ',),
'inkommensurabel': ('inkommensurabel',),
'inkommensurabelt': ('inkommensurabel',),
'inkommensurable': ('inkommensurabel',),
'inkommensurablere': ('inkommensurabel',),
'inkommensurablest': ('inkommensurabel',),
'inkommensurableste': ('inkommensurabel',),
'inkontinent': ('inkontinent',),
'inkontinente': ('inkontinent',),
'inkontinentere': ('inkontinent',),
'inkontinentest': ('inkontinent',),
'inkontinenteste': ('inkontinent',),
'inkorporerende': ('inkorporere',),
'inkorporert': ('inkorporere',),
'inkorporerte': ('inkorporere',),
'inkvisitorisk': ('inkvisitorisk',),
'inkvisitoriske': ('inkvisitorisk',),
'inkvisitoriskere': ('inkvisitorisk',),
'inkvisitoriskest': ('inkvisitorisk',),
'inkvisitoriskeste': ('inkvisitorisk',),
'innabords': ('innabords',),
'innabygds': ('innabygds',),
'innabygdsboende': ('innabygdsboende',),
'innabys': ('innabys',),
'innadvendt': ('innadvendt',),
'innadvendte': ('innadvendt',),
'innadvendtere': ('innadvendt',),
'innadvendtest': ('innadvendt',),
'innadvendteste': ('innadvendt',),
'innadørs': ('innadørs',),
'innalandsk': ('innalandsk',),
'innalandske': ('innalandsk',),
'innalandskere': ('innalandsk',),
'innalandskest': ('innalandsk',),
'innalandskeste': ('innalandsk',),
'innanka': ('innanke',),
'innankede': ('innanke',),
'innankende': ('innanke',),
'innanket': ('innanke',),
'innankete': ('innanke',),
'innarbeida': ('innarbeide',),
'innarbeidd': ('innarbeide',),
'innarbeidde': ('innarbeide',),
'innarbeidede': ('innarbeide',),
'innarbeidende': ('innarbeide',),
'innarbeidet': ('innarbeide',),
'innarbeidete': ('innarbeide',),
'innariks': ('innariks',),
'innariksk': ('innariksk',),
'innarikske': ('innariksk',),
'innarikskere': ('innariksk',),
'innarikskest': ('innariksk',),
'innarikskeste': ('innariksk',),
'innbakt': ('innbakt',),
'innbakte': ('innbakt',),
'innbaktere': ('innbakt',),
'innbaktest': ('innbakt',),
'innbakteste': ('innbakt',),
'innballa': ('innballa',),
'innballede': ('innballet',),
'innballet': ('innballet',),
'innballete': ('innballet',),
'innballetere': ('innballet',),
'innballetest': ('innballet',),
'innballeteste': ('innballet',),
'innbarka': ('innbarka',),
'innbarkede': ('innbarket',),
'innbarket': ('innbarket',),
'innbarkete': ('innbarket',),
'innbarketere': ('innbarket',),
'innbarketest': ('innbarket',),
'innbarketeste': ('innbarket',),
'innbefatta': ('innbefatte',),
'innbefattede': ('innbefatte',),
'innbefattende': ('innbefatte',),
'innbefattet': ('innbefatte',),
'innbefattete': ('innbefatte',),
'innberetta': ('innberette',),
'innberettede': ('innberette',),
'innberettende': ('innberette',),
'innberettet': ('innberette',),
'innberettete': ('innberette',),
'innbetalende': ('innbetale',),
'innbetalt': ('innbetale',),
'innbetalte': ('innbetale',),
'innbillende': ('innbille',),
'innbilt': ('innbille',),
'innbilte': ('innbille',),
'innbilsk': ('innbilsk',),
'innbilske': ('innbilsk',),
'innbilskere': ('innbilsk',),
'innbilskest': ('innbilsk',),
'innbilskeste': ('innbilsk',),
'innbindende': ('innbinde',),
'innbunden': ('innbinde',),
'innbundet': ('innbinde',),
'innbundne': ('innbinde',),
'innbitt': ('innbitt',),
'innbitte': ('innbitt',),
'innbittere': ('innbitt',),
'innbittest': ('innbitt',),
'innbitteste': ('innbitt',),
'innblanda': ('innblande',),
'innblandede': ('innblande',),
'innblandende': ('innblande',),
'innblandet': ('innblande',),
'innblandete': ('innblande',),
'innbragt': ('innbringe',),
'innbragte': ('innbringe',),
'innbrakt': ('innbringe',),
'innbrakte': ('innbringe',),
'innbringende': ('innbringe',),
'innbringende': ('innbringende',),
'innbudt': ('innby',),
'innbudte': ('innby',),
'innbydd': ('innby',),
'innbydde': ('innby',),
'innbyende': ('innby',),
'innbydende': ('innbydende',),
'innbygd': ('innbygd',),
'innbygde': ('innbygd',),
'innbygdere': ('innbygd',),
'innbygdest': ('innbygd',),
'innbygdeste': ('innbygd',),
'innbyrdes': ('innbyrdes',),
'inndampa': ('inndampe',),
'inndampede': ('inndampe',),
'inndampende': ('inndampe',),
'inndampet': ('inndampe',),
'inndampete': ('inndampe',),
'inndelende': ('inndele',),
'inndelt': ('inndele',),
'inndelte': ('inndele',),
'inndradd': ('inndra',),
'inndradde': ('inndra',),
'inndragende': ('inndra',),
'inndratt': ('inndra',),
'inndratte': ('inndra',),
'inndreven': ('inndrive',),
'inndrevet': ('inndrive',),
'inndrevne': ('inndrive',),
'inndrivende': ('inndrive',),
'innebygd': ('innebygd',),
'innebygde': ('innebygd',),
'innebygdere': ('innebygd',),
'innebygdest': ('innebygd',),
'innebygdeste': ('innebygd',),
'innebåren': ('innebære',),
'innebåret': ('innebære',),
'innebårne': ('innebære',),
'innebærende': ('innebære',),
'innefrosne': ('innefrosset',),
'innefrosnere': ('innefrosset',),
'innefrosnest': ('innefrosset',),
'innefrosneste': ('innefrosset',),
'innefrosset': ('innefrosset',),
'innehaende': ('inneha',),
'innehatt': ('inneha',),
'innehatte': ('inneha',),
'inneholdende': ('inneholde',),
'inneholdt': ('inneholde',),
'inneholdte': ('inneholde',),
'inneklemt': ('inneklemt',),
'inneklemte': ('inneklemt',),
'inneklemtere': ('inneklemt',),
'inneklemtest': ('inneklemt',),
'inneklemteste': ('inneklemt',),
'innekserserende': ('inneksersere',),
'inneksersert': ('inneksersere',),
'innekserserte': ('inneksersere',),
'innelukka': ('innelukka',),
'innelukkede': ('innelukket',),
'innelukket': ('innelukket',),
'innelukkete': ('innelukket',),
'innelukketere': ('innelukket',),
'innelukketest': ('innelukket',),
'innelukketeste': ('innelukket',),
'innemurt': ('innemurt',),
'innemurte': ('innemurt',),
'innemurtere': ('innemurt',),
'innemurtest': ('innemurt',),
'innemurteste': ('innemurt',),
'innenbords': ('innenbords',),
'innenbygds': ('innenbygds',),
'innenbygdsboende': ('innenbygdsboende',),
'innenbys': ('innenbys',),
'innendørs': ('innendørs',),
'innenlandsk': ('innenlandsk',),
'innenlandske': ('innenlandsk',),
'innenlandskere': ('innenlandsk',),
'innenlandskest': ('innenlandsk',),
'innenlandskeste': ('innenlandsk',),
'innenriks': ('innenriks',),
'innenriksk': ('innenriksk',),
'innenrikske': ('innenriksk',),
'innenrikskere': ('innenriksk',),
'innenrikskest': ('innenriksk',),
'innenrikskeste': ('innenriksk',),
'inneslutta': ('inneslutta',),
'innesluttede': ('innesluttet',),
'innesluttet': ('innesluttet',),
'innesluttete': ('innesluttet',),
'innesluttetere': ('innesluttet',),
'innesluttetest': ('innesluttet',),
'inneslutteteste': ('innesluttet',),
'innesnødd': ('innesnødd',),
'innesnødde': ('innesnødd',),
'innesnøddere': ('innesnødd',),
'innesnøddest': ('innesnødd',),
'innesnøddeste': ('innesnødd',),
'innesperra': ('innesperra',),
'innesperrede': ('innesperret',),
'innesperret': ('innesperret',),
'innesperrete': ('innesperret',),
'innesperretere': ('innesperret',),
'innesperretest': ('innesperret',),
'innesperreteste': ('innesperret',),
'innestengt': ('innestengt',),
'innestengte': ('innestengt',),
'innestengtere': ('innestengt',),
'innestengtest': ('innestengt',),
'innestengteste': ('innestengt',),
'innett': ('innett',),
'innette': ('innett',),
'innettere': ('innett',),
'innettest': ('innett',),
'innetteste': ('innett',),
'inneværende': ('inneværende',),
'innfallen': ('innfallen',),
'innfallent': ('innfallen',),
'innfalne': ('innfallen',),
'innfalnere': ('innfallen',),
'innfalnest': ('innfallen',),
'innfalneste': ('innfallen',),
'innfallsrik': ('innfallsrik',),
'innfallsrike': ('innfallsrik',),
'innfallsrikere': ('innfallsrik',),
'innfallsrikest': ('innfallsrik',),
'innfallsrikeste': ('innfallsrik',),
'innfallsrikt': ('innfallsrik',),
'innfatta': ('innfatte',),
'innfattede': ('innfatte',),
'innfattende': ('innfatte',),
'innfattet': ('innfatte',),
'innfattete': ('innfatte',),
'innfellende': ('innfelle',),
'innfelt': ('innfelle',),
'innfelte': ('innfelle',),
'innfiltra': ('innfiltre',),
'innfiltrede': ('innfiltre',),
'innfiltrende': ('innfiltre',),
'innfiltret': ('innfiltre',),
'innfiltrete': ('innfiltre',),
'innfinnende': ('innfinne',),
'innfunne': ('innfinne',),
'innfunnen': ('innfinne',),
'innfunnet': ('innfinne',),
'innfletta': ('innfletta',),
'innflettede': ('innflettet',),
'innflettet': ('innflettet',),
'innflettete': ('innflettet',),
'innflettetere': ('innflettet',),
'innflettetest': ('innflettet',),
'innfletteteste': ('innflettet',),
'innflytelsesrik': ('innflytelsesrik',),
'innflytelsesrike': ('innflytelsesrik',),
'innflytelsesrikere': ('innflytelsesrik',),
'innflytelsesrikest': ('innflytelsesrik',),
'innflytelsesrikeste': ('innflytelsesrik',),
'innflytelsesrikt': ('innflytelsesrik',),
'innflytningsklar': ('innflytningsklar',),
'innflytningsklare': ('innflytningsklar',),
'innflytningsklarere': ('innflytningsklar',),
'innflytningsklarest': ('innflytningsklar',),
'innflytningsklareste': ('innflytningsklar',),
'innflytningsklart': ('innflytningsklar',),
'innflyttingsklar': ('innflyttingsklar',),
'innflyttingsklare': ('innflyttingsklar',),
'innflyttingsklarere': ('innflyttingsklar',),
'innflyttingsklarest': ('innflyttingsklar',),
'innflyttingsklareste': ('innflyttingsklar',),
'innflyttingsklart': ('innflyttingsklar',),
'innfløkt': ('innfløkt',),
'innfløkte': ('innfløkt',),
'innfløktere': ('innfløkt',),
'innfløktest': ('innfløkt',),
'innfløkteste': ('innfløkt',),
'innforliva': ('innforlive',),
'innforlivede': ('innforlive',),
'innforlivende': ('innforlive',),
'innforlivet': ('innforlive',),
'innforlivete': ('innforlive',),
'innforstått': ('innforstått',),
'innforståtte': ('innforstått',),
'innforståttere': ('innforstått',),
'innforståttest': ('innforstått',),
'innforståtteste': ('innforstått',),
'innfridd': ('innfri',),
'innfridde': ('innfri',),
'innfriende': ('innfri',),
'innful': ('innful',),
'innfule': ('innful',),
'innfulere': ('innful',),
'innfulest': ('innful',),
'innfuleste': ('innful',),
'innfult': ('innful',),
'innfødd': ('innfødd',),
'innfødde': ('innfødd',),
'innføddere': ('innfødd',),
'innføddest': ('innfødd',),
'innføddeste': ('innfødd',),
'innfødt': ('innfødt',),
'innfødte': ('innfødt',),
'innfødtere': ('innfødt',),
'innfødtest': ('innfødt',),
'innfødteste': ('innfødt',),
'innførende': ('innføre',),
'innført': ('innføre',),
'innførte': ('innføre',),
'innføya': ('innføye',),
'innføyd': ('innføye',),
'innføydd': ('innføye',),
'innføydde': ('innføye',),
'innføyde': ('innføye',),
'innføyede': ('innføye',),
'innføyende': ('innføye',),
'innføyet': ('innføye',),
'innføyete': ('innføye',),
'inngiende': ('inngi',),
'inngitt': ('inngi',),
'inngitte': ('inngi',),
'inngivende': ('inngi',),
'inngifta': ('inngifta',),
'inngifta': ('inngifte',),
'inngiftede': ('inngifte',),
'inngiftende': ('inngifte',),
'inngiftet': ('inngifte',),
'inngiftete': ('inngifte',),
'inngiftede': ('inngiftet',),
'inngiftet': ('inngiftet',),
'inngiftete': ('inngiftet',),
'inngiftetere': ('inngiftet',),
'inngiftetest': ('inngiftet',),
'inngifteteste': ('inngiftet',),
'inngjerda': ('inngjerde',),
'inngjerdede': ('inngjerde',),
'inngjerdende': ('inngjerde',),
'inngjerdet': ('inngjerde',),
'inngjerdete': ('inngjerde',),
'inngnidd': ('inngnidd',),
'inngnidde': ('inngnidd',),
'inngniddere': ('inngnidd',),
'inngniddest': ('inngnidd',),
'inngniddeste': ('inngnidd',),
'inngraverende': ('inngravere',),
'inngravert': ('inngravere',),
'inngraverte': ('inngravere',),
'inngripende': ('inngripende',),
'inngrodd': ('inngrodd',),
'inngrodde': ('inngrodd',),
'inngroddere': ('inngrodd',),
'inngroddest': ('inngrodd',),
'inngroddeste': ('inngrodd',),
'inngytende': ('inngyte',),
'inngytt': ('inngyte',),
'inngytte': ('inngyte',),
'inngående': ('inngå',),
'inngått': ('inngå',),
'inngåtte': ('inngå',),
'inngående': ('inngående',),
'innhegna': ('innhegne',),
'innhegnede': ('innhegne',),
'innhegnende': ('innhegne',),
'innhegnet': ('innhegne',),
'innhegnete': ('innhegne',),
'innhenta': ('innhente',),
'innhentede': ('innhente',),
'innhentende': ('innhente',),
'innhentet': ('innhente',),
'innhentete': ('innhente',),
'innhogd': ('innhogd',),
'innhogde': ('innhogd',),
'innhogdere': ('innhogd',),
'innhogdest': ('innhogd',),
'innhogdeste': ('innhogd',),
'innhol': ('innhol',),
'innhole': ('innhol',),
'innholere': ('innhol',),
'innholest': ('innhol',),
'innholeste': ('innhol',),
'innholt': ('innhol',),
'innholdslaus': ('innholdslaus',),
'innholdslause': ('innholdslaus',),
'innholdslausere': ('innholdslaus',),
'innholdslausest': ('innholdslaus',),
'innholdslauseste': ('innholdslaus',),
'innholdslaust': ('innholdslaus',),
'innholdsløs': ('innholdsløs',),
'innholdsløse': ('innholdsløs',),
'innholdsløsere': ('innholdsløs',),
'innholdsløsest': ('innholdsløs',),
'innholdsløseste': ('innholdsløs',),
'innholdsløst': ('innholdsløs',),
'innholdsrik': ('innholdsrik',),
'innholdsrike': ('innholdsrik',),
'innholdsrikere': ('innholdsrik',),
'innholdsrikest': ('innholdsrik',),
'innholdsrikeste': ('innholdsrik',),
'innholdsrikt': ('innholdsrik',),
'innhul': ('innhul',),
'innhule': ('innhul',),
'innhulere': ('innhul',),
'innhulest': ('innhul',),
'innhuleste': ('innhul',),
'innhult': ('innhul',),
'innhylla': ('innhylle',),
'innhyllede': ('innhylle',),
'innhyllende': ('innhylle',),
'innhyllet': ('innhylle',),
'innhyllete': ('innhylle',),
'innhøsta': ('innhøste',),
'innhøstede': ('innhøste',),
'innhøstende': ('innhøste',),
'innhøstet': ('innhøste',),
'innhøstete': ('innhøste',),
'innkalkulerende': ('innkalkulere',),
'innkalkulert': ('innkalkulere',),
'innkalkulerte': ('innkalkulere',),
'innkallende': ('innkalle',),
'innkalt': ('innkalle',),
'innkalte': ('innkalle',),
'innkapsla': ('innkapsle',),
'innkapslede': ('innkapsle',),
'innkapslende': ('innkapsle',),
'innkapslet': ('innkapsle',),
'innkapslete': ('innkapsle',),
'innkasserende': ('innkassere',),
'innkassert': ('innkassere',),
'innkasserte': ('innkassere',),
'innkasta': ('innkaste',),
'innkastede': ('innkaste',),
'innkastende': ('innkaste',),
'innkastet': ('innkaste',),
'innkastete': ('innkaste',),
'innkilt': ('innkilt',),
'innkilte': ('innkilt',),
'innkiltere': ('innkilt',),
'innkiltest': ('innkilt',),
'innkilteste': ('innkilt',),
'innkjøpt': ('innkjøpt',),
'innkjøpte': ('innkjøpt',),
'innkjøptere': ('innkjøpt',),
'innkjøptest': ('innkjøpt',),
'innkjøpteste': ('innkjøpt',),
'innkjørende': ('innkjøre',),
'innkjørt': ('innkjøre',),
'innkjørte': ('innkjøre',),
'innklaga': ('innklage',),
'innklagd': ('innklage',),
'innklagde': ('innklage',),
'innklagede': ('innklage',),
'innklagende': ('innklage',),
'innklaget': ('innklage',),
'innklagete': ('innklage',),
'innklarerende': ('innklarere',),
'innklarert': ('innklarere',),
'innklarerte': ('innklarere',),
'innklemt': ('innklemt',),
'innklemte': ('innklemt',),
'innklemtere': ('innklemt',),
'innklemtest': ('innklemt',),
'innklemteste': ('innklemt',),
'innklint': ('innklint',),
'innklinte': ('innklint',),
'innklintere': ('innklint',),
'innklintest': ('innklint',),
'innklinteste': ('innklint',),
'innkobla': ('innkoble',),
'innkoblede': ('innkoble',),
'innkoblende': ('innkoble',),
'innkoblet': ('innkoble',),
'innkoblete': ('innkoble',),
'innkokt': ('innkokt',),
'innkokte': ('innkokt',),
'innkoktere': ('innkokt',),
'innkoktest': ('innkokt',),
'innkokteste': ('innkokt',),
'innkommanderende': ('innkommandere',),
'innkommandert': ('innkommandere',),
'innkommanderte': ('innkommandere',),
'innkommen': ('innkomme',),
'innkommende': ('innkomme',),
'innkommet': ('innkomme',),
'innkomne': ('innkomme',),
'innkopla': ('innkople',),
'innkoplede': ('innkople',),
'innkoplende': ('innkople',),
'innkoplet': ('innkople',),
'innkoplete': ('innkople',),
'innkorta': ('innkorte',),
'innkortede': ('innkorte',),
'innkortende': ('innkorte',),
'innkortet': ('innkorte',),
'innkortete': ('innkorte',),
'innkreva': ('innkreve',),
'innkrevd': ('innkreve',),
'innkrevde': ('innkreve',),
'innkrevede': ('innkreve',),
'innkrevende': ('innkreve',),
'innkrevet': ('innkreve',),
'innkrevete': ('innkreve',),
'innkvarterende': ('innkvartere',),
'innkvartert': ('innkvartere',),
'innkvarterte': ('innkvartere',),
'innlagt': ('innlagt',),
'innlagte': ('innlagt',),
'innlagtere': ('innlagt',),
'innlagtest': ('innlagt',),
'innlagteste': ('innlagt',),
'innlasta': ('innlasta',),
'innlastede': ('innlastet',),
'innlastet': ('innlastet',),
'innlastete': ('innlastet',),
'innlastetere': ('innlastet',),
'innlastetest': ('innlastet',),
'innlasteteste': ('innlastet',),
'innlatende': ('innlate',),
'innlatt': ('innlate',),
'innlatte': ('innlate',),
'innleda': ('innlede',),
'innledede': ('innlede',),
'innledende': ('innlede',),
'innledet': ('innlede',),
'innledete': ('innlede',),
'innlagt': ('innlegge',),
'innlagte': ('innlegge',),
'innleggende': ('innlegge',),
'innleid': ('innleie',),
'innleide': ('innleie',),
'innleiede': ('innleie',),
'innleiende': ('innleie',),
'innleiet': ('innleie',),
'innleiete': ('innleie',),
'innlemma': ('innlemme',),
'innlemmede': ('innlemme',),
'innlemmende': ('innlemme',),
'innlemmet': ('innlemme',),
'innlemmete': ('innlemme',),
'innlesende': ('innlese',),
'innlest': ('innlese',),
'innleste': ('innlese',),
'innleverende': ('innlevere',),
'innlevert': ('innlevere',),
'innleverte': ('innlevere',),
'innlosjerende': ('innlosjere',),
'innlosjert': ('innlosjere',),
'innlosjerte': ('innlosjere',),
'innlysende': ('innlysende',),
'innlånende': ('innlåne',),
'innlånt': ('innlåne',),
'innlånte': ('innlåne',),
'innlåst': ('innlåst',),
'innlåste': ('innlåst',),
'innlåstere': ('innlåst',),
'innlåstest': ('innlåst',),
'innlåsteste': ('innlåst',),
'innlært': ('innlært',),
'innlærte': ('innlært',),
'innlærtere': ('innlært',),
'innlærtest': ('innlært',),
'innlærteste': ('innlært',),
'innløpende': ('innløpe',),
'innløpet': ('innløpe',),
'innløpt': ('innløpe',),
'innløpte': ('innløpe',),
'innløsende': ('innløse',),
'innløst': ('innløse',),
'innløste': ('innløse',),
'innløselig': ('innløselig',),
'innløselige': ('innløselig',),
'innløseligere': ('innløselig',),
'innløseligst': ('innløselig',),
'innløseligste': ('innløselig',),
'innløysende': ('innløyse',),
'innløyst': ('innløyse',),
'innløyste': ('innløyse',),
'innløyselig': ('innløyselig',),
'innløyselige': ('innløyselig',),
'innløyseligere': ('innløyselig',),
'innløyseligst': ('innløyselig',),
'innløyseligste': ('innløyselig',),
'innmari': ('innmari',),
'innmarisk': ('innmarisk',),
'innmariske': ('innmarisk',),
'innmariskere': ('innmarisk',),
'innmariskest': ('innmarisk',),
'innmariskeste': ('innmarisk',),
'innmeldt': ('innmeldt',),
'innmeldte': ('innmeldt',),
'innmeldtere': ('innmeldt',),
'innmeldtest': ('innmeldt',),
'innmeldteste': ('innmeldt',),
'innmura': ('innmure',),
'innmurede': ('innmure',),
'innmurende': ('innmure',),
'innmuret': ('innmure',),
'innmurete': ('innmure',),
'innmurt': ('innmure',),
'innmurte': ('innmure',),
'innordna': ('innordne',),
'innordnede': ('innordne',),
'innordnende': ('innordne',),
'innordnet': ('innordne',),
'innordnete': ('innordne',),
'innovativ': ('innovativ',),
'innovative': ('innovativ',),
'innovativere': ('innovativ',),
'innovativest': ('innovativ',),
'innovativeste': ('innovativ',),
'innovativt': ('innovativ',),
'innoverende': ('innovere',),
'innovert': ('innovere',),
'innoverte': ('innovere',),
'innpakka': ('innpakke',),
'innpakkede': ('innpakke',),
'innpakkende': ('innpakke',),
'innpakket': ('innpakke',),
'innpakkete': ('innpakke',),
'innpassa': ('innpasse',),
'innpassede': ('innpasse',),
'innpassende': ('innpasse',),
'innpasset': ('innpasse',),
'innpassete': ('innpasse',),
'innpasserende': ('innpassere',),
'innpassert': ('innpassere',),
'innpasserte': ('innpassere',),
'innpiska': ('innpiske',),
'innpiskede': ('innpiske',),
'innpiskende': ('innpiske',),
'innpisket': ('innpiske',),
'innpiskete': ('innpiske',),
'innplanta': ('innplante',),
'innplantede': ('innplante',),
'innplantende': ('innplante',),
'innplantet': ('innplante',),
'innplantete': ('innplante',),
'innpoda': ('innpode',),
'innpodede': ('innpode',),
'innpodende': ('innpode',),
'innpodet': ('innpode',),
'innpodete': ('innpode',),
'innpota': ('innpote',),
'innpotede': ('innpote',),
'innpotende': ('innpote',),
'innpotet': ('innpote',),
'innpotete': ('innpote',),
'innprenta': ('innprente',),
'innprentede': ('innprente',),
'innprentende': ('innprente',),
'innprentet': ('innprente',),
'innprentete': ('innprente',),
'innpåsliten': ('innpåsliten',),
'innpåslitent': ('innpåsliten',),
'innpåslitne': ('innpåsliten',),
'innpåslitnere': ('innpåsliten',),
'innpåslitnest': ('innpåsliten',),
'innpåslitneste': ('innpåsliten',),
'innramma': ('innramme',),
'innrammede': ('innramme',),
'innrammende': ('innramme',),
'innrammet': ('innramme',),
'innrammete': ('innramme',),
'innrapporterende': ('innrapportere',),
'innrapportert': ('innrapportere',),
'innrapporterte': ('innrapportere',),
'innreda': ('innrede',),
'innredede': ('innrede',),
'innredende': ('innrede',),
'innredet': ('innrede',),
'innredete': ('innrede',),
'innreid': ('innreie',),
'innreidd': ('innreie',),
'innreidde': ('innreie',),
'innreide': ('innreie',),
'innreiende': ('innreie',),
'innretta': ('innrette',),
'innrettede': ('innrette',),
'innrettende': ('innrette',),
'innrettet': ('innrette',),
'innrettete': ('innrette',),
'innrigga': ('innrigga',),
'innriggede': ('innrigget',),
'innrigget': ('innrigget',),
'innriggete': ('innrigget',),
'innriggetere': ('innrigget',),
'innriggetest': ('innrigget',),
'innriggeteste': ('innrigget',),
'innringa': ('innringe',),
'innringede': ('innringe',),
'innringende': ('innringe',),
'innringet': ('innringe',),
'innringete': ('innringe',),
'innrissa': ('innrissa',),
'innrissede': ('innrisset',),
'innrisset': ('innrisset',),
'innrissete': ('innrisset',),
'innrissetere': ('innrisset',),
'innrissetest': ('innrisset',),
'innrisseteste': ('innrisset',),
'innrullerende': ('innrullere',),
'innrullert': ('innrullere',),
'innrullerte': ('innrullere',),
'innrykka': ('innrykke',),
'innrykkede': ('innrykke',),
'innrykkende': ('innrykke',),
'innrykket': ('innrykke',),
'innrykkete': ('innrykke',),
'innrykt': ('innrykke',),
'innrykte': ('innrykke',),
'innrømma': ('innrømme',),
'innrømmede': ('innrømme',),
'innrømmende': ('innrømme',),
'innrømmet': ('innrømme',),
'innrømmete': ('innrømme',),
'innrømt': ('innrømme',),
'innrømte': ('innrømme',),
'innrøykt': ('innrøykt',),
'innrøykte': ('innrøykt',),
'innrøyktere': ('innrøykt',),
'innrøyktest': ('innrøykt',),
'innrøykteste': ('innrøykt',),
'innsamla': ('innsamle',),
'innsamlede': ('innsamle',),
'innsamlende': ('innsamle',),
'innsamlet': ('innsamle',),
'innsamlete': ('innsamle',),
'innsatt': ('innsatt',),
'innsatte': ('innsatt',),
'innsattere': ('innsatt',),
'innsattest': ('innsatt',),
'innsatteste': ('innsatt',),
'innsausa': ('innsausa',),
'innsausede': ('innsauset',),
'innsauset': ('innsauset',),
'innsausete': ('innsauset',),
'innsausetere': ('innsauset',),
'innsausetest': ('innsauset',),
'innsauseteste': ('innsauset',),
'innseende': ('innse',),
'innsett': ('innse',),
'innsette': ('innse',),
'innsegla': ('innsegle',),
'innseglede': ('innsegle',),
'innseglende': ('innsegle',),
'innseglet': ('innsegle',),
'innseglete': ('innsegle',),
'innseilende': ('innseile',),
'innseilt': ('innseile',),
'innseilte': ('innseile',),
'innsendende': ('innsende',),
'innsendt': ('innsende',),
'innsendte': ('innsende',),
'innsatt': ('innsette',),
'innsatte': ('innsette',),
'innsettende': ('innsette',),
'innsikta': ('innsikte',),
'innsiktede': ('innsikte',),
'innsiktende': ('innsikte',),
'innsiktet': ('innsikte',),
'innsiktete': ('innsikte',),
'innsiktsfull': ('innsiktsfull',),
'innsiktsfulle': ('innsiktsfull',),
'innsiktsfullere': ('innsiktsfull',),
'innsiktsfullest': ('innsiktsfull',),
'innsiktsfulleste': ('innsiktsfull',),
'innsiktsfullt': ('innsiktsfull',),
'innsirkla': ('innsirkle',),
'innsirklede': ('innsirkle',),
'innsirklende': ('innsirkle',),
'innsirklet': ('innsirkle',),
'innsirklete': ('innsirkle',),
'innskipa': ('innskipe',),
'innskipede': ('innskipe',),
'innskipende': ('innskipe',),
'innskipet': ('innskipe',),
'innskipete': ('innskipe',),
'innskjerpa': ('innskjerpe',),
'innskjerpede': ('innskjerpe',),
'innskjerpende': ('innskjerpe',),
'innskjerpet': ('innskjerpe',),
'innskjerpete': ('innskjerpe',),
'innskjærende': ('innskjære',),
'innskåren': ('innskjære',),
'innskåret': ('innskjære',),
'innskårne': ('innskjære',),
'innskrenka': ('innskrenke',),
'innskrenkede': ('innskrenke',),
'innskrenkende': ('innskrenke',),
'innskrenket': ('innskrenke',),
'innskrenkete': ('innskrenke',),
'innskreven': ('innskrive',),
'innskrevet': ('innskrive',),
'innskrevne': ('innskrive',),
'innskrivende': ('innskrive',),
'innskrumpa': ('innskrumpa',),
'innskrumpede': ('innskrumpet',),
'innskrumpet': ('innskrumpet',),
'innskrumpete': ('innskrumpet',),
'innskrumpetere': ('innskrumpet',),
'innskrumpetest': ('innskrumpet',),
'innskrumpeteste': ('innskrumpet',),
'innskutt': ('innskyte',),
'innskutte': ('innskyte',),
'innskytende': ('innskyte',),
'innslått': ('innslått',),
'innslåtte': ('innslått',),
'innslåttere': ('innslått',),
'innslåttest': ('innslått',),
'innslåtteste': ('innslått',),
'innsmigra': ('innsmigre',),
'innsmigrede': ('innsmigre',),
'innsmigrende': ('innsmigre',),
'innsmigret': ('innsmigre',),
'innsmigrete': ('innsmigre',),
'innsmugla': ('innsmugle',),
'innsmuglede': ('innsmugle',),
'innsmuglende': ('innsmugle',),
'innsmuglet': ('innsmugle',),
'innsmuglete': ('innsmugle',),
'innsmurt': ('innsmøre',),
'innsmurte': ('innsmøre',),
'innsmørende': ('innsmøre',),
'innsnevra': ('innsnevre',),
'innsnevrede': ('innsnevre',),
'innsnevrende': ('innsnevre',),
'innsnevret': ('innsnevre',),
'innsnevrete': ('innsnevre',),
'innsnørt': ('innsnørt',),
'innsnørte': ('innsnørt',),
'innsnørtere': ('innsnørt',),
'innsnørtest': ('innsnørt',),
'innsnørteste': ('innsnørt',),
'innspart': ('innspart',),
'innsparte': ('innspart',),
'innspartere': ('innspart',),
'innspartest': ('innspart',),
'innsparteste': ('innspart',),
'innspilt': ('innspilt',),
'innspilte': ('innspilt',),
'innspiltere': ('innspilt',),
'innspiltest': ('innspilt',),
'innspilteste': ('innspilt',),
'innsprengt': ('innsprengt',),
'innsprengte': ('innsprengt',),
'innsprengtere': ('innsprengt',),
'innsprengtest': ('innsprengt',),
'innsprengteste': ('innsprengt',),
'innsprøyta': ('innsprøyte',),
'innsprøytede': ('innsprøyte',),
'innsprøytende': ('innsprøyte',),
'innsprøytet': ('innsprøyte',),
'innsprøytete': ('innsprøyte',),
'innspunne': ('innspunnet',),
'innspunnere': ('innspunnet',),
'innspunnest': ('innspunnet',),
'innspunneste': ('innspunnet',),
'innspunnet': ('innspunnet',),
'innstendig': ('innstendig',),
'innstendige': ('innstendig',),
'innstendigere': ('innstendig',),
'innstendigst': ('innstendig',),
'innstendigste': ('innstendig',),
'innstevna': ('innstevne',),
'innstevnede': ('innstevne',),
'innstevnende': ('innstevne',),
'innstevnet': ('innstevne',),
'innstevnete': ('innstevne',),
'innstevnt': ('innstevne',),
'innstevnte': ('innstevne',),
'innstevna': ('innstevne',),
'innstevnede': ('innstevne',),
'innstevnende': ('innstevne',),
'innstevnet': ('innstevne',),
'innstevnete': ('innstevne',),
'innstevnt': ('innstevne',),
'innstevnte': ('innstevne',),
'innstifta': ('innstifte',),
'innstiftede': ('innstifte',),
'innstiftende': ('innstifte',),
'innstiftet': ('innstifte',),
'innstiftete': ('innstifte',),
'innstillende': ('innstille',),
'innstilt': ('innstille',),
'innstilte': ('innstille',),
'innstramma': ('innstramme',),
'innstrammede': ('innstramme',),
'innstrammende': ('innstramme',),
'innstrammet': ('innstramme',),
'innstrammete': ('innstramme',),
'innstuderende': ('innstudere',),
'innstudert': ('innstudere',),
'innstuderte': ('innstudere',),
'innstukket': ('innstukket',),
'innstukne': ('innstukket',),
'innstuknere': ('innstukket',),
'innstuknest': ('innstukket',),
'innstukneste': ('innstukket',),
'innstøpende': ('innstøpe',),
'innstøpt': ('innstøpe',),
'innstøpte': ('innstøpe',),
'innstøypende': ('innstøype',),
'innstøypt': ('innstøype',),
'innstøypte': ('innstøype',),
'innsuga': ('innsuge',),
'innsugd': ('innsuge',),
'innsugde': ('innsuge',),
'innsugede': ('innsuge',),
'innsugende': ('innsuge',),
'innsuget': ('innsuge',),
'innsugete': ('innsuge',),
'innsunket': ('innsunket',),
'innsunkne': ('innsunket',),
'innsunknere': ('innsunket',),
'innsunknest': ('innsunket',),
'innsunkneste': ('innsunket',),
'innsvinga': ('innsvinga',),
'innsvingede': ('innsvinget',),
'innsvinget': ('innsvinget',),
'innsvingete': ('innsvinget',),
'innsvingetere': ('innsvinget',),
'innsvingetest': ('innsvinget',),
'innsvingeteste': ('innsvinget',),
'innsvingt': ('innsvingt',),
'innsvingte': ('innsvingt',),
'innsvingtere': ('innsvingt',),
'innsvingtest': ('innsvingt',),
'innsvingteste': ('innsvingt',),
'innsvøpt': ('innsvøpt',),
'innsvøpte': ('innsvøpt',),
'innsvøptere': ('innsvøpt',),
'innsvøptest': ('innsvøpt',),
'innsvøpteste': ('innsvøpt',),
'innsydd': ('innsydd',),
'innsydde': ('innsydd',),
'innsyddere': ('innsydd',),
'innsyddest': ('innsydd',),
'innsyddeste': ('innsydd',),
'innsungen': ('innsynge',),
'innsunget': ('innsynge',),
'innsungne': ('innsynge',),
'innsyngende': ('innsynge',),
'innsåpa': ('innsåpa',),
'innsåpede': ('innsåpet',),
'innsåpet': ('innsåpet',),
'innsåpete': ('innsåpet',),
'innsåpetere': ('innsåpet',),
'innsåpetest': ('innsåpet',),
'innsåpeteste': ('innsåpet',),
'innsåpt': ('innsåpt',),
'innsåpte': ('innsåpt',),
'innsåptere': ('innsåpt',),
'innsåptest': ('innsåpt',),
'innsåpteste': ('innsåpt',),
'inntakende': ('innta',),
'inntatt': ('innta',),
'inntatte': ('innta',),
'inntagende': ('inntagende',),
'inntakende': ('inntakende',),
'inntasta': ('inntaste',),
'inntastede': ('inntaste',),
'inntastende': ('inntaste',),
'inntastet': ('inntaste',),
'inntastete': ('inntaste',),
'inntatt': ('inntatt',),
'inntatte': ('inntatt',),
'inntattere': ('inntatt',),
'inntattest': ('inntatt',),
'inntatteste': ('inntatt',),
'inntegna': ('inntegne',),
'inntegnede': ('inntegne',),
'inntegnende': ('inntegne',),
'inntegnet': ('inntegne',),
'inntegnete': ('inntegne',),
'inntektsgivende': ('inntektsgivende',),
'inntilbeins': ('inntilbeins',),
'inntilbens': ('inntilbens',),
'inntjent': ('inntjent',),
'inntjente': ('inntjent',),
'inntjentere': ('inntjent',),
'inntjentest': ('inntjent',),
'inntjenteste': ('inntjent',),
'inntredende': ('inntre',),
'inntrådt': ('inntre',),
'inntrådte': ('inntre',),
'inntreffende': ('inntreffe',),
'inntruffen': ('inntreffe',),
'inntruffet': ('inntreffe',),
'inntrufne': ('inntreffe',),
'inntrengende': ('inntrengende',),
'inntrykksøm': ('inntrykksøm',),
'inntrykksømme': ('inntrykksøm',),
'inntrykksømmere': ('inntrykksøm',),
'inntrykksømmest': ('inntrykksøm',),
'inntrykksømmeste': ('inntrykksøm',),
'inntrykksømt': ('inntrykksøm',),
'inntrykt': ('inntrykt',),
'inntrykte': ('inntrykt',),
'inntryktere': ('inntrykt',),
'inntryktest': ('inntrykt',),
'inntrykteste': ('inntrykt',),
'inntulla': ('inntulla',),
'inntullede': ('inntullet',),
'inntullet': ('inntullet',),
'inntullete': ('inntullet',),
'inntulletere': ('inntullet',),
'inntulletest': ('inntullet',),
'inntulleteste': ('inntullet',),
'inntørka': ('inntørka',),
'inntørkede': ('inntørket',),
'inntørket': ('inntørket',),
'inntørkete': ('inntørket',),
'inntørketere': ('inntørket',),
'inntørketest': ('inntørket',),
'inntørketeste': ('inntørket',),
'innvandra': ('innvandre',),
'innvandrede': ('innvandre',),
'innvandrende': ('innvandre',),
'innvandret': ('innvandre',),
'innvandrete': ('innvandre',),
'innvarsla': ('innvarsle',),
'innvarslede': ('innvarsle',),
'innvarslende': ('innvarsle',),
'innvarslet': ('innvarsle',),
'innvarslete': ('innvarsle',),
'innveid': ('innveie',),
'innveide': ('innveie',),
'innveiede': ('innveie',),
'innveiende': ('innveie',),
'innveiet': ('innveie',),
'innveiete': ('innveie',),
'innvalgt': ('innvelge',),
'innvalgte': ('innvelge',),
'innvelgende': ('innvelge',),
'innvendende': ('innvende',),
'innvendt': ('innvende',),
'innvendte': ('innvende',),
'innvendig': ('innvendig',),
'innvendige': ('innvendig',),
'innvendigere': ('innvendig',),
'innvendigst': ('innvendig',),
'innvendigste': ('innvendig',),
'innvevd': ('innvevd',),
'innvevde': ('innvevd',),
'innvevdere': ('innvevd',),
'innvevdest': ('innvevd',),
'innvevdeste': ('innvevd',),
'innvia': ('innvie',),
'innvidd': ('innvie',),
'innvidde': ('innvie',),
'innviede': ('innvie',),
'innviende': ('innvie',),
'innviet': ('innvie',),
'innviete': ('innvie',),
'innvigd': ('innvie',),
'innvigde': ('innvie',),
'innvikla': ('innvikla',),
'innvikla': ('innvikle',),
'innviklede': ('innvikle',),
'innviklende': ('innvikle',),
'innviklet': ('innvikle',),
'innviklete': ('innvikle',),
'innviklede': ('innviklet',),
'innviklet': ('innviklet',),
'innviklete': ('innviklet',),
'innvikletere': ('innviklet',),
'innvikletest': ('innviklet',),
'innvikleteste': ('innviklet',),
'innvilga': ('innvilge',),
'innvilgede': ('innvilge',),
'innvilgende': ('innvilge',),
'innvilget': ('innvilge',),
'innvilgete': ('innvilge',),
'innvinnende': ('innvinne',),
'innvunne': ('innvinne',),
'innvunnen': ('innvinne',),
'innvunnet': ('innvinne',),
'innvirka': ('innvirke',),
'innvirkede': ('innvirke',),
'innvirkende': ('innvirke',),
'innvirket': ('innvirke',),
'innvirkete': ('innvirke',),
'innvortes': ('innvortes',),
'innvoterende': ('innvotere',),
'innvotert': ('innvotere',),
'innvoterte': ('innvotere',),
'innynda': ('innynde',),
'innyndede': ('innynde',),
'innyndende': ('innynde',),
'innyndet': ('innynde',),
'innyndete': ('innynde',),
'innånda': ('innånde',),
'innåndede': ('innånde',),
'innåndende': ('innånde',),
'innåndet': ('innånde',),
'innåndete': ('innånde',),
'innøva': ('innøve',),
'innøvd': ('innøve',),
'innøvde': ('innøve',),
'innøvede': ('innøve',),
'innøvende': ('innøve',),
'innøvet': ('innøve',),
'innøvete': ('innøve',),
'inokulerende': ('inokulere',),
'inokulert': ('inokulere',),
'inokulerte': ('inokulere',),
'inopportun': ('inopportun',),
'inopportune': ('inopportun',),
'inopportunere': ('inopportun',),
'inopportunest': ('inopportun',),
'inopportuneste': ('inopportun',),
'inopportunt': ('inopportun',),
'insektdrepende': ('insektdrepende',),
'insektetende': ('insektetende',),
'inseminerende': ('inseminere',),
'inseminert': ('inseminere',),
'inseminerte': ('inseminere',),
'insinuant': ('insinuant',),
'insinuante': ('insinuant',),
'insinuantere': ('insinuant',),
'insinuantest': ('insinuant',),
'insinuanteste': ('insinuant',),
'insinuerende': ('insinuere',),
'insinuert': ('insinuere',),
'insinuerte': ('insinuere',),
'insisterende': ('insistere',),
'insistert': ('insistere',),
'insisterte': ('insistere',),
'inspirerende': ('inspirere',),
'inspirert': ('inspirere',),
'inspirerte': ('inspirere',),
'inspiserende': ('inspisere',),
'inspisert': ('inspisere',),
'inspiserte': ('inspisere',),
'instabil': ('instabil',),
'instabile': ('instabil',),
'instabilere': ('instabil',),
'instabilest': ('instabil',),
'instabileste': ('instabil',),
'instabilt': ('instabil',),
'installerende': ('installere',),
'installert': ('installere',),
'installerte': ('installere',),
'instinktiv': ('instinktiv',),
'instinktive': ('instinktiv',),
'instinktivere': ('instinktiv',),
'instinktivest': ('instinktiv',),
'instinktiveste': ('instinktiv',),
'instinktivt': ('instinktiv',),
'instituerende': ('instituere',),
'instituert': ('instituere',),
'instituerte': ('instituere',),
'institusjonaliserende': ('institusjonalisere',),
'institusjonalisert': ('institusjonalisere',),
'institusjonaliserte': ('institusjonalisere',),
'institusjonell': ('institusjonell',),
'institusjonelle': ('institusjonell',),
'institusjonellere': ('institusjonell',),
'institusjonellest': ('institusjonell',),
'institusjonelleste': ('institusjonell',),
'institusjonelt': ('institusjonell',),
'instruerende': ('instruere',),
'instruert': ('instruere',),
'instruerte': ('instruere',),
'instruktiv': ('instruktiv',),
'instruktive': ('instruktiv',),
'instruktivere': ('instruktiv',),
'instruktivest': ('instruktiv',),
'instruktiveste': ('instruktiv',),
'instruktivt': ('instruktiv',),
'instrumental': ('instrumental',),
'instrumentale': ('instrumental',),
'instrumentalere': ('instrumental',),
'instrumentalest': ('instrumental',),
'instrumentaleste': ('instrumental',),
'instrumentalt': ('instrumental',),
'instrumentell': ('instrumentell',),
'instrumentelle': ('instrumentell',),
'instrumentellere': ('instrumentell',),
'instrumentellest': ('instrumentell',),
'instrumentelleste': ('instrumentell',),
'instrumentelt': ('instrumentell',),
'instrumenterende': ('instrumentere',),
'instrumentert': ('instrumentere',),
'instrumenterte': ('instrumentere',),
'insuffisient': ('insuffisient',),
'insulær': ('insulær',),
'insulære': ('insulær',),
'insulærere': ('insulær',),
'insulærest': ('insulær',),
'insulæreste': ('insulær',),
'insulært': ('insulær',),
'intakt': ('intakt',),
'intakte': ('intakt',),
'intaktere': ('intakt',),
'intaktest': ('intakt',),
'intakteste': ('intakt',),
'integrerende': ('integrere',),
'integrert': ('integrere',),
'integrerte': ('integrere',),
'intellektualiserende': ('intellektualisere',),
'intellektualisert': ('intellektualisere',),
'intellektualiserte': ('intellektualisere',),
'intellektualistisk': ('intellektualistisk',),
'intellektualistiske': ('intellektualistisk',),
'intellektualistiskere': ('intellektualistisk',),
'intellektualistiskest': ('intellektualistisk',),
'intellektualistiskeste': ('intellektualistisk',),
'intellektuell': ('intellektuell',),
'intellektuelle': ('intellektuell',),
'intellektuellere': ('intellektuell',),
'intellektuellest': ('intellektuell',),
'intellektuelleste': ('intellektuell',),
'intellektuelt': ('intellektuell',),
'intelligent': ('intelligent',),
'intelligente': ('intelligent',),
'intelligentere': ('intelligent',),
'intelligentest': ('intelligent',),
'intelligenteste': ('intelligent',),
'intelligibel': ('intelligibel',),
'intelligibelt': ('intelligibel',),
'intelligible': ('intelligibel',),
'intelligiblere': ('intelligibel',),
'intelligiblest': ('intelligibel',),
'intelligibleste': ('intelligibel',),
'intenderende': ('intendere',),
'intendert': ('intendere',),
'intenderte': ('intendere',),
'intens': ('intens',),
'intense': ('intens',),
'intensere': ('intens',),
'intensest': ('intens',),
'intenseste': ('intens',),
'intenst': ('intens',),
'intensiv': ('intensiv',),
'intensive': ('intensiv',),
'intensivere': ('intensiv',),
'intensivest': ('intensiv',),
'intensiveste': ('intensiv',),
'intensivt': ('intensiv',),
'intensiverende': ('intensivere',),
'intensivert': ('intensivere',),
'intensiverte': ('intensivere',),
'intensjonal': ('intensjonal',),
'intensjonale': ('intensjonal',),
'intensjonalere': ('intensjonal',),
'intensjonalest': ('intensjonal',),
'intensjonaleste': ('intensjonal',),
'intensjonalt': ('intensjonal',),
'intensjonell': ('intensjonell',),
'intensjonelle': ('intensjonell',),
'intensjonellere': ('intensjonell',),
'intensjonellest': ('intensjonell',),
'intensjonelleste': ('intensjonell',),
'intensjonelt': ('intensjonell',),
'interdental': ('interdental',),
'interdentale': ('interdental',),
'interdentalere': ('interdental',),
'interdentalest': ('interdental',),
'interdentaleste': ('interdental',),
'interdentalt': ('interdental',),
'interdepartemental': ('interdepartemental',),
'interdepartementale': ('interdepartemental',),
'interdepartementalere': ('interdepartemental',),
'interdepartementalest': ('interdepartemental',),
'interdepartementaleste': ('interdepartemental',),
'interdepartementalt': ('interdepartemental',),
'interdisiplinær': ('interdisiplinær',),
'interdisiplinære': ('interdisiplinær',),
'interdisiplinærere': ('interdisiplinær',),
'interdisiplinærest': ('interdisiplinær',),
'interdisiplinæreste': ('interdisiplinær',),
'interdisiplinært': ('interdisiplinær',),
'interessant': ('interessant',),
'interessante': ('interessant',),
'interessantere': ('interessant',),
'interessantest': ('interessant',),
'interessanteste': ('interessant',),
'interesselaus': ('interesselaus',),
'interesselause': ('interesselaus',),
'interesselausere': ('interesselaus',),
'interesselausest': ('interesselaus',),
'interesselauseste': ('interesselaus',),
'interesselaust': ('interesselaus',),
'interesseløs': ('interesseløs',),
'interesseløse': ('interesseløs',),
'interesseløsere': ('interesseløs',),
'interesseløsest': ('interesseløs',),
'interesseløseste': ('interesseløs',),
'interesseløst': ('interesseløs',),
'interesserende': ('interessere',),
'interessert': ('interessere',),
'interesserte': ('interessere',),
'interessevekkende': ('interessevekkende',),
'intereuropeisk': ('intereuropeisk',),
'intereuropeiske': ('intereuropeisk',),
'intereuropeiskere': ('intereuropeisk',),
'intereuropeiskest': ('intereuropeisk',),
'intereuropeiskeste': ('intereuropeisk',),
'interfererende': ('interferere',),
'interferert': ('interferere',),
'interfererte': ('interferere',),
'interfolierende': ('interfoliere',),
'interfoliert': ('interfoliere',),
'interfolierte': ('interfoliere',),
'interglasial': ('interglasial',),
'interglasiale': ('interglasial',),
'interglasialere': ('interglasial',),
'interglasialest': ('interglasial',),
'interglasialeste': ('interglasial',),
'interglasialt': ('interglasial',),
'interimistisk': ('interimistisk',),
'interimistiske': ('interimistisk',),
'interimistiskere': ('interimistisk',),
'interimistiskest': ('interimistisk',),
'interimistiskeste': ('interimistisk',),
'interkommunal': ('interkommunal',),
'interkommunale': ('interkommunal',),
'interkommunalere': ('interkommunal',),
'interkommunalest': ('interkommunal',),
'interkommunaleste': ('interkommunal',),
'interkommunalt': ('interkommunal',),
'interkonfesjonell': ('interkonfesjonell',),
'interkonfesjonelle': ('interkonfesjonell',),
'interkonfesjonellere': ('interkonfesjonell',),
'interkonfesjonellest': ('interkonfesjonell',),
'interkonfesjonelleste': ('interkonfesjonell',),
'interkonfesjonelt': ('interkonfesjonell',),
'interkontinental': ('interkontinental',),
'interkontinentale': ('interkontinental',),
'interkontinentalere': ('interkontinental',),
'interkontinentalest': ('interkontinental',),
'interkontinentaleste': ('interkontinental',),
'interkontinentalt': ('interkontinental',),
'intern': ('intern',),
'interne': ('intern',),
'internere': ('intern',),
'internest': ('intern',),
'interneste': ('intern',),
'internt': ('intern',),
'internasjonal': ('internasjonal',),
'internasjonale': ('internasjonal',),
'internasjonalere': ('internasjonal',),
'internasjonalest': ('internasjonal',),
'internasjonaleste': ('internasjonal',),
'internasjonalt': ('internasjonal',),
'internasjonaliserende': ('internasjonalisere',),
'internasjonalisert': ('internasjonalisere',),
'internasjonaliserte': ('internasjonalisere',),
'internasjonalistisk': ('internasjonalistisk',),
'internasjonalistiske': ('internasjonalistisk',),
'internasjonalistiskere': ('internasjonalistisk',),
'internasjonalistiskest': ('internasjonalistisk',),
'internasjonalistiskeste': ('internasjonalistisk',),
'internerende': ('internere',),
'internert': ('internere',),
'internerte': ('internere',),
'internordisk': ('internordisk',),
'internordiske': ('internordisk',),
'internordiskere': ('internordisk',),
'internordiskest': ('internordisk',),
'internordiskeste': ('internordisk',),
'interparlamentarisk': ('interparlamentarisk',),
'interparlamentariske': ('interparlamentarisk',),
'interparlamentariskere': ('interparlamentarisk',),
'interparlamentariskest': ('interparlamentarisk',),
'interparlamentariskeste': ('interparlamentarisk',),
'interpellerende': ('interpellere',),
'interpellert': ('interpellere',),
'interpellerte': ('interpellere',),
'interplanetarisk': ('interplanetarisk',),
'interplanetariske': ('interplanetarisk',),
'interplanetariskere': ('interplanetarisk',),
'interplanetariskest': ('interplanetarisk',),
'interplanetariskeste': ('interplanetarisk',),
'interpolerende': ('interpolere',),
'interpolert': ('interpolere',),
'interpolerte': ('interpolere',),
'interpreterende': ('interpretere',),
'interpretert': ('interpretere',),
'interpreterte': ('interpretere',),
'interrogativ': ('interrogativ',),
'interrogative': ('interrogativ',),
'interrogativere': ('interrogativ',),
'interrogativest': ('interrogativ',),
'interrogativeste': ('interrogativ',),
'interrogativt': ('interrogativ',),
'interseksuell': ('interseksuell',),
'interseksuelle': ('interseksuell',),
'interseksuellere': ('interseksuell',),
'interseksuellest': ('interseksuell',),
'interseksuelleste': ('interseksuell',),
'interseksuelt': ('interseksuell',),
'interskandinavisk': ('interskandinavisk',),
'interskandinaviske': ('interskandinavisk',),
'interskandinaviskere': ('interskandinavisk',),
'interskandinaviskest': ('interskandinavisk',),
'interskandinaviskeste': ('interskandinavisk',),
'interstellar': ('interstellar',),
'interstellare': ('interstellar',),
'interstellarere': ('interstellar',),
'interstellarest': ('interstellar',),
'interstellareste': ('interstellar',),
'interstellart': ('interstellar',),
'intersubjektiv': ('intersubjektiv',),
'intersubjektive': ('intersubjektiv',),
'intersubjektivere': ('intersubjektiv',),
'intersubjektivest': ('intersubjektiv',),
'intersubjektiveste': ('intersubjektiv',),
'intersubjektivt': ('intersubjektiv',),
'intervenerende': ('intervenere',),
'intervenert': ('intervenere',),
'intervenerte': ('intervenere',),
'intervjua': ('intervjue',),
'intervjuede': ('intervjue',),
'intervjuende': ('intervjue',),
'intervjuet': ('intervjue',),
'intervjuete': ('intervjue',),
'intervokalisk': ('intervokalisk',),
'intervokaliske': ('intervokalisk',),
'intervokaliskere': ('intervokalisk',),
'intervokaliskest': ('intervokalisk',),
'intervokaliskeste': ('intervokalisk',),
'intetanende': ('intetanende',),
'intetsigende': ('intetsigende',),
'intim': ('intim',),
'intime': ('intim',),
'intimere': ('intim',),
'intimest': ('intim',),
'intimeste': ('intim',),
'intimt': ('intim',),
'intimiderende': ('intimidere',),
'intimidert': ('intimidere',),
'intimiderte': ('intimidere',),
'intonerende': ('intonere',),
'intonert': ('intonere',),
'intonerte': ('intonere',),
'intracellulær': ('intracellulær',),
'intracellulære': ('intracellulær',),
'intracellulærere': ('intracellulær',),
'intracellulærest': ('intracellulær',),
'intracellulæreste': ('intracellulær',),
'intracellulært': ('intracellulær',),
'intramolekylær': ('intramolekylær',),
'intramolekylære': ('intramolekylær',),
'intramolekylærere': ('intramolekylær',),
'intramolekylærest': ('intramolekylær',),
'intramolekylæreste': ('intramolekylær',),
'intramolekylært': ('intramolekylær',),
'intransitiv': ('intransitiv',),
'intransitive': ('intransitiv',),
'intransitivere': ('intransitiv',),
'intransitivest': ('intransitiv',),
'intransitiveste': ('intransitiv',),
'intransitivt': ('intransitiv',),
'intravenøs': ('intravenøs',),
'intravenøse': ('intravenøs',),
'intravenøsere': ('intravenøs',),
'intravenøsest': ('intravenøs',),
'intravenøseste': ('intravenøs',),
'intravenøst': ('intravenøs',),
'intrigant': ('intrigant',),
'intrigante': ('intrigant',),
'intrigantere': ('intrigant',),
'intrigantest': ('intrigant',),
'intriganteste': ('intrigant',),
'intrigerende': ('intrigere',),
'intrigert': ('intrigere',),
'intrigerte': ('intrigere',),
'intrikat': ('intrikat',),
'intrikate': ('intrikat',),
'intrikatere': ('intrikat',),
'intrikatest': ('intrikat',),
'intrikateste': ('intrikat',),
'introduserende': ('introdusere',),
'introdusert': ('introdusere',),
'introduserte': ('introdusere',),
'introspektiv': ('introspektiv',),
'introspektive': ('introspektiv',),
'introspektivere': ('introspektiv',),
'introspektivest': ('introspektiv',),
'introspektiveste': ('introspektiv',),
'introspektivt': ('introspektiv',),
'introvert': ('introvert',),
'introverte': ('introvert',),
'introvertere': ('introvert',),
'introvertest': ('introvert',),
'introverteste': ('introvert',),
'intuitiv': ('intuitiv',),
'intuitive': ('intuitiv',),
'intuitivere': ('intuitiv',),
'intuitivest': ('intuitiv',),
'intuitiveste': ('intuitiv',),
'intuitivt': ('intuitiv',),
'invaderende': ('invadere',),
'invadert': ('invadere',),
'invaderte': ('invadere',),
'invalid': ('invalid',),
'invalide': ('invalid',),
'invalidere': ('invalid',),
'invalidest': ('invalid',),
'invalideste': ('invalid',),
'invalidiserende': ('invalidisere',),
'invalidisert': ('invalidisere',),
'invalidiserte': ('invalidisere',),
'invariabel': ('invariabel',),
'invariabelt': ('invariabel',),
'invariable': ('invariabel',),
'invariablere': ('invariabel',),
'invariablest': ('invariabel',),
'invariableste': ('invariabel',),
'invariabel': ('invariabel',),
'invariabelt': ('invariabel',),
'invariable': ('invariabel',),
'invariablere': ('invariabel',),
'invariablest': ('invariabel',),
'invariableste': ('invariabel',),
'inventerende': ('inventere',),
'inventert': ('inventere',),
'inventerte': ('inventere',),
'invers': ('invers',),
'inverse': ('invers',),
'inversere': ('invers',),
'inversest': ('invers',),
'inverseste': ('invers',),
'inverst': ('invers',),
'inverterende': ('invertere',),
'invertert': ('invertere',),
'inverterte': ('invertere',),
'investerende': ('investere',),
'investert': ('investere',),
'investerte': ('investere',),
'inviterende': ('invitere',),
'invitert': ('invitere',),
'inviterte': ('invitere',),
'involverende': ('involvere',),
'involvert': ('involvere',),
'involverte': ('involvere',),
'ioniserende': ('ionisere',),
'ionisert': ('ionisere',),
'ioniserte': ('ionisere',),
'ionogen': ('ionogen',),
'ionogene': ('ionogen',),
'ionogenere': ('ionogen',),
'ionogenest': ('ionogen',),
'ionogeneste': ('ionogen',),
'ionogent': ('ionogen',),
'ionosfærisk': ('ionosfærisk',),
'ionosfæriske': ('ionosfærisk',),
'ionosfæriskere': ('ionosfærisk',),
'ionosfæriskest': ('ionosfærisk',),
'ionosfæriskeste': ('ionosfærisk',),
'irakisk': ('irakisk',),
'irakiske': ('irakisk',),
'irakiskere': ('irakisk',),
'irakiskest': ('irakisk',),
'irakiskeste': ('irakisk',),
'iraksk': ('iraksk',),
'irakske': ('iraksk',),
'irakskere': ('iraksk',),
'irakskest': ('iraksk',),
'irakskeste': ('iraksk',),
'iransk': ('iransk',),
'iranske': ('iransk',),
'iranskere': ('iransk',),
'iranskest': ('iransk',),
'iranskeste': ('iransk',),
'irettesatt': ('irettesette',),
'irettesatte': ('irettesette',),
'irettesettende': ('irettesette',),
'iriserende': ('irisere',),
'irisert': ('irisere',),
'iriserte': ('irisere',),
'irokesisk': ('irokesisk',),
'irokesiske': ('irokesisk',),
'irokesiskere': ('irokesisk',),
'irokesiskest': ('irokesisk',),
'irokesiskeste': ('irokesisk',),
'ironiserende': ('ironisere',),
'ironisert': ('ironisere',),
'ironiserte': ('ironisere',),
'ironisk': ('ironisk',),
'ironiske': ('ironisk',),
'ironiskere': ('ironisk',),
'ironiskest': ('ironisk',),
'ironiskeste': ('ironisk',),
'irrasjonal': ('irrasjonal',),
'irrasjonale': ('irrasjonal',),
'irrasjonalere': ('irrasjonal',),
'irrasjonalest': ('irrasjonal',),
'irrasjonaleste': ('irrasjonal',),
'irrasjonalt': ('irrasjonal',),
'irrasjonell': ('irrasjonell',),
'irrasjonelle': ('irrasjonell',),
'irrasjonellere': ('irrasjonell',),
'irrasjonellest': ('irrasjonell',),
'irrasjonelleste': ('irrasjonell',),
'irrasjonelt': ('irrasjonell',),
'irra': ('irre',),
'irrede': ('irre',),
'irrende': ('irre',),
'irret': ('irre',),
'irrete': ('irre',),
'irra': ('irre',),
'irrede': ('irre',),
'irrende': ('irre',),
'irret': ('irre',),
'irrete': ('irre',),
'irreal': ('irreal',),
'irreale': ('irreal',),
'irrealere': ('irreal',),
'irrealest': ('irreal',),
'irrealeste': ('irreal',),
'irrealt': ('irreal',),
'irreell': ('irreell',),
'irreelle': ('irreell',),
'irreellere': ('irreell',),
'irreellest': ('irreell',),
'irreelleste': ('irreell',),
'irreelt': ('irreell',),
'irreligiøs': ('irreligiøs',),
'irreligiøse': ('irreligiøs',),
'irreligiøsere': ('irreligiøs',),
'irreligiøsest': ('irreligiøs',),
'irreligiøseste': ('irreligiøs',),
'irreligiøst': ('irreligiøs',),
'irreparabel': ('irreparabel',),
'irreparabelt': ('irreparabel',),
'irreparable': ('irreparabel',),
'irreparablere': ('irreparabel',),
'irreparablest': ('irreparabel',),
'irreparableste': ('irreparabel',),
'irret': ('irret',),
'irrete': ('irret',),
'irretere': ('irret',),
'irretest': ('irret',),
'irreteste': ('irret',),
'irrete': ('irrete',),
'irreversibel': ('irreversibel',),
'irreversibelt': ('irreversibel',),
'irreversible': ('irreversibel',),
'irreversiblere': ('irreversibel',),
'irreversiblest': ('irreversibel',),
'irreversibleste': ('irreversibel',),
'irrgrøn': ('irrgrøn',),
'irrgrøne': ('irrgrøn',),
'irrgrønere': ('irrgrøn',),
'irrgrønest': ('irrgrøn',),
'irrgrøneste': ('irrgrøn',),
'irrgrønt': ('irrgrøn',),
'irrgrønn': ('irrgrønn',),
'irrgrønne': ('irrgrønn',),
'irrgrønnere': ('irrgrønn',),
'irrgrønnest': ('irrgrønn',),
'irrgrønneste': ('irrgrønn',),
'irrgrønt': ('irrgrønn',),
'irrigerende': ('irrigere',),
'irrigert': ('irrigere',),
'irrigerte': ('irrigere',),
'irritabel': ('irritabel',),
'irritabelt': ('irritabel',),
'irritable': ('irritabel',),
'irritablere': ('irritabel',),
'irritablest': ('irritabel',),
'irritableste': ('irritabel',),
'irriterende': ('irritere',),
'irritert': ('irritere',),
'irriterte': ('irritere',),
'irsk': ('irsk',),
'irske': ('irsk',),
'irskere': ('irsk',),
'irskest': ('irsk',),
'irskeste': ('irsk',),
'isblå': ('isblå',),
'isblåe': ('isblå',),
'isblåere': ('isblå',),
'isblåest': ('isblå',),
'isblåeste': ('isblå',),
'isblått': ('isblå',),
'iscenesatt': ('iscenesette',),
'iscenesatte': ('iscenesette',),
'iscenesettende': ('iscenesette',),
'isa': ('ise',),
'isede': ('ise',),
'isende': ('ise',),
'iset': ('ise',),
'isete': ('ise',),
'ist': ('ise',),
'iste': ('ise',),
'isende': ('isende',),
'iset': ('iset',),
'isete': ('iset',),
'isetere': ('iset',),
'isetest': ('iset',),
'iseteste': ('iset',),
'isete': ('isete',),
'isgrønn': ('isgrønn',),
'isgrønne': ('isgrønn',),
'isgrønnere': ('isgrønn',),
'isgrønnest': ('isgrønn',),
'isgrønneste': ('isgrønn',),
'isgrønt': ('isgrønn',),
'isgående': ('isgående',),
'iskald': ('iskald',),
'iskalde': ('iskald',),
'iskaldere': ('iskald',),
'iskaldest': ('iskald',),
'iskaldeste': ('iskald',),
'iskaldt': ('iskald',),
'islagt': ('islagt',),
'islagte': ('islagt',),
'islagtere': ('islagt',),
'islagtest': ('islagt',),
'islagteste': ('islagt',),
'islamiserende': ('islamisere',),
'islamisert': ('islamisere',),
'islamiserte': ('islamisere',),
'islamittisk': ('islamittisk',),
'islamittiske': ('islamittisk',),
'islamittiskere': ('islamittisk',),
'islamittiskest': ('islamittisk',),
'islamittiskeste': ('islamittisk',),
'islamsk': ('islamsk',),
'islamske': ('islamsk',),
'islamskere': ('islamsk',),
'islamskest': ('islamsk',),
'islamskeste': ('islamsk',),
'islandsk': ('islandsk',),
'islandske': ('islandsk',),
'islandskere': ('islandsk',),
'islandskest': ('islandsk',),
'islandskeste': ('islandsk',),
'isna': ('isne',),
'isnede': ('isne',),
'isnende': ('isne',),
'isnet': ('isne',),
'isnete': ('isne',),
'isokron': ('isokron',),
'isokrone': ('isokron',),
'isokronere': ('isokron',),
'isokronest': ('isokron',),
'isokroneste': ('isokron',),
'isokront': ('isokron',),
'isolasjonistisk': ('isolasjonistisk',),
'isolasjonistiske': ('isolasjonistisk',),
'isolasjonistiskere': ('isolasjonistisk',),
'isolasjonistiskest': ('isolasjonistisk',),
'isolasjonistiskeste': ('isolasjonistisk',),
'isolerende': ('isolere',),
'isolert': ('isolere',),
'isolerte': ('isolere',),
'isometrisk': ('isometrisk',),
'isometriske': ('isometrisk',),
'isometriskere': ('isometrisk',),
'isometriskest': ('isometrisk',),
'isometriskeste': ('isometrisk',),
'isomorf': ('isomorf',),
'isomorfe': ('isomorf',),
'isomorfere': ('isomorf',),
'isomorfest': ('isomorf',),
'isomorfeste': ('isomorf',),
'isomorft': ('isomorf',),
'isoterm': ('isoterm',),
'isoterme': ('isoterm',),
'isotermere': ('isoterm',),
'isotermest': ('isoterm',),
'isotermeste': ('isoterm',),
'isotermt': ('isoterm',),
'isotermisk': ('isotermisk',),
'isotermiske': ('isotermisk',),
'isotermiskere': ('isotermisk',),
'isotermiskest': ('isotermisk',),
'isotermiskeste': ('isotermisk',),
'isotonisk': ('isotonisk',),
'isotoniske': ('isotonisk',),
'isotoniskere': ('isotonisk',),
'isotoniskest': ('isotonisk',),
'isotoniskeste': ('isotonisk',),
'isotop': ('isotop',),
'isotope': ('isotop',),
'isotopere': ('isotop',),
'isotopest': ('isotop',),
'isotopeste': ('isotop',),
'isotopt': ('isotop',),
'isotopisk': ('isotopisk',),
'isotopiske': ('isotopisk',),
'isotopiskere': ('isotopisk',),
'isotopiskest': ('isotopisk',),
'isotopiskeste': ('isotopisk',),
'isotrop': ('isotrop',),
'isotrope': ('isotrop',),
'isotropere': ('isotrop',),
'isotropest': ('isotrop',),
'isotropeste': ('isotrop',),
'isotropt': ('isotrop',),
'ispedd': ('ispe',),
'ispedde': ('ispe',),
'ispeende': ('ispe',),
'isprengt': ('isprengt',),
'isprengte': ('isprengt',),
'isprengtere': ('isprengt',),
'isprengtest': ('isprengt',),
'isprengteste': ('isprengt',),
'israelittisk': ('israelittisk',),
'israelittiske': ('israelittisk',),
'israelittiskere': ('israelittisk',),
'israelittiskest': ('israelittisk',),
'israelittiskeste': ('israelittisk',),
'israelsk': ('israelsk',),
'israelske': ('israelsk',),
'israelskere': ('israelsk',),
'israelskest': ('israelsk',),
'israelskeste': ('israelsk',),
'istandsatt': ('istandsatt',),
'istandsatte': ('istandsatt',),
'istandsattere': ('istandsatt',),
'istandsattest': ('istandsatt',),
'istandsatteste': ('istandsatt',),
'istemmende': ('istemme',),
'istemt': ('istemme',),
'istemte': ('istemme',),
'istykkerslått': ('istykkerslått',),
'istykkerslåtte': ('istykkerslått',),
'istykkerslåttere': ('istykkerslått',),
'istykkerslåttest': ('istykkerslått',),
'istykkerslåtteste': ('istykkerslått',),
'italiensk': ('italiensk',),
'italienske': ('italiensk',),
'italienskere': ('italiensk',),
'italienskest': ('italiensk',),
'italienskeste': ('italiensk',),
'italisk': ('italisk',),
'italiske': ('italisk',),
'italiskere': ('italisk',),
'italiskest': ('italisk',),
'italiskeste': ('italisk',),
'iterativ': ('iterativ',),
'iterative': ('iterativ',),
'iterativere': ('iterativ',),
'iterativest': ('iterativ',),
'iterativeste': ('iterativ',),
'iterativt': ('iterativ',),
'itererende': ('iterere',),
'iterert': ('iterere',),
'itererte': ('iterere',),
'ivaretakende': ('ivareta',),
'ivaretatt': ('ivareta',),
'ivaretatte': ('ivareta',),
'iverksatt': ('iverksette',),
'iverksatte': ('iverksette',),
'iverksettende': ('iverksette',),
'ivoriansk': ('ivoriansk',),
'ivorianske': ('ivoriansk',),
'ivorianskere': ('ivoriansk',),
'ivorianskest': ('ivoriansk',),
'ivorianskeste': ('ivoriansk',),
'ivra': ('ivre',),
'ivrede': ('ivre',),
'ivrende': ('ivre',),
'ivret': ('ivre',),
'ivrete': ('ivre',),
'ivrig': ('ivrig',),
'ivrige': ('ivrig',),
'ivrigere': ('ivrig',),
'ivrigst': ('ivrig',),
'ivrigste': ('ivrig',),
'iørefallende': ('iørefallende',),
'iøynefallende': ('iøynefallende',),
'jabba': ('jabbe',),
'jabbede': ('jabbe',),
'jabbende': ('jabbe',),
'jabbet': ('jabbe',),
'jabbete': ('jabbe',),
'jabba': ('jabbe',),
'jabbede': ('jabbe',),
'jabbende': ('jabbe',),
'jabbet': ('jabbe',),
'jabbete': ('jabbe',),
'jafsa': ('jafse',),
'jafsede': ('jafse',),
'jafsende': ('jafse',),
'jafset': ('jafse',),
'jafsete': ('jafse',),
'jaga': ('jage',),
'jagd': ('jage',),
'jagde': ('jage',),
'jagede': ('jage',),
'jagende': ('jage',),
'jaget': ('jage',),
'jagete': ('jage',),
'jaktbar': ('jaktbar',),
'jaktbare': ('jaktbar',),
'jaktbarere': ('jaktbar',),
'jaktbarest': ('jaktbar',),
'jaktbareste': ('jaktbar',),
'jaktbart': ('jaktbar',),
'jakta': ('jakte',),
'jaktede': ('jakte',),
'jaktende': ('jakte',),
'jaktet': ('jakte',),
'jaktete': ('jakte',),
'jakutisk': ('jakutisk',),
'jakutiske': ('jakutisk',),
'jakutiskere': ('jakutisk',),
'jakutiskest': ('jakutisk',),
'jakutiskeste': ('jakutisk',),
'jalma': ('jalme',),
'jalmede': ('jalme',),
'jalmende': ('jalme',),
'jalmet': ('jalme',),
'jalmete': ('jalme',),
'jamaicansk': ('jamaicansk',),
'jamaicanske': ('jamaicansk',),
'jamaicanskere': ('jamaicansk',),
'jamaicanskest': ('jamaicansk',),
'jamaicanskeste': ('jamaicansk',),
'jamaicansk': ('jamaicansk',),
'jamaicanske': ('jamaicansk',),
'jamaicanskere': ('jamaicansk',),
'jamaicanskest': ('jamaicansk',),
'jamaicanskeste': ('jamaicansk',),
'jamaikansk': ('jamaikansk',),
'jamaikanske': ('jamaikansk',),
'jamaikanskere': ('jamaikansk',),
'jamaikanskest': ('jamaikansk',),
'jamaikanskeste': ('jamaikansk',),
'jamaikansk': ('jamaikansk',),
'jamaikanske': ('jamaikansk',),
'jamaikanskere': ('jamaikansk',),
'jamaikanskest': ('jamaikansk',),
'jamaikanskeste': ('jamaikansk',),
'jamaldra': ('jamaldra',),
'jamaldrede': ('jamaldret',),
'jamaldret': ('jamaldret',),
'jamaldrete': ('jamaldret',),
'jamaldretere': ('jamaldret',),
'jamaldretest': ('jamaldret',),
'jamaldreteste': ('jamaldret',),
'jambisk': ('jambisk',),
'jambiske': ('jambisk',),
'jambiskere': ('jambisk',),
'jambiskest': ('jambisk',),
'jambiskeste': ('jambisk',),
'jambyrdig': ('jambyrdig',),
'jambyrdige': ('jambyrdig',),
'jambyrdigere': ('jambyrdig',),
'jambyrdigst': ('jambyrdig',),
'jambyrdigste': ('jambyrdig',),
'jamførende': ('jamføre',),
'jamført': ('jamføre',),
'jamførte': ('jamføre',),
'jameldre': ('jamgammel',),
'jameldst': ('jamgammel',),
'jameldste': ('jamgammel',),
'jamgamle': ('jamgammel',),
'jamgammel': ('jamgammel',),
'jamgammelt': ('jamgammel',),
'jambedre': ('jamgod',),
'jambest': ('jamgod',),
'jambeste': ('jamgod',),
'jamgod': ('jamgod',),
'jamgode': ('jamgod',),
'jamgodt': ('jamgod',),
'jamlang': ('jamlang',),
'jamlange': ('jamlang',),
'jamlangt': ('jamlang',),
'jamlenger': ('jamlang',),
'jamlengre': ('jamlang',),
'jamlengst': ('jamlang',),
'jamlengste': ('jamlang',),
'jamlik': ('jamlik',),
'jamlike': ('jamlik',),
'jamlikere': ('jamlik',),
'jamlikest': ('jamlik',),
'jamlikeste': ('jamlik',),
'jamlikt': ('jamlik',),
'jamma': ('jamme',),
'jammede': ('jamme',),
'jammende': ('jamme',),
'jammet': ('jamme',),
'jammete': ('jamme',),
'jamma': ('jamme',),
'jammede': ('jamme',),
'jammende': ('jamme',),
'jammet': ('jamme',),
'jammete': ('jamme',),
'jammerlig': ('jammerlig',),
'jammerlige': ('jammerlig',),
'jammerligere': ('jammerlig',),
'jammerligst': ('jammerlig',),
'jammerligste': ('jammerlig',),
'jamn': ('jamn',),
'jamne': ('jamn',),
'jamnere': ('jamn',),
'jamnest': ('jamn',),
'jamneste': ('jamn',),
'jamt': ('jamn',),
'jamna': ('jamne',),
'jamnede': ('jamne',),
'jamnende': ('jamne',),
'jamnet': ('jamne',),
'jamnete': ('jamne',),
'jamra': ('jamre',),
'jamrede': ('jamre',),
'jamrende': ('jamre',),
'jamret': ('jamre',),
'jamrete': ('jamre',),
'jamspelt': ('jamspelt',),
'jamspelte': ('jamspelt',),
'jamspeltere': ('jamspelt',),
'jamspeltest': ('jamspelt',),
'jamspelteste': ('jamspelt',),
'jamspilt': ('jamspilt',),
'jamspilte': ('jamspilt',),
'jamspiltere': ('jamspilt',),
'jamspiltest': ('jamspilt',),
'jamspilteste': ('jamspilt',),
'jamsterk': ('jamsterk',),
'jamsterke': ('jamsterk',),
'jamsterkere': ('jamsterk',),
'jamsterkest': ('jamsterk',),
'jamsterkeste': ('jamsterk',),
'jamsterkt': ('jamsterk',),
'jamstillende': ('jamstille',),
'jamstilt': ('jamstille',),
'jamstilte': ('jamstille',),
'jamstor': ('jamstor',),
'jamstore': ('jamstor',),
'jamstort': ('jamstor',),
'jamstørre': ('jamstor',),
'jamstørst': ('jamstor',),
'jamstørste': ('jamstor',),
'jamtjukk': ('jamtjukk',),
'jamtjukke': ('jamtjukk',),
'jamtjukkere': ('jamtjukk',),
'jamtjukkest': ('jamtjukk',),
'jamtjukkeste': ('jamtjukk',),
'jamtjukt': ('jamtjukk',),
'jamtykk': ('jamtykk',),
'jamtykke': ('jamtykk',),
'jamtykkere': ('jamtykk',),
'jamtykkest': ('jamtykk',),
'jamtykkeste': ('jamtykk',),
'jamtykt': ('jamtykk',),
'japansk': ('japansk',),
'japanske': ('japansk',),
'japanskere': ('japansk',),
'japanskest': ('japansk',),
'japanskeste': ('japansk',),
'jara': ('jare',),
'jarede': ('jare',),
'jarende': ('jare',),
'jaret': ('jare',),
'jarete': ('jare',),
'jaska': ('jaske',),
'jaskede': ('jaske',),
'jaskende': ('jaske',),
'jasket': ('jaske',),
'jaskete': ('jaske',),
'jasket': ('jasket',),
'jaskete': ('jasket',),
'jasketere': ('jasket',),
'jasketest': ('jasket',),
'jasketeste': ('jasket',),
'jaskete': ('jaskete',),
'jassa': ('jasse',),
'jassede': ('jasse',),
'jassende': ('jasse',),
'jasset': ('jasse',),
'jassete': ('jasse',),
'jassifiserende': ('jassifisere',),
'jassifisert': ('jassifisere',),
'jassifiserte': ('jassifisere',),
'jatta': ('jatte',),
'jattede': ('jatte',),
'jattende': ('jatte',),
'jattet': ('jatte',),
'jattete': ('jatte',),
'jattet': ('jattet',),
'jattete': ('jattet',),
'jattetere': ('jattet',),
'jattetest': ('jattet',),
'jatteteste': ('jattet',),
'jattete': ('jattete',),
'javanesisk': ('javanesisk',),
'javanesiske': ('javanesisk',),
'javanesiskere': ('javanesisk',),
'javanesiskest': ('javanesisk',),
'javanesiskeste': ('javanesisk',),
'jazza': ('jazze',),
'jazzede': ('jazze',),
'jazzende': ('jazze',),
'jazzet': ('jazze',),
'jazzete': ('jazze',),
'jazzifiserende': ('jazzifisere',),
'jazzifisert': ('jazzifisere',),
'jazzifiserte': ('jazzifisere',),
'jekka': ('jekke',),
'jekkede': ('jekke',),
'jekkende': ('jekke',),
'jekket': ('jekke',),
'jekkete': ('jekke',),
'jelka': ('jelke',),
'jelkede': ('jelke',),
'jelkende': ('jelke',),
'jelket': ('jelke',),
'jelkete': ('jelke',),
'jemenittisk': ('jemenittisk',),
'jemenittiske': ('jemenittisk',),
'jemenittiskere': ('jemenittisk',),
'jemenittiskest': ('jemenittisk',),
'jemenittiskeste': ('jemenittisk',),
'jemenittisk': ('jemenittisk',),
'jemenittiske': ('jemenittisk',),
'jemenittiskere': ('jemenittisk',),
'jemenittiskest': ('jemenittisk',),
'jemenittiskeste': ('jemenittisk',),
'jenka': ('jenke',),
'jenkede': ('jenke',),
'jenkende': ('jenke',),
'jenket': ('jenke',),
'jenkete': ('jenke',),
'jentegalen': ('jentegalen',),
'jentegalent': ('jentegalen',),
'jentegalne': ('jentegalen',),
'jentegalnere': ('jentegalen',),
'jentegalnest': ('jentegalen',),
'jentegalneste': ('jentegalen',),
'jernfattig': ('jernfattig',),
'jernfattige': ('jernfattig',),
'jernfattigere': ('jernfattig',),
'jernfattigst': ('jernfattig',),
'jernfattigste': ('jernfattig',),
'jernførende': ('jernførende',),
'jernhard': ('jernhard',),
'jernharde': ('jernhard',),
'jernhardere': ('jernhard',),
'jernhardest': ('jernhard',),
'jernhardeste': ('jernhard',),
'jernhardt': ('jernhard',),
'jernholdig': ('jernholdig',),
'jernholdige': ('jernholdig',),
'jernholdigere': ('jernholdig',),
'jernholdigst': ('jernholdig',),
'jernholdigste': ('jernholdig',),
'jesuittisk': ('jesuittisk',),
'jesuittiske': ('jesuittisk',),
'jesuittiskere': ('jesuittisk',),
'jesuittiskest': ('jesuittisk',),
'jesuittiskeste': ('jesuittisk',),
'jetdrevet': ('jetdrevet',),
'jetdrevne': ('jetdrevet',),
'jetdrevnere': ('jetdrevet',),
'jetdrevnest': ('jetdrevet',),
'jetdrevneste': ('jetdrevet',),
'jettesterk': ('jettesterk',),
'jettesterke': ('jettesterk',),
'jettesterkere': ('jettesterk',),
'jettesterkest': ('jettesterk',),
'jettesterkeste': ('jettesterk',),
'jettesterkt': ('jettesterk',),
'jettestor': ('jettestor',),
'jettestore': ('jettestor',),
'jettestort': ('jettestor',),
'jettestørre': ('jettestor',),
'jettestørst': ('jettestor',),
'jettestørste': ('jettestor',),
'jevn': ('jevn',),
'jevne': ('jevn',),
'jevnere': ('jevn',),
'jevnest': ('jevn',),
'jevneste': ('jevn',),
'jevnt': ('jevn',),
'jevnaldrende': ('jevnaldrende',),
'jevnbyrdig': ('jevnbyrdig',),
'jevnbyrdige': ('jevnbyrdig',),
'jevnbyrdigere': ('jevnbyrdig',),
'jevnbyrdigst': ('jevnbyrdig',),
'jevnbyrdigste': ('jevnbyrdig',),
'jevna': ('jevne',),
'jevnede': ('jevne',),
'jevnende': ('jevne',),
'jevnet': ('jevne',),
'jevnete': ('jevne',),
'jevnførende': ('jevnføre',),
'jevnført': ('jevnføre',),
'jevnførte': ('jevnføre',),
'jevneldre': ('jevngammel',),
'jevneldst': ('jevngammel',),
'jevneldste': ('jevngammel',),
'jevngamle': ('jevngammel',),
'jevngammel': ('jevngammel',),
'jevngammelt': ('jevngammel',),
'jevnbedre': ('jevngod',),
'jevnbest': ('jevngod',),
'jevnbeste': ('jevngod',),
'jevngod': ('jevngod',),
'jevngode': ('jevngod',),
'jevngodt': ('jevngod',),
'jevnlang': ('jevnlang',),
'jevnlange': ('jevnlang',),
'jevnlangt': ('jevnlang',),
'jevnlenger': ('jevnlang',),
'jevnlengre': ('jevnlang',),
'jevnlengst': ('jevnlang',),
'jevnlengste': ('jevnlang',),
'jevnlik': ('jevnlik',),
'jevnlike': ('jevnlik',),
'jevnlikere': ('jevnlik',),
'jevnlikest': ('jevnlik',),
'jevnlikeste': ('jevnlik',),
'jevnlikt': ('jevnlik',),
'jevnspelt': ('jevnspelt',),
'jevnspelte': ('jevnspelt',),
'jevnspeltere': ('jevnspelt',),
'jevnspeltest': ('jevnspelt',),
'jevnspelteste': ('jevnspelt',),
'jevnspilt': ('jevnspilt',),
'jevnspilte': ('jevnspilt',),
'jevnspiltere': ('jevnspilt',),
'jevnspiltest': ('jevnspilt',),
'jevnspilteste': ('jevnspilt',),
'jevnsterk': ('jevnsterk',),
'jevnsterke': ('jevnsterk',),
'jevnsterkere': ('jevnsterk',),
'jevnsterkest': ('jevnsterk',),
'jevnsterkeste': ('jevnsterk',),
'jevnsterkt': ('jevnsterk',),
'jevnstor': ('jevnstor',),
'jevnstore': ('jevnstor',),
'jevnstort': ('jevnstor',),
'jevnstørre': ('jevnstor',),
'jevnstørst': ('jevnstor',),
'jevnstørste': ('jevnstor',),
'jevntjukk': ('jevntjukk',),
'jevntjukke': ('jevntjukk',),
'jevntjukkere': ('jevntjukk',),
'jevntjukkest': ('jevntjukk',),
'jevntjukkeste': ('jevntjukk',),
'jevntjukt': ('jevntjukk',),
'jevntykk': ('jevntykk',),
'jevntykke': ('jevntykk',),
'jevntykkere': ('jevntykk',),
'jevntykkest': ('jevntykk',),
'jevntykkeste': ('jevntykk',),
'jevntykt': ('jevntykk',),
'jibba': ('jibbe',),
'jibbede': ('jibbe',),
'jibbende': ('jibbe',),
'jibbet': ('jibbe',),
'jibbete': ('jibbe',),
'jiddisch': ('jiddisch',),
'jiddische': ('jiddisch',),
'jiddischere': ('jiddisch',),
'jiddischest': ('jiddisch',),
'jiddischeste': ('jiddisch',),
'jiddisk': ('jiddisk',),
'jiddiske': ('jiddisk',),
'jiddiskere': ('jiddisk',),
'jiddiskest': ('jiddisk',),
'jiddiskeste': ('jiddisk',),
'jobba': ('jobbe',),
'jobbede': ('jobbe',),
'jobbende': ('jobbe',),
'jobbet': ('jobbe',),
'jobbete': ('jobbe',),
'joderende': ('jodere',),
'jodert': ('jodere',),
'joderte': ('jodere',),
'jodiserende': ('jodisere',),
'jodisert': ('jodisere',),
'jodiserte': ('jodisere',),
'jodla': ('jodle',),
'jodlede': ('jodle',),
'jodlende': ('jodle',),
'jodlet': ('jodle',),
'jodlete': ('jodle',),
'jogga': ('jogge',),
'joggede': ('jogge',),
'joggende': ('jogge',),
'jogget': ('jogge',),
'joggete': ('jogge',),
'joika': ('joike',),
'joikede': ('joike',),
'joikende': ('joike',),
'joiket': ('joike',),
'joikete': ('joike',),
'jomfruelig': ('jomfruelig',),
'jomfruelige': ('jomfruelig',),
'jomfrueligere': ('jomfruelig',),
'jomfrueligst': ('jomfruelig',),
'jomfrueligste': ('jomfruelig',),
'jomfrunalsk': ('jomfrunalsk',),
'jomfrunalske': ('jomfrunalsk',),
'jomfrunalskere': ('jomfrunalsk',),
'jomfrunalskest': ('jomfrunalsk',),
'jomfrunalskeste': ('jomfrunalsk',),
'jonisk': ('jonisk',),
'joniske': ('jonisk',),
'joniskere': ('jonisk',),
'joniskest': ('jonisk',),
'joniskeste': ('jonisk',),
'jordansk': ('jordansk',),
'jordanske': ('jordansk',),
'jordanskere': ('jordansk',),
'jordanskest': ('jordansk',),
'jordanskeste': ('jordansk',),
'jordbunden': ('jordbunden',),
'jordbundet': ('jordbunden',),
'jordbundne': ('jordbunden',),
'jordbundnere': ('jordbunden',),
'jordbundnest': ('jordbunden',),
'jordbundneste': ('jordbunden',),
'jordbundet': ('jordbundet',),
'jordbundne': ('jordbundet',),
'jordbundnere': ('jordbundet',),
'jordbundnest': ('jordbundet',),
'jordbundneste': ('jordbundet',),
'jorda': ('jorde',),
'jordede': ('jorde',),
'jordende': ('jorde',),
'jordet': ('jorde',),
'jordete': ('jorde',),
'jordet': ('jordet',),
'jordete': ('jordet',),
'jordetere': ('jordet',),
'jordetest': ('jordet',),
'jordeteste': ('jordet',),
'jordete': ('jordete',),
'jordfast': ('jordfast',),
'jordfaste': ('jordfast',),
'jordfastere': ('jordfast',),
'jordfastest': ('jordfast',),
'jordfasteste': ('jordfast',),
'jordfesta': ('jordfeste',),
'jordfestede': ('jordfeste',),
'jordfestende': ('jordfeste',),
'jordfestet': ('jordfeste',),
'jordfestete': ('jordfeste',),
'jordisk': ('jordisk',),
'jordiske': ('jordisk',),
'jordiskere': ('jordisk',),
'jordiskest': ('jordisk',),
'jordiskeste': ('jordisk',),
'jordnær': ('jordnær',),
'jordnære': ('jordnær',),
'jordnærere': ('jordnær',),
'jordnærest': ('jordnær',),
'jordnæreste': ('jordnær',),
'jordnært': ('jordnær',),
'jordskjelvsikker': ('jordskjelvsikker',),
'jordskjelvsikkert': ('jordskjelvsikker',),
'jordskjelvsikre': ('jordskjelvsikker',),
'jordskjelvsikrere': ('jordskjelvsikker',),
'jordskjelvsikrest': ('jordskjelvsikker',),
'jordskjelvsikreste': ('jordskjelvsikker',),
'jordslående': ('jordslå',),
'jordslått': ('jordslå',),
'jordslåtte': ('jordslå',),
'jordslått': ('jordslått',),
'jordslåtte': ('jordslått',),
'jordslåttere': ('jordslått',),
'jordslåttest': ('jordslått',),
'jordslåtteste': ('jordslått',),
'jorta': ('jorte',),
'jortede': ('jorte',),
'jortende': ('jorte',),
'jortet': ('jorte',),
'jortete': ('jorte',),
'jourhavende': ('jourhavende',),
'journalførende': ('journalføre',),
'journalført': ('journalføre',),
'journalførte': ('journalføre',),
'journaliserende': ('journalisere',),
'journalisert': ('journalisere',),
'journaliserte': ('journalisere',),
'journalistisk': ('journalistisk',),
'journalistiske': ('journalistisk',),
'journalistiskere': ('journalistisk',),
'journalistiskest': ('journalistisk',),
'journalistiskeste': ('journalistisk',),
'jovial': ('jovial',),
'joviale': ('jovial',),
'jovialere': ('jovial',),
'jovialest': ('jovial',),
'jovialeste': ('jovial',),
'jovialt': ('jovial',),
'jubilerende': ('jubilere',),
'jubilert': ('jubilere',),
'jubilerte': ('jubilere',),
'jubla': ('juble',),
'jublede': ('juble',),
'jublende': ('juble',),
'jublet': ('juble',),
'jublete': ('juble',),
'judeisk': ('judeisk',),
'judeiske': ('judeisk',),
'judeiskere': ('judeisk',),
'judeiskest': ('judeisk',),
'judeiskeste': ('judeisk',),
'judisiell': ('judisiell',),
'judisielle': ('judisiell',),
'judisiellere': ('judisiell',),
'judisiellest': ('judisiell',),
'judisielleste': ('judisiell',),
'judisielt': ('judisiell',),
'jugla': ('jugle',),
'juglede': ('jugle',),
'juglende': ('jugle',),
'juglet': ('jugle',),
'juglete': ('jugle',),
'juglet': ('juglet',),
'juglete': ('juglet',),
'jugletere': ('juglet',),
'jugletest': ('juglet',),
'jugleteste': ('juglet',),
'juglete': ('juglete',),
'jugoslavisk': ('jugoslavisk',),
'jugoslaviske': ('jugoslavisk',),
'jugoslaviskere': ('jugoslavisk',),
'jugoslaviskest': ('jugoslavisk',),
'jugoslaviskeste': ('jugoslavisk',),
'juksa': ('jukse',),
'juksede': ('jukse',),
'juksende': ('jukse',),
'jukset': ('jukse',),
'juksete': ('jukse',),
'juksa': ('jukse',),
'juksede': ('jukse',),
'juksende': ('jukse',),
'jukset': ('jukse',),
'juksete': ('jukse',),
'julende': ('jule',),
'jult': ('jule',),
'julte': ('jule',),
'juliansk': ('juliansk',),
'julianske': ('juliansk',),
'julianskere': ('juliansk',),
'julianskest': ('juliansk',),
'julianskeste': ('juliansk',),
'jumpa': ('jumpe',),
'jumpede': ('jumpe',),
'jumpende': ('jumpe',),
'jumpet': ('jumpe',),
'jumpete': ('jumpe',),
'junior': ('junior',),
'junka': ('junke',),
'junkede': ('junke',),
'junkende': ('junke',),
'junket': ('junke',),
'junkete': ('junke',),
'junonisk': ('junonisk',),
'junoniske': ('junonisk',),
'junoniskere': ('junonisk',),
'junoniskest': ('junonisk',),
'junoniskeste': ('junonisk',),
'juraisk': ('juraisk',),
'juraiske': ('juraisk',),
'juraiskere': ('juraisk',),
'juraiskest': ('juraisk',),
'juraiskeste': ('juraisk',),
'juridisk': ('juridisk',),
'juridiske': ('juridisk',),
'juridiskere': ('juridisk',),
'juridiskest': ('juridisk',),
'juridiskeste': ('juridisk',),
'juryerende': ('juryere',),
'juryert': ('juryere',),
'juryerte': ('juryere',),
'justerbar': ('justerbar',),
'justerbare': ('justerbar',),
'justerbarere': ('justerbar',),
'justerbarest': ('justerbar',),
'justerbareste': ('justerbar',),
'justerbart': ('justerbar',),
'justerende': ('justere',),
'justert': ('justere',),
'justerte': ('justere',),
'justitiell': ('justitiell',),
'justitielle': ('justitiell',),
'justitiellere': ('justitiell',),
'justitiellest': ('justitiell',),
'justitielleste': ('justitiell',),
'justitielt': ('justitiell',),
'jyllandsk': ('jyllandsk',),
'jyllandske': ('jyllandsk',),
'jyllandskere': ('jyllandsk',),
'jyllandskest': ('jyllandsk',),
'jyllandskeste': ('jyllandsk',),
'jysk': ('jysk',),
'jyske': ('jysk',),
'jyskere': ('jysk',),
'jyskest': ('jysk',),
'jyskeste': ('jysk',),
'jåla': ('jåle',),
'jålede': ('jåle',),
'jålende': ('jåle',),
'jålet': ('jåle',),
'jålete': ('jåle',),
'jålt': ('jåle',),
'jålte': ('jåle',),
'jålet': ('jålet',),
'jålete': ('jålet',),
'jåletere': ('jålet',),
'jåletest': ('jålet',),
'jåleteste': ('jålet',),
'jålete': ('jålete',),
'jækla': ('jækla',),
'jæklig': ('jæklig',),
'jæklige': ('jæklig',),
'jækligere': ('jæklig',),
'jækligst': ('jæklig',),
'jækligste': ('jæklig',),
'jærsk': ('jærsk',),
'jærske': ('jærsk',),
'jærskere': ('jærsk',),
'jærskest': ('jærsk',),
'jærskeste': ('jærsk',),
'jævla': ('jævla',),
'jævlig': ('jævlig',),
'jævlige': ('jævlig',),
'jævligere': ('jævlig',),
'jævligst': ('jævlig',),
'jævligste': ('jævlig',),
'jødekristen': ('jødekristen',),
'jødekristent': ('jødekristen',),
'jødekristne': ('jødekristen',),
'jødekristnere': ('jødekristen',),
'jødekristnest': ('jødekristen',),
'jødekristneste': ('jødekristen',),
'jødisk': ('jødisk',),
'jødiske': ('jødisk',),
'jødiskere': ('jødisk',),
'jødiskest': ('jødisk',),
'jødiskeste': ('jødisk',),
'jøya': ('jøye',),
'jøyede': ('jøye',),
'jøyende': ('jøye',),
'jøyet': ('jøye',),
'jøyete': ('jøye',),
'kabbalistisk': ('kabbalistisk',),
'kabbalistiske': ('kabbalistisk',),
'kabbalistiskere': ('kabbalistisk',),
'kabbalistiskest': ('kabbalistisk',),
'kabbalistiskeste': ('kabbalistisk',),
'kabba': ('kabbe',),
'kabbede': ('kabbe',),
'kabbende': ('kabbe',),
'kabbet': ('kabbe',),
'kabbete': ('kabbe',),
'kabylsk': ('kabylsk',),
'kabylske': ('kabylsk',),
'kabylskere': ('kabylsk',),
'kabylskest': ('kabylsk',),
'kabylskeste': ('kabylsk',),
'kadmierende': ('kadmiere',),
'kadmiert': ('kadmiere',),
'kadmierte': ('kadmiere',),
'kadreia': ('kadreie',),
'kadreid': ('kadreie',),
'kadreidd': ('kadreie',),
'kadreidde': ('kadreie',),
'kadreide': ('kadreie',),
'kadreiede': ('kadreie',),
'kadreiende': ('kadreie',),
'kadreiet': ('kadreie',),
'kadreiete': ('kadreie',),
'kaka': ('kake',),
'kakede': ('kake',),
'kakende': ('kake',),
'kaket': ('kake',),
'kakete': ('kake',),
'kakka': ('kakke',),
'kakkede': ('kakke',),
'kakkende': ('kakke',),
'kakket': ('kakke',),
'kakkete': ('kakke',),
'kakla': ('kakle',),
'kaklede': ('kakle',),
'kaklende': ('kakle',),
'kaklet': ('kakle',),
'kaklete': ('kakle',),
'kakofon': ('kakofon',),
'kakofone': ('kakofon',),
'kakofonere': ('kakofon',),
'kakofonest': ('kakofon',),
'kakofoneste': ('kakofon',),
'kakofont': ('kakofon',),
'kakofonisk': ('kakofonisk',),
'kakofoniske': ('kakofonisk',),
'kakofoniskere': ('kakofonisk',),
'kakofoniskest': ('kakofonisk',),
'kakofoniskeste': ('kakofonisk',),
'kakstrykende': ('kakstryke',),
'kakstrøken': ('kakstryke',),
'kakstrøket': ('kakstryke',),
'kakstrøkne': ('kakstryke',),
'kakuminal': ('kakuminal',),
'kakuminale': ('kakuminal',),
'kakuminalere': ('kakuminal',),
'kakuminalest': ('kakuminal',),
'kakuminaleste': ('kakuminal',),
'kakuminalt': ('kakuminal',),
'kakuminaliserende': ('kakuminalisere',),
'kakuminalisert': ('kakuminalisere',),
'kakuminaliserte': ('kakuminalisere',),
'kalandrerende': ('kalandrere',),
'kalandrert': ('kalandrere',),
'kalandrerte': ('kalandrere',),
'kald': ('kald',),
'kalde': ('kald',),
'kaldere': ('kald',),
'kaldest': ('kald',),
'kaldeste': ('kald',),
'kaldt': ('kald',),
'kaldblodig': ('kaldblodig',),
'kaldblodige': ('kaldblodig',),
'kaldblodigere': ('kaldblodig',),
'kaldblodigst': ('kaldblodig',),
'kaldblodigste': ('kaldblodig',),
'kaldeisk': ('kaldeisk',),
'kaldeiske': ('kaldeisk',),
'kaldeiskere': ('kaldeisk',),
'kaldeiskest': ('kaldeisk',),
'kaldeiskeste': ('kaldeisk',),
'kaldflirende': ('kaldflire',),
'kaldflirt': ('kaldflire',),
'kaldflirte': ('kaldflire',),
'kaldrøyka': ('kaldrøyke',),
'kaldrøykede': ('kaldrøyke',),
'kaldrøykende': ('kaldrøyke',),
'kaldrøyket': ('kaldrøyke',),
'kaldrøykete': ('kaldrøyke',),
'kaldrøykt': ('kaldrøyke',),
'kaldrøykte': ('kaldrøyke',),
'kaldskjør': ('kaldskjør',),
'kaldskjøre': ('kaldskjør',),
'kaldskjørere': ('kaldskjør',),
'kaldskjørest': ('kaldskjør',),
'kaldskjøreste': ('kaldskjør',),
'kaldskjørt': ('kaldskjør',),
'kaldskratta': ('kaldskratte',),
'kaldskrattede': ('kaldskratte',),
'kaldskrattende': ('kaldskratte',),
'kaldskrattet': ('kaldskratte',),
'kaldskrattete': ('kaldskratte',),
'kaldslig': ('kaldslig',),
'kaldslige': ('kaldslig',),
'kaldsligere': ('kaldslig',),
'kaldsligst': ('kaldslig',),
'kaldsligste': ('kaldslig',),
'kaldsmidd': ('kaldsmi',),
'kaldsmidde': ('kaldsmi',),
'kaldsmiende': ('kaldsmi',),
'kaldsvetta': ('kaldsvette',),
'kaldsvettede': ('kaldsvette',),
'kaldsvettende': ('kaldsvette',),
'kaldsvettet': ('kaldsvette',),
'kaldsvettete': ('kaldsvette',),
'kaldsvetta': ('kaldsvette',),
'kaldsvettede': ('kaldsvette',),
'kaldsvettende': ('kaldsvette',),
'kaldsvettet': ('kaldsvette',),
'kaldsvettete': ('kaldsvette',),
'kaledonsk': ('kaledonsk',),
'kaledonske': ('kaledonsk',),
'kaledonskere': ('kaledonsk',),
'kaledonskest': ('kaledonsk',),
'kaledonskeste': ('kaledonsk',),
'kaleidoskopisk': ('kaleidoskopisk',),
'kaleidoskopiske': ('kaleidoskopisk',),
'kaleidoskopiskere': ('kaleidoskopisk',),
'kaleidoskopiskest': ('kaleidoskopisk',),
'kaleidoskopiskeste': ('kaleidoskopisk',),
'kalfatra': ('kalfatre',),
'kalfatrede': ('kalfatre',),
'kalfatrende': ('kalfatre',),
'kalfatret': ('kalfatre',),
'kalfatrete': ('kalfatre',),
'kalibrerende': ('kalibrere',),
'kalibrert': ('kalibrere',),
'kalibrerte': ('kalibrere',),
'kalifornisk': ('kalifornisk',),
'kaliforniske': ('kalifornisk',),
'kaliforniskere': ('kalifornisk',),
'kaliforniskest': ('kalifornisk',),
'kaliforniskeste': ('kalifornisk',),
'kalka': ('kalke',),
'kalkede': ('kalke',),
'kalkende': ('kalke',),
'kalket': ('kalke',),
'kalkete': ('kalke',),
'kalkerende': ('kalkere',),
'kalkert': ('kalkere',),
'kalkerte': ('kalkere',),
'kalkholdig': ('kalkholdig',),
'kalkholdige': ('kalkholdig',),
'kalkholdigere': ('kalkholdig',),
'kalkholdigst': ('kalkholdig',),
'kalkholdigste': ('kalkholdig',),
'kalkulatorisk': ('kalkulatorisk',),
'kalkulatoriske': ('kalkulatorisk',),
'kalkulatoriskere': ('kalkulatorisk',),
'kalkulatoriskest': ('kalkulatorisk',),
'kalkulatoriskeste': ('kalkulatorisk',),
'kalkulerende': ('kalkulere',),
'kalkulert': ('kalkulere',),
'kalkulerte': ('kalkulere',),
'kalkunsk': ('kalkunsk',),
'kalkunske': ('kalkunsk',),
'kalkunskere': ('kalkunsk',),
'kalkunskest': ('kalkunsk',),
'kalkunskeste': ('kalkunsk',),
'kallende': ('kalle',),
'kalt': ('kalle',),
'kalte': ('kalle',),
'kalligraferende': ('kalligrafere',),
'kalligrafert': ('kalligrafere',),
'kalligraferte': ('kalligrafere',),
'kalligrafisk': ('kalligrafisk',),
'kalligrafiske': ('kalligrafisk',),
'kalligrafiskere': ('kalligrafisk',),
'kalligrafiskest': ('kalligrafisk',),
'kalligrafiskeste': ('kalligrafisk',),
'kalmukkisk': ('kalmukkisk',),
'kalmukkiske': ('kalmukkisk',),
'kalmukkiskere': ('kalmukkisk',),
'kalmukkiskest': ('kalmukkisk',),
'kalmukkiskeste': ('kalmukkisk',),
'kalorifattig': ('kalorifattig',),
'kalorifattige': ('kalorifattig',),
'kalorifattigere': ('kalorifattig',),
'kalorifattigst': ('kalorifattig',),
'kalorifattigste': ('kalorifattig',),
'kalsinerende': ('kalsinere',),
'kalsinert': ('kalsinere',),
'kalsinerte': ('kalsinere',),
'kalvbeint': ('kalvbeint',),
'kalvbeinte': ('kalvbeint',),
'kalvbeintere': ('kalvbeint',),
'kalvbeintest': ('kalvbeint',),
'kalvbeinteste': ('kalvbeint',),
'kalvbent': ('kalvbent',),
'kalvbente': ('kalvbent',),
'kalvbentere': ('kalvbent',),
'kalvbentest': ('kalvbent',),
'kalvbenteste': ('kalvbent',),
'kalvdiger': ('kalvdiger',),
'kalvdigert': ('kalvdiger',),
'kalvdigre': ('kalvdiger',),
'kalvdigrere': ('kalvdiger',),
'kalvdigrest': ('kalvdiger',),
'kalvdigreste': ('kalvdiger',),
'kalva': ('kalve',),
'kalvede': ('kalve',),
'kalvende': ('kalve',),
'kalvet': ('kalve',),
'kalvete': ('kalve',),
'kalvet': ('kalvet',),
'kalvete': ('kalvet',),
'kalvetere': ('kalvet',),
'kalvetest': ('kalvet',),
'kalveteste': ('kalvet',),
'kalvete': ('kalvete',),
'kalvinistisk': ('kalvinistisk',),
'kalvinistiske': ('kalvinistisk',),
'kalvinistiskere': ('kalvinistisk',),
'kalvinistiskest': ('kalvinistisk',),
'kalvinistiskeste': ('kalvinistisk',),
'kalvinsk': ('kalvinsk',),
'kalvinske': ('kalvinsk',),
'kalvinskere': ('kalvinsk',),
'kalvinskest': ('kalvinsk',),
'kalvinskeste': ('kalvinsk',),
'kambial': ('kambial',),
'kambiale': ('kambial',),
'kambialere': ('kambial',),
'kambialest': ('kambial',),
'kambialeste': ('kambial',),
'kambialt': ('kambial',),
'kambodsjansk': ('kambodsjansk',),
'kambodsjanske': ('kambodsjansk',),
'kambodsjanskere': ('kambodsjansk',),
'kambodsjanskest': ('kambodsjansk',),
'kambodsjanskeste': ('kambodsjansk',),
'kambrisk': ('kambrisk',),
'kambriske': ('kambrisk',),
'kambriskere': ('kambrisk',),
'kambriskest': ('kambrisk',),
'kambriskeste': ('kambrisk',),
'kameleonaktig': ('kameleonaktig',),
'kameleonaktige': ('kameleonaktig',),
'kameleonaktigere': ('kameleonaktig',),
'kameleonaktigst': ('kameleonaktig',),
'kameleonaktigste': ('kameleonaktig',),
'kameratslig': ('kameratslig',),
'kameratslige': ('kameratslig',),
'kameratsligere': ('kameratslig',),
'kameratsligst': ('kameratslig',),
'kameratsligste': ('kameratslig',),
'kamerunsk': ('kamerunsk',),
'kamerunske': ('kamerunsk',),
'kamerunskere': ('kamerunsk',),
'kamerunskest': ('kamerunsk',),
'kamerunskeste': ('kamerunsk',),
'kamma': ('kamme',),
'kammede': ('kamme',),
'kammende': ('kamme',),
'kammet': ('kamme',),
'kammete': ('kamme',),
'kampdyktig': ('kampdyktig',),
'kampdyktige': ('kampdyktig',),
'kampdyktigere': ('kampdyktig',),
'kampdyktigst': ('kampdyktig',),
'kampdyktigste': ('kampdyktig',),
'kamperende': ('kampere',),
'kampert': ('kampere',),
'kamperte': ('kampere',),
'kamplysten': ('kamplysten',),
'kamplystent': ('kamplysten',),
'kamplystne': ('kamplysten',),
'kamplystnere': ('kamplysten',),
'kamplystnest': ('kamplysten',),
'kamplystneste': ('kamplysten',),
'kampudyktig': ('kampudyktig',),
'kampudyktige': ('kampudyktig',),
'kampudyktigere': ('kampudyktig',),
'kampudyktigst': ('kampudyktig',),
'kampudyktigste': ('kampudyktig',),
'kamsa': ('kamse',),
'kamsede': ('kamse',),
'kamsende': ('kamse',),
'kamset': ('kamse',),
'kamsete': ('kamse',),
'kamuflerende': ('kamuflere',),
'kamuflert': ('kamuflere',),
'kamuflerte': ('kamuflere',),
'kanaaneisk': ('kanaaneisk',),
'kanaaneiske': ('kanaaneisk',),
'kanaaneiskere': ('kanaaneisk',),
'kanaaneiskest': ('kanaaneisk',),
'kanaaneiskeste': ('kanaaneisk',),
'kanaanittisk': ('kanaanittisk',),
'kanaanittiske': ('kanaanittisk',),
'kanaanittiskere': ('kanaanittisk',),
'kanaanittiskest': ('kanaanittisk',),
'kanaanittiskeste': ('kanaanittisk',),
'kanadisk': ('kanadisk',),
'kanadiske': ('kanadisk',),
'kanadiskere': ('kanadisk',),
'kanadiskest': ('kanadisk',),
'kanadiskeste': ('kanadisk',),
'kanaliserende': ('kanalisere',),
'kanalisert': ('kanalisere',),
'kanaliserte': ('kanalisere',),
'kanarisk': ('kanarisk',),
'kanariske': ('kanarisk',),
'kanariskere': ('kanarisk',),
'kanariskest': ('kanarisk',),
'kanariskeste': ('kanarisk',),
'kandiderende': ('kandidere',),
'kandidert': ('kandidere',),
'kandiderte': ('kandidere',),
'kandiserende': ('kandisere',),
'kandisert': ('kandisere',),
'kandiserte': ('kandisere',),
'kannelerende': ('kannelere',),
'kannelert': ('kannelere',),
'kannelerte': ('kannelere',),
'kannibalsk': ('kannibalsk',),
'kannibalske': ('kannibalsk',),
'kannibalskere': ('kannibalsk',),
'kannibalskest': ('kannibalsk',),
'kannibalskeste': ('kannibalsk',),
'kanoniserende': ('kanonisere',),
'kanonisert': ('kanonisere',),
'kanoniserte': ('kanonisere',),
'kanonisk': ('kanonisk',),
'kanoniske': ('kanonisk',),
'kanoniskere': ('kanonisk',),
'kanoniskest': ('kanonisk',),
'kanoniskeste': ('kanonisk',),
'kansellerende': ('kansellere',),
'kansellert': ('kansellere',),
'kansellerte': ('kansellere',),
'kanta': ('kante',),
'kantede': ('kante',),
'kantende': ('kante',),
'kantet': ('kante',),
'kantete': ('kante',),
'kantet': ('kantet',),
'kantete': ('kantet',),
'kantetere': ('kantet',),
'kantetest': ('kantet',),
'kanteteste': ('kantet',),
'kantete': ('kantete',),
'kantra': ('kantre',),
'kantrede': ('kantre',),
'kantrende': ('kantre',),
'kantret': ('kantre',),
'kantrete': ('kantre',),
'kaotisk': ('kaotisk',),
'kaotiske': ('kaotisk',),
'kaotiskere': ('kaotisk',),
'kaotiskest': ('kaotisk',),
'kaotiskeste': ('kaotisk',),
'kapabel': ('kapabel',),
'kapabelt': ('kapabel',),
'kapable': ('kapabel',),
'kapablere': ('kapabel',),
'kapablest': ('kapabel',),
'kapableste': ('kapabel',),
'kapillær': ('kapillær',),
'kapillære': ('kapillær',),
'kapillærere': ('kapillær',),
'kapillærest': ('kapillær',),
'kapillæreste': ('kapillær',),
'kapillært': ('kapillær',),
'kapital': ('kapital',),
'kapitale': ('kapital',),
'kapitalere': ('kapital',),
'kapitalest': ('kapital',),
'kapitaleste': ('kapital',),
'kapitalt': ('kapital',),
'kapitalintensiv': ('kapitalintensiv',),
'kapitalintensive': ('kapitalintensiv',),
'kapitalintensivere': ('kapitalintensiv',),
'kapitalintensivest': ('kapitalintensiv',),
'kapitalintensiveste': ('kapitalintensiv',),
'kapitalintensivt': ('kapitalintensiv',),
'kapitaliserende': ('kapitalisere',),
'kapitalisert': ('kapitalisere',),
'kapitaliserte': ('kapitalisere',),
'kapitalistisk': ('kapitalistisk',),
'kapitalistiske': ('kapitalistisk',),
'kapitalistiskere': ('kapitalistisk',),
'kapitalistiskest': ('kapitalistisk',),
'kapitalistiskeste': ('kapitalistisk',),
'kapitalkrevende': ('kapitalkrevende',),
'kapitulerende': ('kapitulere',),
'kapitulert': ('kapitulere',),
'kapitulerte': ('kapitulere',),
'kappdrikkende': ('kappdrikke',),
'kappdrukken': ('kappdrikke',),
'kappdrukket': ('kappdrikke',),
'kappdrukne': ('kappdrikke',),
'kappa': ('kappe',),
'kappede': ('kappe',),
'kappende': ('kappe',),
'kappet': ('kappe',),
'kappete': ('kappe',),
'kappekledd': ('kappekledd',),
'kappekledde': ('kappekledd',),
'kappekleddere': ('kappekledd',),
'kappekleddest': ('kappekledd',),
'kappekleddeste': ('kappekledd',),
'kappkjørende': ('kappkjøre',),
'kappkjørt': ('kappkjøre',),
'kappkjørte': ('kappkjøre',),
'kappverdisk': ('kappverdisk',),
'kappverdiske': ('kappverdisk',),
'kappverdiskere': ('kappverdisk',),
'kappverdiskest': ('kappverdisk',),
'kappverdiskeste': ('kappverdisk',),
'kapra': ('kapre',),
'kaprede': ('kapre',),
'kaprende': ('kapre',),
'kapret': ('kapre',),
'kaprete': ('kapre',),
'kaprisiøs': ('kaprisiøs',),
'kaprisiøse': ('kaprisiøs',),
'kaprisiøsere': ('kaprisiøs',),
'kaprisiøsest': ('kaprisiøs',),
'kaprisiøseste': ('kaprisiøs',),
'kaprisiøst': ('kaprisiøs',),
'kapseisende': ('kapseise',),
'kapseist': ('kapseise',),
'kapseiste': ('kapseise',),
'kapsla': ('kapsle',),
'kapslede': ('kapsle',),
'kapslende': ('kapsle',),
'kapslet': ('kapsle',),
'kapslete': ('kapsle',),
'kapunerende': ('kapunere',),
'kapunert': ('kapunere',),
'kapunerte': ('kapunere',),
'kaputt': ('kaputt',),
'karakterdannende': ('karakterdannende',),
'karakterfast': ('karakterfast',),
'karakterfaste': ('karakterfast',),
'karakterfastere': ('karakterfast',),
'karakterfastest': ('karakterfast',),
'karakterfasteste': ('karakterfast',),
'karakteriserende': ('karakterisere',),
'karakterisert': ('karakterisere',),
'karakteriserte': ('karakterisere',),
'karakteristisk': ('karakteristisk',),
'karakteristiske': ('karakteristisk',),
'karakteristiskere': ('karakteristisk',),
'karakteristiskest': ('karakteristisk',),
'karakteristiskeste': ('karakteristisk',),
'karakterlaus': ('karakterlaus',),
'karakterlause': ('karakterlaus',),
'karakterlausere': ('karakterlaus',),
'karakterlausest': ('karakterlaus',),
'karakterlauseste': ('karakterlaus',),
'karakterlaust': ('karakterlaus',),
'karakterløs': ('karakterløs',),
'karakterløse': ('karakterløs',),
'karakterløsere': ('karakterløs',),
'karakterløsest': ('karakterløs',),
'karakterløseste': ('karakterløs',),
'karakterløst': ('karakterløs',),
'kardansk': ('kardansk',),
'kardanske': ('kardansk',),
'kardanskere': ('kardansk',),
'kardanskest': ('kardansk',),
'kardanskeste': ('kardansk',),
'karda': ('karde',),
'kardede': ('karde',),
'kardende': ('karde',),
'kardet': ('karde',),
'kardete': ('karde',),
'kara': ('kare',),
'karede': ('kare',),
'karende': ('kare',),
'karet': ('kare',),
'karete': ('kare',),
'karelsk': ('karelsk',),
'karelske': ('karelsk',),
'karelskere': ('karelsk',),
'karelskest': ('karelsk',),
'karelskeste': ('karelsk',),
'karibisk': ('karibisk',),
'karibiske': ('karibisk',),
'karibiskere': ('karibisk',),
'karibiskest': ('karibisk',),
'karibiskeste': ('karibisk',),
'karikerende': ('karikere',),
'karikert': ('karikere',),
'karikerte': ('karikere',),
'karismatisk': ('karismatisk',),
'karismatiske': ('karismatisk',),
'karismatiskere': ('karismatisk',),
'karismatiskest': ('karismatisk',),
'karismatiskeste': ('karismatisk',),
'kariøs': ('kariøs',),
'kariøse': ('kariøs',),
'kariøsere': ('kariøs',),
'kariøsest': ('kariøs',),
'kariøseste': ('kariøs',),
'kariøst': ('kariøs',),
'karminrød': ('karminrød',),
'karminrøde': ('karminrød',),
'karminrødere': ('karminrød',),
'karminrødest': ('karminrød',),
'karminrødeste': ('karminrød',),
'karminrødt': ('karminrød',),
'karnøfla': ('karnøfle',),
'karnøflede': ('karnøfle',),
'karnøflende': ('karnøfle',),
'karnøflet': ('karnøfle',),
'karnøflete': ('karnøfle',),
'karolingisk': ('karolingisk',),
'karolingiske': ('karolingisk',),
'karolingiskere': ('karolingisk',),
'karolingiskest': ('karolingisk',),
'karolingiskeste': ('karolingisk',),
'karolinsk': ('karolinsk',),
'karolinske': ('karolinsk',),
'karolinskere': ('karolinsk',),
'karolinskest': ('karolinsk',),
'karolinskeste': ('karolinsk',),
'karrig': ('karrig',),
'karrige': ('karrig',),
'karrigere': ('karrig',),
'karrigst': ('karrig',),
'karrigste': ('karrig',),
'karsk': ('karsk',),
'karske': ('karsk',),
'karskere': ('karsk',),
'karskest': ('karsk',),
'karskeste': ('karsk',),
'karskt': ('karsk',),
'karslig': ('karslig',),
'karslige': ('karslig',),
'karsligere': ('karslig',),
'karsligst': ('karslig',),
'karsligste': ('karslig',),
'karta': ('karte',),
'kartede': ('karte',),
'kartende': ('karte',),
'kartet': ('karte',),
'kartete': ('karte',),
'karterende': ('kartere',),
'kartert': ('kartere',),
'karterte': ('kartere',),
'kartesiansk': ('kartesiansk',),
'kartesianske': ('kartesiansk',),
'kartesianskere': ('kartesiansk',),
'kartesianskest': ('kartesiansk',),
'kartesianskeste': ('kartesiansk',),
'kartesisk': ('kartesisk',),
'kartesiske': ('kartesisk',),
'kartesiskere': ('kartesisk',),
'kartesiskest': ('kartesisk',),
'kartesiskeste': ('kartesisk',),
'kartlagt': ('kartlegge',),
'kartlagte': ('kartlegge',),
'kartleggende': ('kartlegge',),
'kartonerende': ('kartonere',),
'kartonert': ('kartonere',),
'kartonerte': ('kartonere',),
'karva': ('karve',),
'karvede': ('karve',),
'karvende': ('karve',),
'karvet': ('karve',),
'karvete': ('karve',),
'kasakhisk': ('kasakhisk',),
'kasakhiske': ('kasakhisk',),
'kasakhiskere': ('kasakhisk',),
'kasakhiskest': ('kasakhisk',),
'kasakhiskeste': ('kasakhisk',),
'kasa': ('kase',),
'kasede': ('kase',),
'kasende': ('kase',),
'kaset': ('kase',),
'kasete': ('kase',),
'kasjmirsk': ('kasjmirsk',),
'kasjmirske': ('kasjmirsk',),
'kasjmirskere': ('kasjmirsk',),
'kasjmirskest': ('kasjmirsk',),
'kasjmirskeste': ('kasjmirsk',),
'kassabel': ('kassabel',),
'kassabelt': ('kassabel',),
'kassable': ('kassabel',),
'kassablere': ('kassabel',),
'kassablest': ('kassabel',),
'kassableste': ('kassabel',),
'kasserende': ('kassere',),
'kassert': ('kassere',),
'kasserte': ('kassere',),
'kasserende': ('kassere',),
'kassert': ('kassere',),
'kasserte': ('kassere',),
'kastanjebrun': ('kastanjebrun',),
'kastanjebrune': ('kastanjebrun',),
'kastanjebrunere': ('kastanjebrun',),
'kastanjebrunest': ('kastanjebrun',),
'kastanjebruneste': ('kastanjebrun',),
'kastanjebrunt': ('kastanjebrun',),
'kasta': ('kaste',),
'kastede': ('kaste',),
'kastende': ('kaste',),
'kastet': ('kaste',),
'kastete': ('kaste',),
'kastebytta': ('kastebytte',),
'kastebyttede': ('kastebytte',),
'kastebyttende': ('kastebytte',),
'kastebyttet': ('kastebytte',),
'kastebyttete': ('kastebytte',),
'kastelaus': ('kastelaus',),
'kastelause': ('kastelaus',),
'kastelausere': ('kastelaus',),
'kastelausest': ('kastelaus',),
'kastelauseste': ('kastelaus',),
'kastelaust': ('kastelaus',),
'kasteløs': ('kasteløs',),
'kasteløse': ('kasteløs',),
'kasteløsere': ('kasteløs',),
'kasteløsest': ('kasteløs',),
'kasteløseste': ('kasteløs',),
'kasteløst': ('kasteløs',),
'kastiljansk': ('kastiljansk',),
'kastiljanske': ('kastiljansk',),
'kastiljanskere': ('kastiljansk',),
'kastiljanskest': ('kastiljansk',),
'kastiljanskeste': ('kastiljansk',),
'kastrerende': ('kastrere',),
'kastrert': ('kastrere',),
'kastrerte': ('kastrere',),
'kasuistisk': ('kasuistisk',),
'kasuistiske': ('kasuistisk',),
'kasuistiskere': ('kasuistisk',),
'kasuistiskest': ('kasuistisk',),
'kasuistiskeste': ('kasuistisk',),
'katalansk': ('katalansk',),
'katalanske': ('katalansk',),
'katalanskere': ('katalansk',),
'katalanskest': ('katalansk',),
'katalanskeste': ('katalansk',),
'katalogiserende': ('katalogisere',),
'katalogisert': ('katalogisere',),
'katalogiserte': ('katalogisere',),
'katalyserende': ('katalysere',),
'katalysert': ('katalysere',),
'katalyserte': ('katalysere',),
'katalytisk': ('katalytisk',),
'katalytiske': ('katalytisk',),
'katalytiskere': ('katalytisk',),
'katalytiskest': ('katalytisk',),
'katalytiskeste': ('katalytisk',),
'katarralsk': ('katarralsk',),
'katarralske': ('katarralsk',),
'katarralskere': ('katarralsk',),
'katarralskest': ('katarralsk',),
'katarralskeste': ('katarralsk',),
'katastrofal': ('katastrofal',),
'katastrofale': ('katastrofal',),
'katastrofalere': ('katastrofal',),
'katastrofalest': ('katastrofal',),
'katastrofaleste': ('katastrofal',),
'katastrofalt': ('katastrofal',),
'katataktisk': ('katataktisk',),
'katataktiske': ('katataktisk',),
'katataktiskere': ('katataktisk',),
'katataktiskest': ('katataktisk',),
'katataktiskeste': ('katataktisk',),
'kategoriserende': ('kategorisere',),
'kategorisert': ('kategorisere',),
'kategoriserte': ('kategorisere',),
'kategorisk': ('kategorisk',),
'kategoriske': ('kategorisk',),
'kategoriskere': ('kategorisk',),
'kategoriskest': ('kategorisk',),
'kategoriskeste': ('kategorisk',),
'kateketisk': ('kateketisk',),
'kateketiske': ('kateketisk',),
'kateketiskere': ('kateketisk',),
'kateketiskest': ('kateketisk',),
'kateketiskeste': ('kateketisk',),
'katekiserende': ('katekisere',),
'katekisert': ('katekisere',),
'katekiserte': ('katekisere',),
'katoliserende': ('katolisere',),
'katolisert': ('katolisere',),
'katoliserte': ('katolisere',),
'katolsk': ('katolsk',),
'katolske': ('katolsk',),
'katolskere': ('katolsk',),
'katolskest': ('katolsk',),
'katolskeste': ('katolsk',),
'kattaktig': ('kattaktig',),
'kattaktige': ('kattaktig',),
'kattaktigere': ('kattaktig',),
'kattaktigst': ('kattaktig',),
'kattaktigste': ('kattaktig',),
'katta': ('katte',),
'kattede': ('katte',),
'kattende': ('katte',),
'kattet': ('katte',),
'kattete': ('katte',),
'katteaktig': ('katteaktig',),
'katteaktige': ('katteaktig',),
'katteaktigere': ('katteaktig',),
'katteaktigst': ('katteaktig',),
'katteaktigste': ('katteaktig',),
'kattemjuk': ('kattemjuk',),
'kattemjuke': ('kattemjuk',),
'kattemjukere': ('kattemjuk',),
'kattemjukest': ('kattemjuk',),
'kattemjukeste': ('kattemjuk',),
'kattemjukt': ('kattemjuk',),
'kattemyk': ('kattemyk',),
'kattemyke': ('kattemyk',),
'kattemykere': ('kattemyk',),
'kattemykest': ('kattemyk',),
'kattemykeste': ('kattemyk',),
'kattemykt': ('kattemyk',),
'kaua': ('kaue',),
'kauede': ('kaue',),
'kauende': ('kaue',),
'kauet': ('kaue',),
'kauete': ('kaue',),
'kaukasisk': ('kaukasisk',),
'kaukasiske': ('kaukasisk',),
'kaukasiskere': ('kaukasisk',),
'kaukasiskest': ('kaukasisk',),
'kaukasiskeste': ('kaukasisk',),
'kaukasoid': ('kaukasoid',),
'kaukasoide': ('kaukasoid',),
'kaukasoidere': ('kaukasoid',),
'kaukasoidest': ('kaukasoid',),
'kaukasoideste': ('kaukasoid',),
'kauka': ('kauke',),
'kaukede': ('kauke',),
'kaukende': ('kauke',),
'kauket': ('kauke',),
'kaukete': ('kauke',),
'kausal': ('kausal',),
'kausale': ('kausal',),
'kausalere': ('kausal',),
'kausalest': ('kausal',),
'kausaleste': ('kausal',),
'kausalt': ('kausal',),
'kausativ': ('kausativ',),
'kausative': ('kausativ',),
'kausativere': ('kausativ',),
'kausativest': ('kausativ',),
'kausativeste': ('kausativ',),
'kausativt': ('kausativ',),
'kausjonerende': ('kausjonere',),
'kausjonert': ('kausjonere',),
'kausjonerte': ('kausjonere',),
'kaustisk': ('kaustisk',),
'kaustiske': ('kaustisk',),
'kaustiskere': ('kaustisk',),
'kaustiskest': ('kaustisk',),
'kaustiskeste': ('kaustisk',),
'kaut': ('kaut',),
'kaute': ('kaut',),
'kautere': ('kaut',),
'kautest': ('kaut',),
'kauteste': ('kaut',),
'kava': ('kave',),
'kavd': ('kave',),
'kavde': ('kave',),
'kavede': ('kave',),
'kavende': ('kave',),
'kavet': ('kave',),
'kavete': ('kave',),
'kaverende': ('kavere',),
'kavert': ('kavere',),
'kaverte': ('kavere',),
'kavernøs': ('kavernøs',),
'kavernøse': ('kavernøs',),
'kavernøsere': ('kavernøs',),
'kavernøsest': ('kavernøs',),
'kavernøseste': ('kavernøs',),
'kavernøst': ('kavernøs',),
'kavla': ('kavle',),
'kavlede': ('kavle',),
'kavlende': ('kavle',),
'kavlet': ('kavle',),
'kavlete': ('kavle',),
'kavla': ('kavle',),
'kavlede': ('kavle',),
'kavlende': ('kavle',),
'kavlet': ('kavle',),
'kavlete': ('kavle',),
'kavlet': ('kavlet',),
'kavlete': ('kavlet',),
'kavletere': ('kavlet',),
'kavletest': ('kavlet',),
'kavleteste': ('kavlet',),
'kavlete': ('kavlete',),
'keia': ('keie',),
'keiede': ('keie',),
'keiende': ('keie',),
'keiet': ('keie',),
'keiete': ('keie',),
'keik': ('keik',),
'keike': ('keik',),
'keikere': ('keik',),
'keikest': ('keik',),
'keikeste': ('keik',),
'keikt': ('keik',),
'keika': ('keike',),
'keikede': ('keike',),
'keikende': ('keike',),
'keiket': ('keike',),
'keikete': ('keike',),
'keikt': ('keike',),
'keikte': ('keike',),
'keiket': ('keiket',),
'keikete': ('keiket',),
'keiketere': ('keiket',),
'keiketest': ('keiket',),
'keiketeste': ('keiket',),
'keikete': ('keikete',),
'keisam': ('keisam',),
'keisamme': ('keisam',),
'keisammere': ('keisam',),
'keisamst': ('keisam',),
'keisamste': ('keisam',),
'keisamt': ('keisam',),
'keiserlig': ('keiserlig',),
'keiserlige': ('keiserlig',),
'keiserligere': ('keiserlig',),
'keiserligst': ('keiserlig',),
'keiserligste': ('keiserlig',),
'keisom': ('keisom',),
'keisomme': ('keisom',),
'keisommere': ('keisom',),
'keisomst': ('keisom',),
'keisomste': ('keisom',),
'keisomt': ('keisom',),
'keitet': ('keitet',),
'keitete': ('keitet',),
'keitetere': ('keitet',),
'keitetest': ('keitet',),
'keiteteste': ('keitet',),
'keitete': ('keitete',),
'keiv': ('keiv',),
'keive': ('keiv',),
'keivere': ('keiv',),
'keivest': ('keiv',),
'keiveste': ('keiv',),
'keivt': ('keiv',),
'keivelig': ('keivelig',),
'keivelige': ('keivelig',),
'keiveligere': ('keivelig',),
'keiveligst': ('keivelig',),
'keiveligste': ('keivelig',),
'keiven': ('keiven',),
'keivent': ('keiven',),
'keivne': ('keiven',),
'keivnere': ('keiven',),
'keivnest': ('keiven',),
'keivneste': ('keiven',),
'keivet': ('keivet',),
'keivete': ('keivet',),
'keivetere': ('keivet',),
'keivetest': ('keivet',),
'keiveteste': ('keivet',),
'keivete': ('keivete',),
'keivhendt': ('keivhendt',),
'keivhendte': ('keivhendt',),
'keivhendtere': ('keivhendt',),
'keivhendtest': ('keivhendt',),
'keivhendteste': ('keivhendt',),
'keivla': ('keivle',),
'keivlede': ('keivle',),
'keivlende': ('keivle',),
'keivlet': ('keivle',),
'keivlete': ('keivle',),
'keltisk': ('keltisk',),
'keltiske': ('keltisk',),
'keltiskere': ('keltisk',),
'keltiskest': ('keltisk',),
'keltiskeste': ('keltisk',),
'kenyansk': ('kenyansk',),
'kenyanske': ('kenyansk',),
'kenyanskere': ('kenyansk',),
'kenyanskest': ('kenyansk',),
'kenyanskeste': ('kenyansk',),
'keramisk': ('keramisk',),
'keramiske': ('keramisk',),
'keramiskere': ('keramisk',),
'keramiskest': ('keramisk',),
'keramiskeste': ('keramisk',),
'kibba': ('kibbe',),
'kibbede': ('kibbe',),
'kibbende': ('kibbe',),
'kibbet': ('kibbe',),
'kibbete': ('kibbe',),
'kidnappa': ('kidnappe',),
'kidnappede': ('kidnappe',),
'kidnappende': ('kidnappe',),
'kidnappet': ('kidnappe',),
'kidnappete': ('kidnappe',),
'kika': ('kike',),
'kikede': ('kike',),
'kikende': ('kike',),
'kiket': ('kike',),
'kikete': ('kike',),
'kikende': ('kike',),
'kikt': ('kike',),
'kikte': ('kike',),
'kikka': ('kikke',),
'kikkede': ('kikke',),
'kikkende': ('kikke',),
'kikket': ('kikke',),
'kikkete': ('kikke',),
'kikka': ('kikke',),
'kikkede': ('kikke',),
'kikkende': ('kikke',),
'kikket': ('kikke',),
'kikkete': ('kikke',),
'kikna': ('kikne',),
'kiknede': ('kikne',),
'kiknende': ('kikne',),
'kiknet': ('kikne',),
'kiknete': ('kikne',),
'kikra': ('kikre',),
'kikrede': ('kikre',),
'kikrende': ('kikre',),
'kikret': ('kikre',),
'kikrete': ('kikre',),
'kiksa': ('kikse',),
'kiksede': ('kikse',),
'kiksende': ('kikse',),
'kikset': ('kikse',),
'kiksete': ('kikse',),
'kilden': ('kilden',),
'kildent': ('kilden',),
'kildne': ('kilden',),
'kildnere': ('kilden',),
'kildnest': ('kilden',),
'kildneste': ('kilden',),
'kildra': ('kildre',),
'kildrede': ('kildre',),
'kildrende': ('kildre',),
'kildret': ('kildre',),
'kildrete': ('kildre',),
'kilende': ('kile',),
'kilt': ('kile',),
'kilte': ('kile',),
'kilende': ('kile',),
'kilt': ('kile',),
'kilte': ('kile',),
'kilen': ('kilen',),
'kilent': ('kilen',),
'kilne': ('kilen',),
'kilnere': ('kilen',),
'kilnest': ('kilen',),
'kilneste': ('kilen',),
'kimbrisk': ('kimbrisk',),
'kimbriske': ('kimbrisk',),
'kimbriskere': ('kimbrisk',),
'kimbriskest': ('kimbrisk',),
'kimbriskeste': ('kimbrisk',),
'kima': ('kime',),
'kimede': ('kime',),
'kimende': ('kime',),
'kimet': ('kime',),
'kimete': ('kime',),
'kimt': ('kime',),
'kimte': ('kime',),
'kimsa': ('kimse',),
'kimsede': ('kimse',),
'kimsende': ('kimse',),
'kimset': ('kimse',),
'kimsete': ('kimse',),
'kinesisk': ('kinesisk',),
'kinesiske': ('kinesisk',),
'kinesiskere': ('kinesisk',),
'kinesiskest': ('kinesisk',),
'kinesiskeste': ('kinesisk',),
'kinestetisk': ('kinestetisk',),
'kinestetiske': ('kinestetisk',),
'kinestetiskere': ('kinestetisk',),
'kinestetiskest': ('kinestetisk',),
'kinestetiskeste': ('kinestetisk',),
'kinetisk': ('kinetisk',),
'kinetiske': ('kinetisk',),
'kinetiskere': ('kinetisk',),
'kinetiskest': ('kinetisk',),
'kinetiskeste': ('kinetisk',),
'kingsa': ('kingse',),
'kingsede': ('kingse',),
'kingsende': ('kingse',),
'kingset': ('kingse',),
'kingsete': ('kingse',),
'kinka': ('kinke',),
'kinkede': ('kinke',),
'kinkende': ('kinke',),
'kinket': ('kinke',),
'kinkete': ('kinke',),
'kinkig': ('kinkig',),
'kinkige': ('kinkig',),
'kinkigere': ('kinkig',),
'kinkigst': ('kinkig',),
'kinkigste': ('kinkig',),
'kinksa': ('kinkse',),
'kinksede': ('kinkse',),
'kinksende': ('kinkse',),
'kinkset': ('kinkse',),
'kinksete': ('kinkse',),
'kinna': ('kinne',),
'kinnede': ('kinne',),
'kinnende': ('kinne',),
'kinnet': ('kinne',),
'kinnete': ('kinne',),
'kipen': ('kipen',),
'kipent': ('kipen',),
'kipne': ('kipen',),
'kipnere': ('kipen',),
'kipnest': ('kipen',),
'kipneste': ('kipen',),
'kippa': ('kippe',),
'kippede': ('kippe',),
'kippende': ('kippe',),
'kippet': ('kippe',),
'kippete': ('kippe',),
'kipt': ('kippe',),
'kipte': ('kippe',),
'kippskodd': ('kippskodd',),
'kippskodde': ('kippskodd',),
'kippskoddere': ('kippskodd',),
'kippskoddest': ('kippskodd',),
'kippskoddeste': ('kippskodd',),
'kirgisisk': ('kirgisisk',),
'kirgisiske': ('kirgisisk',),
'kirgisiskere': ('kirgisisk',),
'kirgisiskest': ('kirgisisk',),
'kirgisiskeste': ('kirgisisk',),
'kiribatisk': ('kiribatisk',),
'kiribatiske': ('kiribatisk',),
'kiribatiskere': ('kiribatisk',),
'kiribatiskest': ('kiribatisk',),
'kiribatiskeste': ('kiribatisk',),
'kirkefremmed': ('kirkefremmed',),
'kirkefremmede': ('kirkefremmed',),
'kirkefremmedere': ('kirkefremmed',),
'kirkefremmedest': ('kirkefremmed',),
'kirkefremmedeste': ('kirkefremmed',),
'kirkefremmend': ('kirkefremmend',),
'kirkefremmende': ('kirkefremmend',),
'kirkefremmendere': ('kirkefremmend',),
'kirkefremmendest': ('kirkefremmend',),
'kirkefremmendeste': ('kirkefremmend',),
'kirkefremmendt': ('kirkefremmend',),
'kirkelig': ('kirkelig',),
'kirkelige': ('kirkelig',),
'kirkeligere': ('kirkelig',),
'kirkeligst': ('kirkelig',),
'kirkeligste': ('kirkelig',),
'kiropraktisk': ('kiropraktisk',),
'kiropraktiske': ('kiropraktisk',),
'kiropraktiskere': ('kiropraktisk',),
'kiropraktiskest': ('kiropraktisk',),
'kiropraktiskeste': ('kiropraktisk',),
'kirurgisk': ('kirurgisk',),
'kirurgiske': ('kirurgisk',),
'kirurgiskere': ('kirurgisk',),
'kirurgiskest': ('kirurgisk',),
'kirurgiskeste': ('kirurgisk',),
'kisla': ('kisle',),
'kislede': ('kisle',),
'kislende': ('kisle',),
'kislet': ('kisle',),
'kislete': ('kisle',),
'kisla': ('kisle',),
'kislede': ('kisle',),
'kislende': ('kisle',),
'kislet': ('kisle',),
'kislete': ('kisle',),
'kislen': ('kislen',),
'kislent': ('kislen',),
'kislne': ('kislen',),
'kislnere': ('kislen',),
'kislnest': ('kislen',),
'kislneste': ('kislen',),
'kisteglad': ('kisteglad',),
'kisteglade': ('kisteglad',),
'kistegladere': ('kisteglad',),
'kistegladest': ('kisteglad',),
'kistegladeste': ('kisteglad',),
'kitla': ('kitle',),
'kitlede': ('kitle',),
'kitlende': ('kitle',),
'kitlet': ('kitle',),
'kitlete': ('kitle',),
'kitlen': ('kitlen',),
'kitlent': ('kitlen',),
'kitlne': ('kitlen',),
'kitlnere': ('kitlen',),
'kitlnest': ('kitlen',),
'kitlneste': ('kitlen',),
'kitta': ('kitte',),
'kittede': ('kitte',),
'kittende': ('kitte',),
'kittet': ('kitte',),
'kittete': ('kitte',),
'kivaktig': ('kivaktig',),
'kivaktige': ('kivaktig',),
'kivaktigere': ('kivaktig',),
'kivaktigst': ('kivaktig',),
'kivaktigste': ('kivaktig',),
'kiva': ('kive',),
'kivd': ('kive',),
'kivde': ('kive',),
'kivede': ('kive',),
'kivende': ('kive',),
'kivet': ('kive',),
'kivete': ('kive',),
'kjaksa': ('kjakse',),
'kjaksede': ('kjakse',),
'kjaksende': ('kjakse',),
'kjakset': ('kjakse',),
'kjaksete': ('kjakse',),
'kjangsa': ('kjangse',),
'kjangsede': ('kjangse',),
'kjangsende': ('kjangse',),
'kjangset': ('kjangse',),
'kjangsete': ('kjangse',),
'kjapp': ('kjapp',),
'kjappe': ('kjapp',),
'kjappere': ('kjapp',),
'kjappest': ('kjapp',),
'kjappeste': ('kjapp',),
'kjapt': ('kjapp',),
'kjappa': ('kjappe',),
'kjappede': ('kjappe',),
'kjappende': ('kjappe',),
'kjappet': ('kjappe',),
'kjappete': ('kjappe',),
'kjasende': ('kjase',),
'kjast': ('kjase',),
'kjaste': ('kjase',),
'kjava': ('kjave',),
'kjavd': ('kjave',),
'kjavde': ('kjave',),
'kjavede': ('kjave',),
'kjavende': ('kjave',),
'kjavet': ('kjave',),
'kjavete': ('kjave',),
'kjed': ('kjed',),
'kjede': ('kjed',),
'kjedere': ('kjed',),
'kjedest': ('kjed',),
'kjedeste': ('kjed',),
'kjedt': ('kjed',),
'kjeda': ('kjede',),
'kjedede': ('kjede',),
'kjedende': ('kjede',),
'kjedet': ('kjede',),
'kjedete': ('kjede',),
'kjeda': ('kjede',),
'kjedede': ('kjede',),
'kjedende': ('kjede',),
'kjedet': ('kjede',),
'kjedete': ('kjede',),
'kjedelig': ('kjedelig',),
'kjedelige': ('kjedelig',),
'kjedeligere': ('kjedelig',),
'kjedeligst': ('kjedelig',),
'kjedeligste': ('kjedelig',),
'kjederøyka': ('kjederøyke',),
'kjederøykede': ('kjederøyke',),
'kjederøykende': ('kjederøyke',),
'kjederøyket': ('kjederøyke',),
'kjederøykete': ('kjederøyke',),
'kjederøykt': ('kjederøyke',),
'kjederøykte': ('kjederøyke',),
'kjedsom': ('kjedsom',),
'kjedsomme': ('kjedsom',),
'kjedsommere': ('kjedsom',),
'kjedsomst': ('kjedsom',),
'kjedsomste': ('kjedsom',),
'kjedsomt': ('kjedsom',),
'kjedsommelig': ('kjedsommelig',),
'kjedsommelige': ('kjedsommelig',),
'kjedsommeligere': ('kjedsommelig',),
'kjedsommeligst': ('kjedsommelig',),
'kjedsommeligste': ('kjedsommelig',),
'kjea': ('kjee',),
'kjeede': ('kjee',),
'kjeende': ('kjee',),
'kjeet': ('kjee',),
'kjeete': ('kjee',),
'kjefta': ('kjefte',),
'kjeftede': ('kjefte',),
'kjeftende': ('kjefte',),
'kjeftet': ('kjefte',),
'kjeftete': ('kjefte',),
'kjekk': ('kjekk',),
'kjekke': ('kjekk',),
'kjekkere': ('kjekk',),
'kjekkest': ('kjekk',),
'kjekkeste': ('kjekk',),
'kjekt': ('kjekk',),
'kjekka': ('kjekke',),
'kjekkede': ('kjekke',),
'kjekkende': ('kjekke',),
'kjekket': ('kjekke',),
'kjekkete': ('kjekke',),
'kjekkesen': ('kjekkesen',),
'kjekla': ('kjekle',),
'kjeklede': ('kjekle',),
'kjeklende': ('kjekle',),
'kjeklet': ('kjekle',),
'kjeklete': ('kjekle',),
'kjeksa': ('kjekse',),
'kjeksede': ('kjekse',),
'kjeksende': ('kjekse',),
'kjekset': ('kjekse',),
'kjeksete': ('kjekse',),
'kjelket': ('kjelket',),
'kjelkete': ('kjelket',),
'kjelketere': ('kjelket',),
'kjelketest': ('kjelket',),
'kjelketeste': ('kjelket',),
'kjelkete': ('kjelkete',),
'kjellerkald': ('kjellerkald',),
'kjellerkalde': ('kjellerkald',),
'kjellerkaldere': ('kjellerkald',),
'kjellerkaldest': ('kjellerkald',),
'kjellerkaldeste': ('kjellerkald',),
'kjellerkaldt': ('kjellerkald',),
'kjemigrafisk': ('kjemigrafisk',),
'kjemigrafiske': ('kjemigrafisk',),
'kjemigrafiskere': ('kjemigrafisk',),
'kjemigrafiskest': ('kjemigrafisk',),
'kjemigrafiskeste': ('kjemigrafisk',),
'kjemisk': ('kjemisk',),
'kjemiske': ('kjemisk',),
'kjemiskere': ('kjemisk',),
'kjemiskest': ('kjemisk',),
'kjemiskeste': ('kjemisk',),
'kjemma': ('kjemme',),
'kjemmede': ('kjemme',),
'kjemmende': ('kjemme',),
'kjemmet': ('kjemme',),
'kjemmete': ('kjemme',),
'kjemt': ('kjemme',),
'kjemte': ('kjemme',),
'kjempa': ('kjempe',),
'kjempede': ('kjempe',),
'kjempende': ('kjempe',),
'kjempet': ('kjempe',),
'kjempete': ('kjempe',),
'kjempemessig': ('kjempemessig',),
'kjempemessige': ('kjempemessig',),
'kjempemessigere': ('kjempemessig',),
'kjempemessigst': ('kjempemessig',),
'kjempemessigste': ('kjempemessig',),
'kjennende': ('kjenne',),
'kjent': ('kjenne',),
'kjente': ('kjenne',),
'kjennelig': ('kjennelig',),
'kjennelige': ('kjennelig',),
'kjenneligere': ('kjennelig',),
'kjenneligst': ('kjennelig',),
'kjenneligste': ('kjennelig',),
'kjennetegna': ('kjennetegne',),
'kjennetegnede': ('kjennetegne',),
'kjennetegnende': ('kjennetegne',),
'kjennetegnet': ('kjennetegne',),
'kjennetegnete': ('kjennetegne',),
'kjenslelaus': ('kjenslelaus',),
'kjenslelause': ('kjenslelaus',),
'kjenslelausere': ('kjenslelaus',),
'kjenslelausest': ('kjenslelaus',),
'kjenslelauseste': ('kjenslelaus',),
'kjenslelaust': ('kjenslelaus',),
'kjensleløs': ('kjensleløs',),
'kjensleløse': ('kjensleløs',),
'kjensleløsere': ('kjensleløs',),
'kjensleløsest': ('kjensleløs',),
'kjensleløseste': ('kjensleløs',),
'kjensleløst': ('kjensleløs',),
'kjenslevar': ('kjenslevar',),
'kjenslevare': ('kjenslevar',),
'kjenslevarere': ('kjenslevar',),
'kjenslevarest': ('kjenslevar',),
'kjenslevareste': ('kjenslevar',),
'kjenslevart': ('kjenslevar',),
'kjent': ('kjent',),
'kjente': ('kjent',),
'kjentere': ('kjent',),
'kjentest': ('kjent',),
'kjenteste': ('kjent',),
'kjepphøg': ('kjepphøg',),
'kjepphøge': ('kjepphøg',),
'kjepphøgere': ('kjepphøg',),
'kjepphøgest': ('kjepphøg',),
'kjepphøgeste': ('kjepphøg',),
'kjepphøgre': ('kjepphøg',),
'kjepphøgst': ('kjepphøg',),
'kjepphøgste': ('kjepphøg',),
'kjepphøgt': ('kjepphøg',),
'kjepphøy': ('kjepphøy',),
'kjepphøye': ('kjepphøy',),
'kjepphøyere': ('kjepphøy',),
'kjepphøyest': ('kjepphøy',),
'kjepphøyeste': ('kjepphøy',),
'kjepphøyt': ('kjepphøy',),
'kjeppjaga': ('kjeppjage',),
'kjeppjagd': ('kjeppjage',),
'kjeppjagde': ('kjeppjage',),
'kjeppjagede': ('kjeppjage',),
'kjeppjagende': ('kjeppjage',),
'kjeppjaget': ('kjeppjage',),
'kjeppjagete': ('kjeppjage',),
'kjerna': ('kjerne',),
'kjernede': ('kjerne',),
'kjernende': ('kjerne',),
'kjernet': ('kjerne',),
'kjernete': ('kjerne',),
'kjernefysisk': ('kjernefysisk',),
'kjernefysiske': ('kjernefysisk',),
'kjernefysiskere': ('kjernefysisk',),
'kjernefysiskest': ('kjernefysisk',),
'kjernefysiskeste': ('kjernefysisk',),
'kjernesunn': ('kjernesunn',),
'kjernesunne': ('kjernesunn',),
'kjernesunnere': ('kjernesunn',),
'kjernesunnest': ('kjernesunn',),
'kjernesunneste': ('kjernesunn',),
'kjernesunt': ('kjernesunn',),
'kjerva': ('kjerve',),
'kjervede': ('kjerve',),
'kjervende': ('kjerve',),
'kjervet': ('kjerve',),
'kjervete': ('kjerve',),
'kjesende': ('kjese',),
'kjest': ('kjese',),
'kjeste': ('kjese',),
'kjeska': ('kjeske',),
'kjeskede': ('kjeske',),
'kjeskende': ('kjeske',),
'kjesket': ('kjeske',),
'kjeskete': ('kjeske',),
'kjesken': ('kjesken',),
'kjeskent': ('kjesken',),
'kjeskne': ('kjesken',),
'kjesknere': ('kjesken',),
'kjesknest': ('kjesken',),
'kjeskneste': ('kjesken',),
'kjettersk': ('kjettersk',),
'kjetterske': ('kjettersk',),
'kjetterskere': ('kjettersk',),
'kjetterskest': ('kjettersk',),
'kjetterskeste': ('kjettersk',),
'kjevla': ('kjevle',),
'kjevlede': ('kjevle',),
'kjevlende': ('kjevle',),
'kjevlet': ('kjevle',),
'kjevlete': ('kjevle',),
'kjælende': ('kjæle',),
'kjælt': ('kjæle',),
'kjælte': ('kjæle',),
'kjælen': ('kjælen',),
'kjælent': ('kjælen',),
'kjælne': ('kjælen',),
'kjælnere': ('kjælen',),
'kjælnest': ('kjælen',),
'kjælneste': ('kjælen',),
'kjær': ('kjær',),
'kjære': ('kjær',),
'kjærere': ('kjær',),
'kjærest': ('kjær',),
'kjæreste': ('kjær',),
'kjært': ('kjær',),
'kjærende': ('kjære',),
'kjært': ('kjære',),
'kjærte': ('kjære',),
'kjærkommen': ('kjærkommen',),
'kjærkomment': ('kjærkommen',),
'kjærkomne': ('kjærkommen',),
'kjærkomnere': ('kjærkommen',),
'kjærkomnest': ('kjærkommen',),
'kjærkomneste': ('kjærkommen',),
'kjærlig': ('kjærlig',),
'kjærlige': ('kjærlig',),
'kjærligere': ('kjærlig',),
'kjærligst': ('kjærlig',),
'kjærligste': ('kjærlig',),
'kjærtegna': ('kjærtegne',),
'kjærtegnede': ('kjærtegne',),
'kjærtegnende': ('kjærtegne',),
'kjærtegnet': ('kjærtegne',),
'kjærtegnete': ('kjærtegne',),
'kjætende': ('kjæte',),
'kjætt': ('kjæte',),
'kjætte': ('kjæte',),
'kjødelig': ('kjødelig',),
'kjødelige': ('kjødelig',),
'kjødeligere': ('kjødelig',),
'kjødeligst': ('kjødelig',),
'kjødeligste': ('kjødelig',),
'kjølende': ('kjøle',),
'kjølt': ('kjøle',),
'kjølte': ('kjøle',),
'kjølhala': ('kjølhale',),
'kjølhalede': ('kjølhale',),
'kjølhalende': ('kjølhale',),
'kjølhalet': ('kjølhale',),
'kjølhalete': ('kjølhale',),
'kjølhalt': ('kjølhale',),
'kjølhalte': ('kjølhale',),
'kjølig': ('kjølig',),
'kjølige': ('kjølig',),
'kjøligere': ('kjølig',),
'kjøligst': ('kjølig',),
'kjøligste': ('kjølig',),
'kjølna': ('kjølne',),
'kjølnede': ('kjølne',),
'kjølnende': ('kjølne',),
'kjølnet': ('kjølne',),
'kjølnete': ('kjølne',),
'kjøn': ('kjøn',),
'kjøne': ('kjøn',),
'kjønere': ('kjøn',),
'kjønest': ('kjøn',),
'kjøneste': ('kjøn',),
'kjønt': ('kjøn',),
'kjønna': ('kjønna',),
'kjønnede': ('kjønnet',),
'kjønnet': ('kjønnet',),
'kjønnete': ('kjønnet',),
'kjønnetere': ('kjønnet',),
'kjønnetest': ('kjønnet',),
'kjønneteste': ('kjønnet',),
'kjønnsbestemt': ('kjønnsbestemt',),
'kjønnsbestemte': ('kjønnsbestemt',),
'kjønnsbestemtere': ('kjønnsbestemt',),
'kjønnsbestemtest': ('kjønnsbestemt',),
'kjønnsbestemteste': ('kjønnsbestemt',),
'kjønnsbundet': ('kjønnsbundet',),
'kjønnsbundne': ('kjønnsbundet',),
'kjønnsbundnere': ('kjønnsbundet',),
'kjønnsbundnest': ('kjønnsbundet',),
'kjønnsbundneste': ('kjønnsbundet',),
'kjønnslaus': ('kjønnslaus',),
'kjønnslause': ('kjønnslaus',),
'kjønnslausere': ('kjønnslaus',),
'kjønnslausest': ('kjønnslaus',),
'kjønnslauseste': ('kjønnslaus',),
'kjønnslaust': ('kjønnslaus',),
'kjønnslig': ('kjønnslig',),
'kjønnslige': ('kjønnslig',),
'kjønnsligere': ('kjønnslig',),
'kjønnsligst': ('kjønnslig',),
'kjønnsligste': ('kjønnslig',),
'kjønnsløs': ('kjønnsløs',),
'kjønnsløse': ('kjønnsløs',),
'kjønnsløsere': ('kjønnsløs',),
'kjønnsløsest': ('kjønnsløs',),
'kjønnsløseste': ('kjønnsløs',),
'kjønnsløst': ('kjønnsløs',),
'kjønnsmoden': ('kjønnsmoden',),
'kjønnsmodent': ('kjønnsmoden',),
'kjønnsmodne': ('kjønnsmoden',),
'kjønnsmodnere': ('kjønnsmoden',),
'kjønnsmodnest': ('kjønnsmoden',),
'kjønnsmodneste': ('kjønnsmoden',),
'kjønnsnøytral': ('kjønnsnøytral',),
'kjønnsnøytrale': ('kjønnsnøytral',),
'kjønnsnøytralere': ('kjønnsnøytral',),
'kjønnsnøytralest': ('kjønnsnøytral',),
'kjønnsnøytraleste': ('kjønnsnøytral',),
'kjønnsnøytralt': ('kjønnsnøytral',),
'kjøpende': ('kjøpe',),
'kjøpt': ('kjøpe',),
'kjøpte': ('kjøpe',),
'kjøpekraftig': ('kjøpekraftig',),
'kjøpekraftige': ('kjøpekraftig',),
'kjøpekraftigere': ('kjøpekraftig',),
'kjøpekraftigst': ('kjøpekraftig',),
'kjøpekraftigste': ('kjøpekraftig',),
'kjørbar': ('kjørbar',),
'kjørbare': ('kjørbar',),
'kjørbarere': ('kjørbar',),
'kjørbarest': ('kjørbar',),
'kjørbareste': ('kjørbar',),
'kjørbart': ('kjørbar',),
'kjørende': ('kjøre',),
'kjørt': ('kjøre',),
'kjørte': ('kjøre',),
'kjørna': ('kjørne',),
'kjørnede': ('kjørne',),
'kjørnende': ('kjørne',),
'kjørnet': ('kjørne',),
'kjørnete': ('kjørne',),
'kjørt': ('kjørt',),
'kjørte': ('kjørt',),
'kjørtere': ('kjørt',),
'kjørtest': ('kjørt',),
'kjørteste': ('kjørt',),
'kjøttetende': ('kjøttetende',),
'kjøttfull': ('kjøttfull',),
'kjøttfulle': ('kjøttfull',),
'kjøttfullere': ('kjøttfull',),
'kjøttfullest': ('kjøttfull',),
'kjøttfulleste': ('kjøttfull',),
'kjøttfullt': ('kjøttfull',),
'kjøvd': ('kjøve',),
'kjøvde': ('kjøve',),
'kjøvende': ('kjøve',),
'klabba': ('klabbe',),
'klabbede': ('klabbe',),
'klabbende': ('klabbe',),
'klabbet': ('klabbe',),
'klabbete': ('klabbe',),
'klabbet': ('klabbet',),
'klabbete': ('klabbet',),
'klabbetere': ('klabbet',),
'klabbetest': ('klabbet',),
'klabbeteste': ('klabbet',),
'klabbete': ('klabbete',),
'kladda': ('kladde',),
'kladdede': ('kladde',),
'kladdende': ('kladde',),
'kladdet': ('kladde',),
'kladdete': ('kladde',),
'klaffa': ('klaffe',),
'klaffede': ('klaffe',),
'klaffende': ('klaffe',),
'klaffet': ('klaffe',),
'klaffete': ('klaffe',),
'klaga': ('klage',),
'klagd': ('klage',),
'klagde': ('klage',),
'klagede': ('klage',),
'klagende': ('klage',),
'klaget': ('klage',),
'klagete': ('klage',),
'klaka': ('klake',),
'klakede': ('klake',),
'klakende': ('klake',),
'klaket': ('klake',),
'klakete': ('klake',),
'klaket': ('klaket',),
'klakete': ('klaket',),
'klaketere': ('klaket',),
'klaketest': ('klaket',),
'klaketeste': ('klaket',),
'klakete': ('klakete',),
'klakka': ('klakke',),
'klakkede': ('klakke',),
'klakkende': ('klakke',),
'klakket': ('klakke',),
'klakkete': ('klakke',),
'klam': ('klam',),
'klamme': ('klam',),
'klammere': ('klam',),
'klammest': ('klam',),
'klammeste': ('klam',),
'klamt': ('klam',),
'klampa': ('klampe',),
'klampede': ('klampe',),
'klampende': ('klampe',),
'klampet': ('klampe',),
'klampete': ('klampe',),
'klamra': ('klamre',),
'klamrede': ('klamre',),
'klamrende': ('klamre',),
'klamret': ('klamre',),
'klamrete': ('klamre',),
'klanderverdig': ('klanderverdig',),
'klanderverdige': ('klanderverdig',),
'klanderverdigere': ('klanderverdig',),
'klanderverdigst': ('klanderverdig',),
'klanderverdigste': ('klanderverdig',),
'klandra': ('klandre',),
'klandrede': ('klandre',),
'klandrende': ('klandre',),
'klandret': ('klandre',),
'klandrete': ('klandre',),
'klangfull': ('klangfull',),
'klangfulle': ('klangfull',),
'klangfullere': ('klangfull',),
'klangfullest': ('klangfull',),
'klangfulleste': ('klangfull',),
'klangfullt': ('klangfull',),
'klanglig': ('klanglig',),
'klanglige': ('klanglig',),
'klangligere': ('klanglig',),
'klangligst': ('klanglig',),
'klangligste': ('klanglig',),
'klappa': ('klappe',),
'klappede': ('klappe',),
'klappende': ('klappe',),
'klappet': ('klappe',),
'klappete': ('klappe',),
'klapra': ('klapre',),
'klaprede': ('klapre',),
'klaprende': ('klapre',),
'klapret': ('klapre',),
'klaprete': ('klapre',),
'klapsa': ('klapse',),
'klapsede': ('klapse',),
'klapsende': ('klapse',),
'klapset': ('klapse',),
'klapsete': ('klapse',),
'klar': ('klar',),
'klare': ('klar',),
'klarere': ('klar',),
'klarest': ('klar',),
'klareste': ('klar',),
'klart': ('klar',),
'klara': ('klare',),
'klarede': ('klare',),
'klarende': ('klare',),
'klaret': ('klare',),
'klarete': ('klare',),
'klart': ('klare',),
'klarte': ('klare',),
'klarende': ('klare',),
'klart': ('klare',),
'klarte': ('klare',),
'klarerende': ('klarere',),
'klarert': ('klarere',),
'klarerte': ('klarere',),
'klargjort': ('klargjøre',),
'klargjorte': ('klargjøre',),
'klargjørende': ('klargjøre',),
'klarlagt': ('klarlegge',),
'klarlagte': ('klarlegge',),
'klarleggende': ('klarlegge',),
'klarna': ('klarne',),
'klarnede': ('klarne',),
'klarnende': ('klarne',),
'klarnet': ('klarne',),
'klarnete': ('klarne',),
'klarsynt': ('klarsynt',),
'klarsynte': ('klarsynt',),
'klarsyntere': ('klarsynt',),
'klarsyntest': ('klarsynt',),
'klarsynteste': ('klarsynt',),
'klartseende': ('klartseende',),
'klarøyd': ('klarøyd',),
'klarøyde': ('klarøyd',),
'klarøydere': ('klarøyd',),
'klarøydest': ('klarøyd',),
'klarøydeste': ('klarøyd',),
'klasa': ('klase',),
'klasede': ('klase',),
'klasende': ('klase',),
'klaset': ('klase',),
'klasete': ('klase',),
'klast': ('klase',),
'klaste': ('klase',),
'klaska': ('klaske',),
'klaskede': ('klaske',),
'klaskende': ('klaske',),
'klasket': ('klaske',),
'klaskete': ('klaske',),
'klassa': ('klasse',),
'klassede': ('klasse',),
'klassende': ('klasse',),
'klasset': ('klasse',),
'klassete': ('klasse',),
'klassa': ('klasse',),
'klassede': ('klasse',),
'klassende': ('klasse',),
'klasset': ('klasse',),
'klassete': ('klasse',),
'klassebevisst': ('klassebevisst',),
'klassebevisste': ('klassebevisst',),
'klassebevisstere': ('klassebevisst',),
'klassebevisstest': ('klassebevisst',),
'klassebevissteste': ('klassebevisst',),
'klasselaus': ('klasselaus',),
'klasselause': ('klasselaus',),
'klasselausere': ('klasselaus',),
'klasselausest': ('klasselaus',),
'klasselauseste': ('klasselaus',),
'klasselaust': ('klasselaus',),
'klasseløs': ('klasseløs',),
'klasseløse': ('klasseløs',),
'klasseløsere': ('klasseløs',),
'klasseløsest': ('klasseløs',),
'klasseløseste': ('klasseløs',),
'klasseløst': ('klasseløs',),
'klassifiserende': ('klassifisere',),
'klassifisert': ('klassifisere',),
'klassifiserte': ('klassifisere',),
'klassisistisk': ('klassisistisk',),
'klassisistiske': ('klassisistisk',),
'klassisistiskere': ('klassisistisk',),
'klassisistiskest': ('klassisistisk',),
'klassisistiskeste': ('klassisistisk',),
'klassisk': ('klassisk',),
'klassiske': ('klassisk',),
'klassiskere': ('klassisk',),
'klassiskest': ('klassisk',),
'klassiskeste': ('klassisk',),
'klatra': ('klatre',),
'klatrede': ('klatre',),
'klatrende': ('klatre',),
'klatret': ('klatre',),
'klatrete': ('klatre',),
'klatta': ('klatte',),
'klattede': ('klatte',),
'klattende': ('klatte',),
'klattet': ('klatte',),
'klattete': ('klatte',),
'klattemalende': ('klattemale',),
'klattemalt': ('klattemale',),
'klattemalte': ('klattemale',),
'klattmalende': ('klattmale',),
'klattmalt': ('klattmale',),
'klattmalte': ('klattmale',),
'klaustrofobisk': ('klaustrofobisk',),
'klaustrofobiske': ('klaustrofobisk',),
'klaustrofobiskere': ('klaustrofobisk',),
'klaustrofobiskest': ('klaustrofobisk',),
'klaustrofobiskeste': ('klaustrofobisk',),
'klausulerende': ('klausulere',),
'klausulert': ('klausulere',),
'klausulerte': ('klausulere',),
'klava': ('klave',),
'klavd': ('klave',),
'klavde': ('klave',),
'klavede': ('klave',),
'klavende': ('klave',),
'klavet': ('klave',),
'klavete': ('klave',),
'klavebindende': ('klavebinde',),
'klavebunden': ('klavebinde',),
'klavebundet': ('klavebinde',),
'klavebundne': ('klavebinde',),
'kledd': ('kle',),
'kledde': ('kle',),
'kledt': ('kle',),
'kledte': ('kle',),
'kleende': ('kle',),
'kleba': ('klebe',),
'klebede': ('klebe',),
'klebende': ('klebe',),
'klebet': ('klebe',),
'klebete': ('klebe',),
'klebt': ('klebe',),
'klebte': ('klebe',),
'klebrig': ('klebrig',),
'klebrige': ('klebrig',),
'klebrigere': ('klebrig',),
'klebrigst': ('klebrig',),
'klebrigste': ('klebrig',),
'kledd': ('klede',),
'kledde': ('klede',),
'kledende': ('klede',),
'kledelig': ('kledelig',),
'kledelige': ('kledelig',),
'kledeligere': ('kledelig',),
'kledeligst': ('kledelig',),
'kledeligste': ('kledelig',),
'kleia': ('kleie',),
'kleid': ('kleie',),
'kleidd': ('kleie',),
'kleidde': ('kleie',),
'kleide': ('kleie',),
'kleiede': ('kleie',),
'kleiende': ('kleie',),
'kleiet': ('kleie',),
'kleiete': ('kleie',),
'kleimende': ('kleime',),
'kleimt': ('kleime',),
'kleimte': ('kleime',),
'kleimen': ('kleimen',),
'kleiment': ('kleimen',),
'kleimne': ('kleimen',),
'kleimnere': ('kleimen',),
'kleimnest': ('kleimen',),
'kleimneste': ('kleimen',),
'klein': ('klein',),
'kleine': ('klein',),
'kleinere': ('klein',),
'kleinest': ('klein',),
'kleineste': ('klein',),
'kleint': ('klein',),
'kleis': ('kleis',),
'kleise': ('kleis',),
'kleisere': ('kleis',),
'kleisest': ('kleis',),
'kleiseste': ('kleis',),
'kleist': ('kleis',),
'kleisa': ('kleise',),
'kleisede': ('kleise',),
'kleisende': ('kleise',),
'kleiset': ('kleise',),
'kleisete': ('kleise',),
'kleist': ('kleise',),
'kleiste': ('kleise',),
'klekka': ('klekke',),
'klekkede': ('klekke',),
'klekkende': ('klekke',),
'klekket': ('klekke',),
'klekkete': ('klekke',),
'klekt': ('klekke',),
'klekte': ('klekke',),
'klekkelig': ('klekkelig',),
'klekkelige': ('klekkelig',),
'klekkeligere': ('klekkelig',),
'klekkeligst': ('klekkelig',),
'klekkeligste': ('klekkelig',),
'klemmende': ('klemme',),
'klemt': ('klemme',),
'klemte': ('klemme',),
'klemta': ('klemte',),
'klemtede': ('klemte',),
'klemtende': ('klemte',),
'klemtet': ('klemte',),
'klemtete': ('klemte',),
'klen': ('klen',),
'klene': ('klen',),
'klenere': ('klen',),
'klenest': ('klen',),
'kleneste': ('klen',),
'klent': ('klen',),
'klengende': ('klenge',),
'klengt': ('klenge',),
'klengte': ('klenge',),
'klenga': ('klenge',),
'klengede': ('klenge',),
'klengende': ('klenge',),
'klenget': ('klenge',),
'klengete': ('klenge',),
'klengt': ('klenge',),
'klengte': ('klenge',),
'klengen': ('klengen',),
'klengent': ('klengen',),
'klengne': ('klengen',),
'klengnere': ('klengen',),
'klengnest': ('klengen',),
'klengneste': ('klengen',),
'klenget': ('klenget',),
'klengete': ('klenget',),
'klengetere': ('klenget',),
'klengetest': ('klenget',),
'klengeteste': ('klenget',),
'klengete': ('klengete',),
'kleppa': ('kleppe',),
'kleppede': ('kleppe',),
'kleppende': ('kleppe',),
'kleppet': ('kleppe',),
'kleppete': ('kleppe',),
'kleptoman': ('kleptoman',),
'kleptomane': ('kleptoman',),
'kleptomanere': ('kleptoman',),
'kleptomanest': ('kleptoman',),
'kleptomaneste': ('kleptoman',),
'kleptomant': ('kleptoman',),
'klerikal': ('klerikal',),
'klerikale': ('klerikal',),
'klerikalere': ('klerikal',),
'klerikalest': ('klerikal',),
'klerikaleste': ('klerikal',),
'klerikalt': ('klerikal',),
'klesset': ('klesset',),
'klessete': ('klesset',),
'klessetere': ('klesset',),
'klessetest': ('klesset',),
'klesseteste': ('klesset',),
'klessete': ('klessete',),
'klikka': ('klikke',),
'klikkede': ('klikke',),
'klikkende': ('klikke',),
'klikket': ('klikke',),
'klikkete': ('klikke',),
'klimakterisk': ('klimakterisk',),
'klimakteriske': ('klimakterisk',),
'klimakteriskere': ('klimakterisk',),
'klimakteriskest': ('klimakterisk',),
'klimakteriskeste': ('klimakterisk',),
'klimatiserende': ('klimatisere',),
'klimatisert': ('klimatisere',),
'klimatiserte': ('klimatisere',),
'klimatisk': ('klimatisk',),
'klimatiske': ('klimatisk',),
'klimatiskere': ('klimatisk',),
'klimatiskest': ('klimatisk',),
'klimatiskeste': ('klimatisk',),
'klimatologisk': ('klimatologisk',),
'klimatologiske': ('klimatologisk',),
'klimatologiskere': ('klimatologisk',),
'klimatologiskest': ('klimatologisk',),
'klimatologiskeste': ('klimatologisk',),
'klimpra': ('klimpre',),
'klimprede': ('klimpre',),
'klimprende': ('klimpre',),
'klimpret': ('klimpre',),
'klimprete': ('klimpre',),
'klina': ('kline',),
'klinede': ('kline',),
'klinende': ('kline',),
'klinet': ('kline',),
'klinete': ('kline',),
'klint': ('kline',),
'klinte': ('kline',),
'klinet': ('klinet',),
'klinete': ('klinet',),
'klinetere': ('klinet',),
'klinetest': ('klinet',),
'klineteste': ('klinet',),
'klinete': ('klinete',),
'klingen': ('klinge',),
'klingende': ('klinge',),
'klinget': ('klinge',),
'klingne': ('klinge',),
'klingt': ('klinge',),
'klingte': ('klinge',),
'klinger': ('klinger',),
'klingert': ('klinger',),
'klingre': ('klinger',),
'klingrere': ('klinger',),
'klingrest': ('klinger',),
'klingreste': ('klinger',),
'klingra': ('klingre',),
'klingrede': ('klingre',),
'klingrende': ('klingre',),
'klingret': ('klingre',),
'klingrete': ('klingre',),
'klingra': ('klingre',),
'klinisk': ('klinisk',),
'kliniske': ('klinisk',),
'kliniskere': ('klinisk',),
'kliniskest': ('klinisk',),
'kliniskeste': ('klinisk',),
'klinkbygd': ('klinkbygd',),
'klinkbygde': ('klinkbygd',),
'klinkbygdere': ('klinkbygd',),
'klinkbygdest': ('klinkbygd',),
'klinkbygdeste': ('klinkbygd',),
'klinka': ('klinke',),
'klinkede': ('klinke',),
'klinkende': ('klinke',),
'klinket': ('klinke',),
'klinkete': ('klinke',),
'klinka': ('klinke',),
'klinkede': ('klinke',),
'klinkende': ('klinke',),
'klinket': ('klinke',),
'klinkete': ('klinke',),
'klinkhard': ('klinkhard',),
'klinkharde': ('klinkhard',),
'klinkhardere': ('klinkhard',),
'klinkhardest': ('klinkhard',),
'klinkhardeste': ('klinkhard',),
'klinkhardt': ('klinkhard',),
'klipende': ('klipe',),
'klipt': ('klipe',),
'klipte': ('klipe',),
'klippa': ('klippe',),
'klippede': ('klippe',),
'klippende': ('klippe',),
'klippet': ('klippe',),
'klippete': ('klippe',),
'klipt': ('klippe',),
'klipte': ('klippe',),
'klippefast': ('klippefast',),
'klippefaste': ('klippefast',),
'klippefastere': ('klippefast',),
'klippefastest': ('klippefast',),
'klippefasteste': ('klippefast',),
'klirra': ('klirre',),
'klirrede': ('klirre',),
'klirrende': ('klirre',),
'klirret': ('klirre',),
'klirrete': ('klirre',),
'klisjerende': ('klisjere',),
'klisjert': ('klisjere',),
'klisjerte': ('klisjere',),
'kliss-klass': ('kliss-klass',),
'klissa': ('klisse',),
'klissede': ('klisse',),
'klissende': ('klisse',),
'klisset': ('klisse',),
'klissete': ('klisse',),
'klisne': ('klissen',),
'klisnere': ('klissen',),
'klisnest': ('klissen',),
'klisneste': ('klissen',),
'klissen': ('klissen',),
'klissent': ('klissen',),
'klisset': ('klisset',),
'klissete': ('klisset',),
'klissetere': ('klisset',),
'klissetest': ('klisset',),
'klisseteste': ('klisset',),
'klissete': ('klissete',),
'klissvåt': ('klissvåt',),
'klissvåte': ('klissvåt',),
'klissvåtere': ('klissvåt',),
'klissvåtest': ('klissvåt',),
'klissvåteste': ('klissvåt',),
'klissvått': ('klissvåt',),
'klistra': ('klistre',),
'klistrede': ('klistre',),
'klistrende': ('klistre',),
'klistret': ('klistre',),
'klistrete': ('klistre',),
'kleven': ('klive',),
'klevet': ('klive',),
'klevne': ('klive',),
'klivd': ('klive',),
'klivde': ('klive',),
'klivende': ('klive',),
'kloakkerende': ('kloakkere',),
'kloakkert': ('kloakkere',),
'kloakkerte': ('kloakkere',),
'klok': ('klok',),
'kloke': ('klok',),
'klokere': ('klok',),
'klokest': ('klok',),
'klokeste': ('klok',),
'klokt': ('klok',),
'klokka': ('klokke',),
'klokkede': ('klokke',),
'klokkende': ('klokke',),
'klokket': ('klokke',),
'klokkete': ('klokke',),
'klokkeklar': ('klokkeklar',),
'klokkeklare': ('klokkeklar',),
'klokkeklarere': ('klokkeklar',),
'klokkeklarest': ('klokkeklar',),
'klokkeklareste': ('klokkeklar',),
'klokkeklart': ('klokkeklar',),
'klokkerein': ('klokkerein',),
'klokkereine': ('klokkerein',),
'klokkereinere': ('klokkerein',),
'klokkereinest': ('klokkerein',),
'klokkereineste': ('klokkerein',),
'klokkereint': ('klokkerein',),
'klokkeren': ('klokkeren',),
'klokkerene': ('klokkeren',),
'klokkerenere': ('klokkeren',),
'klokkerenest': ('klokkeren',),
'klokkereneste': ('klokkeren',),
'klokkerent': ('klokkeren',),
'klona': ('klone',),
'klonede': ('klone',),
'klonende': ('klone',),
'klonet': ('klone',),
'klonete': ('klone',),
'klorende': ('klore',),
'klort': ('klore',),
'klorte': ('klore',),
'klorende': ('klore',),
'klort': ('klore',),
'klorte': ('klore',),
'klorerende': ('klorere',),
'klorert': ('klorere',),
'klorerte': ('klorere',),
'kloroformerende': ('kloroformere',),
'kloroformert': ('kloroformere',),
'kloroformerte': ('kloroformere',),
'kloss': ('kloss',),
'klosset': ('klosset',),
'klossete': ('klosset',),
'klossetere': ('klosset',),
'klossetest': ('klosset',),
'klosseteste': ('klosset',),
'klossete': ('klossete',),
'kloven': ('kloven',),
'klovent': ('kloven',),
'klovne': ('kloven',),
'klovnere': ('kloven',),
'klovnest': ('kloven',),
'klovneste': ('kloven',),
'klovna': ('klovne',),
'klovnede': ('klovne',),
'klovnende': ('klovne',),
'klovnet': ('klovne',),
'klovnete': ('klovne',),
'klovna': ('klovne',),
'klovnede': ('klovne',),
'klovnende': ('klovne',),
'klovnet': ('klovne',),
'klovnete': ('klovne',),
'klubba': ('klubbe',),
'klubbede': ('klubbe',),
'klubbende': ('klubbe',),
'klubbet': ('klubbe',),
'klubbete': ('klubbe',),
'klubbet': ('klubbet',),
'klubbete': ('klubbet',),
'klubbetere': ('klubbet',),
'klubbetest': ('klubbet',),
'klubbeteste': ('klubbet',),
'klubbete': ('klubbete',),
'kludra': ('kludre',),
'kludrede': ('kludre',),
'kludrende': ('kludre',),
'kludret': ('kludre',),
'kludrete': ('kludre',),
'kludret': ('kludret',),
'kludrete': ('kludret',),
'kludretere': ('kludret',),
'kludretest': ('kludret',),
'kludreteste': ('kludret',),
'kludrete': ('kludrete',),
'klukk': ('klukk',),
'klukke': ('klukk',),
'klukkere': ('klukk',),
'klukkest': ('klukk',),
'klukkeste': ('klukk',),
'klukt': ('klukk',),
'klukka': ('klukke',),
'klukkede': ('klukke',),
'klukkende': ('klukke',),
'klukket': ('klukke',),
'klukkete': ('klukke',),
'klumpa': ('klumpe',),
'klumpede': ('klumpe',),
'klumpende': ('klumpe',),
'klumpet': ('klumpe',),
'klumpete': ('klumpe',),
'klumpet': ('klumpet',),
'klumpete': ('klumpet',),
'klumpetere': ('klumpet',),
'klumpetest': ('klumpet',),
'klumpeteste': ('klumpet',),
'klumpete': ('klumpete',),
'klumpfota': ('klumpfota',),
'klumpfotede': ('klumpfotet',),
'klumpfotet': ('klumpfotet',),
'klumpfotete': ('klumpfotet',),
'klumpfotetere': ('klumpfotet',),
'klumpfotetest': ('klumpfotet',),
'klumpfoteteste': ('klumpfotet',),
'klumpføtt': ('klumpføtt',),
'klumpføtte': ('klumpføtt',),
'klumpføttere': ('klumpføtt',),
'klumpføttest': ('klumpføtt',),
'klumpføtteste': ('klumpføtt',),
'klums': ('klums',),
'klumsa': ('klumse',),
'klumsede': ('klumse',),
'klumsende': ('klumse',),
'klumset': ('klumse',),
'klumsete': ('klumse',),
'klumset': ('klumset',),
'klumsete': ('klumset',),
'klumsetere': ('klumset',),
'klumsetest': ('klumset',),
'klumseteste': ('klumset',),
'klumsete': ('klumsete',),
'klundra': ('klundre',),
'klundrede': ('klundre',),
'klundrende': ('klundre',),
'klundret': ('klundre',),
'klundrete': ('klundre',),
'klundret': ('klundret',),
'klundrete': ('klundret',),
'klundretere': ('klundret',),
'klundretest': ('klundret',),
'klundreteste': ('klundret',),
'klundrete': ('klundrete',),
'klungret': ('klungret',),
'klungrete': ('klungret',),
'klungretere': ('klungret',),
'klungretest': ('klungret',),
'klungreteste': ('klungret',),
'klungrete': ('klungrete',),
'klunka': ('klunke',),
'klunkede': ('klunke',),
'klunkende': ('klunke',),
'klunket': ('klunke',),
'klunkete': ('klunke',),
'klunset': ('klunset',),
'klunsete': ('klunset',),
'klunsetere': ('klunset',),
'klunsetest': ('klunset',),
'klunseteste': ('klunset',),
'klunsete': ('klunsete',),
'kluntet': ('kluntet',),
'kluntete': ('kluntet',),
'kluntetere': ('kluntet',),
'kluntetest': ('kluntet',),
'klunteteste': ('kluntet',),
'kluntete': ('kluntete',),
'klusil': ('klusil',),
'klusile': ('klusil',),
'klusilere': ('klusil',),
'klusilest': ('klusil',),
'klusileste': ('klusil',),
'klusilt': ('klusil',),
'klussa': ('klusse',),
'klussede': ('klusse',),
'klussende': ('klusse',),
'klusset': ('klusse',),
'klussete': ('klusse',),
'klynga': ('klynge',),
'klyngede': ('klynge',),
'klyngende': ('klynge',),
'klynget': ('klynge',),
'klyngete': ('klynge',),
'klynka': ('klynke',),
'klynkede': ('klynke',),
'klynkende': ('klynke',),
'klynket': ('klynke',),
'klynkete': ('klynke',),
'klypende': ('klype',),
'klypt': ('klype',),
'klypte': ('klype',),
'kløpen': ('klype',),
'kløpet': ('klype',),
'kløpne': ('klype',),
'klyset': ('klyset',),
'klysete': ('klyset',),
'klysetere': ('klyset',),
'klysetest': ('klyset',),
'klyseteste': ('klyset',),
'klysete': ('klysete',),
'klyvd': ('klyve',),
'klyvde': ('klyve',),
'klyvende': ('klyve',),
'kløven': ('klyve',),
'kløvet': ('klyve',),
'kløvne': ('klyve',),
'klådd': ('klå',),
'klådde': ('klå',),
'klående': ('klå',),
'klåfingra': ('klåfingra',),
'klåfingrede': ('klåfingret',),
'klåfingret': ('klåfingret',),
'klåfingrete': ('klåfingret',),
'klåfingretere': ('klåfingret',),
'klåfingretest': ('klåfingret',),
'klåfingreteste': ('klåfingret',),
'klødd': ('klø',),
'klødde': ('klø',),
'kløende': ('klø',),
'kløfta': ('kløfte',),
'kløftede': ('kløfte',),
'kløftende': ('kløfte',),
'kløftet': ('kløfte',),
'kløftete': ('kløfte',),
'kløftet': ('kløftet',),
'kløftete': ('kløftet',),
'kløftetere': ('kløftet',),
'kløftetest': ('kløftet',),
'kløfteteste': ('kløftet',),
'kløftete': ('kløftete',),
'kløkk': ('kløkk',),
'kløkke': ('kløkk',),
'kløkkere': ('kløkk',),
'kløkkest': ('kløkk',),
'kløkkeste': ('kløkk',),
'kløkt': ('kløkk',),
'kløkkende': ('kløkke',),
'kløkt': ('kløkke',),
'kløkte': ('kløkke',),
'kløktig': ('kløktig',),
'kløktige': ('kløktig',),
'kløktigere': ('kløktig',),
'kløktigst': ('kløktig',),
'kløktigste': ('kløktig',),
'klønende': ('kløne',),
'klønt': ('kløne',),
'klønte': ('kløne',),
'klønet': ('klønet',),
'klønete': ('klønet',),
'klønetere': ('klønet',),
'klønetest': ('klønet',),
'kløneteste': ('klønet',),
'klønete': ('klønete',),
'kløtsja': ('kløtsje',),
'kløtsjede': ('kløtsje',),
'kløtsjende': ('kløtsje',),
'kløtsjet': ('kløtsje',),
'kløtsjete': ('kløtsje',),
'kløv': ('kløv',),
'kløve': ('kløv',),
'kløvere': ('kløv',),
'kløvest': ('kløv',),
'kløveste': ('kløv',),
'kløvt': ('kløv',),
'kløvbar': ('kløvbar',),
'kløvbare': ('kløvbar',),
'kløvbarere': ('kløvbar',),
'kløvbarest': ('kløvbar',),
'kløvbareste': ('kløvbar',),
'kløvbart': ('kløvbar',),
'kløvd': ('kløve',),
'kløvde': ('kløve',),
'kløvende': ('kløve',),
'kløvja': ('kløvje',),
'kløvjede': ('kløvje',),
'kløvjende': ('kløvje',),
'kløvjet': ('kløvje',),
'kløvjete': ('kløvje',),
'kløvna': ('kløvne',),
'kløvnede': ('kløvne',),
'kløvnende': ('kløvne',),
'kløvnet': ('kløvne',),
'kløvnete': ('kløvne',),
'kløyv': ('kløyv',),
'kløyve': ('kløyv',),
'kløyvere': ('kløyv',),
'kløyvest': ('kløyv',),
'kløyveste': ('kløyv',),
'kløyvt': ('kløyv',),
'kløyva': ('kløyva',),
'kløyvbar': ('kløyvbar',),
'kløyvbare': ('kløyvbar',),
'kløyvbarere': ('kløyvbar',),
'kløyvbarest': ('kløyvbar',),
'kløyvbareste': ('kløyvbar',),
'kløyvbart': ('kløyvbar',),
'kløyvd': ('kløyve',),
'kløyvde': ('kløyve',),
'kløyvende': ('kløyve',),
'knadd': ('kna',),
'knadde': ('kna',),
'knaende': ('kna',),
'knabba': ('knabbe',),
'knabbede': ('knabbe',),
'knabbende': ('knabbe',),
'knabbet': ('knabbe',),
'knabbete': ('knabbe',),
'knaka': ('knake',),
'knakede': ('knake',),
'knakende': ('knake',),
'knaket': ('knake',),
'knakete': ('knake',),
'knakt': ('knake',),
'knakte': ('knake',),
'knakka': ('knakke',),
'knakkede': ('knakke',),
'knakkende': ('knakke',),
'knakket': ('knakke',),
'knakkete': ('knakke',),
'knallblå': ('knallblå',),
'knallblåe': ('knallblå',),
'knallblåere': ('knallblå',),
'knallblåest': ('knallblå',),
'knallblåeste': ('knallblå',),
'knallblått': ('knallblå',),
'knalla': ('knalle',),
'knallede': ('knalle',),
'knallende': ('knalle',),
'knallet': ('knalle',),
'knallete': ('knalle',),
'knallhard': ('knallhard',),
'knallharde': ('knallhard',),
'knallhardere': ('knallhard',),
'knallhardest': ('knallhard',),
'knallhardeste': ('knallhard',),
'knallhardt': ('knallhard',),
'knapp': ('knapp',),
'knappe': ('knapp',),
'knappere': ('knapp',),
'knappest': ('knapp',),
'knappeste': ('knapp',),
'knapt': ('knapp',),
'knappa': ('knappe',),
'knappede': ('knappe',),
'knappende': ('knappe',),
'knappet': ('knappe',),
'knappete': ('knappe',),
'knappa': ('knappe',),
'knappede': ('knappe',),
'knappende': ('knappe',),
'knappet': ('knappe',),
'knappete': ('knappe',),
'knarka': ('knarke',),
'knarkede': ('knarke',),
'knarkende': ('knarke',),
'knarket': ('knarke',),
'knarkete': ('knarke',),
'knarta': ('knarte',),
'knartede': ('knarte',),
'knartende': ('knarte',),
'knartet': ('knarte',),
'knartete': ('knarte',),
'knartet': ('knartet',),
'knartete': ('knartet',),
'knartetere': ('knartet',),
'knartetest': ('knartet',),
'knarteteste': ('knartet',),
'knartete': ('knartete',),
'knas': ('knas',),
'knase': ('knas',),
'knasere': ('knas',),
'knasest': ('knas',),
'knaseste': ('knas',),
'knast': ('knas',),
'knasa': ('knase',),
'knasede': ('knase',),
'knasende': ('knase',),
'knaset': ('knase',),
'knasete': ('knase',),
'knast': ('knase',),
'knaste': ('knase',),
'knaska': ('knaske',),
'knaskede': ('knaske',),
'knaskende': ('knaske',),
'knasket': ('knaske',),
'knaskete': ('knaske',),
'knastørr': ('knastørr',),
'knastørre': ('knastørr',),
'knastørrere': ('knastørr',),
'knastørrest': ('knastørr',),
'knastørreste': ('knastørr',),
'knastørt': ('knastørr',),
'knatra': ('knatre',),
'knatrede': ('knatre',),
'knatrende': ('knatre',),
'knatret': ('knatre',),
'knatrete': ('knatre',),
'knatta': ('knatte',),
'knattede': ('knatte',),
'knattende': ('knatte',),
'knattet': ('knatte',),
'knattete': ('knatte',),
'knebla': ('kneble',),
'kneblede': ('kneble',),
'kneblende': ('kneble',),
'kneblet': ('kneble',),
'kneblete': ('kneble',),
'knega': ('knege',),
'knegede': ('knege',),
'knegende': ('knege',),
'kneget': ('knege',),
'knegete': ('knege',),
'knegen': ('knegen',),
'knegent': ('knegen',),
'knegne': ('knegen',),
'knegnere': ('knegen',),
'knegnest': ('knegen',),
'knegneste': ('knegen',),
'knegd': ('knegge',),
'knegde': ('knegge',),
'knegga': ('knegge',),
'kneggede': ('knegge',),
'kneggende': ('knegge',),
'knegget': ('knegge',),
'kneggete': ('knegge',),
'knegående': ('knegå',),
'knegått': ('knegå',),
'knegåtte': ('knegå',),
'kneiket': ('kneiket',),
'kneikete': ('kneiket',),
'kneiketere': ('kneiket',),
'kneiketest': ('kneiket',),
'kneiketeste': ('kneiket',),
'kneikete': ('kneikete',),
'kneisende': ('kneise',),
'kneist': ('kneise',),
'kneiste': ('kneise',),
'knekka': ('knekke',),
'knekkede': ('knekke',),
'knekkende': ('knekke',),
'knekket': ('knekke',),
'knekkete': ('knekke',),
'knekt': ('knekke',),
'knekte': ('knekke',),
'knekken': ('knekke',),
'knekkende': ('knekke',),
'knekket': ('knekke',),
'knekne': ('knekke',),
'knekt': ('knekke',),
'knekte': ('knekke',),
'knekort': ('knekort',),
'knekorte': ('knekort',),
'knekortere': ('knekort',),
'knekortest': ('knekort',),
'knekorteste': ('knekort',),
'knekta': ('knekte',),
'knektede': ('knekte',),
'knektende': ('knekte',),
'knektet': ('knekte',),
'knektete': ('knekte',),
'knelende': ('knele',),
'knelt': ('knele',),
'knelte': ('knele',),
'knepen': ('knepen',),
'knepent': ('knepen',),
'knepne': ('knepen',),
'knepnere': ('knepen',),
'knepnest': ('knepen',),
'knepneste': ('knepen',),
'kneppa': ('kneppe',),
'kneppede': ('kneppe',),
'kneppende': ('kneppe',),
'kneppet': ('kneppe',),
'kneppete': ('kneppe',),
'knept': ('kneppe',),
'knepte': ('kneppe',),
'kneppende': ('kneppe',),
'knept': ('kneppe',),
'knepte': ('kneppe',),
'knepra': ('knepre',),
'kneprede': ('knepre',),
'kneprende': ('knepre',),
'knepret': ('knepre',),
'kneprete': ('knepre',),
'knerta': ('knerte',),
'knertede': ('knerte',),
'knertende': ('knerte',),
'knertet': ('knerte',),
'knertete': ('knerte',),
'knesatt': ('knesette',),
'knesatte': ('knesette',),
'knesettende': ('knesette',),
'knesten': ('kneste',),
'knestende': ('kneste',),
'knestet': ('kneste',),
'knestne': ('kneste',),
'knestående': ('knestående',),
'knetne': ('knette',),
'knetten': ('knette',),
'knettende': ('knette',),
'knettet': ('knette',),
'kniksa': ('knikse',),
'kniksede': ('knikse',),
'kniksende': ('knikse',),
'knikset': ('knikse',),
'kniksete': ('knikse',),
'knipal': ('knipal',),
'knipale': ('knipal',),
'knipalere': ('knipal',),
'knipalest': ('knipal',),
'knipaleste': ('knipal',),
'knipalt': ('knipal',),
'knepen': ('knipe',),
'knepet': ('knipe',),
'knepne': ('knipe',),
'knipende': ('knipe',),
'knipen': ('knipen',),
'knipent': ('knipen',),
'knipne': ('knipen',),
'knipnere': ('knipen',),
'knipnest': ('knipen',),
'knipneste': ('knipen',),
'knipla': ('kniple',),
'kniplede': ('kniple',),
'kniplende': ('kniple',),
'kniplet': ('kniple',),
'kniplete': ('kniple',),
'knippa': ('knippe',),
'knippede': ('knippe',),
'knippende': ('knippe',),
'knippet': ('knippe',),
'knippete': ('knippe',),
'knipsa': ('knipse',),
'knipsede': ('knipse',),
'knipsende': ('knipse',),
'knipset': ('knipse',),
'knipsete': ('knipse',),
'knipsk': ('knipsk',),
'knipske': ('knipsk',),
'knipskere': ('knipsk',),
'knipskest': ('knipsk',),
'knipskeste': ('knipsk',),
'knirka': ('knirke',),
'knirkede': ('knirke',),
'knirkende': ('knirke',),
'knirket': ('knirke',),
'knirkete': ('knirke',),
'knisende': ('knise',),
'knist': ('knise',),
'kniste': ('knise',),
'knisla': ('knisle',),
'knislede': ('knisle',),
'knislende': ('knisle',),
'knislet': ('knisle',),
'knislete': ('knisle',),
'knistra': ('knistre',),
'knistrede': ('knistre',),
'knistrende': ('knistre',),
'knistret': ('knistre',),
'knistrete': ('knistre',),
'knitra': ('knitre',),
'knitrede': ('knitre',),
'knitrende': ('knitre',),
'knitret': ('knitre',),
'knitrete': ('knitre',),
'kniva': ('knive',),
'knivede': ('knive',),
'knivende': ('knive',),
'knivet': ('knive',),
'knivete': ('knive',),
'knivskarp': ('knivskarp',),
'knivskarpe': ('knivskarp',),
'knivskarpere': ('knivskarp',),
'knivskarpest': ('knivskarp',),
'knivskarpeste': ('knivskarp',),
'knivskarpt': ('knivskarp',),
'knocka': ('knocke',),
'knockede': ('knocke',),
'knockende': ('knocke',),
'knocket': ('knocke',),
'knockete': ('knocke',),
'knockout': ('knockout',),
'knockouta': ('knockoute',),
'knockoutede': ('knockoute',),
'knockoutende': ('knockoute',),
'knockoutet': ('knockoute',),
'knockoutete': ('knockoute',),
'knoga': ('knoge',),
'knogede': ('knoge',),
'knogende': ('knoge',),
'knoget': ('knoge',),
'knogete': ('knoge',),
'knoket': ('knoket',),
'knokete': ('knoket',),
'knoketere': ('knoket',),
'knoketest': ('knoket',),
'knoketeste': ('knoket',),
'knokete': ('knokete',),
'knoklet': ('knoklet',),
'knoklete': ('knoklet',),
'knokletere': ('knoklet',),
'knokletest': ('knoklet',),
'knokleteste': ('knoklet',),
'knoklete': ('knoklete',),
'knopa': ('knope',),
'knopede': ('knope',),
'knopende': ('knope',),
'knopet': ('knope',),
'knopete': ('knope',),
'knoppa': ('knoppe',),
'knoppede': ('knoppe',),
'knoppende': ('knoppe',),
'knoppet': ('knoppe',),
'knoppete': ('knoppe',),
'knortet': ('knortet',),
'knortete': ('knortet',),
'knortetere': ('knortet',),
'knortetest': ('knortet',),
'knorteteste': ('knortet',),
'knortete': ('knortete',),
'knota': ('knote',),
'knotede': ('knote',),
'knotende': ('knote',),
'knotet': ('knote',),
'knotete': ('knote',),
'knotet': ('knotet',),
'knotete': ('knotet',),
'knotetere': ('knotet',),
'knotetest': ('knotet',),
'knoteteste': ('knotet',),
'knotete': ('knotete',),
'knubba': ('knubbe',),
'knubbede': ('knubbe',),
'knubbende': ('knubbe',),
'knubbet': ('knubbe',),
'knubbete': ('knubbe',),
'knubbet': ('knubbet',),
'knubbete': ('knubbet',),
'knubbetere': ('knubbet',),
'knubbetest': ('knubbet',),
'knubbeteste': ('knubbet',),
'knubbete': ('knubbete',),
'knudret': ('knudret',),
'knudrete': ('knudret',),
'knudretere': ('knudret',),
'knudretest': ('knudret',),
'knudreteste': ('knudret',),
'knudrete': ('knudrete',),
'knuffa': ('knuffe',),
'knuffede': ('knuffe',),
'knuffende': ('knuffe',),
'knuffet': ('knuffe',),
'knuffete': ('knuffe',),
'knuga': ('knuge',),
'knugede': ('knuge',),
'knugende': ('knuge',),
'knuget': ('knuge',),
'knugete': ('knuge',),
'knulla': ('knulle',),
'knullede': ('knulle',),
'knullende': ('knulle',),
'knullet': ('knulle',),
'knullete': ('knulle',),
'knultret': ('knultret',),
'knultrete': ('knultret',),
'knultretere': ('knultret',),
'knultretest': ('knultret',),
'knultreteste': ('knultret',),
'knultrete': ('knultrete',),
'knupsa': ('knupse',),
'knupsede': ('knupse',),
'knupsende': ('knupse',),
'knupset': ('knupse',),
'knupsete': ('knupse',),
'knurka': ('knurke',),
'knurkede': ('knurke',),
'knurkende': ('knurke',),
'knurket': ('knurke',),
'knurkete': ('knurke',),
'knurpa': ('knurpe',),
'knurpede': ('knurpe',),
'knurpende': ('knurpe',),
'knurpet': ('knurpe',),
'knurpete': ('knurpe',),
'knurra': ('knurre',),
'knurrede': ('knurre',),
'knurrende': ('knurre',),
'knurret': ('knurre',),
'knurrete': ('knurre',),
'knurva': ('knurve',),
'knurvede': ('knurve',),
'knurvende': ('knurve',),
'knurvet': ('knurve',),
'knurvete': ('knurve',),
'knusende': ('knuse',),
'knust': ('knuse',),
'knuste': ('knuse',),
'knuselska': ('knuselske',),
'knuselskede': ('knuselske',),
'knuselskende': ('knuselske',),
'knuselsket': ('knuselske',),
'knuselskete': ('knuselske',),
'knusktørr': ('knusktørr',),
'knusktørre': ('knusktørr',),
'knusktørrere': ('knusktørr',),
'knusktørrest': ('knusktørr',),
'knusktørreste': ('knusktørr',),
'knusktørt': ('knusktørr',),
'knusla': ('knusle',),
'knuslede': ('knusle',),
'knuslende': ('knusle',),
'knuslet': ('knusle',),
'knuslete': ('knusle',),
'knuslet': ('knuslet',),
'knuslete': ('knuslet',),
'knusletere': ('knuslet',),
'knusletest': ('knuslet',),
'knusleteste': ('knuslet',),
'knuslete': ('knuslete',),
'knuspa': ('knuspe',),
'knuspede': ('knuspe',),
'knuspende': ('knuspe',),
'knuspet': ('knuspe',),
'knuspete': ('knuspe',),
'knuspra': ('knuspre',),
'knusprede': ('knuspre',),
'knusprende': ('knuspre',),
'knuspret': ('knuspre',),
'knusprete': ('knuspre',),
'knustra': ('knustre',),
'knustrede': ('knustre',),
'knustrende': ('knustre',),
'knustret': ('knustre',),
'knustrete': ('knustre',),
'knuvla': ('knuvle',),
'knuvlede': ('knuvle',),
'knuvlende': ('knuvle',),
'knuvlet': ('knuvle',),
'knuvlete': ('knuvle',),
'knuvlet': ('knuvlet',),
'knuvlete': ('knuvlet',),
'knuvletere': ('knuvlet',),
'knuvletest': ('knuvlet',),
'knuvleteste': ('knuvlet',),
'knuvlete': ('knuvlete',),
'knydd': ('kny',),
'knydde': ('kny',),
'knyende': ('kny',),
'knysta': ('knyste',),
'knystede': ('knyste',),
'knystende': ('knyste',),
'knystet': ('knyste',),
'knystete': ('knyste',),
'knytende': ('knyte',),
'knytt': ('knyte',),
'knytte': ('knyte',),
'knytta': ('knytte',),
'knyttede': ('knytte',),
'knyttende': ('knytte',),
'knyttet': ('knytte',),
'knyttete': ('knytte',),
'knølen': ('knølen',),
'knølent': ('knølen',),
'knølne': ('knølen',),
'knølnere': ('knølen',),
'knølnest': ('knølen',),
'knølneste': ('knølen',),
'knøten': ('knøten',),
'knøtent': ('knøten',),
'knøtne': ('knøten',),
'knøtnere': ('knøten',),
'knøtnest': ('knøten',),
'knøtneste': ('knøten',),
'knøttlille': ('knøttliten',),
'knøttlita': ('knøttliten',),
'knøttlite': ('knøttliten',),
'knøttliten': ('knøttliten',),
'knøttmindre': ('knøttliten',),
'knøttminst': ('knøttliten',),
'knøttminste': ('knøttliten',),
'knøttsmå': ('knøttliten',),
'knøttsmått': ('knøttliten',),
'knøttvesle': ('knøttliten',),
'ko-ko': ('ko-ko',),
'koagulerende': ('koagulere',),
'koagulert': ('koagulere',),
'koagulerte': ('koagulere',),
'koaksial': ('koaksial',),
'koaksiale': ('koaksial',),
'koaksialere': ('koaksial',),
'koaksialest': ('koaksial',),
'koaksialeste': ('koaksial',),
'koaksialt': ('koaksial',),
'kobberbrun': ('kobberbrun',),
'kobberbrune': ('kobberbrun',),
'kobberbrunere': ('kobberbrun',),
'kobberbrunest': ('kobberbrun',),
'kobberbruneste': ('kobberbrun',),
'kobberbrunt': ('kobberbrun',),
'kobla': ('koble',),
'koblede': ('koble',),
'koblende': ('koble',),
'koblet': ('koble',),
'koblete': ('koble',),
'koda': ('kode',),
'kodede': ('kode',),
'kodende': ('kode',),
'kodet': ('kode',),
'kodete': ('kode',),
'kodifiserende': ('kodifisere',),
'kodifisert': ('kodifisere',),
'kodifiserte': ('kodifisere',),
'kogla': ('kogle',),
'koglede': ('kogle',),
'koglende': ('kogle',),
'koglet': ('kogle',),
'koglete': ('kogle',),
'kognatisk': ('kognatisk',),
'kognatiske': ('kognatisk',),
'kognatiskere': ('kognatisk',),
'kognatiskest': ('kognatisk',),
'kognatiskeste': ('kognatisk',),
'kognitiv': ('kognitiv',),
'kognitive': ('kognitiv',),
'kognitivere': ('kognitiv',),
'kognitivest': ('kognitiv',),
'kognitiveste': ('kognitiv',),
'kognitivt': ('kognitiv',),
'koherent': ('koherent',),
'koherente': ('koherent',),
'koherentere': ('koherent',),
'koherentest': ('koherent',),
'koherenteste': ('koherent',),
'kokende': ('koke',),
'kokt': ('koke',),
'kokte': ('koke',),
'kokett': ('kokett',),
'kokette': ('kokett',),
'kokettere': ('kokett',),
'kokettest': ('kokett',),
'koketteste': ('kokett',),
'koketterende': ('kokettere',),
'kokettert': ('kokettere',),
'koketterte': ('kokettere',),
'kokheit': ('kokheit',),
'kokheite': ('kokheit',),
'kokheitere': ('kokheit',),
'kokheitest': ('kokheit',),
'kokheiteste': ('kokheit',),
'kokheitt': ('kokheit',),
'kokhett': ('kokheit',),
'kokhet': ('kokhet',),
'kokhete': ('kokhet',),
'kokhetere': ('kokhet',),
'kokhetest': ('kokhet',),
'kokheteste': ('kokhet',),
'kokhett': ('kokhet',),
'kokkelerende': ('kokkelere',),
'kokkelert': ('kokkelere',),
'kokkelerte': ('kokkelere',),
'kokkererende': ('kokkerere',),
'kokkerert': ('kokkerere',),
'kokkererte': ('kokkerere',),
'kokos': ('kokos',),
'kokra': ('kokre',),
'kokrede': ('kokre',),
'kokrende': ('kokre',),
'kokret': ('kokre',),
'kokrete': ('kokre',),
'kola': ('kole',),
'kolede': ('kole',),
'kolende': ('kole',),
'kolet': ('kole',),
'kolete': ('kole',),
'kola': ('kole',),
'kolede': ('kole',),
'kolende': ('kole',),
'kolet': ('kole',),
'kolete': ('kole',),
'kolerisk': ('kolerisk',),
'koleriske': ('kolerisk',),
'koleriskere': ('kolerisk',),
'koleriskest': ('kolerisk',),
'koleriskeste': ('kolerisk',),
'kolet': ('kolet',),
'kolete': ('kolet',),
'koletere': ('kolet',),
'koletest': ('kolet',),
'koleteste': ('kolet',),
'kolete': ('kolete',),
'kollabera': ('kollabere',),
'kollaberede': ('kollabere',),
'kollaberende': ('kollabere',),
'kollaberet': ('kollabere',),
'kollaberete': ('kollabere',),
'kollaborerende': ('kollaborere',),
'kollaborert': ('kollaborere',),
'kollaborerte': ('kollaborere',),
'kollapsa': ('kollapse',),
'kollapsede': ('kollapse',),
'kollapsende': ('kollapse',),
'kollapset': ('kollapse',),
'kollapsete': ('kollapse',),
'kollasjonerende': ('kollasjonere',),
'kollasjonert': ('kollasjonere',),
'kollasjonerte': ('kollasjonere',),
'kolla': ('kolle',),
'kollede': ('kolle',),
'kollende': ('kolle',),
'kollet': ('kolle',),
'kollete': ('kolle',),
'kollegial': ('kollegial',),
'kollegiale': ('kollegial',),
'kollegialere': ('kollegial',),
'kollegialest': ('kollegial',),
'kollegialeste': ('kollegial',),
'kollegialt': ('kollegial',),
'kollektiv': ('kollektiv',),
'kollektive': ('kollektiv',),
'kollektivere': ('kollektiv',),
'kollektivest': ('kollektiv',),
'kollektiveste': ('kollektiv',),
'kollektivt': ('kollektiv',),
'kollektiviserende': ('kollektivisere',),
'kollektivisert': ('kollektivisere',),
'kollektiviserte': ('kollektivisere',),
'kollektivistisk': ('kollektivistisk',),
'kollektivistiske': ('kollektivistisk',),
'kollektivistiskere': ('kollektivistisk',),
'kollektivistiskest': ('kollektivistisk',),
'kollektivistiskeste': ('kollektivistisk',),
'kollet': ('kollet',),
'kollete': ('kollet',),
'kolletere': ('kollet',),
'kolletest': ('kollet',),
'kolleteste': ('kollet',),
'kollete': ('kollete',),
'kolliderende': ('kollidere',),
'kollidert': ('kollidere',),
'kolliderte': ('kollidere',),
'kolloid': ('kolloid',),
'kolloide': ('kolloid',),
'kolloidere': ('kolloid',),
'kolloidest': ('kolloid',),
'kolloideste': ('kolloid',),
'kolloidal': ('kolloidal',),
'kolloidale': ('kolloidal',),
'kolloidalere': ('kolloidal',),
'kolloidalest': ('kolloidal',),
'kolloidaleste': ('kolloidal',),
'kolloidalt': ('kolloidal',),
'kollokverende': ('kollokvere',),
'kollokvert': ('kollokvere',),
'kollokverte': ('kollokvere',),
'kollsegla': ('kollsegle',),
'kollseglede': ('kollsegle',),
'kollseglende': ('kollsegle',),
'kollseglet': ('kollsegle',),
'kollseglete': ('kollsegle',),
'kollseilende': ('kollseile',),
'kollseilt': ('kollseile',),
'kollseilte': ('kollseile',),
'kolmørk': ('kolmørk',),
'kolmørke': ('kolmørk',),
'kolmørkere': ('kolmørk',),
'kolmørkest': ('kolmørk',),
'kolmørkeste': ('kolmørk',),
'kolmørkt': ('kolmørk',),
'kolmørk': ('kolmørk',),
'kolmørke': ('kolmørk',),
'kolmørkere': ('kolmørk',),
'kolmørkest': ('kolmørk',),
'kolmørkeste': ('kolmørk',),
'kolmørkt': ('kolmørk',),
'kolombiansk': ('kolombiansk',),
'kolombianske': ('kolombiansk',),
'kolombianskere': ('kolombiansk',),
'kolombianskest': ('kolombiansk',),
'kolombianskeste': ('kolombiansk',),
'kolonial': ('kolonial',),
'koloniale': ('kolonial',),
'kolonialere': ('kolonial',),
'kolonialest': ('kolonial',),
'kolonialeste': ('kolonial',),
'kolonialt': ('kolonial',),
'kolonialistisk': ('kolonialistisk',),
'kolonialistiske': ('kolonialistisk',),
'kolonialistiskere': ('kolonialistisk',),
'kolonialistiskest': ('kolonialistisk',),
'kolonialistiskeste': ('kolonialistisk',),
'koloniserende': ('kolonisere',),
'kolonisert': ('kolonisere',),
'koloniserte': ('kolonisere',),
'kolorerende': ('kolorere',),
'kolorert': ('kolorere',),
'kolorerte': ('kolorere',),
'kolossal': ('kolossal',),
'kolossale': ('kolossal',),
'kolossalere': ('kolossal',),
'kolossalest': ('kolossal',),
'kolossaleste': ('kolossal',),
'kolossalt': ('kolossal',),
'kolporterende': ('kolportere',),
'kolportert': ('kolportere',),
'kolporterte': ('kolportere',),
'kolsvart': ('kolsvart',),
'kolsvarte': ('kolsvart',),
'kolsvartere': ('kolsvart',),
'kolsvartest': ('kolsvart',),
'kolsvarteste': ('kolsvart',),
'kombinatorisk': ('kombinatorisk',),
'kombinatoriske': ('kombinatorisk',),
'kombinatoriskere': ('kombinatorisk',),
'kombinatoriskest': ('kombinatorisk',),
'kombinatoriskeste': ('kombinatorisk',),
'kombinerende': ('kombinere',),
'kombinert': ('kombinere',),
'kombinerte': ('kombinere',),
'kometaktig': ('kometaktig',),
'kometaktige': ('kometaktig',),
'kometaktigere': ('kometaktig',),
'kometaktigst': ('kometaktig',),
'kometaktigste': ('kometaktig',),
'komfortabel': ('komfortabel',),
'komfortabelt': ('komfortabel',),
'komfortable': ('komfortabel',),
'komfortablere': ('komfortabel',),
'komfortablest': ('komfortabel',),
'komfortableste': ('komfortabel',),
'komisk': ('komisk',),
'komiske': ('komisk',),
'komiskere': ('komisk',),
'komiskest': ('komisk',),
'komiskeste': ('komisk',),
'komitébehandla': ('komitébehandle',),
'komitébehandlede': ('komitébehandle',),
'komitébehandlende': ('komitébehandle',),
'komitébehandlet': ('komitébehandle',),
'komitébehandlete': ('komitébehandle',),
'kommanderende': ('kommandere',),
'kommandert': ('kommandere',),
'kommanderte': ('kommandere',),
'kommen': ('komme',),
'kommende': ('komme',),
'kommet': ('komme',),
'komne': ('komme',),
'kommensurabel': ('kommensurabel',),
'kommensurabelt': ('kommensurabel',),
'kommensurable': ('kommensurabel',),
'kommensurablere': ('kommensurabel',),
'kommensurablest': ('kommensurabel',),
'kommensurableste': ('kommensurabel',),
'kommenterende': ('kommentere',),
'kommentert': ('kommentere',),
'kommenterte': ('kommentere',),
'kommersialiserende': ('kommersialisere',),
'kommersialisert': ('kommersialisere',),
'kommersialiserte': ('kommersialisere',),
'kommersiell': ('kommersiell',),
'kommersielle': ('kommersiell',),
'kommersiellere': ('kommersiell',),
'kommersiellest': ('kommersiell',),
'kommersielleste': ('kommersiell',),
'kommersielt': ('kommersiell',),
'kommissarisk': ('kommissarisk',),
'kommissariske': ('kommissarisk',),
'kommissariskere': ('kommissarisk',),
'kommissariskest': ('kommissarisk',),
'kommissariskeste': ('kommissarisk',),
'kommunal': ('kommunal',),
'kommunale': ('kommunal',),
'kommunalere': ('kommunal',),
'kommunalest': ('kommunal',),
'kommunaleste': ('kommunal',),
'kommunalt': ('kommunal',),
'kommunaliserende': ('kommunalisere',),
'kommunalisert': ('kommunalisere',),
'kommunaliserte': ('kommunalisere',),
'kommuniserende': ('kommunisere',),
'kommunisert': ('kommunisere',),
'kommuniserte': ('kommunisere',),
'kommunistisk': ('kommunistisk',),
'kommunistiske': ('kommunistisk',),
'kommunistiskere': ('kommunistisk',),
'kommunistiskest': ('kommunistisk',),
'kommunistiskeste': ('kommunistisk',),
'kommutabel': ('kommutabel',),
'kommutabelt': ('kommutabel',),
'kommutable': ('kommutabel',),
'kommutablere': ('kommutabel',),
'kommutablest': ('kommutabel',),
'kommutableste': ('kommutabel',),
'kommutativ': ('kommutativ',),
'kommutative': ('kommutativ',),
'kommutativere': ('kommutativ',),
'kommutativest': ('kommutativ',),
'kommutativeste': ('kommutativ',),
'kommutativt': ('kommutativ',),
'kommuterende': ('kommutere',),
'kommutert': ('kommutere',),
'kommuterte': ('kommutere',),
'komorisk': ('komorisk',),
'komoriske': ('komorisk',),
'komoriskere': ('komorisk',),
'komoriskest': ('komorisk',),
'komoriskeste': ('komorisk',),
'kompakt': ('kompakt',),
'kompakte': ('kompakt',),
'kompaktere': ('kompakt',),
'kompaktest': ('kompakt',),
'kompakteste': ('kompakt',),
'komparabel': ('komparabel',),
'komparabelt': ('komparabel',),
'komparable': ('komparabel',),
'komparablere': ('komparabel',),
'komparablest': ('komparabel',),
'komparableste': ('komparabel',),
'komparativ': ('komparativ',),
'komparative': ('komparativ',),
'komparativere': ('komparativ',),
'komparativest': ('komparativ',),
'komparativeste': ('komparativ',),
'komparativt': ('komparativ',),
'komparerende': ('komparere',),
'komparert': ('komparere',),
'komparerte': ('komparere',),
'kompatibel': ('kompatibel',),
'kompatibelt': ('kompatibel',),
'kompatible': ('kompatibel',),
'kompatiblere': ('kompatibel',),
'kompatiblest': ('kompatibel',),
'kompatibleste': ('kompatibel',),
'kompa': ('kompe',),
'kompede': ('kompe',),
'kompende': ('kompe',),
'kompet': ('kompe',),
'kompete': ('kompe',),
'kompensatorisk': ('kompensatorisk',),
'kompensatoriske': ('kompensatorisk',),
'kompensatoriskere': ('kompensatorisk',),
'kompensatoriskest': ('kompensatorisk',),
'kompensatoriskeste': ('kompensatorisk',),
'kompenserende': ('kompensere',),
'kompensert': ('kompensere',),
'kompenserte': ('kompensere',),
'kompetent': ('kompetent',),
'kompetente': ('kompetent',),
'kompetentere': ('kompetent',),
'kompetentest': ('kompetent',),
'kompetenteste': ('kompetent',),
'kompilerende': ('kompilere',),
'kompilert': ('kompilere',),
'kompilerte': ('kompilere',),
'kompleks': ('kompleks',),
'komplekse': ('kompleks',),
'kompleksere': ('kompleks',),
'kompleksest': ('kompleks',),
'komplekseste': ('kompleks',),
'komplekst': ('kompleks',),
'komplementær': ('komplementær',),
'komplementære': ('komplementær',),
'komplementærere': ('komplementær',),
'komplementærest': ('komplementær',),
'komplementæreste': ('komplementær',),
'komplementært': ('komplementær',),
'komplett': ('komplett',),
'komplette': ('komplett',),
'komplettere': ('komplett',),
'komplettest': ('komplett',),
'kompletteste': ('komplett',),
'kompletterende': ('komplettere',),
'komplettert': ('komplettere',),
'kompletterte': ('komplettere',),
'komplimenterende': ('komplimentere',),
'komplimentert': ('komplimentere',),
'komplimenterte': ('komplimentere',),
'kompliserende': ('komplisere',),
'komplisert': ('komplisere',),
'kompliserte': ('komplisere',),
'komponerende': ('komponere',),
'komponert': ('komponere',),
'komponerte': ('komponere',),
'kompositorisk': ('kompositorisk',),
'kompositoriske': ('kompositorisk',),
'kompositoriskere': ('kompositorisk',),
'kompositoriskest': ('kompositorisk',),
'kompositoriskeste': ('kompositorisk',),
'komposterende': ('kompostere',),
'kompostert': ('kompostere',),
'komposterte': ('kompostere',),
'kompressibel': ('kompressibel',),
'kompressibelt': ('kompressibel',),
'kompressible': ('kompressibel',),
'kompressiblere': ('kompressibel',),
'kompressiblest': ('kompressibel',),
'kompressibleste': ('kompressibel',),
'komprimerende': ('komprimere',),
'komprimert': ('komprimere',),
'komprimerte': ('komprimere',),
'kompromissa': ('kompromisse',),
'kompromissede': ('kompromisse',),
'kompromissende': ('kompromisse',),
'kompromisset': ('kompromisse',),
'kompromissete': ('kompromisse',),
'kompromisslaus': ('kompromisslaus',),
'kompromisslause': ('kompromisslaus',),
'kompromisslausere': ('kompromisslaus',),
'kompromisslausest': ('kompromisslaus',),
'kompromisslauseste': ('kompromisslaus',),
'kompromisslaust': ('kompromisslaus',),
'kompromissløs': ('kompromissløs',),
'kompromissløse': ('kompromissløs',),
'kompromissløsere': ('kompromissløs',),
'kompromissløsest': ('kompromissløs',),
'kompromissløseste': ('kompromissløs',),
'kompromissløst': ('kompromissløs',),
'kompromitterende': ('kompromittere',),
'kompromittert': ('kompromittere',),
'kompromitterte': ('kompromittere',),
'kondemnabel': ('kondemnabel',),
'kondemnabelt': ('kondemnabel',),
'kondemnable': ('kondemnabel',),
'kondemnablere': ('kondemnabel',),
'kondemnablest': ('kondemnabel',),
'kondemnableste': ('kondemnabel',),
'kondemnerende': ('kondemnere',),
'kondemnert': ('kondemnere',),
'kondemnerte': ('kondemnere',),
'kondenserende': ('kondensere',),
'kondensert': ('kondensere',),
'kondenserte': ('kondensere',),
'kondisjonal': ('kondisjonal',),
'kondisjonale': ('kondisjonal',),
'kondisjonalere': ('kondisjonal',),
'kondisjonalest': ('kondisjonal',),
'kondisjonaleste': ('kondisjonal',),
'kondisjonalt': ('kondisjonal',),
'kondisjonerende': ('kondisjonere',),
'kondisjonert': ('kondisjonere',),
'kondisjonerte': ('kondisjonere',),
'kondisjonert': ('kondisjonert',),
'kondisjonerte': ('kondisjonert',),
'kondisjonertere': ('kondisjonert',),
'kondisjonertest': ('kondisjonert',),
'kondisjonerteste': ('kondisjonert',),
'kondisjonssterk': ('kondisjonssterk',),
'kondisjonssterke': ('kondisjonssterk',),
'kondisjonssterkere': ('kondisjonssterk',),
'kondisjonssterkest': ('kondisjonssterk',),
'kondisjonssterkeste': ('kondisjonssterk',),
'kondisjonssterkt': ('kondisjonssterk',),
'kondolerende': ('kondolere',),
'kondolert': ('kondolere',),
'kondolerte': ('kondolere',),
'konfererende': ('konferere',),
'konferert': ('konferere',),
'konfererte': ('konferere',),
'konfesjonell': ('konfesjonell',),
'konfesjonelle': ('konfesjonell',),
'konfesjonellere': ('konfesjonell',),
'konfesjonellest': ('konfesjonell',),
'konfesjonelleste': ('konfesjonell',),
'konfesjonelt': ('konfesjonell',),
'konfesjonløs': ('konfesjonløs',),
'konfesjonløse': ('konfesjonløs',),
'konfesjonløsere': ('konfesjonløs',),
'konfesjonløsest': ('konfesjonløs',),
'konfesjonløseste': ('konfesjonløs',),
'konfesjonløst': ('konfesjonløs',),
'konfesjonslaus': ('konfesjonslaus',),
'konfesjonslause': ('konfesjonslaus',),
'konfesjonslausere': ('konfesjonslaus',),
'konfesjonslausest': ('konfesjonslaus',),
'konfesjonslauseste': ('konfesjonslaus',),
'konfesjonslaust': ('konfesjonslaus',),
'konfidensiell': ('konfidensiell',),
'konfidensielle': ('konfidensiell',),
'konfidensiellere': ('konfidensiell',),
'konfidensiellest': ('konfidensiell',),
'konfidensielleste': ('konfidensiell',),
'konfidensielt': ('konfidensiell',),
'konfirmerende': ('konfirmere',),
'konfirmert': ('konfirmere',),
'konfirmerte': ('konfirmere',),
'konfiskatorisk': ('konfiskatorisk',),
'konfiskatoriske': ('konfiskatorisk',),
'konfiskatoriskere': ('konfiskatorisk',),
'konfiskatoriskest': ('konfiskatorisk',),
'konfiskatoriskeste': ('konfiskatorisk',),
'konfiskerende': ('konfiskere',),
'konfiskert': ('konfiskere',),
'konfiskerte': ('konfiskere',),
'konform': ('konform',),
'konforme': ('konform',),
'konformere': ('konform',),
'konformest': ('konform',),
'konformeste': ('konform',),
'konformt': ('konform',),
'konformistisk': ('konformistisk',),
'konformistiske': ('konformistisk',),
'konformistiskere': ('konformistisk',),
'konformistiskest': ('konformistisk',),
'konformistiskeste': ('konformistisk',),
'konfronterende': ('konfrontere',),
'konfrontert': ('konfrontere',),
'konfronterte': ('konfrontere',),
'konfus': ('konfus',),
'konfuse': ('konfus',),
'konfusere': ('konfus',),
'konfusest': ('konfus',),
'konfuseste': ('konfus',),
'konfust': ('konfus',),
'konfusiansk': ('konfusiansk',),
'konfusianske': ('konfusiansk',),
'konfusianskere': ('konfusiansk',),
'konfusianskest': ('konfusiansk',),
'konfusianskeste': ('konfusiansk',),
'konføderert': ('konføderert',),
'konfødererte': ('konføderert',),
'konføderertere': ('konføderert',),
'konføderertest': ('konføderert',),
'konfødererteste': ('konføderert',),
'kongelig': ('kongelig',),
'kongelige': ('kongelig',),
'kongeligere': ('kongelig',),
'kongeligst': ('kongelig',),
'kongeligste': ('kongelig',),
'kongenial': ('kongenial',),
'kongeniale': ('kongenial',),
'kongenialere': ('kongenial',),
'kongenialest': ('kongenial',),
'kongenialeste': ('kongenial',),
'kongenialt': ('kongenial',),
'kongenital': ('kongenital',),
'kongenitale': ('kongenital',),
'kongenitalere': ('kongenital',),
'kongenitalest': ('kongenital',),
'kongenitaleste': ('kongenital',),
'kongenitalt': ('kongenital',),
'kongolesisk': ('kongolesisk',),
'kongolesiske': ('kongolesisk',),
'kongolesiskere': ('kongolesisk',),
'kongolesiskest': ('kongolesisk',),
'kongolesiskeste': ('kongolesisk',),
'kongruent': ('kongruent',),
'kongruente': ('kongruent',),
'kongruentere': ('kongruent',),
'kongruentest': ('kongruent',),
'kongruenteste': ('kongruent',),
'kongruerende': ('kongruere',),
'kongruert': ('kongruere',),
'kongruerte': ('kongruere',),
'konisk': ('konisk',),
'koniske': ('konisk',),
'koniskere': ('konisk',),
'koniskest': ('konisk',),
'koniskeste': ('konisk',),
'konjugal': ('konjugal',),
'konjugale': ('konjugal',),
'konjugalere': ('konjugal',),
'konjugalest': ('konjugal',),
'konjugaleste': ('konjugal',),
'konjugalt': ('konjugal',),
'konjugerende': ('konjugere',),
'konjugert': ('konjugere',),
'konjugerte': ('konjugere',),
'konjugert': ('konjugert',),
'konjugerte': ('konjugert',),
'konjugertere': ('konjugert',),
'konjugertest': ('konjugert',),
'konjugerteste': ('konjugert',),
'konjunktivisk': ('konjunktivisk',),
'konjunktiviske': ('konjunktivisk',),
'konjunktiviskere': ('konjunktivisk',),
'konjunktiviskest': ('konjunktivisk',),
'konjunktiviskeste': ('konjunktivisk',),
'konjunkturell': ('konjunkturell',),
'konjunkturelle': ('konjunkturell',),
'konjunkturellere': ('konjunkturell',),
'konjunkturellest': ('konjunkturell',),
'konjunkturelleste': ('konjunkturell',),
'konjunkturelt': ('konjunkturell',),
'konk': ('konk',),
'konkav': ('konkav',),
'konkave': ('konkav',),
'konkavere': ('konkav',),
'konkavest': ('konkav',),
'konkaveste': ('konkav',),
'konkavt': ('konkav',),
'konka': ('konke',),
'konkede': ('konke',),
'konkende': ('konke',),
'konket': ('konke',),
'konkete': ('konke',),
'konkluderende': ('konkludere',),
'konkludert': ('konkludere',),
'konkluderte': ('konkludere',),
'konkret': ('konkret',),
'konkrete': ('konkret',),
'konkretere': ('konkret',),
'konkretest': ('konkret',),
'konkreteste': ('konkret',),
'konkretiserende': ('konkretisere',),
'konkretisert': ('konkretisere',),
'konkretiserte': ('konkretisere',),
'konkurransedyktig': ('konkurransedyktig',),
'konkurransedyktige': ('konkurransedyktig',),
'konkurransedyktigere': ('konkurransedyktig',),
'konkurransedyktigst': ('konkurransedyktig',),
'konkurransedyktigste': ('konkurransedyktig',),
'konkurranseutsatt': ('konkurranseutsatt',),
'konkurranseutsatte': ('konkurranseutsatt',),
'konkurranseutsattere': ('konkurranseutsatt',),
'konkurranseutsattest': ('konkurranseutsatt',),
'konkurranseutsatteste': ('konkurranseutsatt',),
'konkurrerende': ('konkurrere',),
'konkurrert': ('konkurrere',),
'konkurrerte': ('konkurrere',),
'konkurs': ('konkurs',),
'konnotativ': ('konnotativ',),
'konnotative': ('konnotativ',),
'konnotativere': ('konnotativ',),
'konnotativest': ('konnotativ',),
'konnotativeste': ('konnotativ',),
'konnoterende': ('konnotere',),
'konnotert': ('konnotere',),
'konnoterte': ('konnotere',),
'konsekvent': ('konsekvent',),
'konsekvente': ('konsekvent',),
'konsekventere': ('konsekvent',),
'konsekventest': ('konsekvent',),
'konsekventeste': ('konsekvent',),
'konsentrerende': ('konsentrere',),
'konsentrert': ('konsentrere',),
'konsentrerte': ('konsentrere',),
'konsentrisk': ('konsentrisk',),
'konsentriske': ('konsentrisk',),
'konsentriskere': ('konsentrisk',),
'konsentriskest': ('konsentrisk',),
'konsentriskeste': ('konsentrisk',),
'konserterende': ('konsertere',),
'konsertert': ('konsertere',),
'konserterte': ('konsertere',),
'konservativ': ('konservativ',),
'konservative': ('konservativ',),
'konservativere': ('konservativ',),
'konservativest': ('konservativ',),
'konservativeste': ('konservativ',),
'konservativt': ('konservativ',),
'konserverende': ('konservere',),
'konservert': ('konservere',),
'konserverte': ('konservere',),
'konsignerende': ('konsignere',),
'konsignert': ('konsignere',),
'konsignerte': ('konsignere',),
'konsiperende': ('konsipere',),
'konsipert': ('konsipere',),
'konsiperte': ('konsipere',),
'konsis': ('konsis',),
'konsise': ('konsis',),
'konsisere': ('konsis',),
'konsisest': ('konsis',),
'konsiseste': ('konsis',),
'konsist': ('konsis',),
'konsistent': ('konsistent',),
'konsistente': ('konsistent',),
'konsistentere': ('konsistent',),
'konsistentest': ('konsistent',),
'konsistenteste': ('konsistent',),
'konskriberende': ('konskribere',),
'konskribert': ('konskribere',),
'konskriberte': ('konskribere',),
'konsoliderende': ('konsolidere',),
'konsolidert': ('konsolidere',),
'konsoliderte': ('konsolidere',),
'konsonantisk': ('konsonantisk',),
'konsonantiske': ('konsonantisk',),
'konsonantiskere': ('konsonantisk',),
'konsonantiskest': ('konsonantisk',),
'konsonantiskeste': ('konsonantisk',),
'konspirativ': ('konspirativ',),
'konspirative': ('konspirativ',),
'konspirativere': ('konspirativ',),
'konspirativest': ('konspirativ',),
'konspirativeste': ('konspirativ',),
'konspirativt': ('konspirativ',),
'konspiratorisk': ('konspiratorisk',),
'konspiratoriske': ('konspiratorisk',),
'konspiratoriskere': ('konspiratorisk',),
'konspiratoriskest': ('konspiratorisk',),
'konspiratoriskeste': ('konspiratorisk',),
'konspirerende': ('konspirere',),
'konspirert': ('konspirere',),
'konspirerte': ('konspirere',),
'konstant': ('konstant',),
'konstante': ('konstant',),
'konstantere': ('konstant',),
'konstantest': ('konstant',),
'konstanteste': ('konstant',),
'konstaterende': ('konstatere',),
'konstatert': ('konstatere',),
'konstaterte': ('konstatere',),
'konstituerende': ('konstituere',),
'konstituert': ('konstituere',),
'konstituerte': ('konstituere',),
'konstitusjonell': ('konstitusjonell',),
'konstitusjonelle': ('konstitusjonell',),
'konstitusjonellere': ('konstitusjonell',),
'konstitusjonellest': ('konstitusjonell',),
'konstitusjonelleste': ('konstitusjonell',),
'konstitusjonelt': ('konstitusjonell',),
'konstitutiv': ('konstitutiv',),
'konstitutive': ('konstitutiv',),
'konstitutivere': ('konstitutiv',),
'konstitutivest': ('konstitutiv',),
'konstitutiveste': ('konstitutiv',),
'konstitutivt': ('konstitutiv',),
'konstruerende': ('konstruere',),
'konstruert': ('konstruere',),
'konstruerte': ('konstruere',),
'konstruktiv': ('konstruktiv',),
'konstruktive': ('konstruktiv',),
'konstruktivere': ('konstruktiv',),
'konstruktivest': ('konstruktiv',),
'konstruktiveste': ('konstruktiv',),
'konstruktivt': ('konstruktiv',),
'konstruktivistisk': ('konstruktivistisk',),
'konstruktivistiske': ('konstruktivistisk',),
'konstruktivistiskere': ('konstruktivistisk',),
'konstruktivistiskest': ('konstruktivistisk',),
'konstruktivistiskeste': ('konstruktivistisk',),
'konsultativ': ('konsultativ',),
'konsultative': ('konsultativ',),
'konsultativere': ('konsultativ',),
'konsultativest': ('konsultativ',),
'konsultativeste': ('konsultativ',),
'konsultativt': ('konsultativ',),
'konsulterende': ('konsultere',),
'konsultert': ('konsultere',),
'konsulterte': ('konsultere',),
'konsulær': ('konsulær',),
'konsulære': ('konsulær',),
'konsulærere': ('konsulær',),
'konsulærest': ('konsulær',),
'konsulæreste': ('konsulær',),
'konsulært': ('konsulær',),
'konsumerende': ('konsumere',),
'konsumert': ('konsumere',),
'konsumerte': ('konsumere',),
'kontakta': ('kontakte',),
'kontaktede': ('kontakte',),
'kontaktende': ('kontakte',),
'kontaktet': ('kontakte',),
'kontaktete': ('kontakte',),
'kontant': ('kontant',),
'kontante': ('kontant',),
'kontantere': ('kontant',),
'kontantest': ('kontant',),
'kontanteste': ('kontant',),
'kontekstuell': ('kontekstuell',),
'kontekstuelle': ('kontekstuell',),
'kontekstuellere': ('kontekstuell',),
'kontekstuellest': ('kontekstuell',),
'kontekstuelleste': ('kontekstuell',),
'kontekstuelt': ('kontekstuell',),
'kontemplativ': ('kontemplativ',),
'kontemplative': ('kontemplativ',),
'kontemplativere': ('kontemplativ',),
'kontemplativest': ('kontemplativ',),
'kontemplativeste': ('kontemplativ',),
'kontemplativt': ('kontemplativ',),
'konterende': ('kontere',),
'kontert': ('kontere',),
'konterte': ('kontere',),
'kontinental': ('kontinental',),
'kontinentale': ('kontinental',),
'kontinentalere': ('kontinental',),
'kontinentalest': ('kontinental',),
'kontinentaleste': ('kontinental',),
'kontinentalt': ('kontinental',),
'kontingent': ('kontingent',),
'kontingente': ('kontingent',),
'kontingentere': ('kontingent',),
'kontingentest': ('kontingent',),
'kontingenteste': ('kontingent',),
'kontingenterende': ('kontingentere',),
'kontingentert': ('kontingentere',),
'kontingenterte': ('kontingentere',),
'kontinuerende': ('kontinuere',),
'kontinuert': ('kontinuere',),
'kontinuerte': ('kontinuere',),
'kontinuerlig': ('kontinuerlig',),
'kontinuerlige': ('kontinuerlig',),
'kontinuerligere': ('kontinuerlig',),
'kontinuerligst': ('kontinuerlig',),
'kontinuerligste': ('kontinuerlig',),
'kontoriserende': ('kontorisere',),
'kontorisert': ('kontorisere',),
'kontoriserte': ('kontorisere',),
'kontra': ('kontra',),
'kontradiktorisk': ('kontradiktorisk',),
'kontradiktoriske': ('kontradiktorisk',),
'kontradiktoriskere': ('kontradiktorisk',),
'kontradiktoriskest': ('kontradiktorisk',),
'kontradiktoriskeste': ('kontradiktorisk',),
'kontraherende': ('kontrahere',),
'kontrahert': ('kontrahere',),
'kontraherte': ('kontrahere',),
'kontraktil': ('kontraktil',),
'kontraktile': ('kontraktil',),
'kontraktilere': ('kontraktil',),
'kontraktilest': ('kontraktil',),
'kontraktileste': ('kontraktil',),
'kontraktilt': ('kontraktil',),
'kontrapunktisk': ('kontrapunktisk',),
'kontrapunktiske': ('kontrapunktisk',),
'kontrapunktiskere': ('kontrapunktisk',),
'kontrapunktiskest': ('kontrapunktisk',),
'kontrapunktiskeste': ('kontrapunktisk',),
'kontrarevolusjonær': ('kontrarevolusjonær',),
'kontrarevolusjonære': ('kontrarevolusjonær',),
'kontrarevolusjonærere': ('kontrarevolusjonær',),
'kontrarevolusjonærest': ('kontrarevolusjonær',),
'kontrarevolusjonæreste': ('kontrarevolusjonær',),
'kontrarevolusjonært': ('kontrarevolusjonær',),
'kontrarevolusjonær': ('kontrarevolusjonær',),
'kontrarevolusjonære': ('kontrarevolusjonær',),
'kontrarevolusjonærere': ('kontrarevolusjonær',),
'kontrarevolusjonærest': ('kontrarevolusjonær',),
'kontrarevolusjonæreste': ('kontrarevolusjonær',),
'kontrarevolusjonært': ('kontrarevolusjonær',),
'kontrari': ('kontrari',),
'kontrasignerende': ('kontrasignere',),
'kontrasignert': ('kontrasignere',),
'kontrasignerte': ('kontrasignere',),
'kontrasterende': ('kontrastere',),
'kontrastert': ('kontrastere',),
'kontrasterte': ('kontrastere',),
'kontrastiv': ('kontrastiv',),
'kontrastive': ('kontrastiv',),
'kontrastivere': ('kontrastiv',),
'kontrastivest': ('kontrastiv',),
'kontrastiveste': ('kontrastiv',),
'kontrastivt': ('kontrastiv',),
'kontra': ('kontre',),
'kontrede': ('kontre',),
'kontrende': ('kontre',),
'kontret': ('kontre',),
'kontrete': ('kontre',),
'kontribuerende': ('kontribuere',),
'kontribuert': ('kontribuere',),
'kontribuerte': ('kontribuere',),
'kontrollerende': ('kontrollere',),
'kontrollert': ('kontrollere',),
'kontrollerte': ('kontrollere',),
'kontroversiell': ('kontroversiell',),
'kontroversielle': ('kontroversiell',),
'kontroversiellere': ('kontroversiell',),
'kontroversiellest': ('kontroversiell',),
'kontroversielleste': ('kontroversiell',),
'kontroversielt': ('kontroversiell',),
'kontrær': ('kontrær',),
'kontrære': ('kontrær',),
'kontrærere': ('kontrær',),
'kontrærest': ('kontrær',),
'kontræreste': ('kontrær',),
'kontrært': ('kontrær',),
'konturlaus': ('konturlaus',),
'konturlause': ('konturlaus',),
'konturlausere': ('konturlaus',),
'konturlausest': ('konturlaus',),
'konturlauseste': ('konturlaus',),
'konturlaust': ('konturlaus',),
'konturløs': ('konturløs',),
'konturløse': ('konturløs',),
'konturløsere': ('konturløs',),
'konturløsest': ('konturløs',),
'konturløseste': ('konturløs',),
'konturløst': ('konturløs',),
'konveks': ('konveks',),
'konvekse': ('konveks',),
'konveksere': ('konveks',),
'konveksest': ('konveks',),
'konvekseste': ('konveks',),
'konvekst': ('konveks',),
'konvektiv': ('konvektiv',),
'konvektive': ('konvektiv',),
'konvektivere': ('konvektiv',),
'konvektivest': ('konvektiv',),
'konvektiveste': ('konvektiv',),
'konvektivt': ('konvektiv',),
'konvensjonell': ('konvensjonell',),
'konvensjonelle': ('konvensjonell',),
'konvensjonellere': ('konvensjonell',),
'konvensjonellest': ('konvensjonell',),
'konvensjonelleste': ('konvensjonell',),
'konvensjonelt': ('konvensjonell',),
'konvergent': ('konvergent',),
'konvergente': ('konvergent',),
'konvergentere': ('konvergent',),
'konvergentest': ('konvergent',),
'konvergenteste': ('konvergent',),
'konvergerende': ('konvergere',),
'konvergert': ('konvergere',),
'konvergerte': ('konvergere',),
'konversabel': ('konversabel',),
'konversabelt': ('konversabel',),
'konversable': ('konversabel',),
'konversablere': ('konversabel',),
'konversablest': ('konversabel',),
'konversableste': ('konversabel',),
'konverserende': ('konversere',),
'konversert': ('konversere',),
'konverserte': ('konversere',),
'konverterende': ('konvertere',),
'konvertert': ('konvertere',),
'konverterte': ('konvertere',),
'konvertibel': ('konvertibel',),
'konvertibelt': ('konvertibel',),
'konvertible': ('konvertibel',),
'konvertiblere': ('konvertibel',),
'konvertiblest': ('konvertibel',),
'konvertibleste': ('konvertibel',),
'konvoierende': ('konvoiere',),
'konvoiert': ('konvoiere',),
'konvoierte': ('konvoiere',),
'konvolutterende': ('konvoluttere',),
'konvoluttert': ('konvoluttere',),
'konvolutterte': ('konvoluttere',),
'konvulsivisk': ('konvulsivisk',),
'konvulsiviske': ('konvulsivisk',),
'konvulsiviskere': ('konvulsivisk',),
'konvulsiviskest': ('konvulsivisk',),
'konvulsiviskeste': ('konvulsivisk',),
'kooperativ': ('kooperativ',),
'kooperative': ('kooperativ',),
'kooperativere': ('kooperativ',),
'kooperativest': ('kooperativ',),
'kooperativeste': ('kooperativ',),
'kooperativt': ('kooperativ',),
'koopererende': ('kooperere',),
'kooperert': ('kooperere',),
'koopererte': ('kooperere',),
'koordinerende': ('koordinere',),
'koordinert': ('koordinere',),
'koordinerte': ('koordinere',),
'kopende': ('kope',),
'kopt': ('kope',),
'kopte': ('kope',),
'kopen': ('kopen',),
'kopent': ('kopen',),
'kopne': ('kopen',),
'kopnere': ('kopen',),
'kopnest': ('kopen',),
'kopneste': ('kopen',),
'kopernikansk': ('kopernikansk',),
'kopernikanske': ('kopernikansk',),
'kopernikanskere': ('kopernikansk',),
'kopernikanskest': ('kopernikansk',),
'kopernikanskeste': ('kopernikansk',),
'kopierende': ('kopiere',),
'kopiert': ('kopiere',),
'kopierte': ('kopiere',),
'kopiøs': ('kopiøs',),
'kopiøse': ('kopiøs',),
'kopiøsere': ('kopiøs',),
'kopiøsest': ('kopiøs',),
'kopiøseste': ('kopiøs',),
'kopiøst': ('kopiøs',),
'kopla': ('kople',),
'koplede': ('kople',),
'koplende': ('kople',),
'koplet': ('kople',),
'koplete': ('kople',),
'kopparret': ('kopparret',),
'kopparrete': ('kopparret',),
'kopparretere': ('kopparret',),
'kopparretest': ('kopparret',),
'kopparreteste': ('kopparret',),
'kopparrete': ('kopparrete',),
'koppa': ('koppe',),
'koppede': ('koppe',),
'koppende': ('koppe',),
'koppet': ('koppe',),
'koppete': ('koppe',),
'kopperbrun': ('kopperbrun',),
'kopperbrune': ('kopperbrun',),
'kopperbrunere': ('kopperbrun',),
'kopperbrunest': ('kopperbrun',),
'kopperbruneste': ('kopperbrun',),
'kopperbrunt': ('kopperbrun',),
'koptisk': ('koptisk',),
'koptiske': ('koptisk',),
'koptiskere': ('koptisk',),
'koptiskest': ('koptisk',),
'koptiskeste': ('koptisk',),
'kopulerende': ('kopulere',),
'kopulert': ('kopulere',),
'kopulerte': ('kopulere',),
'kordial': ('kordial',),
'kordiale': ('kordial',),
'kordialere': ('kordial',),
'kordialest': ('kordial',),
'kordialeste': ('kordial',),
'kordialt': ('kordial',),
'kora': ('kore',),
'korede': ('kore',),
'korende': ('kore',),
'koret': ('kore',),
'korete': ('kore',),
'koreansk': ('koreansk',),
'koreanske': ('koreansk',),
'koreanskere': ('koreansk',),
'koreanskest': ('koreansk',),
'koreanskeste': ('koreansk',),
'koreograferende': ('koreografere',),
'koreografert': ('koreografere',),
'koreograferte': ('koreografere',),
'koreografisk': ('koreografisk',),
'koreografiske': ('koreografisk',),
'koreografiskere': ('koreografisk',),
'koreografiskest': ('koreografisk',),
'koreografiskeste': ('koreografisk',),
'korgblomstra': ('korgblomstra',),
'korgblomstrede': ('korgblomstret',),
'korgblomstret': ('korgblomstret',),
'korgblomstrete': ('korgblomstret',),
'korgblomstretere': ('korgblomstret',),
'korgblomstretest': ('korgblomstret',),
'korgblomstreteste': ('korgblomstret',),
'korintisk': ('korintisk',),
'korintiske': ('korintisk',),
'korintiskere': ('korintisk',),
'korintiskest': ('korintisk',),
'korintiskeste': ('korintisk',),
'korka': ('korka',),
'korka': ('korke',),
'korkede': ('korke',),
'korkende': ('korke',),
'korket': ('korke',),
'korkete': ('korke',),
'kornblå': ('kornblå',),
'kornblåe': ('kornblå',),
'kornblåere': ('kornblå',),
'kornblåest': ('kornblå',),
'kornblåeste': ('kornblå',),
'kornblått': ('kornblå',),
'korna': ('korne',),
'kornede': ('korne',),
'kornende': ('korne',),
'kornet': ('korne',),
'kornete': ('korne',),
'kornet': ('kornet',),
'kornete': ('kornet',),
'kornetere': ('kornet',),
'kornetest': ('kornet',),
'korneteste': ('kornet',),
'kornete': ('kornete',),
'korngul': ('korngul',),
'korngule': ('korngul',),
'korngulere': ('korngul',),
'korngulest': ('korngul',),
'kornguleste': ('korngul',),
'korngult': ('korngul',),
'kornisk': ('kornisk',),
'korniske': ('kornisk',),
'korniskere': ('kornisk',),
'korniskest': ('kornisk',),
'korniskeste': ('kornisk',),
'korporativ': ('korporativ',),
'korporative': ('korporativ',),
'korporativere': ('korporativ',),
'korporativest': ('korporativ',),
'korporativeste': ('korporativ',),
'korporativt': ('korporativ',),
'korporativiserende': ('korporativisere',),
'korporativisert': ('korporativisere',),
'korporativiserte': ('korporativisere',),
'korporlig': ('korporlig',),
'korporlige': ('korporlig',),
'korporligere': ('korporlig',),
'korporligst': ('korporlig',),
'korporligste': ('korporlig',),
'korpulent': ('korpulent',),
'korpulente': ('korpulent',),
'korpulentere': ('korpulent',),
'korpulentest': ('korpulent',),
'korpulenteste': ('korpulent',),
'korrekt': ('korrekt',),
'korrekte': ('korrekt',),
'korrektere': ('korrekt',),
'korrektest': ('korrekt',),
'korrekteste': ('korrekt',),
'korrelativ': ('korrelativ',),
'korrelative': ('korrelativ',),
'korrelativere': ('korrelativ',),
'korrelativest': ('korrelativ',),
'korrelativeste': ('korrelativ',),
'korrelativt': ('korrelativ',),
'korresponderende': ('korrespondere',),
'korrespondert': ('korrespondere',),
'korresponderte': ('korrespondere',),
'korrigerende': ('korrigere',),
'korrigert': ('korrigere',),
'korrigerte': ('korrigere',),
'korroderende': ('korrodere',),
'korrodert': ('korrodere',),
'korroderte': ('korrodere',),
'korrugerende': ('korrugere',),
'korrugert': ('korrugere',),
'korrugerte': ('korrugere',),
'korrumperende': ('korrumpere',),
'korrumpert': ('korrumpere',),
'korrumperte': ('korrumpere',),
'korrupt': ('korrupt',),
'korrupte': ('korrupt',),
'korruptere': ('korrupt',),
'korruptest': ('korrupt',),
'korrupteste': ('korrupt',),
'korsblomstra': ('korsblomstra',),
'korsblomstrede': ('korsblomstret',),
'korsblomstret': ('korsblomstret',),
'korsblomstrete': ('korsblomstret',),
'korsblomstretere': ('korsblomstret',),
'korsblomstretest': ('korsblomstret',),
'korsblomstreteste': ('korsblomstret',),
'korsa': ('korse',),
'korsede': ('korse',),
'korsende': ('korse',),
'korset': ('korse',),
'korsete': ('korse',),
'korsfesta': ('korsfeste',),
'korsfestede': ('korsfeste',),
'korsfestende': ('korsfeste',),
'korsfestet': ('korsfeste',),
'korsfestete': ('korsfeste',),
'korsikansk': ('korsikansk',),
'korsikanske': ('korsikansk',),
'korsikanskere': ('korsikansk',),
'korsikanskest': ('korsikansk',),
'korsikanskeste': ('korsikansk',),
'korslagt': ('korslegge',),
'korslagte': ('korslegge',),
'korsleggende': ('korslegge',),
'kort': ('kort',),
'korte': ('kort',),
'kortere': ('kort',),
'kortest': ('kort',),
'korteste': ('kort',),
'korta': ('korte',),
'kortede': ('korte',),
'kortende': ('korte',),
'kortet': ('korte',),
'kortete': ('korte',),
'korterma': ('korterma',),
'kortermede': ('kortermet',),
'kortermet': ('kortermet',),
'kortermete': ('kortermet',),
'kortermetere': ('kortermet',),
'kortermetest': ('kortermet',),
'kortermeteste': ('kortermet',),
'kortfatta': ('kortfatta',),
'kortfattede': ('kortfattet',),
'kortfattet': ('kortfattet',),
'kortfattete': ('kortfattet',),
'kortfattetere': ('kortfattet',),
'kortfattetest': ('kortfattet',),
'kortfatteteste': ('kortfattet',),
'kortna': ('kortne',),
'kortnede': ('kortne',),
'kortnende': ('kortne',),
'kortnet': ('kortne',),
'kortnete': ('kortne',),
'kortpusta': ('kortpusta',),
'kortpustede': ('kortpustet',),
'kortpustet': ('kortpustet',),
'kortpustete': ('kortpustet',),
'kortpustetere': ('kortpustet',),
'kortpustetest': ('kortpustet',),
'kortpusteteste': ('kortpustet',),
'kortsiktig': ('kortsiktig',),
'kortsiktige': ('kortsiktig',),
'kortsiktigere': ('kortsiktig',),
'kortsiktigst': ('kortsiktig',),
'kortsiktigste': ('kortsiktig',),
'kortskalla': ('kortskalla',),
'kortskallede': ('kortskallet',),
'kortskallet': ('kortskallet',),
'kortskallete': ('kortskallet',),
'kortskalletere': ('kortskallet',),
'kortskalletest': ('kortskallet',),
'kortskalleteste': ('kortskallet',),
'kortslutta': ('kortslutte',),
'kortsluttede': ('kortslutte',),
'kortsluttende': ('kortslutte',),
'kortsluttet': ('kortslutte',),
'kortsluttete': ('kortslutte',),
'kortsynt': ('kortsynt',),
'kortsynte': ('kortsynt',),
'kortsyntere': ('kortsynt',),
'kortsyntest': ('kortsynt',),
'kortsynteste': ('kortsynt',),
'korttenkt': ('korttenkt',),
'korttenkte': ('korttenkt',),
'korttenktere': ('korttenkt',),
'korttenktest': ('korttenkt',),
'korttenkteste': ('korttenkt',),
'kortvarig': ('kortvarig',),
'kortvarige': ('kortvarig',),
'kortvarigere': ('kortvarig',),
'kortvarigst': ('kortvarig',),
'kortvarigste': ('kortvarig',),
'kortvokst': ('kortvokst',),
'kortvokste': ('kortvokst',),
'kortvokstere': ('kortvokst',),
'kortvokstest': ('kortvokst',),
'kortvoksteste': ('kortvokst',),
'kos': ('kos',),
'kose': ('kos',),
'kosere': ('kos',),
'kosest': ('kos',),
'koseste': ('kos',),
'kost': ('kos',),
'koscher': ('koscher',),
'koschere': ('koscher',),
'koscherere': ('koscher',),
'koscherest': ('koscher',),
'koschereste': ('koscher',),
'koschert': ('koscher',),
'kosa': ('kose',),
'kosede': ('kose',),
'kosende': ('kose',),
'koset': ('kose',),
'kosete': ('kose',),
'kost': ('kose',),
'koste': ('kose',),
'koselig': ('koselig',),
'koselige': ('koselig',),
'koseligere': ('koselig',),
'koseligst': ('koselig',),
'koseligste': ('koselig',),
'kosmetisk': ('kosmetisk',),
'kosmetiske': ('kosmetisk',),
'kosmetiskere': ('kosmetisk',),
'kosmetiskest': ('kosmetisk',),
'kosmetiskeste': ('kosmetisk',),
'kosmisk': ('kosmisk',),
'kosmiske': ('kosmisk',),
'kosmiskere': ('kosmisk',),
'kosmiskest': ('kosmisk',),
'kosmiskeste': ('kosmisk',),
'kosmopolitisk': ('kosmopolitisk',),
'kosmopolitiske': ('kosmopolitisk',),
'kosmopolitiskere': ('kosmopolitisk',),
'kosmopolitiskest': ('kosmopolitisk',),
'kosmopolitiskeste': ('kosmopolitisk',),
'kostarikansk': ('kostarikansk',),
'kostarikanske': ('kostarikansk',),
'kostarikanskere': ('kostarikansk',),
'kostarikanskest': ('kostarikansk',),
'kostarikanskeste': ('kostarikansk',),
'kostbar': ('kostbar',),
'kostbare': ('kostbar',),
'kostbarere': ('kostbar',),
'kostbarest': ('kostbar',),
'kostbareste': ('kostbar',),
'kostbart': ('kostbar',),
'kosta': ('koste',),
'kostede': ('koste',),
'kostende': ('koste',),
'kostet': ('koste',),
'kostete': ('koste',),
'kosta': ('koste',),
'kostede': ('koste',),
'kostende': ('koste',),
'kostet': ('koste',),
'kostete': ('koste',),
'kostelig': ('kostelig',),
'kostelige': ('kostelig',),
'kosteligere': ('kostelig',),
'kosteligst': ('kostelig',),
'kosteligste': ('kostelig',),
'kostnadsberegna': ('kostnadsberegne',),
'kostnadsberegnede': ('kostnadsberegne',),
'kostnadsberegnende': ('kostnadsberegne',),
'kostnadsberegnet': ('kostnadsberegne',),
'kostnadsberegnete': ('kostnadsberegne',),
'kostnadsberekna': ('kostnadsberekne',),
'kostnadsbereknede': ('kostnadsberekne',),
'kostnadsbereknende': ('kostnadsberekne',),
'kostnadsbereknet': ('kostnadsberekne',),
'kostnadsbereknete': ('kostnadsberekne',),
'kostymerende': ('kostymere',),
'kostymert': ('kostymere',),
'kostymerte': ('kostymere',),
'kovna': ('kovne',),
'kovnede': ('kovne',),
'kovnende': ('kovne',),
'kovnet': ('kovne',),
'kovnete': ('kovne',),
'krabba': ('krabbe',),
'krabbede': ('krabbe',),
'krabbende': ('krabbe',),
'krabbet': ('krabbe',),
'krabbete': ('krabbe',),
'krafsa': ('krafse',),
'krafsede': ('krafse',),
'krafsende': ('krafse',),
'krafset': ('krafse',),
'krafsete': ('krafse',),
'kraftfull': ('kraftfull',),
'kraftfulle': ('kraftfull',),
'kraftfullere': ('kraftfull',),
'kraftfullest': ('kraftfull',),
'kraftfulleste': ('kraftfull',),
'kraftfullt': ('kraftfull',),
'kraftig': ('kraftig',),
'kraftige': ('kraftig',),
'kraftigere': ('kraftig',),
'kraftigst': ('kraftig',),
'kraftigste': ('kraftig',),
'kraftkrevende': ('kraftkrevende',),
'kraftlaus': ('kraftlaus',),
'kraftlause': ('kraftlaus',),
'kraftlausere': ('kraftlaus',),
'kraftlausest': ('kraftlaus',),
'kraftlauseste': ('kraftlaus',),
'kraftlaust': ('kraftlaus',),
'kraftløs': ('kraftløs',),
'kraftløse': ('kraftløs',),
'kraftløsere': ('kraftløs',),
'kraftløsest': ('kraftløs',),
'kraftløseste': ('kraftløs',),
'kraftløst': ('kraftløs',),
'kraga': ('krage',),
'kragede': ('krage',),
'kragende': ('krage',),
'kraget': ('krage',),
'kragete': ('krage',),
'kraka': ('krake',),
'krakede': ('krake',),
'krakende': ('krake',),
'kraket': ('krake',),
'krakete': ('krake',),
'krakelerende': ('krakelere',),
'krakelert': ('krakelere',),
'krakelerte': ('krakelere',),
'kraket': ('kraket',),
'krakete': ('kraket',),
'kraketere': ('kraket',),
'kraketest': ('kraket',),
'kraketeste': ('kraket',),
'krakete': ('krakete',),
'krakilsk': ('krakilsk',),
'krakilske': ('krakilsk',),
'krakilskere': ('krakilsk',),
'krakilskest': ('krakilsk',),
'krakilskeste': ('krakilsk',),
'krakka': ('krakke',),
'krakkede': ('krakke',),
'krakkende': ('krakke',),
'krakket': ('krakke',),
'krakkete': ('krakke',),
'kram': ('kram',),
'kramme': ('kram',),
'krammere': ('kram',),
'krammest': ('kram',),
'krammeste': ('kram',),
'kramt': ('kram',),
'kramma': ('kramme',),
'krammede': ('kramme',),
'krammende': ('kramme',),
'krammet': ('kramme',),
'krammete': ('kramme',),
'kramma': ('kramme',),
'krammede': ('kramme',),
'krammende': ('kramme',),
'krammet': ('kramme',),
'krammete': ('kramme',),
'krampaktig': ('krampaktig',),
'krampaktige': ('krampaktig',),
'krampaktigere': ('krampaktig',),
'krampaktigst': ('krampaktig',),
'krampaktigste': ('krampaktig',),
'kramsa': ('kramse',),
'kramsede': ('kramse',),
'kramsende': ('kramse',),
'kramset': ('kramse',),
'kramsete': ('kramse',),
'krangla': ('krangle',),
'kranglede': ('krangle',),
'kranglende': ('krangle',),
'kranglet': ('krangle',),
'kranglete': ('krangle',),
'kranglet': ('kranglet',),
'kranglete': ('kranglet',),
'krangletere': ('kranglet',),
'krangletest': ('kranglet',),
'krangleteste': ('kranglet',),
'kranglete': ('kranglete',),
'kranglevoren': ('kranglevoren',),
'kranglevorent': ('kranglevoren',),
'kranglevorne': ('kranglevoren',),
'kranglevornere': ('kranglevoren',),
'kranglevornest': ('kranglevoren',),
'kranglevorneste': ('kranglevoren',),
'krank': ('krank',),
'kranke': ('krank',),
'krankere': ('krank',),
'krankest': ('krank',),
'krankeste': ('krank',),
'krankt': ('krank',),
'kransa': ('kranse',),
'kransede': ('kranse',),
'kransende': ('kranse',),
'kranset': ('kranse',),
'kransete': ('kranse',),
'kransstilt': ('kransstilt',),
'kransstilte': ('kransstilt',),
'kransstiltere': ('kransstilt',),
'kransstiltest': ('kransstilt',),
'kransstilteste': ('kransstilt',),
'krapp': ('krapp',),
'krappe': ('krapp',),
'krappere': ('krapp',),
'krappest': ('krapp',),
'krappeste': ('krapp',),
'krapt': ('krapp',),
'krasa': ('krase',),
'krasede': ('krase',),
'krasende': ('krase',),
'kraset': ('krase',),
'krasete': ('krase',),
'krast': ('krase',),
'kraste': ('krase',),
'krasja': ('krasje',),
'krasjede': ('krasje',),
'krasjende': ('krasje',),
'krasjet': ('krasje',),
'krasjete': ('krasje',),
'krasjlanda': ('krasjlande',),
'krasjlandede': ('krasjlande',),
'krasjlandende': ('krasjlande',),
'krasjlandet': ('krasjlande',),
'krasjlandete': ('krasjlande',),
'krasla': ('krasle',),
'kraslede': ('krasle',),
'kraslende': ('krasle',),
'kraslet': ('krasle',),
'kraslete': ('krasle',),
'krass': ('krass',),
'krasse': ('krass',),
'krassere': ('krass',),
'krassest': ('krass',),
'krasseste': ('krass',),
'krast': ('krass',),
'krassa': ('krasse',),
'krassede': ('krasse',),
'krassende': ('krasse',),
'krasset': ('krasse',),
'krassete': ('krasse',),
'krauma': ('kraume',),
'kraumede': ('kraume',),
'kraumende': ('kraume',),
'kraumet': ('kraume',),
'kraumete': ('kraume',),
'krava': ('krave',),
'kravede': ('krave',),
'kravende': ('krave',),
'kravet': ('krave',),
'kravete': ('krave',),
'kravellbygd': ('kravellbygd',),
'kravellbygde': ('kravellbygd',),
'kravellbygdere': ('kravellbygd',),
'kravellbygdest': ('kravellbygd',),
'kravellbygdeste': ('kravellbygd',),
'kravfull': ('kravfull',),
'kravfulle': ('kravfull',),
'kravfullere': ('kravfull',),
'kravfullest': ('kravfull',),
'kravfulleste': ('kravfull',),
'kravfullt': ('kravfull',),
'kravlaus': ('kravlaus',),
'kravlause': ('kravlaus',),
'kravlausere': ('kravlaus',),
'kravlausest': ('kravlaus',),
'kravlauseste': ('kravlaus',),
'kravlaust': ('kravlaus',),
'kravla': ('kravle',),
'kravlede': ('kravle',),
'kravlende': ('kravle',),
'kravlet': ('kravle',),
'kravlete': ('kravle',),
'kravløs': ('kravløs',),
'kravløse': ('kravløs',),
'kravløsere': ('kravløs',),
'kravløsest': ('kravløs',),
'kravløseste': ('kravløs',),
'kravløst': ('kravløs',),
'kravstor': ('kravstor',),
'kravstore': ('kravstor',),
'kravstort': ('kravstor',),
'kravstørre': ('kravstor',),
'kravstørst': ('kravstor',),
'kravstørste': ('kravstor',),
'kreativ': ('kreativ',),
'kreative': ('kreativ',),
'kreativere': ('kreativ',),
'kreativest': ('kreativ',),
'kreativeste': ('kreativ',),
'kreativt': ('kreativ',),
'krediterende': ('kreditere',),
'kreditert': ('kreditere',),
'krediterte': ('kreditere',),
'kreerende': ('kreere',),
'kreert': ('kreere',),
'kreerte': ('kreere',),
'kreista': ('kreiste',),
'kreistede': ('kreiste',),
'kreistende': ('kreiste',),
'kreistet': ('kreiste',),
'kreistete': ('kreiste',),
'kreka': ('kreke',),
'krekede': ('kreke',),
'kreken': ('kreke',),
'krekende': ('kreke',),
'kreket': ('kreke',),
'krekete': ('kreke',),
'krekne': ('kreke',),
'krekt': ('kreke',),
'krekte': ('kreke',),
'kremerende': ('kremere',),
'kremert': ('kremere',),
'kremerte': ('kremere',),
'kremta': ('kremte',),
'kremtede': ('kremte',),
'kremtende': ('kremte',),
'kremtet': ('kremte',),
'kremtete': ('kremte',),
'krenelerende': ('krenelere',),
'krenelert': ('krenelere',),
'krenelerte': ('krenelere',),
'krenga': ('krenge',),
'krengede': ('krenge',),
'krengende': ('krenge',),
'krenget': ('krenge',),
'krengete': ('krenge',),
'krengt': ('krenge',),
'krengte': ('krenge',),
'krenka': ('krenke',),
'krenkede': ('krenke',),
'krenkende': ('krenke',),
'krenket': ('krenke',),
'krenkete': ('krenke',),
'krenkt': ('krenke',),
'krenkte': ('krenke',),
'kreolsk': ('kreolsk',),
'kreolske': ('kreolsk',),
'kreolskere': ('kreolsk',),
'kreolskest': ('kreolsk',),
'kreolskeste': ('kreolsk',),
'kreperende': ('krepere',),
'krepert': ('krepere',),
'kreperte': ('krepere',),
'kreppa': ('kreppe',),
'kreppede': ('kreppe',),
'kreppende': ('kreppe',),
'kreppet': ('kreppe',),
'kreppete': ('kreppe',),
'krept': ('kreppe',),
'krepte': ('kreppe',),
'kreppa': ('kreppe',),
'kreppede': ('kreppe',),
'kreppende': ('kreppe',),
'kreppet': ('kreppe',),
'kreppete': ('kreppe',),
'krept': ('kreppe',),
'krepte': ('kreppe',),
'krepsa': ('krepse',),
'krepsede': ('krepse',),
'krepsende': ('krepse',),
'krepset': ('krepse',),
'krepsete': ('krepse',),
'kresen': ('kresen',),
'kresent': ('kresen',),
'kresne': ('kresen',),
'kresnere': ('kresen',),
'kresnest': ('kresen',),
'kresneste': ('kresen',),
'kretasisk': ('kretasisk',),
'kretasiske': ('kretasisk',),
'kretasiskere': ('kretasisk',),
'kretasiskest': ('kretasisk',),
'kretasiskeste': ('kretasisk',),
'kretisk': ('kretisk',),
'kretiske': ('kretisk',),
'kretiskere': ('kretisk',),
'kretiskest': ('kretisk',),
'kretiskeste': ('kretisk',),
'kretsa': ('kretse',),
'kretsede': ('kretse',),
'kretsende': ('kretse',),
'kretset': ('kretse',),
'kretsete': ('kretse',),
'kreva': ('kreve',),
'krevd': ('kreve',),
'krevde': ('kreve',),
'krevede': ('kreve',),
'krevende': ('kreve',),
'krevet': ('kreve',),
'krevete': ('kreve',),
'kribla': ('krible',),
'kriblede': ('krible',),
'kriblende': ('krible',),
'kriblet': ('krible',),
'kriblete': ('krible',),
'kriga': ('krige',),
'krigede': ('krige',),
'krigende': ('krige',),
'kriget': ('krige',),
'krigete': ('krige',),
'krigersk': ('krigersk',),
'krigerske': ('krigersk',),
'krigerskere': ('krigersk',),
'krigerskest': ('krigersk',),
'krigerskeste': ('krigersk',),
'krigførende': ('krigførende',),
'krikla': ('krikle',),
'kriklede': ('krikle',),
'kriklende': ('krikle',),
'kriklet': ('krikle',),
'kriklete': ('krikle',),
'krilla': ('krille',),
'krillede': ('krille',),
'krillende': ('krille',),
'krillet': ('krille',),
'krillete': ('krille',),
'krimfull': ('krimfull',),
'krimfulle': ('krimfull',),
'krimfullere': ('krimfull',),
'krimfullest': ('krimfull',),
'krimfulleste': ('krimfull',),
'krimfullt': ('krimfull',),
'kriminal': ('kriminal',),
'kriminale': ('kriminal',),
'kriminalere': ('kriminal',),
'kriminalest': ('kriminal',),
'kriminaleste': ('kriminal',),
'kriminalt': ('kriminal',),
'kriminaliserende': ('kriminalisere',),
'kriminalisert': ('kriminalisere',),
'kriminaliserte': ('kriminalisere',),
'kriminell': ('kriminell',),
'kriminelle': ('kriminell',),
'kriminellere': ('kriminell',),
'kriminellest': ('kriminell',),
'kriminelleste': ('kriminell',),
'kriminelt': ('kriminell',),
'krimsjuk': ('krimsjuk',),
'krimsjuke': ('krimsjuk',),
'krimsjukere': ('krimsjuk',),
'krimsjukest': ('krimsjuk',),
'krimsjukeste': ('krimsjuk',),
'krimsjukt': ('krimsjuk',),
'kring': ('kring',),
'kringe': ('kring',),
'kringere': ('kring',),
'kringest': ('kring',),
'kringeste': ('kring',),
'kringt': ('kring',),
'kringgående': ('kringgå',),
'kringgått': ('kringgå',),
'kringgåtte': ('kringgå',),
'kringkasta': ('kringkaste',),
'kringkastede': ('kringkaste',),
'kringkastende': ('kringkaste',),
'kringkastet': ('kringkaste',),
'kringkastete': ('kringkaste',),
'kringsatt': ('kringsette',),
'kringsatte': ('kringsette',),
'kringsettende': ('kringsette',),
'krinsa': ('krinse',),
'krinsede': ('krinse',),
'krinsende': ('krinse',),
'krinset': ('krinse',),
'krinsete': ('krinse',),
'krinst': ('krinse',),
'krinste': ('krinse',),
'krisla': ('krisle',),
'krislede': ('krisle',),
'krislende': ('krisle',),
'krislet': ('krisle',),
'krislete': ('krisle',),
'kristelig': ('kristelig',),
'kristelige': ('kristelig',),
'kristeligere': ('kristelig',),
'kristeligst': ('kristelig',),
'kristeligste': ('kristelig',),
'kristen': ('kristen',),
'kristent': ('kristen',),
'kristne': ('kristen',),
'kristnere': ('kristen',),
'kristnest': ('kristen',),
'kristneste': ('kristen',),
'kristna': ('kristne',),
'kristnede': ('kristne',),
'kristnende': ('kristne',),
'kristnet': ('kristne',),
'kristnete': ('kristne',),
'krita': ('krite',),
'kritede': ('krite',),
'kritende': ('krite',),
'kritet': ('krite',),
'kritete': ('krite',),
'kritikklaus': ('kritikklaus',),
'kritikklause': ('kritikklaus',),
'kritikklausere': ('kritikklaus',),
'kritikklausest': ('kritikklaus',),
'kritikklauseste': ('kritikklaus',),
'kritikklaust': ('kritikklaus',),
'kritikkløs': ('kritikkløs',),
'kritikkløse': ('kritikkløs',),
'kritikkløsere': ('kritikkløs',),
'kritikkløsest': ('kritikkløs',),
'kritikkløseste': ('kritikkløs',),
'kritikkløst': ('kritikkløs',),
'kritiserende': ('kritisere',),
'kritisert': ('kritisere',),
'kritiserte': ('kritisere',),
'kritisk': ('kritisk',),
'kritiske': ('kritisk',),
'kritiskere': ('kritisk',),
'kritiskest': ('kritisk',),
'kritiskeste': ('kritisk',),
'kritla': ('kritle',),
'kritlede': ('kritle',),
'kritlende': ('kritle',),
'kritlet': ('kritle',),
'kritlete': ('kritle',),
'kritta': ('kritte',),
'krittede': ('kritte',),
'krittende': ('kritte',),
'krittet': ('kritte',),
'krittete': ('kritte',),
'kritthvit': ('kritthvit',),
'kritthvite': ('kritthvit',),
'kritthvitere': ('kritthvit',),
'kritthvitest': ('kritthvit',),
'kritthviteste': ('kritthvit',),
'kritthvitt': ('kritthvit',),
'krittkvit': ('krittkvit',),
'krittkvite': ('krittkvit',),
'krittkvitere': ('krittkvit',),
'krittkvitest': ('krittkvit',),
'krittkviteste': ('krittkvit',),
'krittkvitt': ('krittkvit',),
'krodd': ('kro',),
'krodde': ('kro',),
'kroende': ('kro',),
'kroatisk': ('kroatisk',),
'kroatiske': ('kroatisk',),
'kroatiskere': ('kroatisk',),
'kroatiskest': ('kroatisk',),
'kroatiskeste': ('kroatisk',),
'krokbøyd': ('krokbøyd',),
'krokbøyde': ('krokbøyd',),
'krokbøydere': ('krokbøyd',),
'krokbøydest': ('krokbøyd',),
'krokbøydeste': ('krokbøyd',),
'kroka': ('kroke',),
'krokede': ('kroke',),
'krokende': ('kroke',),
'kroket': ('kroke',),
'krokete': ('kroke',),
'krokerende': ('krokere',),
'krokert': ('krokere',),
'krokerte': ('krokere',),
'kroket': ('kroket',),
'krokete': ('kroket',),
'kroketere': ('kroket',),
'kroketest': ('kroket',),
'kroketeste': ('kroket',),
'krokete': ('krokete',),
'krokkerende': ('krokkere',),
'krokkert': ('krokkere',),
'krokkerte': ('krokkere',),
'krokna': ('krokne',),
'kroknede': ('krokne',),
'kroknende': ('krokne',),
'kroknet': ('krokne',),
'kroknete': ('krokne',),
'krokrygga': ('krokrygga',),
'krokryggede': ('krokrygget',),
'krokrygget': ('krokrygget',),
'krokryggete': ('krokrygget',),
'krokryggetere': ('krokrygget',),
'krokryggetest': ('krokrygget',),
'krokryggeteste': ('krokrygget',),
'kromatisk': ('kromatisk',),
'kromatiske': ('kromatisk',),
'kromatiskere': ('kromatisk',),
'kromatiskest': ('kromatisk',),
'kromatiskeste': ('kromatisk',),
'kromgarva': ('kromgarve',),
'kromgarvede': ('kromgarve',),
'kromgarvende': ('kromgarve',),
'kromgarvet': ('kromgarve',),
'kromgarvete': ('kromgarve',),
'krona': ('krone',),
'kronede': ('krone',),
'kronende': ('krone',),
'kronet': ('krone',),
'kronete': ('krone',),
'kront': ('krone',),
'kronte': ('krone',),
'kronglet': ('kronglet',),
'kronglete': ('kronglet',),
'krongletere': ('kronglet',),
'krongletest': ('kronglet',),
'krongleteste': ('kronglet',),
'kronglete': ('kronglete',),
'kronglete': ('kronglete',),
'kronikkerende': ('kronikkere',),
'kronikkert': ('kronikkere',),
'kronikkerte': ('kronikkere',),
'kronisk': ('kronisk',),
'kroniske': ('kronisk',),
'kroniskere': ('kronisk',),
'kroniskest': ('kronisk',),
'kroniskeste': ('kronisk',),
'kronologisk': ('kronologisk',),
'kronologiske': ('kronologisk',),
'kronologiskere': ('kronologisk',),
'kronologiskest': ('kronologisk',),
'kronologiskeste': ('kronologisk',),
'kroppslig': ('kroppslig',),
'kroppslige': ('kroppslig',),
'kroppsligere': ('kroppslig',),
'kroppsligst': ('kroppslig',),
'kroppsligste': ('kroppslig',),
'kroppsvisiterende': ('kroppsvisitere',),
'kroppsvisitert': ('kroppsvisitere',),
'kroppsvisiterte': ('kroppsvisitere',),
'krota': ('krote',),
'krotede': ('krote',),
'krotende': ('krote',),
'krotet': ('krote',),
'krotete': ('krote',),
'krugg': ('krugg',),
'krugge': ('krugg',),
'kruggere': ('krugg',),
'kruggest': ('krugg',),
'kruggeste': ('krugg',),
'krugt': ('krugg',),
'krugget': ('krugget',),
'kruggete': ('krugget',),
'kruggetere': ('krugget',),
'kruggetest': ('krugget',),
'kruggeteste': ('krugget',),
'kruggete': ('kruggete',),
'krukende': ('kruke',),
'krukt': ('kruke',),
'krukte': ('kruke',),
'kruksa': ('krukse',),
'kruksede': ('krukse',),
'kruksende': ('krukse',),
'krukset': ('krukse',),
'kruksete': ('krukse',),
'kruksen': ('kruksen',),
'kruksent': ('kruksen',),
'kruksne': ('kruksen',),
'kruksnere': ('kruksen',),
'kruksnest': ('kruksen',),
'kruksneste': ('kruksen',),
'krulla': ('krulle',),
'krullede': ('krulle',),
'krullende': ('krulle',),
'krullet': ('krulle',),
'krullete': ('krulle',),
'krullet': ('krullet',),
'krullete': ('krullet',),
'krulletere': ('krullet',),
'krulletest': ('krullet',),
'krulleteste': ('krullet',),
'krullete': ('krullete',),
'krum': ('krum',),
'krumme': ('krum',),
'krummere': ('krum',),
'krummest': ('krum',),
'krummeste': ('krum',),
'krumt': ('krum',),
'krumbøyd': ('krumbøyd',),
'krumbøyde': ('krumbøyd',),
'krumbøydere': ('krumbøyd',),
'krumbøydest': ('krumbøyd',),
'krumbøydeste': ('krumbøyd',),
'krumma': ('krumme',),
'krummede': ('krumme',),
'krummende': ('krumme',),
'krummet': ('krumme',),
'krummete': ('krumme',),
'krumrygga': ('krumrygga',),
'krumryggede': ('krumrygget',),
'krumrygget': ('krumrygget',),
'krumryggete': ('krumrygget',),
'krumryggetere': ('krumrygget',),
'krumryggetest': ('krumrygget',),
'krumryggeteste': ('krumrygget',),
'krunglet': ('krunglet',),
'krunglete': ('krunglet',),
'krungletere': ('krunglet',),
'krungletest': ('krunglet',),
'krungleteste': ('krunglet',),
'krunglet': ('krunglet',),
'krunglete': ('krunglet',),
'krungletere': ('krunglet',),
'krungletest': ('krunglet',),
'krungleteste': ('krunglet',),
'krunglete': ('krunglete',),
'krusa': ('kruse',),
'krusede': ('kruse',),
'krusende': ('kruse',),
'kruset': ('kruse',),
'krusete': ('kruse',),
'krust': ('kruse',),
'kruste': ('kruse',),
'kruset': ('kruset',),
'krusete': ('kruset',),
'krusetere': ('kruset',),
'krusetest': ('kruset',),
'kruseteste': ('kruset',),
'krusete': ('krusete',),
'krusla': ('krusle',),
'kruslede': ('krusle',),
'kruslende': ('krusle',),
'kruslet': ('krusle',),
'kruslete': ('krusle',),
'kruslet': ('kruslet',),
'kruslete': ('kruslet',),
'krusletere': ('kruslet',),
'krusletest': ('kruslet',),
'krusleteste': ('kruslet',),
'kruslete': ('kruslete',),
'kruttsterk': ('kruttsterk',),
'kruttsterke': ('kruttsterk',),
'kruttsterkere': ('kruttsterk',),
'kruttsterkest': ('kruttsterk',),
'kruttsterkeste': ('kruttsterk',),
'kruttsterkt': ('kruttsterk',),
'krydd': ('kry',),
'krydde': ('kry',),
'kryende': ('kry',),
'kry': ('kry',),
'krye': ('kry',),
'kryere': ('kry',),
'kryest': ('kry',),
'kryeste': ('kry',),
'krydra': ('krydre',),
'krydrede': ('krydre',),
'krydrende': ('krydre',),
'krydret': ('krydre',),
'krydrete': ('krydre',),
'krylrygga': ('krylrygga',),
'krylryggede': ('krylrygget',),
'krylrygget': ('krylrygget',),
'krylryggete': ('krylrygget',),
'krylryggetere': ('krylrygget',),
'krylryggetest': ('krylrygget',),
'krylryggeteste': ('krylrygget',),
'krympa': ('krympe',),
'krympede': ('krympe',),
'krympende': ('krympe',),
'krympet': ('krympe',),
'krympete': ('krympe',),
'krynende': ('kryne',),
'krynt': ('kryne',),
'krynte': ('kryne',),
'krypende': ('krype',),
'krøpen': ('krype',),
'krøpet': ('krype',),
'krøpne': ('krype',),
'krypterende': ('kryptere',),
'kryptert': ('kryptere',),
'krypterte': ('kryptere',),
'kryptifiserende': ('kryptifisere',),
'kryptifisert': ('kryptifisere',),
'kryptifiserte': ('kryptifisere',),
'kryptisk': ('kryptisk',),
'kryptiske': ('kryptisk',),
'kryptiskere': ('kryptisk',),
'kryptiskest': ('kryptisk',),
'kryptiskeste': ('kryptisk',),
'kryptogam': ('kryptogam',),
'kryptogame': ('kryptogam',),
'kryptogamere': ('kryptogam',),
'kryptogamest': ('kryptogam',),
'kryptogameste': ('kryptogam',),
'kryptogamt': ('kryptogam',),
'kryptogen': ('kryptogen',),
'kryptogene': ('kryptogen',),
'kryptogenere': ('kryptogen',),
'kryptogenest': ('kryptogen',),
'kryptogeneste': ('kryptogen',),
'kryptogent': ('kryptogen',),
'kryptogenetisk': ('kryptogenetisk',),
'kryptogenetiske': ('kryptogenetisk',),
'kryptogenetiskere': ('kryptogenetisk',),
'kryptogenetiskest': ('kryptogenetisk',),
'kryptogenetiskeste': ('kryptogenetisk',),
'kryssa': ('krysse',),
'kryssede': ('krysse',),
'kryssende': ('krysse',),
'krysset': ('krysse',),
'kryssete': ('krysse',),
'kryssa': ('krysse',),
'kryssede': ('krysse',),
'kryssende': ('krysse',),
'krysset': ('krysse',),
'kryssete': ('krysse',),
'kryssforhørende': ('kryssforhøre',),
'kryssforhørt': ('kryssforhøre',),
'kryssforhørte': ('kryssforhøre',),
'kryssklippa': ('kryssklippe',),
'kryssklippede': ('kryssklippe',),
'kryssklippende': ('kryssklippe',),
'kryssklippet': ('kryssklippe',),
'kryssklippete': ('kryssklippe',),
'kryssklipt': ('kryssklippe',),
'kryssklipte': ('kryssklippe',),
'krystallin': ('krystallin',),
'krystalline': ('krystallin',),
'krystallinere': ('krystallin',),
'krystallinest': ('krystallin',),
'krystallineste': ('krystallin',),
'krystallint': ('krystallin',),
'krystallinsk': ('krystallinsk',),
'krystallinske': ('krystallinsk',),
'krystallinskere': ('krystallinsk',),
'krystallinskest': ('krystallinsk',),
'krystallinskeste': ('krystallinsk',),
'krystalliserende': ('krystallisere',),
'krystallisert': ('krystallisere',),
'krystalliserte': ('krystallisere',),
'krystallisk': ('krystallisk',),
'krystalliske': ('krystallisk',),
'krystalliskere': ('krystallisk',),
'krystalliskest': ('krystallisk',),
'krystalliskeste': ('krystallisk',),
'krystallklar': ('krystallklar',),
'krystallklare': ('krystallklar',),
'krystallklarere': ('krystallklar',),
'krystallklarest': ('krystallklar',),
'krystallklareste': ('krystallklar',),
'krystallklart': ('krystallklar',),
'krysta': ('kryste',),
'krystede': ('kryste',),
'krystende': ('kryste',),
'krystet': ('kryste',),
'krystete': ('kryste',),
'kråla': ('kråle',),
'krålede': ('kråle',),
'krålende': ('kråle',),
'krålet': ('kråle',),
'krålete': ('kråle',),
'krålt': ('kråle',),
'krålte': ('kråle',),
'krøka': ('krøke',),
'krøkede': ('krøke',),
'krøkende': ('krøke',),
'krøket': ('krøke',),
'krøkete': ('krøke',),
'krøkt': ('krøke',),
'krøkte': ('krøke',),
'krøken': ('krøken',),
'krøkent': ('krøken',),
'krøkne': ('krøken',),
'krøknere': ('krøken',),
'krøknest': ('krøken',),
'krøkneste': ('krøken',),
'krøkket': ('krøkket',),
'krøkkete': ('krøkket',),
'krøkketere': ('krøkket',),
'krøkketest': ('krøkket',),
'krøkketeste': ('krøkket',),
'krøkkete': ('krøkkete',),
'krøklet': ('krøklet',),
'krøklete': ('krøklet',),
'krøkletere': ('krøklet',),
'krøkletest': ('krøklet',),
'krøkleteste': ('krøklet',),
'krøklete': ('krøklete',),
'krøkna': ('krøkne',),
'krøknede': ('krøkne',),
'krøknende': ('krøkne',),
'krøknet': ('krøkne',),
'krøknete': ('krøkne',),
'krølla': ('krølle',),
'krøllede': ('krølle',),
'krøllende': ('krølle',),
'krøllet': ('krølle',),
'krøllete': ('krølle',),
'krøllet': ('krøllet',),
'krøllete': ('krøllet',),
'krølletere': ('krøllet',),
'krølletest': ('krøllet',),
'krølleteste': ('krøllet',),
'krøllete': ('krøllete',),
'krøpla': ('krøple',),
'krøplede': ('krøple',),
'krøplende': ('krøple',),
'krøplet': ('krøple',),
'krøplete': ('krøple',),
'krøssa': ('krøsse',),
'krøssede': ('krøsse',),
'krøssende': ('krøsse',),
'krøsset': ('krøsse',),
'krøssete': ('krøsse',),
'kubansk': ('kubansk',),
'kubanske': ('kubansk',),
'kubanskere': ('kubansk',),
'kubanskest': ('kubansk',),
'kubanskeste': ('kubansk',),
'kubba': ('kubbe',),
'kubbede': ('kubbe',),
'kubbende': ('kubbe',),
'kubbet': ('kubbe',),
'kubbete': ('kubbe',),
'kubbet': ('kubbet',),
'kubbete': ('kubbet',),
'kubbetere': ('kubbet',),
'kubbetest': ('kubbet',),
'kubbeteste': ('kubbet',),
'kubbete': ('kubbete',),
'kuba': ('kube',),
'kubede': ('kube',),
'kubende': ('kube',),
'kubet': ('kube',),
'kubete': ('kube',),
'kuberende': ('kubere',),
'kubert': ('kubere',),
'kuberte': ('kubere',),
'kubisk': ('kubisk',),
'kubiske': ('kubisk',),
'kubiskere': ('kubisk',),
'kubiskest': ('kubisk',),
'kubiskeste': ('kubisk',),
'kubistisk': ('kubistisk',),
'kubistiske': ('kubistisk',),
'kubistiskere': ('kubistisk',),
'kubistiskest': ('kubistisk',),
'kubistiskeste': ('kubistisk',),
'kua': ('kue',),
'kuede': ('kue',),
'kuende': ('kue',),
'kuet': ('kue',),
'kuete': ('kue',),
'kujonerende': ('kujonere',),
'kujonert': ('kujonere',),
'kujonerte': ('kujonere',),
'kukelurende': ('kukelure',),
'kukelurt': ('kukelure',),
'kukelurte': ('kukelure',),
'kul': ('kul',),
'kule': ('kul',),
'kulere': ('kul',),
'kulest': ('kul',),
'kuleste': ('kul',),
'kult': ('kul',),
'kuldskjær': ('kuldskjær',),
'kuldskjære': ('kuldskjær',),
'kuldskjærere': ('kuldskjær',),
'kuldskjærest': ('kuldskjær',),
'kuldskjæreste': ('kuldskjær',),
'kuldskjært': ('kuldskjær',),
'kuldslående': ('kuldslå',),
'kuldslått': ('kuldslå',),
'kuldslåtte': ('kuldslå',),
'kula': ('kule',),
'kulede': ('kule',),
'kulende': ('kule',),
'kulet': ('kule',),
'kulete': ('kule',),
'kult': ('kule',),
'kulte': ('kule',),
'kula': ('kule',),
'kulede': ('kule',),
'kulende': ('kule',),
'kulet': ('kule',),
'kulete': ('kule',),
'kult': ('kule',),
'kulte': ('kule',),
'kulinarisk': ('kulinarisk',),
'kulinariske': ('kulinarisk',),
'kulinariskere': ('kulinarisk',),
'kulinariskest': ('kulinarisk',),
'kulinariskeste': ('kulinarisk',),
'kull-lysende': ('kull-lyse',),
'kull-lyst': ('kull-lyse',),
'kull-lyste': ('kull-lyse',),
'kullet': ('kullet',),
'kullete': ('kullet',),
'kulletere': ('kullet',),
'kulletest': ('kullet',),
'kulleteste': ('kullet',),
'kullete': ('kullete',),
'kullkasta': ('kullkaste',),
'kullkastede': ('kullkaste',),
'kullkastende': ('kullkaste',),
'kullkastet': ('kullkaste',),
'kullkastete': ('kullkaste',),
'kullmørk': ('kullmørk',),
'kullmørke': ('kullmørk',),
'kullmørkere': ('kullmørk',),
'kullmørkest': ('kullmørk',),
'kullmørkeste': ('kullmørk',),
'kullmørkt': ('kullmørk',),
'kullmørk': ('kullmørk',),
'kullmørke': ('kullmørk',),
'kullmørkere': ('kullmørk',),
'kullmørkest': ('kullmørk',),
'kullmørkeste': ('kullmørk',),
'kullmørkt': ('kullmørk',),
'kullsegla': ('kullsegle',),
'kullseglede': ('kullsegle',),
'kullseglende': ('kullsegle',),
'kullseglet': ('kullsegle',),
'kullseglete': ('kullsegle',),
'kullseilende': ('kullseile',),
'kullseilt': ('kullseile',),
'kullseilte': ('kullseile',),
'kullsvart': ('kullsvart',),
'kullsvarte': ('kullsvart',),
'kullsvartere': ('kullsvart',),
'kullsvartest': ('kullsvart',),
'kullsvarteste': ('kullsvart',),
'kullysende': ('kullyse',),
'kullyst': ('kullyse',),
'kullyste': ('kullyse',),
'kulminerende': ('kulminere',),
'kulminert': ('kulminere',),
'kulminerte': ('kulminere',),
'kulsa': ('kulse',),
'kulsede': ('kulse',),
'kulsende': ('kulse',),
'kulset': ('kulse',),
'kulsete': ('kulse',),
'kulsen': ('kulsen',),
'kulsent': ('kulsen',),
'kulsne': ('kulsen',),
'kulsnere': ('kulsen',),
'kulsnest': ('kulsen',),
'kulsneste': ('kulsen',),
'kulska': ('kulske',),
'kulskede': ('kulske',),
'kulskende': ('kulske',),
'kulsket': ('kulske',),
'kulskete': ('kulske',),
'kulslig': ('kulslig',),
'kulslige': ('kulslig',),
'kulsligere': ('kulslig',),
'kulsligst': ('kulslig',),
'kulsligste': ('kulslig',),
'kulta': ('kulte',),
'kultede': ('kulte',),
'kultende': ('kulte',),
'kultet': ('kulte',),
'kultete': ('kulte',),
'kulten': ('kulten',),
'kultent': ('kulten',),
'kultne': ('kulten',),
'kultnere': ('kulten',),
'kultnest': ('kulten',),
'kultneste': ('kulten',),
'kulten': ('kulten',),
'kultent': ('kulten',),
'kultne': ('kulten',),
'kultnere': ('kulten',),
'kultnest': ('kulten',),
'kultneste': ('kulten',),
'kultisk': ('kultisk',),
'kultiske': ('kultisk',),
'kultiskere': ('kultisk',),
'kultiskest': ('kultisk',),
'kultiskeste': ('kultisk',),
'kultiverende': ('kultivere',),
'kultivert': ('kultivere',),
'kultiverte': ('kultivere',),
'kulturell': ('kulturell',),
'kulturelle': ('kulturell',),
'kulturellere': ('kulturell',),
'kulturellest': ('kulturell',),
'kulturelleste': ('kulturell',),
'kulturelt': ('kulturell',),
'kulørt': ('kulørt',),
'kulørte': ('kulørt',),
'kulørtere': ('kulørt',),
'kulørtest': ('kulørt',),
'kulørteste': ('kulørt',),
'kumla': ('kumle',),
'kumlede': ('kumle',),
'kumlende': ('kumle',),
'kumlet': ('kumle',),
'kumlete': ('kumle',),
'kummerlig': ('kummerlig',),
'kummerlige': ('kummerlig',),
'kummerligere': ('kummerlig',),
'kummerligst': ('kummerlig',),
'kummerligste': ('kummerlig',),
'kumulativ': ('kumulativ',),
'kumulative': ('kumulativ',),
'kumulativere': ('kumulativ',),
'kumulativest': ('kumulativ',),
'kumulativeste': ('kumulativ',),
'kumulativt': ('kumulativ',),
'kumulerende': ('kumulere',),
'kumulert': ('kumulere',),
'kumulerte': ('kumulere',),
'kunnende': ('kunne',),
'kunnet': ('kunne',),
'kunngjort': ('kunngjøre',),
'kunngjorte': ('kunngjøre',),
'kunngjørende': ('kunngjøre',),
'kunnig': ('kunnig',),
'kunnige': ('kunnig',),
'kunnigere': ('kunnig',),
'kunnigst': ('kunnig',),
'kunnigste': ('kunnig',),
'kunnskapsrik': ('kunnskapsrik',),
'kunnskapsrike': ('kunnskapsrik',),
'kunnskapsrikere': ('kunnskapsrik',),
'kunnskapsrikest': ('kunnskapsrik',),
'kunnskapsrikeste': ('kunnskapsrik',),
'kunnskapsrikt': ('kunnskapsrik',),
'kunstferdig': ('kunstferdig',),
'kunstferdige': ('kunstferdig',),
'kunstferdigere': ('kunstferdig',),
'kunstferdigst': ('kunstferdig',),
'kunstferdigste': ('kunstferdig',),
'kunstfrosne': ('kunstfrossen',),
'kunstfrosnere': ('kunstfrossen',),
'kunstfrosnest': ('kunstfrossen',),
'kunstfrosneste': ('kunstfrossen',),
'kunstfrossen': ('kunstfrossen',),
'kunstfrosset': ('kunstfrossen',),
'kunstfrosne': ('kunstfrosset',),
'kunstfrosnere': ('kunstfrosset',),
'kunstfrosnest': ('kunstfrosset',),
'kunstfrosneste': ('kunstfrosset',),
'kunstfrosset': ('kunstfrosset',),
'kunstig': ('kunstig',),
'kunstige': ('kunstig',),
'kunstigere': ('kunstig',),
'kunstigst': ('kunstig',),
'kunstigste': ('kunstig',),
'kunstlede': ('kunstlet',),
'kunstlet': ('kunstlet',),
'kunstlete': ('kunstlet',),
'kunstletere': ('kunstlet',),
'kunstletest': ('kunstlet',),
'kunstleteste': ('kunstlet',),
'kunstnerisk': ('kunstnerisk',),
'kunstneriske': ('kunstnerisk',),
'kunstneriskere': ('kunstnerisk',),
'kunstneriskest': ('kunstnerisk',),
'kunstneriskeste': ('kunstnerisk',),
'kuperende': ('kupere',),
'kupert': ('kupere',),
'kuperte': ('kupere',),
'kupert': ('kupert',),
'kuperte': ('kupert',),
'kupertere': ('kupert',),
'kupertest': ('kupert',),
'kuperteste': ('kupert',),
'kupla': ('kuple',),
'kuplede': ('kuple',),
'kuplende': ('kuple',),
'kuplet': ('kuple',),
'kuplete': ('kuple',),
'kupla': ('kuple',),
'kuplede': ('kuple',),
'kuplende': ('kuple',),
'kuplet': ('kuple',),
'kuplete': ('kuple',),
'kuplet': ('kuplet',),
'kuplete': ('kuplet',),
'kupletere': ('kuplet',),
'kupletest': ('kuplet',),
'kupleteste': ('kuplet',),
'kuplete': ('kuplete',),
'kuppa': ('kuppe',),
'kuppede': ('kuppe',),
'kuppende': ('kuppe',),
'kuppet': ('kuppe',),
'kuppete': ('kuppe',),
'kurant': ('kurant',),
'kurante': ('kurant',),
'kurantere': ('kurant',),
'kurantest': ('kurant',),
'kuranteste': ('kurant',),
'kurativ': ('kurativ',),
'kurative': ('kurativ',),
'kurativere': ('kurativ',),
'kurativest': ('kurativ',),
'kurativeste': ('kurativ',),
'kurativt': ('kurativ',),
'kurdisk': ('kurdisk',),
'kurdiske': ('kurdisk',),
'kurdiskere': ('kurdisk',),
'kurdiskest': ('kurdisk',),
'kurdiskeste': ('kurdisk',),
'kurerende': ('kurere',),
'kurert': ('kurere',),
'kurerte': ('kurere',),
'kuriøs': ('kuriøs',),
'kuriøse': ('kuriøs',),
'kuriøsere': ('kuriøs',),
'kuriøsest': ('kuriøs',),
'kuriøseste': ('kuriøs',),
'kuriøst': ('kuriøs',),
'kurlandsk': ('kurlandsk',),
'kurlandske': ('kurlandsk',),
'kurlandskere': ('kurlandsk',),
'kurlandskest': ('kurlandsk',),
'kurlandskeste': ('kurlandsk',),
'kurlet': ('kurlet',),
'kurlete': ('kurlet',),
'kurletere': ('kurlet',),
'kurletest': ('kurlet',),
'kurleteste': ('kurlet',),
'kurlete': ('kurlete',),
'kurr': ('kurr',),
'kurre': ('kurr',),
'kurrere': ('kurr',),
'kurrest': ('kurr',),
'kurreste': ('kurr',),
'kurt': ('kurr',),
'kurra': ('kurre',),
'kurrede': ('kurre',),
'kurrende': ('kurre',),
'kurret': ('kurre',),
'kurrete': ('kurre',),
'kursa': ('kurse',),
'kursede': ('kurse',),
'kursende': ('kurse',),
'kurset': ('kurse',),
'kursete': ('kurse',),
'kurserende': ('kursere',),
'kursert': ('kursere',),
'kurserte': ('kursere',),
'kursiv': ('kursiv',),
'kursive': ('kursiv',),
'kursivere': ('kursiv',),
'kursivest': ('kursiv',),
'kursiveste': ('kursiv',),
'kursivt': ('kursiv',),
'kursiverende': ('kursivere',),
'kursivert': ('kursivere',),
'kursiverte': ('kursivere',),
'kursorisk': ('kursorisk',),
'kursoriske': ('kursorisk',),
'kursoriskere': ('kursorisk',),
'kursoriskest': ('kursorisk',),
'kursoriskeste': ('kursorisk',),
'kurtiserende': ('kurtisere',),
'kurtisert': ('kurtisere',),
'kurtiserte': ('kurtisere',),
'kurvblomstra': ('kurvblomstra',),
'kurvblomstrede': ('kurvblomstret',),
'kurvblomstret': ('kurvblomstret',),
'kurvblomstrete': ('kurvblomstret',),
'kurvblomstretere': ('kurvblomstret',),
'kurvblomstretest': ('kurvblomstret',),
'kurvblomstreteste': ('kurvblomstret',),
'kurva': ('kurve',),
'kurvede': ('kurve',),
'kurvende': ('kurve',),
'kurvet': ('kurve',),
'kurvete': ('kurve',),
'kurvet': ('kurvet',),
'kurvete': ('kurvet',),
'kurvetere': ('kurvet',),
'kurvetest': ('kurvet',),
'kurveteste': ('kurvet',),
'kurvete': ('kurvete',),
'kusjittisk': ('kusjittisk',),
'kusjittiske': ('kusjittisk',),
'kusjittiskere': ('kusjittisk',),
'kusjittiskest': ('kusjittisk',),
'kusjittiskeste': ('kusjittisk',),
'kuska': ('kuske',),
'kuskede': ('kuske',),
'kuskende': ('kuske',),
'kusket': ('kuske',),
'kuskete': ('kuske',),
'kuska': ('kuske',),
'kuskede': ('kuske',),
'kuskende': ('kuske',),
'kusket': ('kuske',),
'kuskete': ('kuske',),
'kuslig': ('kuslig',),
'kuslige': ('kuslig',),
'kusligere': ('kuslig',),
'kusligst': ('kuslig',),
'kusligste': ('kuslig',),
'kusta': ('kuste',),
'kustede': ('kuste',),
'kustende': ('kuste',),
'kustet': ('kuste',),
'kustete': ('kuste',),
'kuta': ('kute',),
'kutede': ('kute',),
'kutende': ('kute',),
'kutet': ('kute',),
'kutete': ('kute',),
'kutt': ('kute',),
'kutte': ('kute',),
'kutta': ('kutte',),
'kuttede': ('kutte',),
'kuttende': ('kutte',),
'kuttet': ('kutte',),
'kuttete': ('kutte',),
'kuva': ('kuve',),
'kuvd': ('kuve',),
'kuvde': ('kuve',),
'kuvede': ('kuve',),
'kuvende': ('kuve',),
'kuvet': ('kuve',),
'kuvete': ('kuve',),
'kuven': ('kuven',),
'kuvent': ('kuven',),
'kuvne': ('kuven',),
'kuvnere': ('kuven',),
'kuvnest': ('kuven',),
'kuvneste': ('kuven',),
'kuvendende': ('kuvende',),
'kuvendt': ('kuvende',),
'kuvendte': ('kuvende',),
'kuvet': ('kuvet',),
'kuvete': ('kuvet',),
'kuvetere': ('kuvet',),
'kuvetest': ('kuvet',),
'kuveteste': ('kuvet',),
'kuvete': ('kuvete',),
'kuwaitisk': ('kuwaitisk',),
'kuwaitiske': ('kuwaitisk',),
'kuwaitiskere': ('kuwaitisk',),
'kuwaitiskest': ('kuwaitisk',),
'kuwaitiskeste': ('kuwaitisk',),
'kuwaitsk': ('kuwaitsk',),
'kuwaitske': ('kuwaitsk',),
'kuwaitskere': ('kuwaitsk',),
'kuwaitskest': ('kuwaitsk',),
'kuwaitskeste': ('kuwaitsk',),
'kvadratisk': ('kvadratisk',),
'kvadratiske': ('kvadratisk',),
'kvadratiskere': ('kvadratisk',),
'kvadratiskest': ('kvadratisk',),
'kvadratiskeste': ('kvadratisk',),
'kvadrerende': ('kvadrere',),
'kvadrert': ('kvadrere',),
'kvadrerte': ('kvadrere',),
'kvadrofonisk': ('kvadrofonisk',),
'kvadrofoniske': ('kvadrofonisk',),
'kvadrofoniskere': ('kvadrofonisk',),
'kvadrofoniskest': ('kvadrofonisk',),
'kvadrofoniskeste': ('kvadrofonisk',),
'kvakka': ('kvakke',),
'kvakkede': ('kvakke',),
'kvakkende': ('kvakke',),
'kvakket': ('kvakke',),
'kvakkete': ('kvakke',),
'kvalfull': ('kvalfull',),
'kvalfulle': ('kvalfull',),
'kvalfullere': ('kvalfull',),
'kvalfullest': ('kvalfull',),
'kvalfulleste': ('kvalfull',),
'kvalfullt': ('kvalfull',),
'kvalifiserende': ('kvalifisere',),
'kvalifisert': ('kvalifisere',),
'kvalifiserte': ('kvalifisere',),
'kvalitativ': ('kvalitativ',),
'kvalitative': ('kvalitativ',),
'kvalitativere': ('kvalitativ',),
'kvalitativest': ('kvalitativ',),
'kvalitativeste': ('kvalitativ',),
'kvalitativt': ('kvalitativ',),
'kvalitetsbevisst': ('kvalitetsbevisst',),
'kvalitetsbevisste': ('kvalitetsbevisst',),
'kvalitetsbevisstere': ('kvalitetsbevisst',),
'kvalitetsbevisstest': ('kvalitetsbevisst',),
'kvalitetsbevissteste': ('kvalitetsbevisst',),
'kvalm': ('kvalm',),
'kvalme': ('kvalm',),
'kvalmere': ('kvalm',),
'kvalmest': ('kvalm',),
'kvalmeste': ('kvalm',),
'kvalmt': ('kvalm',),
'kvalmende': ('kvalmende',),
'kvamna': ('kvamne',),
'kvamnede': ('kvamne',),
'kvamnende': ('kvamne',),
'kvamnet': ('kvamne',),
'kvamnete': ('kvamne',),
'kvantifiserende': ('kvantifisere',),
'kvantifisert': ('kvantifisere',),
'kvantifiserte': ('kvantifisere',),
'kvantitativ': ('kvantitativ',),
'kvantitative': ('kvantitativ',),
'kvantitativere': ('kvantitativ',),
'kvantitativest': ('kvantitativ',),
'kvantitativeste': ('kvantitativ',),
'kvantitativt': ('kvantitativ',),
'kvantiterende': ('kvantitere',),
'kvantitert': ('kvantitere',),
'kvantiterte': ('kvantitere',),
'kvantiterende': ('kvantiterende',),
'kvapset': ('kvapset',),
'kvapsete': ('kvapset',),
'kvapsetere': ('kvapset',),
'kvapsetest': ('kvapset',),
'kvapseteste': ('kvapset',),
'kvapsete': ('kvapsete',),
'kvar': ('kvar',),
'kvare': ('kvar',),
'kvarere': ('kvar',),
'kvarest': ('kvar',),
'kvareste': ('kvar',),
'kvart': ('kvar',),
'kvara': ('kvare',),
'kvarede': ('kvare',),
'kvarende': ('kvare',),
'kvaret': ('kvare',),
'kvarete': ('kvare',),
'kvart': ('kvare',),
'kvarte': ('kvare',),
'kvart': ('kvart',),
'kvarte': ('kvart',),
'kvartere': ('kvart',),
'kvartest': ('kvart',),
'kvarteste': ('kvart',),
'kvarta': ('kvarte',),
'kvartede': ('kvarte',),
'kvartende': ('kvarte',),
'kvartet': ('kvarte',),
'kvartete': ('kvarte',),
'kvartær': ('kvartær',),
'kvartære': ('kvartær',),
'kvartærere': ('kvartær',),
'kvartærest': ('kvartær',),
'kvartæreste': ('kvartær',),
'kvartært': ('kvartær',),
'kvass': ('kvass',),
'kvasse': ('kvass',),
'kvassere': ('kvass',),
'kvassest': ('kvass',),
'kvasseste': ('kvass',),
'kvast': ('kvass',),
'kvassøyd': ('kvassøyd',),
'kvassøyde': ('kvassøyd',),
'kvassøydere': ('kvassøyd',),
'kvassøydest': ('kvassøyd',),
'kvassøydeste': ('kvassøyd',),
'kvasta': ('kvaste',),
'kvastede': ('kvaste',),
'kvastende': ('kvaste',),
'kvastet': ('kvaste',),
'kvastete': ('kvaste',),
'kvat': ('kvat',),
'kvate': ('kvat',),
'kvatere': ('kvat',),
'kvatest': ('kvat',),
'kvateste': ('kvat',),
'kvatt': ('kvat',),
'kveden': ('kvede',),
'kvedende': ('kvede',),
'kvedet': ('kvede',),
'kvedne': ('kvede',),
'kvea': ('kvee',),
'kveede': ('kvee',),
'kveende': ('kvee',),
'kveet': ('kvee',),
'kveete': ('kvee',),
'kvega': ('kvege',),
'kvegede': ('kvege',),
'kvegende': ('kvege',),
'kveget': ('kvege',),
'kvegete': ('kvege',),
'kveikende': ('kveike',),
'kveikt': ('kveike',),
'kveikte': ('kveike',),
'kveila': ('kveile',),
'kveilede': ('kveile',),
'kveilende': ('kveile',),
'kveilet': ('kveile',),
'kveilete': ('kveile',),
'kveilt': ('kveile',),
'kveilte': ('kveile',),
'kveiset': ('kveiset',),
'kveisete': ('kveiset',),
'kveisetere': ('kveiset',),
'kveisetest': ('kveiset',),
'kveiseteste': ('kveiset',),
'kveisete': ('kveisete',),
'kvekken': ('kvekke',),
'kvekkende': ('kvekke',),
'kvekket': ('kvekke',),
'kvekne': ('kvekke',),
'kvekken': ('kvekken',),
'kvekkent': ('kvekken',),
'kvekne': ('kvekken',),
'kveknere': ('kvekken',),
'kveknest': ('kvekken',),
'kvekneste': ('kvekken',),
'kvelda': ('kvelde',),
'kveldede': ('kvelde',),
'kveldende': ('kvelde',),
'kveldet': ('kvelde',),
'kveldete': ('kvelde',),
'kvalt': ('kvele',),
'kvalte': ('kvele',),
'kvelende': ('kvele',),
'kvelt': ('kvele',),
'kvelte': ('kvele',),
'kvell': ('kvell',),
'kvelle': ('kvell',),
'kvellere': ('kvell',),
'kvellest': ('kvell',),
'kvelleste': ('kvell',),
'kvelt': ('kvell',),
'kvelva': ('kvelve',),
'kvelvd': ('kvelve',),
'kvelvde': ('kvelve',),
'kvelvede': ('kvelve',),
'kvelvende': ('kvelve',),
'kvelvet': ('kvelve',),
'kvelvete': ('kvelve',),
'kvelven': ('kvelven',),
'kvelvent': ('kvelven',),
'kvelvne': ('kvelven',),
'kvelvnere': ('kvelven',),
'kvelvnest': ('kvelven',),
'kvelvneste': ('kvelven',),
'kvensk': ('kvensk',),
'kvenske': ('kvensk',),
'kvenskere': ('kvensk',),
'kvenskest': ('kvensk',),
'kvenskeste': ('kvensk',),
'kvepne': ('kveppen',),
'kvepnere': ('kveppen',),
'kvepnest': ('kveppen',),
'kvepneste': ('kveppen',),
'kveppen': ('kveppen',),
'kveppent': ('kveppen',),
'kverka': ('kverke',),
'kverkede': ('kverke',),
'kverkende': ('kverke',),
'kverket': ('kverke',),
'kverkete': ('kverke',),
'kverna': ('kverne',),
'kvernede': ('kverne',),
'kvernende': ('kverne',),
'kvernet': ('kverne',),
'kvernete': ('kverne',),
'kverrsatt': ('kverrsette',),
'kverrsatte': ('kverrsette',),
'kverrsettende': ('kverrsette',),
'kverulantisk': ('kverulantisk',),
'kverulantiske': ('kverulantisk',),
'kverulantiskere': ('kverulantisk',),
'kverulantiskest': ('kverulantisk',),
'kverulantiskeste': ('kverulantisk',),
'kverulerende': ('kverulere',),
'kverulert': ('kverulere',),
'kverulerte': ('kverulere',),
'kverv': ('kverv',),
'kverve': ('kverv',),
'kververe': ('kverv',),
'kvervest': ('kverv',),
'kverveste': ('kverv',),
'kvervt': ('kverv',),
'kverva': ('kverve',),
'kvervd': ('kverve',),
'kvervde': ('kverve',),
'kvervede': ('kverve',),
'kvervende': ('kverve',),
'kvervet': ('kverve',),
'kvervete': ('kverve',),
'kverven': ('kverve',),
'kvervende': ('kverve',),
'kvervet': ('kverve',),
'kvervne': ('kverve',),
'kvesende': ('kvese',),
'kvest': ('kvese',),
'kveste': ('kvese',),
'kvessa': ('kvesse',),
'kvessede': ('kvesse',),
'kvessende': ('kvesse',),
'kvesset': ('kvesse',),
'kvessete': ('kvesse',),
'kvest': ('kvesse',),
'kveste': ('kvesse',),
'kvesta': ('kveste',),
'kvestede': ('kveste',),
'kvestende': ('kveste',),
'kvestet': ('kveste',),
'kvestete': ('kveste',),
'kvia': ('kvi',),
'kvidd': ('kvi',),
'kvidde': ('kvi',),
'kviede': ('kvi',),
'kviende': ('kvi',),
'kviet': ('kvi',),
'kviete': ('kvi',),
'kvidefull': ('kvidefull',),
'kvidefulle': ('kvidefull',),
'kvidefullere': ('kvidefull',),
'kvidefullest': ('kvidefull',),
'kvidefulleste': ('kvidefull',),
'kvidefullt': ('kvidefull',),
'kvia': ('kvie',),
'kvidd': ('kvie',),
'kvidde': ('kvie',),
'kviede': ('kvie',),
'kviende': ('kvie',),
'kviet': ('kvie',),
'kviete': ('kvie',),
'kvikk': ('kvikk',),
'kvikke': ('kvikk',),
'kvikkere': ('kvikk',),
'kvikkest': ('kvikk',),
'kvikkeste': ('kvikk',),
'kvikt': ('kvikk',),
'kvikka': ('kvikke',),
'kvikkede': ('kvikke',),
'kvikkende': ('kvikke',),
'kvikket': ('kvikke',),
'kvikkete': ('kvikke',),
'kvikna': ('kvikne',),
'kviknede': ('kvikne',),
'kviknende': ('kvikne',),
'kviknet': ('kvikne',),
'kviknete': ('kvikne',),
'kvilende': ('kvile',),
'kvilt': ('kvile',),
'kvilte': ('kvile',),
'kvilelaus': ('kvilelaus',),
'kvilelause': ('kvilelaus',),
'kvilelausere': ('kvilelaus',),
'kvilelausest': ('kvilelaus',),
'kvilelauseste': ('kvilelaus',),
'kvilelaust': ('kvilelaus',),
'kvileløs': ('kvileløs',),
'kvileløse': ('kvileløs',),
'kvileløsere': ('kvileløs',),
'kvileløsest': ('kvileløs',),
'kvileløseste': ('kvileløs',),
'kvileløst': ('kvileløs',),
'kvinende': ('kvine',),
'kvint': ('kvine',),
'kvinte': ('kvine',),
'kvinka': ('kvinke',),
'kvinkede': ('kvinke',),
'kvinkende': ('kvinke',),
'kvinket': ('kvinke',),
'kvinkete': ('kvinke',),
'kvinnekjær': ('kvinnekjær',),
'kvinnekjære': ('kvinnekjær',),
'kvinnekjærere': ('kvinnekjær',),
'kvinnekjærest': ('kvinnekjær',),
'kvinnekjæreste': ('kvinnekjær',),
'kvinnekjært': ('kvinnekjær',),
'kvinnelig': ('kvinnelig',),
'kvinnelige': ('kvinnelig',),
'kvinneligere': ('kvinnelig',),
'kvinneligst': ('kvinnelig',),
'kvinneligste': ('kvinnelig',),
'kviset': ('kviset',),
'kvisete': ('kviset',),
'kvisetere': ('kviset',),
'kvisetest': ('kviset',),
'kviseteste': ('kviset',),
'kvisete': ('kvisete',),
'kviskra': ('kviskre',),
'kviskrede': ('kviskre',),
'kviskrende': ('kviskre',),
'kviskret': ('kviskre',),
'kviskrete': ('kviskre',),
'kviskra': ('kviskre',),
'kviskrede': ('kviskre',),
'kviskrende': ('kviskre',),
'kviskret': ('kviskre',),
'kviskrete': ('kviskre',),
'kvisla': ('kvisle',),
'kvislede': ('kvisle',),
'kvislende': ('kvisle',),
'kvislet': ('kvisle',),
'kvislete': ('kvisle',),
'kvista': ('kviste',),
'kvistede': ('kviste',),
'kvistende': ('kviste',),
'kvistet': ('kviste',),
'kvistete': ('kviste',),
'kvistet': ('kvistet',),
'kvistete': ('kvistet',),
'kvistetere': ('kvistet',),
'kvistetest': ('kvistet',),
'kvisteteste': ('kvistet',),
'kvistete': ('kvistete',),
'kvistfri': ('kvistfri',),
'kvistfrie': ('kvistfri',),
'kvistfriere': ('kvistfri',),
'kvistfriest': ('kvistfri',),
'kvistfrieste': ('kvistfri',),
'kvistfritt': ('kvistfri',),
'kvit': ('kvit',),
'kvite': ('kvit',),
'kvitere': ('kvit',),
'kvitest': ('kvit',),
'kviteste': ('kvit',),
'kvitt': ('kvit',),
'kvitbleik': ('kvitbleik',),
'kvitbleike': ('kvitbleik',),
'kvitbleikere': ('kvitbleik',),
'kvitbleikest': ('kvitbleik',),
'kvitbleikeste': ('kvitbleik',),
'kvitbleikt': ('kvitbleik',),
'kvitblek': ('kvitblek',),
'kvitbleke': ('kvitblek',),
'kvitblekere': ('kvitblek',),
'kvitblekest': ('kvitblek',),
'kvitblekeste': ('kvitblek',),
'kvitblekt': ('kvitblek',),
'kvita': ('kvite',),
'kvitede': ('kvite',),
'kvitende': ('kvite',),
'kvitet': ('kvite',),
'kvitete': ('kvite',),
'kviterussisk': ('kviterussisk',),
'kviterussiske': ('kviterussisk',),
'kviterussiskere': ('kviterussisk',),
'kviterussiskest': ('kviterussisk',),
'kviterussiskeste': ('kviterussisk',),
'kvitglødende': ('kvitglødende',),
'kvithåra': ('kvithåra',),
'kvithårede': ('kvithåret',),
'kvithåret': ('kvithåret',),
'kvithårete': ('kvithåret',),
'kvithåretere': ('kvithåret',),
'kvithåretest': ('kvithåret',),
'kvithåreteste': ('kvithåret',),
'kvitkalka': ('kvitkalke',),
'kvitkalkede': ('kvitkalke',),
'kvitkalkende': ('kvitkalke',),
'kvitkalket': ('kvitkalke',),
'kvitkalkete': ('kvitkalke',),
'kvitkledd': ('kvitkledd',),
'kvitkledde': ('kvitkledd',),
'kvitkleddere': ('kvitkledd',),
'kvitkleddest': ('kvitkledd',),
'kvitkleddeste': ('kvitkledd',),
'kvitlett': ('kvitlett',),
'kvitlette': ('kvitlett',),
'kvitlettere': ('kvitlett',),
'kvitlettest': ('kvitlett',),
'kvitletteste': ('kvitlett',),
'kvitna': ('kvitne',),
'kvitnede': ('kvitne',),
'kvitnende': ('kvitne',),
'kvitnet': ('kvitne',),
'kvitnete': ('kvitne',),
'kvitra': ('kvitre',),
'kvitrede': ('kvitre',),
'kvitrende': ('kvitre',),
'kvitret': ('kvitre',),
'kvitrete': ('kvitre',),
'kvitt': ('kvitt',),
'kvitta': ('kvitte',),
'kvittede': ('kvitte',),
'kvittende': ('kvitte',),
'kvittet': ('kvitte',),
'kvittete': ('kvitte',),
'kvitterende': ('kvittere',),
'kvittert': ('kvittere',),
'kvitterte': ('kvittere',),
'kvitvaska': ('kvitvaske',),
'kvitvaskede': ('kvitvaske',),
'kvitvaskende': ('kvitvaske',),
'kvitvasket': ('kvitvaske',),
'kvitvaskete': ('kvitvaske',),
'kvoterende': ('kvotere',),
'kvotert': ('kvotere',),
'kvoterte': ('kvotere',),
'kvævd': ('kvæve',),
'kvævde': ('kvæve',),
'kvævende': ('kvæve',),
'kybernetisk': ('kybernetisk',),
'kybernetiske': ('kybernetisk',),
'kybernetiskere': ('kybernetisk',),
'kybernetiskest': ('kybernetisk',),
'kybernetiskeste': ('kybernetisk',),
'kyklopisk': ('kyklopisk',),
'kyklopiske': ('kyklopisk',),
'kyklopiskere': ('kyklopisk',),
'kyklopiskest': ('kyklopisk',),
'kyklopiskeste': ('kyklopisk',),
'kylende': ('kyle',),
'kylt': ('kyle',),
'kylte': ('kyle',),
'kyllende': ('kylle',),
'kylt': ('kylle',),
'kylte': ('kylle',),
'kymrisk': ('kymrisk',),
'kymriske': ('kymrisk',),
'kymriskere': ('kymrisk',),
'kymriskest': ('kymrisk',),
'kymriskeste': ('kymrisk',),
'kyndig': ('kyndig',),
'kyndige': ('kyndig',),
'kyndigere': ('kyndig',),
'kyndigst': ('kyndig',),
'kyndigste': ('kyndig',),
'kynisk': ('kynisk',),
'kyniske': ('kynisk',),
'kyniskere': ('kynisk',),
'kyniskest': ('kynisk',),
'kyniskeste': ('kynisk',),
'kypriotisk': ('kypriotisk',),
'kypriotiske': ('kypriotisk',),
'kypriotiskere': ('kypriotisk',),
'kypriotiskest': ('kypriotisk',),
'kypriotiskeste': ('kypriotisk',),
'kyrillisk': ('kyrillisk',),
'kyrilliske': ('kyrillisk',),
'kyrilliskere': ('kyrillisk',),
'kyrilliskest': ('kyrillisk',),
'kyrilliskeste': ('kyrillisk',),
'kyrr': ('kyrr',),
'kyrre': ('kyrr',),
'kyrrere': ('kyrr',),
'kyrrest': ('kyrr',),
'kyrreste': ('kyrr',),
'kyrt': ('kyrr',),
'kysk': ('kysk',),
'kyske': ('kysk',),
'kyskere': ('kysk',),
'kyskest': ('kysk',),
'kyskeste': ('kysk',),
'kyskt': ('kysk',),
'kyssa': ('kysse',),
'kyssede': ('kysse',),
'kyssende': ('kysse',),
'kysset': ('kysse',),
'kyssete': ('kysse',),
'kyst': ('kysse',),
'kyste': ('kysse',),
'kyssekte': ('kyssekte',),
'kytende': ('kyte',),
'kytt': ('kyte',),
'kytte': ('kyte',),
'kådd': ('kå',),
'kådde': ('kå',),
'kående': ('kå',),
'kåla': ('kåle',),
'kålede': ('kåle',),
'kålende': ('kåle',),
'kålet': ('kåle',),
'kålete': ('kåle',),
'kåra': ('kåre',),
'kårede': ('kåre',),
'kårende': ('kåre',),
'kåret': ('kåre',),
'kårete': ('kåre',),
'kåra': ('kåre',),
'kårede': ('kåre',),
'kårende': ('kåre',),
'kåret': ('kåre',),
'kårete': ('kåre',),
'kåren': ('kåren',),
'kårent': ('kåren',),
'kårne': ('kåren',),
'kårnere': ('kåren',),
'kårnest': ('kåren',),
'kårneste': ('kåren',),
'kåserende': ('kåsere',),
'kåsert': ('kåsere',),
'kåserte': ('kåsere',),
'kåt': ('kåt',),
'kåte': ('kåt',),
'kåtere': ('kåt',),
'kåtest': ('kåt',),
'kåteste': ('kåt',),
'københavnsk': ('københavnsk',),
'københavnske': ('københavnsk',),
'københavnskere': ('københavnsk',),
'københavnskest': ('københavnsk',),
'københavnskeste': ('københavnsk',),
'kødda': ('kødde',),
'køddede': ('kødde',),
'køddende': ('kødde',),
'køddet': ('kødde',),
'køddete': ('kødde',),
'køa': ('køe',),
'køede': ('køe',),
'køende': ('køe',),
'køet': ('køe',),
'køete': ('køe',),
'køya': ('køye',),
'køyede': ('køye',),
'køyende': ('køye',),
'køyet': ('køye',),
'køyete': ('køye',),
'labba': ('labbe',),
'labbede': ('labbe',),
'labbende': ('labbe',),
'labbet': ('labbe',),
'labbete': ('labbe',),
'labbelensk': ('labbelensk',),
'labbelenske': ('labbelensk',),
'labbelenskere': ('labbelensk',),
'labbelenskest': ('labbelensk',),
'labbelenskeste': ('labbelensk',),
'laber': ('laber',),
'labert': ('laber',),
'labre': ('laber',),
'labrere': ('laber',),
'labrest': ('laber',),
'labreste': ('laber',),
'labial': ('labial',),
'labiale': ('labial',),
'labialere': ('labial',),
'labialest': ('labial',),
'labialeste': ('labial',),
'labialt': ('labial',),
'labialiserende': ('labialisere',),
'labialisert': ('labialisere',),
'labialiserte': ('labialisere',),
'labil': ('labil',),
'labile': ('labil',),
'labilere': ('labil',),
'labilest': ('labil',),
'labileste': ('labil',),
'labilt': ('labil',),
'labiodental': ('labiodental',),
'labiodentale': ('labiodental',),
'labiodentalere': ('labiodental',),
'labiodentalest': ('labiodental',),
'labiodentaleste': ('labiodental',),
'labiodentalt': ('labiodental',),
'laborativ': ('laborativ',),
'laborative': ('laborativ',),
'laborativere': ('laborativ',),
'laborativest': ('laborativ',),
'laborativeste': ('laborativ',),
'laborativt': ('laborativ',),
'lada': ('lade',),
'ladd': ('lade',),
'ladde': ('lade',),
'ladede': ('lade',),
'ladende': ('lade',),
'ladet': ('lade',),
'ladete': ('lade',),
'ladylike': ('ladylike',),
'lafta': ('lafte',),
'laftede': ('lafte',),
'laftende': ('lafte',),
'laftet': ('lafte',),
'laftete': ('lafte',),
'laga': ('laga',),
'lagdelt': ('lagdelt',),
'lagdelte': ('lagdelt',),
'lagdeltere': ('lagdelt',),
'lagdeltest': ('lagdelt',),
'lagdelteste': ('lagdelt',),
'laga': ('lage',),
'lagd': ('lage',),
'lagde': ('lage',),
'lagede': ('lage',),
'lagende': ('lage',),
'laget': ('lage',),
'lagete': ('lage',),
'lagelig': ('lagelig',),
'lagelige': ('lagelig',),
'lageligere': ('lagelig',),
'lageligst': ('lagelig',),
'lageligste': ('lagelig',),
'lagerførende': ('lagerføre',),
'lagerført': ('lagerføre',),
'lagerførte': ('lagerføre',),
'lagga': ('lagge',),
'laggede': ('lagge',),
'laggende': ('lagge',),
'lagget': ('lagge',),
'laggete': ('lagge',),
'laglig': ('laglig',),
'laglige': ('laglig',),
'lagligere': ('laglig',),
'lagligst': ('laglig',),
'lagligste': ('laglig',),
'lagnadstung': ('lagnadstung',),
'lagnadstunge': ('lagnadstung',),
'lagnadstungere': ('lagnadstung',),
'lagnadstungest': ('lagnadstung',),
'lagnadstungeste': ('lagnadstung',),
'lagnadstungt': ('lagnadstung',),
'lagnadstyngre': ('lagnadstung',),
'lagnadstyngst': ('lagnadstung',),
'lagnadstyngste': ('lagnadstung',),
'lagra': ('lagre',),
'lagrede': ('lagre',),
'lagrende': ('lagre',),
'lagret': ('lagre',),
'lagrete': ('lagre',),
'laka': ('lake',),
'lakede': ('lake',),
'lakende': ('lake',),
'laket': ('lake',),
'lakete': ('lake',),
'lakka': ('lakke',),
'lakkede': ('lakke',),
'lakkende': ('lakke',),
'lakket': ('lakke',),
'lakkete': ('lakke',),
'lakka': ('lakke',),
'lakkede': ('lakke',),
'lakkende': ('lakke',),
'lakket': ('lakke',),
'lakkete': ('lakke',),
'lakkerende': ('lakkere',),
'lakkert': ('lakkere',),
'lakkerte': ('lakkere',),
'lakkrød': ('lakkrød',),
'lakkrøde': ('lakkrød',),
'lakkrødere': ('lakkrød',),
'lakkrødest': ('lakkrød',),
'lakkrødeste': ('lakkrød',),
'lakkrødt': ('lakkrød',),
'lakonisk': ('lakonisk',),
'lakoniske': ('lakonisk',),
'lakoniskere': ('lakonisk',),
'lakoniskest': ('lakonisk',),
'lakoniskeste': ('lakonisk',),
'laksefarga': ('laksefarga',),
'laksefargede': ('laksefarget',),
'laksefarget': ('laksefarget',),
'laksefargete': ('laksefarget',),
'laksefargetere': ('laksefarget',),
'laksefargetest': ('laksefarget',),
'laksefargeteste': ('laksefarget',),
'lakserende': ('laksere',),
'laksert': ('laksere',),
'lakserte': ('laksere',),
'lakserød': ('lakserød',),
'lakserøde': ('lakserød',),
'lakserødere': ('lakserød',),
'lakserødest': ('lakserød',),
'lakserødeste': ('lakserød',),
'lakserødt': ('lakserød',),
'lakserød': ('lakserød',),
'lakserøde': ('lakserød',),
'lakserødere': ('lakserød',),
'lakserødest': ('lakserød',),
'lakserødeste': ('lakserød',),
'lakserødt': ('lakserød',),
'laksfarga': ('laksfarga',),
'laksfargede': ('laksfarget',),
'laksfarget': ('laksfarget',),
'laksfargete': ('laksfarget',),
'laksfargetere': ('laksfarget',),
'laksfargetest': ('laksfarget',),
'laksfargeteste': ('laksfarget',),
'laksrød': ('laksrød',),
'laksrøde': ('laksrød',),
'laksrødere': ('laksrød',),
'laksrødest': ('laksrød',),
'laksrødeste': ('laksrød',),
'laksrødt': ('laksrød',),
'laksrød': ('laksrød',),
'laksrøde': ('laksrød',),
'laksrødere': ('laksrød',),
'laksrødest': ('laksrød',),
'laksrødeste': ('laksrød',),
'laksrødt': ('laksrød',),
'lala': ('lale',),
'lalede': ('lale',),
'lalende': ('lale',),
'lalet': ('lale',),
'lalete': ('lale',),
'lalla': ('lalle',),
'lallede': ('lalle',),
'lallende': ('lalle',),
'lallet': ('lalle',),
'lallete': ('lalle',),
'lam': ('lam',),
'lamme': ('lam',),
'lammere': ('lam',),
'lammest': ('lam',),
'lammeste': ('lam',),
'lamt': ('lam',),
'laminerende': ('laminere',),
'laminert': ('laminere',),
'laminerte': ('laminere',),
'laminær': ('laminær',),
'laminære': ('laminær',),
'laminærere': ('laminær',),
'laminærest': ('laminær',),
'laminæreste': ('laminær',),
'laminært': ('laminær',),
'lamma': ('lamme',),
'lammede': ('lamme',),
'lammende': ('lamme',),
'lammet': ('lamme',),
'lammete': ('lamme',),
'lamma': ('lamme',),
'lammede': ('lamme',),
'lammende': ('lamme',),
'lammet': ('lamme',),
'lammete': ('lamme',),
'lamma': ('lamme',),
'lammede': ('lamme',),
'lammende': ('lamme',),
'lammet': ('lamme',),
'lammete': ('lamme',),
'lamslående': ('lamslå',),
'lamslått': ('lamslå',),
'lamslåtte': ('lamslå',),
'landbruksvitenskapelig': ('landbruksvitenskapelig',),
'landbruksvitenskapelige': ('landbruksvitenskapelig',),
'landbruksvitenskapeligere': ('landbruksvitenskapelig',),
'landbruksvitenskapeligest': ('landbruksvitenskapelig',),
'landbruksvitenskapeligeste': ('landbruksvitenskapelig',),
'landbruksvitskapelig': ('landbruksvitskapelig',),
'landbruksvitskapelige': ('landbruksvitskapelig',),
'landbruksvitskapeligere': ('landbruksvitskapelig',),
'landbruksvitskapeligst': ('landbruksvitskapelig',),
'landbruksvitskapeligste': ('landbruksvitskapelig',),
'landa': ('lande',),
'landede': ('lande',),
'landende': ('lande',),
'landet': ('lande',),
'landete': ('lande',),
'landa': ('lande',),
'landede': ('lande',),
'landende': ('lande',),
'landet': ('lande',),
'landete': ('lande',),
'landfast': ('landfast',),
'landfaste': ('landfast',),
'landfastere': ('landfast',),
'landfastest': ('landfast',),
'landfasteste': ('landfast',),
'landflyktig': ('landflyktig',),
'landflyktige': ('landflyktig',),
'landflyktigere': ('landflyktig',),
'landflyktigst': ('landflyktig',),
'landflyktigste': ('landflyktig',),
'landlig': ('landlig',),
'landlige': ('landlig',),
'landligere': ('landlig',),
'landligst': ('landlig',),
'landligste': ('landlig',),
'landsens': ('landsens',),
'landsatt': ('landsette',),
'landsatte': ('landsette',),
'landsettende': ('landsette',),
'landsfaderlig': ('landsfaderlig',),
'landsfaderlige': ('landsfaderlig',),
'landsfaderligere': ('landsfaderlig',),
'landsfaderligst': ('landsfaderlig',),
'landsfaderligste': ('landsfaderlig',),
'landsforvisende': ('landsforvise',),
'landsforvist': ('landsforvise',),
'landsforviste': ('landsforvise',),
'landskjent': ('landskjent',),
'landskjente': ('landskjent',),
'landskjentere': ('landskjent',),
'landskjentest': ('landskjent',),
'landskjenteste': ('landskjent',),
'landsomfattende': ('landsomfattende',),
'lang': ('lang',),
'lange': ('lang',),
'langt': ('lang',),
'lenger': ('lang',),
'lengre': ('lang',),
'lengst': ('lang',),
'lengste': ('lang',),
'langaktig': ('langaktig',),
'langaktige': ('langaktig',),
'langaktigere': ('langaktig',),
'langaktigst': ('langaktig',),
'langaktigste': ('langaktig',),
'langbeint': ('langbeint',),
'langbeinte': ('langbeint',),
'langbeintere': ('langbeint',),
'langbeintest': ('langbeint',),
'langbeinteste': ('langbeint',),
'langbent': ('langbent',),
'langbente': ('langbent',),
'langbentere': ('langbent',),
'langbentest': ('langbent',),
'langbenteste': ('langbent',),
'langdryg': ('langdryg',),
'langdryge': ('langdryg',),
'langdrygere': ('langdryg',),
'langdrygest': ('langdryg',),
'langdrygeste': ('langdryg',),
'langdrygt': ('langdryg',),
'langa': ('lange',),
'langede': ('lange',),
'langende': ('lange',),
'langet': ('lange',),
'langete': ('lange',),
'langelig': ('langelig',),
'langelige': ('langelig',),
'langeligere': ('langelig',),
'langeligst': ('langelig',),
'langeligste': ('langelig',),
'langerma': ('langerma',),
'langermede': ('langermet',),
'langermet': ('langermet',),
'langermete': ('langermet',),
'langermetere': ('langermet',),
'langermetest': ('langermet',),
'langermeteste': ('langermet',),
'langfibra': ('langfibra',),
'langfibrede': ('langfibret',),
'langfibret': ('langfibret',),
'langfibrete': ('langfibret',),
'langfibretere': ('langfibret',),
'langfibretest': ('langfibret',),
'langfibreteste': ('langfibret',),
'langfingra': ('langfingra',),
'langfingrede': ('langfingret',),
'langfingret': ('langfingret',),
'langfingrete': ('langfingret',),
'langfingretere': ('langfingret',),
'langfingretest': ('langfingret',),
'langfingreteste': ('langfingret',),
'langflat': ('langflat',),
'langflate': ('langflat',),
'langflatere': ('langflat',),
'langflatest': ('langflat',),
'langflateste': ('langflat',),
'langflatt': ('langflat',),
'langfri': ('langfri',),
'langfrie': ('langfri',),
'langfriere': ('langfri',),
'langfriest': ('langfri',),
'langfrieste': ('langfri',),
'langfritt': ('langfri',),
'langgrunn': ('langgrunn',),
'langgrunne': ('langgrunn',),
'langgrunnere': ('langgrunn',),
'langgrunnest': ('langgrunn',),
'langgrunneste': ('langgrunn',),
'langgrunt': ('langgrunn',),
'langhåra': ('langhåra',),
'langhårede': ('langhåret',),
'langhåret': ('langhåret',),
'langhårete': ('langhåret',),
'langhåretere': ('langhåret',),
'langhåretest': ('langhåret',),
'langhåreteste': ('langhåret',),
'langlig': ('langlig',),
'langlige': ('langlig',),
'langligere': ('langlig',),
'langligst': ('langlig',),
'langligste': ('langlig',),
'langmodig': ('langmodig',),
'langmodige': ('langmodig',),
'langmodigere': ('langmodig',),
'langmodigst': ('langmodig',),
'langmodigste': ('langmodig',),
'langobardisk': ('langobardisk',),
'langobardiske': ('langobardisk',),
'langobardiskere': ('langobardisk',),
'langobardiskest': ('langobardisk',),
'langobardiskeste': ('langobardisk',),
'langsiktig': ('langsiktig',),
'langsiktige': ('langsiktig',),
'langsiktigere': ('langsiktig',),
'langsiktigst': ('langsiktig',),
'langsiktigste': ('langsiktig',),
'langsint': ('langsint',),
'langsinte': ('langsint',),
'langsintere': ('langsint',),
'langsintest': ('langsint',),
'langsinteste': ('langsint',),
'langsom': ('langsom',),
'langsomme': ('langsom',),
'langsommere': ('langsom',),
'langsomst': ('langsom',),
'langsomste': ('langsom',),
'langsomt': ('langsom',),
'langsommelig': ('langsommelig',),
'langsommelige': ('langsommelig',),
'langsommeligere': ('langsommelig',),
'langsommeligst': ('langsommelig',),
'langsommeligste': ('langsommelig',),
'langstilka': ('langstilka',),
'langstilkede': ('langstilket',),
'langstilket': ('langstilket',),
'langstilkete': ('langstilket',),
'langstilketere': ('langstilket',),
'langstilketest': ('langstilket',),
'langstilketeste': ('langstilket',),
'langstrakt': ('langstrakt',),
'langstrakte': ('langstrakt',),
'langstraktere': ('langstrakt',),
'langstraktest': ('langstrakt',),
'langstrakteste': ('langstrakt',),
'langsynt': ('langsynt',),
'langsynte': ('langsynt',),
'langsyntere': ('langsynt',),
'langsyntest': ('langsynt',),
'langsynteste': ('langsynt',),
'langt': ('langt',),
'lenger': ('langt',),
'lengst': ('langt',),
'langtekkelig': ('langtekkelig',),
'langtekkelige': ('langtekkelig',),
'langtekkeligere': ('langtekkelig',),
'langtekkeligst': ('langtekkelig',),
'langtekkeligste': ('langtekkelig',),
'langtrekkende': ('langtrekkende',),
'langtrukken': ('langtrukken',),
'langtrukkent': ('langtrukken',),
'langtrukne': ('langtrukken',),
'langtruknere': ('langtrukken',),
'langtruknest': ('langtrukken',),
'langtrukneste': ('langtrukken',),
'langvarig': ('langvarig',),
'langvarige': ('langvarig',),
'langvarigere': ('langvarig',),
'langvarigst': ('langvarig',),
'langvarigste': ('langvarig',),
'langvegesfarende': ('langvegesfarende',),
'langvegsfarende': ('langvegsfarende',),
'langveisfarende': ('langveisfarende',),
'langøra': ('langøra',),
'langørede': ('langøret',),
'langøret': ('langøret',),
'langørete': ('langøret',),
'langøretere': ('langøret',),
'langøretest': ('langøret',),
'langøreteste': ('langøret',),
'lanserende': ('lansere',),
'lansert': ('lansere',),
'lanserte': ('lansere',),
'lansettforma': ('lansettforma',),
'lansettformede': ('lansettformet',),
'lansettformet': ('lansettformet',),
'lansettformete': ('lansettformet',),
'lansettformetere': ('lansettformet',),
'lansettformetest': ('lansettformet',),
'lansettformeteste': ('lansettformet',),
'laotisk': ('laotisk',),
'laotiske': ('laotisk',),
'laotiskere': ('laotisk',),
'laotiskest': ('laotisk',),
'laotiskeste': ('laotisk',),
'lapidar': ('lapidar',),
'lapidare': ('lapidar',),
'lapidarere': ('lapidar',),
'lapidarest': ('lapidar',),
'lapidareste': ('lapidar',),
'lapidart': ('lapidar',),
'lapidarisk': ('lapidarisk',),
'lapidariske': ('lapidarisk',),
'lapidariskere': ('lapidarisk',),
'lapidariskest': ('lapidarisk',),
'lapidariskeste': ('lapidarisk',),
'lappa': ('lappe',),
'lappede': ('lappe',),
'lappende': ('lappe',),
'lappet': ('lappe',),
'lappete': ('lappe',),
'lappet': ('lappet',),
'lappete': ('lappet',),
'lappetere': ('lappet',),
'lappetest': ('lappet',),
'lappeteste': ('lappet',),
'lappete': ('lappete',),
'lappisk': ('lappisk',),
'lappiske': ('lappisk',),
'lappiskere': ('lappisk',),
'lappiskest': ('lappisk',),
'lappiskeste': ('lappisk',),
'lapplandsk': ('lapplandsk',),
'lapplandske': ('lapplandsk',),
'lapplandskere': ('lapplandsk',),
'lapplandskest': ('lapplandsk',),
'lapplandskeste': ('lapplandsk',),
'lapset': ('lapset',),
'lapsete': ('lapset',),
'lapsetere': ('lapset',),
'lapsetest': ('lapset',),
'lapseteste': ('lapset',),
'lapsete': ('lapsete',),
'larma': ('larme',),
'larmede': ('larme',),
'larmende': ('larme',),
'larmet': ('larme',),
'larmete': ('larme',),
'laryngal': ('laryngal',),
'laryngale': ('laryngal',),
'laryngalere': ('laryngal',),
'laryngalest': ('laryngal',),
'laryngaleste': ('laryngal',),
'laryngalt': ('laryngal',),
'laserende': ('lasere',),
'lasert': ('lasere',),
'laserte': ('lasere',),
'laset': ('laset',),
'lasete': ('laset',),
'lasetere': ('laset',),
'lasetest': ('laset',),
'laseteste': ('laset',),
'lasete': ('lasete',),
'laska': ('laske',),
'laskede': ('laske',),
'laskende': ('laske',),
'lasket': ('laske',),
'laskete': ('laske',),
'lasket': ('lasket',),
'laskete': ('lasket',),
'lasketere': ('lasket',),
'lasketest': ('lasket',),
'lasketeste': ('lasket',),
'laskete': ('laskete',),
'lasta': ('laste',),
'lastede': ('laste',),
'lastende': ('laste',),
'lastet': ('laste',),
'lastete': ('laste',),
'lasta': ('laste',),
'lastede': ('laste',),
'lastende': ('laste',),
'lastet': ('laste',),
'lastete': ('laste',),
'lastefull': ('lastefull',),
'lastefulle': ('lastefull',),
'lastefullere': ('lastefull',),
'lastefullest': ('lastefull',),
'lastefulleste': ('lastefull',),
'lastefullt': ('lastefull',),
'lastverdig': ('lastverdig',),
'lastverdige': ('lastverdig',),
'lastverdigere': ('lastverdig',),
'lastverdigst': ('lastverdig',),
'lastverdigste': ('lastverdig',),
'lat': ('lat',),
'late': ('lat',),
'latere': ('lat',),
'latest': ('lat',),
'lateste': ('lat',),
'lata': ('late',),
'latede': ('late',),
'latende': ('late',),
'latet': ('late',),
'latete': ('late',),
'latende': ('late',),
'latt': ('late',),
'latte': ('late',),
'latent': ('latent',),
'latente': ('latent',),
'latentere': ('latent',),
'latentest': ('latent',),
'latenteste': ('latent',),
'lateral': ('lateral',),
'laterale': ('lateral',),
'lateralere': ('lateral',),
'lateralest': ('lateral',),
'lateraleste': ('lateral',),
'lateralt': ('lateral',),
'latinamerikansk': ('latinamerikansk',),
'latinamerikanske': ('latinamerikansk',),
'latinamerikanskere': ('latinamerikansk',),
'latinamerikanskest': ('latinamerikansk',),
'latinamerikanskeste': ('latinamerikansk',),
'latiniserende': ('latinisere',),
'latinisert': ('latinisere',),
'latiniserte': ('latinisere',),
'latinsk': ('latinsk',),
'latinske': ('latinsk',),
'latinskere': ('latinsk',),
'latinskest': ('latinsk',),
'latinskeste': ('latinsk',),
'latterlig': ('latterlig',),
'latterlige': ('latterlig',),
'latterligere': ('latterlig',),
'latterligst': ('latterlig',),
'latterligste': ('latterlig',),
'latterliggjort': ('latterliggjøre',),
'latterliggjorte': ('latterliggjøre',),
'latterliggjørende': ('latterliggjøre',),
'lattermild': ('lattermild',),
'lattermilde': ('lattermild',),
'lattermildere': ('lattermild',),
'lattermildest': ('lattermild',),
'lattermildeste': ('lattermild',),
'lattermildt': ('lattermild',),
'latvisk': ('latvisk',),
'latviske': ('latvisk',),
'latviskere': ('latvisk',),
'latviskest': ('latvisk',),
'latviskeste': ('latvisk',),
'laudabel': ('laudabel',),
'laudabelt': ('laudabel',),
'laudable': ('laudabel',),
'laudablere': ('laudabel',),
'laudablest': ('laudabel',),
'laudableste': ('laudabel',),
'lauga': ('lauge',),
'laugede': ('lauge',),
'laugende': ('lauge',),
'lauget': ('lauge',),
'laugete': ('lauge',),
'laus': ('laus',),
'lause': ('laus',),
'lausere': ('laus',),
'lausest': ('laus',),
'lauseste': ('laus',),
'laust': ('laus',),
'lausgiende': ('lausgi',),
'lausgitt': ('lausgi',),
'lausgitte': ('lausgi',),
'lausgivende': ('lausgi',),
'lausgjort': ('lausgjøre',),
'lausgjorte': ('lausgjøre',),
'lausgjørende': ('lausgjøre',),
'lauskjefta': ('lauskjefta',),
'lauskjeftede': ('lauskjeftet',),
'lauskjeftet': ('lauskjeftet',),
'lauskjeftete': ('lauskjeftet',),
'lauskjeftetere': ('lauskjeftet',),
'lauskjeftetest': ('lauskjeftet',),
'lauskjefteteste': ('lauskjeftet',),
'lauslynt': ('lauslynt',),
'lauslynte': ('lauslynt',),
'lauslyntere': ('lauslynt',),
'lauslyntest': ('lauslynt',),
'lauslynteste': ('lauslynt',),
'lausmunna': ('lausmunna',),
'lausmunnede': ('lausmunnet',),
'lausmunnet': ('lausmunnet',),
'lausmunnete': ('lausmunnet',),
'lausmunnetere': ('lausmunnet',),
'lausmunnetest': ('lausmunnet',),
'lausmunneteste': ('lausmunnet',),
'lausreven': ('lausreven',),
'lausrevet': ('lausreven',),
'lausrevne': ('lausreven',),
'lausrevnere': ('lausreven',),
'lausrevnest': ('lausreven',),
'lausrevneste': ('lausreven',),
'lausslupne': ('laussluppen',),
'lausslupnere': ('laussluppen',),
'lausslupnest': ('laussluppen',),
'lausslupneste': ('laussluppen',),
'laussluppen': ('laussluppen',),
'laussluppent': ('laussluppen',),
'lauva': ('lauve',),
'lauvede': ('lauve',),
'lauvende': ('lauve',),
'lauvet': ('lauve',),
'lauvete': ('lauve',),
'lauvtynn': ('lauvtynn',),
'lauvtynne': ('lauvtynn',),
'lauvtynnere': ('lauvtynn',),
'lauvtynnest': ('lauvtynn',),
'lauvtynneste': ('lauvtynn',),
'lauvtynt': ('lauvtynn',),
'lav': ('lav',),
'lave': ('lav',),
'lavere': ('lav',),
'lavest': ('lav',),
'laveste': ('lav',),
'lavt': ('lav',),
'lavadelig': ('lavadelig',),
'lavadelige': ('lavadelig',),
'lavadeligere': ('lavadelig',),
'lavadeligst': ('lavadelig',),
'lavadeligste': ('lavadelig',),
'lava': ('lave',),
'lavd': ('lave',),
'lavde': ('lave',),
'lavede': ('lave',),
'lavende': ('lave',),
'lavet': ('lave',),
'lavete': ('lave',),
'lavendelblå': ('lavendelblå',),
'lavendelblåe': ('lavendelblå',),
'lavendelblåere': ('lavendelblå',),
'lavendelblåest': ('lavendelblå',),
'lavendelblåeste': ('lavendelblå',),
'lavendelblått': ('lavendelblå',),
'lavereliggende': ('lavereliggende',),
'laverestående': ('laverestående',),
'lavfrekvent': ('lavfrekvent',),
'lavfrekvente': ('lavfrekvent',),
'lavfrekventere': ('lavfrekvent',),
'lavfrekventest': ('lavfrekvent',),
'lavfrekventeste': ('lavfrekvent',),
'lavhælt': ('lavhælt',),
'lavhælte': ('lavhælt',),
'lavhæltere': ('lavhælt',),
'lavhæltest': ('lavhælt',),
'lavhælteste': ('lavhælt',),
'lavkirkelig': ('lavkirkelig',),
'lavkirkelige': ('lavkirkelig',),
'lavkirkeligere': ('lavkirkelig',),
'lavkirkeligst': ('lavkirkelig',),
'lavkirkeligste': ('lavkirkelig',),
'lavlendt': ('lavlendt',),
'lavlendte': ('lavlendt',),
'lavlendtere': ('lavlendt',),
'lavlendtest': ('lavlendt',),
'lavlendteste': ('lavlendt',),
'lavlønna': ('lavlønna',),
'lavlønnede': ('lavlønnet',),
'lavlønnet': ('lavlønnet',),
'lavlønnete': ('lavlønnet',),
'lavlønnetere': ('lavlønnet',),
'lavlønnetest': ('lavlønnet',),
'lavlønneteste': ('lavlønnet',),
'lavlønt': ('lavlønt',),
'lavlønte': ('lavlønt',),
'lavløntere': ('lavlønt',),
'lavløntest': ('lavlønt',),
'lavlønteste': ('lavlønt',),
'lavmælt': ('lavmælt',),
'lavmælte': ('lavmælt',),
'lavmæltere': ('lavmælt',),
'lavmæltest': ('lavmælt',),
'lavmælteste': ('lavmælt',),
'lavpanna': ('lavpanna',),
'lavpannede': ('lavpannet',),
'lavpannet': ('lavpannet',),
'lavpannete': ('lavpannet',),
'lavpannetere': ('lavpannet',),
'lavpannetest': ('lavpannet',),
'lavpanneteste': ('lavpannet',),
'lavproduktiv': ('lavproduktiv',),
'lavproduktive': ('lavproduktiv',),
'lavproduktivere': ('lavproduktiv',),
'lavproduktivest': ('lavproduktiv',),
'lavproduktiveste': ('lavproduktiv',),
'lavproduktivt': ('lavproduktiv',),
'lavspent': ('lavspent',),
'lavspente': ('lavspent',),
'lavspentere': ('lavspent',),
'lavspentest': ('lavspent',),
'lavspenteste': ('lavspent',),
'lavtliggende': ('lavtliggende',),
'lavtlønna': ('lavtlønna',),
'lavtlønnede': ('lavtlønnet',),
'lavtlønnet': ('lavtlønnet',),
'lavtlønnete': ('lavtlønnet',),
'lavtlønnetere': ('lavtlønnet',),
'lavtlønnetest': ('lavtlønnet',),
'lavtlønneteste': ('lavtlønnet',),
'lavtlønt': ('lavtlønt',),
'lavtlønte': ('lavtlønt',),
'lavtløntere': ('lavtlønt',),
'lavtløntest': ('lavtlønt',),
'lavtlønteste': ('lavtlønt',),
'lavtstående': ('lavtstående',),
'lavtysk': ('lavtysk',),
'lavtyske': ('lavtysk',),
'lavtyskere': ('lavtysk',),
'lavtyskest': ('lavtysk',),
'lavtyskeste': ('lavtysk',),
'layouta': ('layoute',),
'layoutede': ('layoute',),
'layoutende': ('layoute',),
'layoutet': ('layoute',),
'layoutete': ('layoute',),
'ledd': ('le',),
'ledde': ('le',),
'leende': ('le',),
'le': ('le',),
'lealaus': ('lealaus',),
'lealause': ('lealaus',),
'lealausere': ('lealaus',),
'lealausest': ('lealaus',),
'lealauseste': ('lealaus',),
'lealaust': ('lealaus',),
'leasa': ('lease',),
'leasede': ('lease',),
'leasende': ('lease',),
'leaset': ('lease',),
'leasete': ('lease',),
'lebendig': ('lebendig',),
'lebendige': ('lebendig',),
'lebendigere': ('lebendig',),
'lebendigst': ('lebendig',),
'lebendigste': ('lebendig',),
'ledd-delt': ('ledd-delt',),
'ledd-delte': ('ledd-delt',),
'ledd-deltere': ('ledd-delt',),
'ledd-deltest': ('ledd-delt',),
'ledd-delteste': ('ledd-delt',),
'ledda': ('ledde',),
'leddede': ('ledde',),
'leddende': ('ledde',),
'leddet': ('ledde',),
'leddete': ('ledde',),
'leddelt': ('leddelt',),
'leddelte': ('leddelt',),
'leddeltere': ('leddelt',),
'leddeltest': ('leddelt',),
'leddelteste': ('leddelt',),
'leddet': ('leddet',),
'leddete': ('leddet',),
'leddetere': ('leddet',),
'leddetest': ('leddet',),
'leddeteste': ('leddet',),
'leddete': ('leddete',),
'leddlaus': ('leddlaus',),
'leddlause': ('leddlaus',),
'leddlausere': ('leddlaus',),
'leddlausest': ('leddlaus',),
'leddlauseste': ('leddlaus',),
'leddlaust': ('leddlaus',),
'leddløs': ('leddløs',),
'leddløse': ('leddløs',),
'leddløsere': ('leddløs',),
'leddløsest': ('leddløs',),
'leddløseste': ('leddløs',),
'leddløst': ('leddløs',),
'leddvis': ('leddvis',),
'leddvise': ('leddvis',),
'leddvisere': ('leddvis',),
'leddvisest': ('leddvis',),
'leddviseste': ('leddvis',),
'leddvist': ('leddvis',),
'leda': ('lede',),
'ledede': ('lede',),
'ledende': ('lede',),
'ledet': ('lede',),
'ledete': ('lede',),
'ledig': ('ledig',),
'ledige': ('ledig',),
'ledigere': ('ledig',),
'ledigst': ('ledig',),
'ledigste': ('ledig',),
'ledsaga': ('ledsage',),
'ledsagede': ('ledsage',),
'ledsagende': ('ledsage',),
'ledsaget': ('ledsage',),
'ledsagete': ('ledsage',),
'lea': ('lee',),
'leede': ('lee',),
'leende': ('lee',),
'leet': ('lee',),
'leete': ('lee',),
'lefla': ('lefle',),
'leflede': ('lefle',),
'leflende': ('lefle',),
'leflet': ('lefle',),
'leflete': ('lefle',),
'lefset': ('lefset',),
'lefsete': ('lefset',),
'lefsetere': ('lefset',),
'lefsetest': ('lefset',),
'lefseteste': ('lefset',),
'lefsete': ('lefsete',),
'leg': ('leg',),
'lege': ('leg',),
'legere': ('leg',),
'legest': ('leg',),
'legeste': ('leg',),
'legt': ('leg',),
'legal': ('legal',),
'legale': ('legal',),
'legalere': ('legal',),
'legalest': ('legal',),
'legaleste': ('legal',),
'legalt': ('legal',),
'legaliserende': ('legalisere',),
'legalisert': ('legalisere',),
'legaliserte': ('legalisere',),
'lega': ('lege',),
'legede': ('lege',),
'legende': ('lege',),
'leget': ('lege',),
'legete': ('lege',),
'legt': ('lege',),
'legte': ('lege',),
'legelig': ('legelig',),
'legelige': ('legelig',),
'legeligere': ('legelig',),
'legeligst': ('legelig',),
'legeligste': ('legelig',),
'legemlig': ('legemlig',),
'legemlige': ('legemlig',),
'legemligere': ('legemlig',),
'legemligst': ('legemlig',),
'legemligste': ('legemlig',),
'legemliggjort': ('legemliggjøre',),
'legemliggjorte': ('legemliggjøre',),
'legemliggjørende': ('legemliggjøre',),
'legendarisk': ('legendarisk',),
'legendariske': ('legendarisk',),
'legendariskere': ('legendarisk',),
'legendariskest': ('legendarisk',),
'legendariskeste': ('legendarisk',),
'legerende': ('legere',),
'legert': ('legere',),
'legerte': ('legere',),
'lagt': ('legge',),
'lagte': ('legge',),
'leggende': ('legge',),
'legislativ': ('legislativ',),
'legislative': ('legislativ',),
'legislativere': ('legislativ',),
'legislativest': ('legislativ',),
'legislativeste': ('legislativ',),
'legislativt': ('legislativ',),
'legitim': ('legitim',),
'legitime': ('legitim',),
'legitimere': ('legitim',),
'legitimest': ('legitim',),
'legitimeste': ('legitim',),
'legitimt': ('legitim',),
'legitimerende': ('legitimere',),
'legitimert': ('legitimere',),
'legitimerte': ('legitimere',),
'lei': ('lei',),
'leie': ('lei',),
'leiere': ('lei',),
'leiest': ('lei',),
'leieste': ('lei',),
'leit': ('lei',),
'leitt': ('lei',),
'leira': ('leire',),
'leirede': ('leire',),
'leirende': ('leire',),
'leiret': ('leire',),
'leirete': ('leire',),
'leira': ('leire',),
'leirede': ('leire',),
'leirende': ('leire',),
'leiret': ('leire',),
'leirete': ('leire',),
'leiret': ('leiret',),
'leirete': ('leiret',),
'leiretere': ('leiret',),
'leiretest': ('leiret',),
'leireteste': ('leiret',),
'leirete': ('leirete',),
'leivd': ('leive',),
'leivde': ('leive',),
'leivende': ('leive',),
'lek': ('lek',),
'leke': ('lek',),
'lekere': ('lek',),
'lekest': ('lek',),
'lekeste': ('lek',),
'lekt': ('lek',),
'lekende': ('leke',),
'lekt': ('leke',),
'lekte': ('leke',),
'lekk': ('lekk',),
'lekke': ('lekk',),
'lekkere': ('lekk',),
'lekkest': ('lekk',),
'lekkeste': ('lekk',),
'lekt': ('lekk',),
'lekka': ('lekke',),
'lekkede': ('lekke',),
'lekken': ('lekke',),
'lekkende': ('lekke',),
'lekket': ('lekke',),
'lekkete': ('lekke',),
'lekne': ('lekke',),
'lekt': ('lekke',),
'lekte': ('lekke',),
'lekker': ('lekker',),
'lekkert': ('lekker',),
'lekre': ('lekker',),
'lekrere': ('lekker',),
'lekrest': ('lekker',),
'lekreste': ('lekker',),
'lekkersulten': ('lekkersulten',),
'lekkersultent': ('lekkersulten',),
'lekkersultne': ('lekkersulten',),
'lekkersultnere': ('lekkersulten',),
'lekkersultnest': ('lekkersulten',),
'lekkersultneste': ('lekkersulten',),
'lekra': ('lekre',),
'lekrede': ('lekre',),
'lekrende': ('lekre',),
'lekret': ('lekre',),
'lekrete': ('lekre',),
'leksa': ('lekse',),
'leksede': ('lekse',),
'leksende': ('lekse',),
'lekset': ('lekse',),
'leksete': ('lekse',),
'leksefri': ('leksefri',),
'leksefrie': ('leksefri',),
'leksefriere': ('leksefri',),
'leksefriest': ('leksefri',),
'leksefrieste': ('leksefri',),
'leksefritt': ('leksefri',),
'leksikalsk': ('leksikalsk',),
'leksikalske': ('leksikalsk',),
'leksikalskere': ('leksikalsk',),
'leksikalskest': ('leksikalsk',),
'leksikalskeste': ('leksikalsk',),
'leksikografisk': ('leksikografisk',),
'leksikografiske': ('leksikografisk',),
'leksikografiskere': ('leksikografisk',),
'leksikografiskest': ('leksikografisk',),
'leksikografiskeste': ('leksikografisk',),
'lekta': ('lekte',),
'lektede': ('lekte',),
'lektende': ('lekte',),
'lektet': ('lekte',),
'lektete': ('lekte',),
'lemfeldig': ('lemfeldig',),
'lemfeldige': ('lemfeldig',),
'lemfeldigere': ('lemfeldig',),
'lemfeldigst': ('lemfeldig',),
'lemfeldigste': ('lemfeldig',),
'lemlesta': ('lemleste',),
'lemlestede': ('lemleste',),
'lemlestende': ('lemleste',),
'lemlestet': ('lemleste',),
'lemlestete': ('lemleste',),
'lemmatiserende': ('lemmatisere',),
'lemmatisert': ('lemmatisere',),
'lemmatiserte': ('lemmatisere',),
'lemmatisk': ('lemmatisk',),
'lemmatiske': ('lemmatisk',),
'lemmatiskere': ('lemmatisk',),
'lemmatiskest': ('lemmatisk',),
'lemmatiskeste': ('lemmatisk',),
'lemma': ('lemme',),
'lemmede': ('lemme',),
'lemmende': ('lemme',),
'lemmet': ('lemme',),
'lemmete': ('lemme',),
'lemma': ('lemme',),
'lemmede': ('lemme',),
'lemmende': ('lemme',),
'lemmet': ('lemme',),
'lemmete': ('lemme',),
'lemma': ('lemme',),
'lemmede': ('lemme',),
'lemmende': ('lemme',),
'lemmet': ('lemme',),
'lemmete': ('lemme',),
'lempa': ('lempe',),
'lempede': ('lempe',),
'lempende': ('lempe',),
'lempet': ('lempe',),
'lempete': ('lempe',),
'lempelig': ('lempelig',),
'lempelige': ('lempelig',),
'lempeligere': ('lempelig',),
'lempeligst': ('lempelig',),
'lempeligste': ('lempelig',),
'lemster': ('lemster',),
'lemstert': ('lemster',),
'lemstre': ('lemster',),
'lemstrere': ('lemster',),
'lemstrest': ('lemster',),
'lemstreste': ('lemster',),
'lemstra': ('lemstre',),
'lemstrede': ('lemstre',),
'lemstrende': ('lemstre',),
'lemstret': ('lemstre',),
'lemstrete': ('lemstre',),
'lena': ('lene',),
'lenede': ('lene',),
'lenende': ('lene',),
'lenet': ('lene',),
'lenete': ('lene',),
'lent': ('lene',),
'lente': ('lene',),
'lenge': ('lenge',),
'lenger': ('lenge',),
'lengre': ('lenge',),
'lengst': ('lenge',),
'lengselsfull': ('lengselsfull',),
'lengselsfulle': ('lengselsfull',),
'lengselsfullere': ('lengselsfull',),
'lengselsfullest': ('lengselsfull',),
'lengselsfulleste': ('lengselsfull',),
'lengselsfullt': ('lengselsfull',),
'lengst': ('lengst',),
'lengste': ('lengst',),
'lengstlevende': ('lengstlevende',),
'lengta': ('lengte',),
'lengtede': ('lengte',),
'lengtende': ('lengte',),
'lengtet': ('lengte',),
'lengtete': ('lengte',),
'leninistisk': ('leninistisk',),
'leninistiske': ('leninistisk',),
'leninistiskere': ('leninistisk',),
'leninistiskest': ('leninistisk',),
'leninistiskeste': ('leninistisk',),
'lenka': ('lenke',),
'lenkede': ('lenke',),
'lenkende': ('lenke',),
'lenket': ('lenke',),
'lenkete': ('lenke',),
'lens': ('lens',),
'lensa': ('lense',),
'lensede': ('lense',),
'lensende': ('lense',),
'lenset': ('lense',),
'lensete': ('lense',),
'lensa': ('lense',),
'lensede': ('lense',),
'lensende': ('lense',),
'lenset': ('lense',),
'lensete': ('lense',),
'lepende': ('lepe',),
'lept': ('lepe',),
'lepte': ('lepe',),
'lepeblomstrede': ('lepeblomstret',),
'lepeblomstret': ('lepeblomstret',),
'lepeblomstrete': ('lepeblomstret',),
'lepeblomstretere': ('lepeblomstret',),
'lepeblomstretest': ('lepeblomstret',),
'lepeblomstreteste': ('lepeblomstret',),
'lepja': ('lepje',),
'lepjede': ('lepje',),
'lepjende': ('lepje',),
'lepjet': ('lepje',),
'lepjete': ('lepje',),
'leppeblomstra': ('leppeblomstra',),
'leppeblomstrede': ('leppeblomstret',),
'leppeblomstret': ('leppeblomstret',),
'leppeblomstrete': ('leppeblomstret',),
'leppeblomstretere': ('leppeblomstret',),
'leppeblomstretest': ('leppeblomstret',),
'leppeblomstreteste': ('leppeblomstret',),
'leptosom': ('leptosom',),
'leptosome': ('leptosom',),
'leptosomere': ('leptosom',),
'leptosomest': ('leptosom',),
'leptosomeste': ('leptosom',),
'leptosomt': ('leptosom',),
'lesbisk': ('lesbisk',),
'lesbiske': ('lesbisk',),
'lesbiskere': ('lesbisk',),
'lesbiskest': ('lesbisk',),
'lesbiskeste': ('lesbisk',),
'lesende': ('lese',),
'lest': ('lese',),
'leste': ('lese',),
'leselig': ('leselig',),
'leselige': ('leselig',),
'leseligere': ('leselig',),
'leseligst': ('leselig',),
'leseligste': ('leselig',),
'lesesvak': ('lesesvak',),
'lesesvake': ('lesesvak',),
'lesesvakere': ('lesesvak',),
'lesesvakest': ('lesesvak',),
'lesesvakeste': ('lesesvak',),
'lesesvakt': ('lesesvak',),
'leska': ('leske',),
'leskede': ('leske',),
'leskende': ('leske',),
'lesket': ('leske',),
'leskete': ('leske',),
'lesothisk': ('lesothisk',),
'lesothiske': ('lesothisk',),
'lesothiskere': ('lesothisk',),
'lesothiskest': ('lesothisk',),
'lesothiskeste': ('lesothisk',),
'lesp': ('lesp',),
'lespe': ('lesp',),
'lespere': ('lesp',),
'lespest': ('lesp',),
'lespeste': ('lesp',),
'lespt': ('lesp',),
'lespa': ('lespe',),
'lespede': ('lespe',),
'lespende': ('lespe',),
'lespet': ('lespe',),
'lespete': ('lespe',),
'lessa': ('lesse',),
'lessede': ('lesse',),
'lessende': ('lesse',),
'lesset': ('lesse',),
'lessete': ('lesse',),
'lest': ('lesse',),
'leste': ('lesse',),
'letende': ('lete',),
'lett': ('lete',),
'lette': ('lete',),
'letna': ('letne',),
'letnede': ('letne',),
'letnende': ('letne',),
'letnet': ('letne',),
'letnete': ('letne',),
'lett': ('lett',),
'lette': ('lett',),
'lettere': ('lett',),
'lettest': ('lett',),
'letteste': ('lett',),
'lett-tjent': ('lett-tjent',),
'lett-tjente': ('lett-tjent',),
'lett-tjentere': ('lett-tjent',),
'lett-tjentest': ('lett-tjent',),
'lett-tjenteste': ('lett-tjent',),
'lett-troende': ('lett-troende',),
'lett-truende': ('lett-truende',),
'lettantennelig': ('lettantennelig',),
'lettantennelige': ('lettantennelig',),
'lettantenneligere': ('lettantennelig',),
'lettantenneligst': ('lettantennelig',),
'lettantenneligste': ('lettantennelig',),
'lettbedervelig': ('lettbedervelig',),
'lettbedervelige': ('lettbedervelig',),
'lettbederveligere': ('lettbedervelig',),
'lettbederveligst': ('lettbedervelig',),
'lettbederveligste': ('lettbedervelig',),
'lettbeint': ('lettbeint',),
'lettbeinte': ('lettbeint',),
'lettbeintere': ('lettbeint',),
'lettbeintest': ('lettbeint',),
'lettbeinteste': ('lettbeint',),
'lettbevegelig': ('lettbevegelig',),
'lettbevegelige': ('lettbevegelig',),
'lettbevegeligere': ('lettbevegelig',),
'lettbevegeligst': ('lettbevegelig',),
'lettbevegeligste': ('lettbevegelig',),
'lettbrukt': ('lettbrukt',),
'lettbrukte': ('lettbrukt',),
'lettbruktere': ('lettbrukt',),
'lettbruktest': ('lettbrukt',),
'lettbrukteste': ('lettbrukt',),
'lettdrevet': ('lettdrevet',),
'lettdrevne': ('lettdrevet',),
'lettdrevnere': ('lettdrevet',),
'lettdrevnest': ('lettdrevet',),
'lettdrevneste': ('lettdrevet',),
'letta': ('lette',),
'lettede': ('lette',),
'lettende': ('lette',),
'lettet': ('lette',),
'lettete': ('lette',),
'lettfattelig': ('lettfattelig',),
'lettfattelige': ('lettfattelig',),
'lettfatteligere': ('lettfattelig',),
'lettfatteligst': ('lettfattelig',),
'lettfatteligste': ('lettfattelig',),
'lettferdig': ('lettferdig',),
'lettferdige': ('lettferdig',),
'lettferdigere': ('lettferdig',),
'lettferdigst': ('lettferdig',),
'lettferdigste': ('lettferdig',),
'lettflytende': ('lettflytende',),
'lettfordøyelig': ('lettfordøyelig',),
'lettfordøyelige': ('lettfordøyelig',),
'lettfordøyeligere': ('lettfordøyelig',),
'lettfordøyeligst': ('lettfordøyelig',),
'lettfordøyeligste': ('lettfordøyelig',),
'lettjent': ('lettjent',),
'lettjente': ('lettjent',),
'lettjentere': ('lettjent',),
'lettjentest': ('lettjent',),
'lettjenteste': ('lettjent',),
'lettkjøpt': ('lettkjøpt',),
'lettkjøpte': ('lettkjøpt',),
'lettkjøptere': ('lettkjøpt',),
'lettkjøptest': ('lettkjøpt',),
'lettkjøpteste': ('lettkjøpt',),
'lettkokt': ('lettkokt',),
'lettkokte': ('lettkokt',),
'lettkoktere': ('lettkokt',),
'lettkoktest': ('lettkokt',),
'lettkokteste': ('lettkokt',),
'lettlest': ('lettlest',),
'lettleste': ('lettlest',),
'lettlestere': ('lettlest',),
'lettlestest': ('lettlest',),
'lettlesteste': ('lettlest',),
'lettliva': ('lettliva',),
'lettlivede': ('lettlivet',),
'lettlivet': ('lettlivet',),
'lettlivete': ('lettlivet',),
'lettlivetere': ('lettlivet',),
'lettlivetest': ('lettlivet',),
'lettliveteste': ('lettlivet',),
'lettlynt': ('lettlynt',),
'lettlynte': ('lettlynt',),
'lettlyntere': ('lettlynt',),
'lettlyntest': ('lettlynt',),
'lettlynteste': ('lettlynt',),
'lettrodd': ('lettrodd',),
'lettrodde': ('lettrodd',),
'lettroddere': ('lettrodd',),
'lettroddest': ('lettrodd',),
'lettroddeste': ('lettrodd',),
'lettroende': ('lettroende',),
'lettruen': ('lettruen',),
'lettruene': ('lettruen',),
'lettruenere': ('lettruen',),
'lettruenest': ('lettruen',),
'lettrueneste': ('lettruen',),
'lettruent': ('lettruen',),
'lettrune': ('lettruen',),
'lettrunere': ('lettruen',),
'lettrunest': ('lettruen',),
'lettruneste': ('lettruen',),
'lettruende': ('lettruende',),
'lettrøykt': ('lettrøykt',),
'lettrøykte': ('lettrøykt',),
'lettrøyktere': ('lettrøykt',),
'lettrøyktest': ('lettrøykt',),
'lettrøykteste': ('lettrøykt',),
'lettsalta': ('lettsalta',),
'lettsaltede': ('lettsaltet',),
'lettsaltet': ('lettsaltet',),
'lettsaltete': ('lettsaltet',),
'lettsaltetere': ('lettsaltet',),
'lettsaltetest': ('lettsaltet',),
'lettsalteteste': ('lettsaltet',),
'lettsindig': ('lettsindig',),
'lettsindige': ('lettsindig',),
'lettsindigere': ('lettsindig',),
'lettsindigst': ('lettsindig',),
'lettsindigste': ('lettsindig',),
'lettskya': ('lettskya',),
'lettskyede': ('lettskyet',),
'lettskyet': ('lettskyet',),
'lettskyete': ('lettskyet',),
'lettskyetere': ('lettskyet',),
'lettskyetest': ('lettskyet',),
'lettskyeteste': ('lettskyet',),
'lettsprengt': ('lettsprengt',),
'lettsprengte': ('lettsprengt',),
'lettsprengtere': ('lettsprengt',),
'lettsprengtest': ('lettsprengt',),
'lettsprengteste': ('lettsprengt',),
'lettstelt': ('lettstelt',),
'lettstelte': ('lettstelt',),
'lettsteltere': ('lettstelt',),
'lettsteltest': ('lettstelt',),
'lettstelteste': ('lettstelt',),
'lettvinn': ('lettvinn',),
'lettvinne': ('lettvinn',),
'lettvinnere': ('lettvinn',),
'lettvinnest': ('lettvinn',),
'lettvinneste': ('lettvinn',),
'lettvint': ('lettvinn',),
'lettvint': ('lettvint',),
'lettvinte': ('lettvint',),
'lettvintere': ('lettvint',),
'lettvintest': ('lettvint',),
'lettvinteste': ('lettvint',),
'levantinsk': ('levantinsk',),
'levantinske': ('levantinsk',),
'levantinskere': ('levantinsk',),
'levantinskest': ('levantinsk',),
'levantinskeste': ('levantinsk',),
'levantisk': ('levantisk',),
'levantiske': ('levantisk',),
'levantiskere': ('levantisk',),
'levantiskest': ('levantisk',),
'levantiskeste': ('levantisk',),
'levd': ('leve',),
'levde': ('leve',),
'levede': ('leve',),
'levende': ('leve',),
'levet': ('leve',),
'levete': ('leve',),
'levedyktig': ('levedyktig',),
'levedyktige': ('levedyktig',),
'levedyktigere': ('levedyktig',),
'levedyktigst': ('levedyktig',),
'levedyktigste': ('levedyktig',),
'levelig': ('levelig',),
'levelige': ('levelig',),
'leveligere': ('levelig',),
'leveligst': ('levelig',),
'leveligste': ('levelig',),
'levende': ('levende',),
'levendegjort': ('levendegjøre',),
'levendegjorte': ('levendegjøre',),
'levendegjørende': ('levendegjøre',),
'leveransedyktig': ('leveransedyktig',),
'leveransedyktige': ('leveransedyktig',),
'leveransedyktigere': ('leveransedyktig',),
'leveransedyktigst': ('leveransedyktig',),
'leveransedyktigste': ('leveransedyktig',),
'leverende': ('levere',),
'levert': ('levere',),
'leverte': ('levere',),
'levittisk': ('levittisk',),
'levittiske': ('levittisk',),
'levittiskere': ('levittisk',),
'levittiskest': ('levittisk',),
'levittiskeste': ('levittisk',),
'levna': ('levne',),
'levnede': ('levne',),
'levnende': ('levne',),
'levnet': ('levne',),
'levnete': ('levne',),
'levra': ('levre',),
'levrede': ('levre',),
'levrende': ('levre',),
'levret': ('levre',),
'levrete': ('levre',),
'lidd': ('li',),
'lidde': ('li',),
'liende': ('li',),
'lidd': ('li',),
'lidde': ('li',),
'liende': ('li',),
'libanesisk': ('libanesisk',),
'libanesiske': ('libanesisk',),
'libanesiskere': ('libanesisk',),
'libanesiskest': ('libanesisk',),
'libanesiskeste': ('libanesisk',),
'liberal': ('liberal',),
'liberale': ('liberal',),
'liberalere': ('liberal',),
'liberalest': ('liberal',),
'liberaleste': ('liberal',),
'liberalt': ('liberal',),
'liberaliserende': ('liberalisere',),
'liberalisert': ('liberalisere',),
'liberaliserte': ('liberalisere',),
'liberisk': ('liberisk',),
'liberiske': ('liberisk',),
'liberiskere': ('liberisk',),
'liberiskest': ('liberisk',),
'liberiskeste': ('liberisk',),
'libidinøs': ('libidinøs',),
'libidinøse': ('libidinøs',),
'libidinøsere': ('libidinøs',),
'libidinøsest': ('libidinøs',),
'libidinøseste': ('libidinøs',),
'libidinøst': ('libidinøs',),
'libysk': ('libysk',),
'libyske': ('libysk',),
'libyskere': ('libysk',),
'libyskest': ('libysk',),
'libyskeste': ('libysk',),
'lidderlig': ('lidderlig',),
'lidderlige': ('lidderlig',),
'lidderligere': ('lidderlig',),
'lidderligst': ('lidderlig',),
'lidderligste': ('lidderlig',),
'lidd': ('lide',),
'lidde': ('lide',),
'lidende': ('lide',),
'lidt': ('lide',),
'lidte': ('lide',),
'lidenskapelig': ('lidenskapelig',),
'lidenskapelige': ('lidenskapelig',),
'lidenskapeligere': ('lidenskapelig',),
'lidenskapeligst': ('lidenskapelig',),
'lidenskapeligste': ('lidenskapelig',),
'lidenskapslaus': ('lidenskapslaus',),
'lidenskapslause': ('lidenskapslaus',),
'lidenskapslausere': ('lidenskapslaus',),
'lidenskapslausest': ('lidenskapslaus',),
'lidenskapslauseste': ('lidenskapslaus',),
'lidenskapslaust': ('lidenskapslaus',),
'lidenskapsløs': ('lidenskapsløs',),
'lidenskapsløse': ('lidenskapsløs',),
'lidenskapsløsere': ('lidenskapsløs',),
'lidenskapsløsest': ('lidenskapsløs',),
'lidenskapsløseste': ('lidenskapsløs',),
'lidenskapsløst': ('lidenskapsløs',),
'liderlig': ('liderlig',),
'liderlige': ('liderlig',),
'liderligere': ('liderlig',),
'liderligst': ('liderlig',),
'liderligste': ('liderlig',),
'liechtensteinsk': ('liechtensteinsk',),
'liechtensteinske': ('liechtensteinsk',),
'liechtensteinskere': ('liechtensteinsk',),
'liechtensteinskest': ('liechtensteinsk',),
'liechtensteinskeste': ('liechtensteinsk',),
'liflig': ('liflig',),
'liflige': ('liflig',),
'lifligere': ('liflig',),
'lifligst': ('liflig',),
'lifligste': ('liflig',),
'liggen': ('ligge',),
'liggende': ('ligge',),
'ligget': ('ligge',),
'ligne': ('ligge',),
'ligna': ('ligne',),
'lignede': ('ligne',),
'lignende': ('ligne',),
'lignet': ('ligne',),
'lignete': ('ligne',),
'lignende': ('lignende',),
'lignifiserende': ('lignifisere',),
'lignifisert': ('lignifisere',),
'lignifiserte': ('lignifisere',),
'lik': ('lik',),
'like': ('lik',),
'likere': ('lik',),
'likest': ('lik',),
'likeste': ('lik',),
'likt': ('lik',),
'likbleik': ('likbleik',),
'likbleike': ('likbleik',),
'likbleikere': ('likbleik',),
'likbleikest': ('likbleik',),
'likbleikeste': ('likbleik',),
'likbleikt': ('likbleik',),
'likblek': ('likblek',),
'likbleke': ('likblek',),
'likblekere': ('likblek',),
'likblekest': ('likblek',),
'likblekeste': ('likblek',),
'likblekt': ('likblek',),
'likende': ('like',),
'likt': ('like',),
'likte': ('like',),
'lika': ('like',),
'likede': ('like',),
'likende': ('like',),
'liket': ('like',),
'likete': ('like',),
'likt': ('like',),
'likte': ('like',),
'like': ('like',),
'likebeint': ('likebeint',),
'likebeinte': ('likebeint',),
'likebeintere': ('likebeint',),
'likebeintest': ('likebeint',),
'likebeinteste': ('likebeint',),
'likebent': ('likebent',),
'likebente': ('likebent',),
'likebentere': ('likebent',),
'likebentest': ('likebent',),
'likebenteste': ('likebent',),
'likeberettiga': ('likeberettiga',),
'likeberettigede': ('likeberettiget',),
'likeberettiget': ('likeberettiget',),
'likeberettigete': ('likeberettiget',),
'likeberettigetere': ('likeberettiget',),
'likeberettigetest': ('likeberettiget',),
'likeberettigeteste': ('likeberettiget',),
'likedan': ('likedan',),
'likedanne': ('likedan',),
'likedannere': ('likedan',),
'likedannest': ('likedan',),
'likedanneste': ('likedan',),
'likedant': ('likedan',),
'likedanna': ('likedanna',),
'likedannede': ('likedannet',),
'likedannet': ('likedannet',),
'likedannete': ('likedannet',),
'likedannetere': ('likedannet',),
'likedannetest': ('likedannet',),
'likedanneteste': ('likedannet',),
'likeens': ('likeens',),
'likefinnet': ('likefinnet',),
'likefinnete': ('likefinnet',),
'likefinnetere': ('likefinnet',),
'likefinnetest': ('likefinnet',),
'likefinneteste': ('likefinnet',),
'likefinnete': ('likefinnete',),
'likeforma': ('likeforma',),
'likeformede': ('likeformet',),
'likeformet': ('likeformet',),
'likeformete': ('likeformet',),
'likeformetere': ('likeformet',),
'likeformetest': ('likeformet',),
'likeformeteste': ('likeformet',),
'likefram': ('likefram',),
'likeframme': ('likefram',),
'likeframmere': ('likefram',),
'likeframmest': ('likefram',),
'likeframmeste': ('likefram',),
'likeframt': ('likefram',),
'likefrem': ('likefrem',),
'likefremme': ('likefrem',),
'likefremmere': ('likefrem',),
'likefremmest': ('likefrem',),
'likefremmeste': ('likefrem',),
'likefremt': ('likefrem',),
'likeglad': ('likeglad',),
'likeglade': ('likeglad',),
'likegladere': ('likeglad',),
'likegladest': ('likeglad',),
'likegladeste': ('likeglad',),
'likegyldig': ('likegyldig',),
'likegyldige': ('likegyldig',),
'likegyldigere': ('likegyldig',),
'likegyldigst': ('likegyldig',),
'likegyldigste': ('likegyldig',),
'likelig': ('likelig',),
'likelige': ('likelig',),
'likeligere': ('likelig',),
'likeligst': ('likelig',),
'likeligste': ('likelig',),
'likelydende': ('likelydende',),
'likende': ('likende',),
'likendes': ('likendes',),
'likeretta': ('likerette',),
'likerettede': ('likerette',),
'likerettende': ('likerette',),
'likerettet': ('likerette',),
'likerettete': ('likerette',),
'likesinnede': ('likesinnet',),
'likesinnet': ('likesinnet',),
'likesinnete': ('likesinnet',),
'likesinnetere': ('likesinnet',),
'likesinnetest': ('likesinnet',),
'likesinneteste': ('likesinnet',),
'likestillende': ('likestille',),
'likestilt': ('likestille',),
'likestilte': ('likestille',),
'likesæl': ('likesæl',),
'likesæle': ('likesæl',),
'likesælere': ('likesæl',),
'likesælest': ('likesæl',),
'likesæleste': ('likesæl',),
'likesælt': ('likesæl',),
'liketil': ('liketil',),
'liketille': ('liketil',),
'liketillere': ('liketil',),
'liketillest': ('liketil',),
'liketilleste': ('liketil',),
'liketilt': ('liketil',),
'likevarm': ('likevarm',),
'likevarme': ('likevarm',),
'likevarmere': ('likevarm',),
'likevarmest': ('likevarm',),
'likevarmeste': ('likevarm',),
'likevarmt': ('likevarm',),
'likevektig': ('likevektig',),
'likevektige': ('likevektig',),
'likevektigere': ('likevektig',),
'likevektigst': ('likevektig',),
'likevektigste': ('likevektig',),
'likeverdig': ('likeverdig',),
'likeverdige': ('likeverdig',),
'likeverdigere': ('likeverdig',),
'likeverdigst': ('likeverdig',),
'likeverdigste': ('likeverdig',),
'likna': ('likne',),
'liknede': ('likne',),
'liknende': ('likne',),
'liknet': ('likne',),
'liknete': ('likne',),
'liknende': ('liknende',),
'likvid': ('likvid',),
'likvide': ('likvid',),
'likvidere': ('likvid',),
'likvidest': ('likvid',),
'likvideste': ('likvid',),
'likviderende': ('likvidere',),
'likvidert': ('likvidere',),
'likviderte': ('likvidere',),
'lilla': ('lilla',),
'lille': ('lille',),
'lima': ('lime',),
'limede': ('lime',),
'limende': ('lime',),
'limet': ('lime',),
'limete': ('lime',),
'limt': ('lime',),
'limte': ('lime',),
'linda': ('linde',),
'lindede': ('linde',),
'lindende': ('linde',),
'lindet': ('linde',),
'lindete': ('linde',),
'lindra': ('lindre',),
'lindrede': ('lindre',),
'lindrende': ('lindre',),
'lindret': ('lindre',),
'lindrete': ('lindre',),
'lineær': ('lineær',),
'lineære': ('lineær',),
'lineærere': ('lineær',),
'lineærest': ('lineær',),
'lineæreste': ('lineær',),
'lineært': ('lineær',),
'linfakset': ('linfakset',),
'linfaksete': ('linfakset',),
'linfaksetere': ('linfakset',),
'linfaksetest': ('linfakset',),
'linfakseteste': ('linfakset',),
'linfaksete': ('linfaksete',),
'linfarga': ('linfarga',),
'linfargede': ('linfarget',),
'linfarget': ('linfarget',),
'linfargete': ('linfarget',),
'linfargetere': ('linfarget',),
'linfargetest': ('linfarget',),
'linfargeteste': ('linfarget',),
'lingvistisk': ('lingvistisk',),
'lingvistiske': ('lingvistisk',),
'lingvistiskere': ('lingvistisk',),
'lingvistiskest': ('lingvistisk',),
'lingvistiskeste': ('lingvistisk',),
'linjedelt': ('linjedelt',),
'linjedelte': ('linjedelt',),
'linjedeltere': ('linjedelt',),
'linjedeltest': ('linjedelt',),
'linjedelteste': ('linjedelt',),
'linjerende': ('linjere',),
'linjert': ('linjere',),
'linjerte': ('linjere',),
'links': ('links',),
'linkse': ('links',),
'linksere': ('links',),
'linksest': ('links',),
'linkseste': ('links',),
'linn': ('linn',),
'linne': ('linn',),
'linnere': ('linn',),
'linnest': ('linn',),
'linneste': ('linn',),
'lint': ('linn',),
'linna': ('linne',),
'linnede': ('linne',),
'linnende': ('linne',),
'linnet': ('linne',),
'linnete': ('linne',),
'linnkokende': ('linnkoke',),
'linnkokt': ('linnkoke',),
'linnkokte': ('linnkoke',),
'linnsalta': ('linnsalte',),
'linnsaltede': ('linnsalte',),
'linnsaltende': ('linnsalte',),
'linnsaltet': ('linnsalte',),
'linnsaltete': ('linnsalte',),
'linseforma': ('linseforma',),
'linseformede': ('linseformet',),
'linseformet': ('linseformet',),
'linseformete': ('linseformet',),
'linseformetere': ('linseformet',),
'linseformetest': ('linseformet',),
'linseformeteste': ('linseformet',),
'lira': ('lire',),
'lirede': ('lire',),
'lirende': ('lire',),
'liret': ('lire',),
'lirete': ('lire',),
'lirt': ('lire',),
'lirte': ('lire',),
'lirka': ('lirke',),
'lirkede': ('lirke',),
'lirkende': ('lirke',),
'lirket': ('lirke',),
'lirkete': ('lirke',),
'lisensierende': ('lisensiere',),
'lisensiert': ('lisensiere',),
'lisensierte': ('lisensiere',),
'lisiterende': ('lisitere',),
'lisitert': ('lisitere',),
'lisiterte': ('lisitere',),
'lissa': ('lisse',),
'lissede': ('lisse',),
'lissende': ('lisse',),
'lisset': ('lisse',),
'lissete': ('lisse',),
'lista': ('liste',),
'listede': ('liste',),
'listende': ('liste',),
'listet': ('liste',),
'listete': ('liste',),
'lista': ('liste',),
'listede': ('liste',),
'listende': ('liste',),
'listet': ('liste',),
'listete': ('liste',),
'lista': ('liste',),
'listede': ('liste',),
'listende': ('liste',),
'listet': ('liste',),
'listete': ('liste',),
'listig': ('listig',),
'listige': ('listig',),
'listigere': ('listig',),
'listigst': ('listig',),
'listigste': ('listig',),
'litauisk': ('litauisk',),
'litauiske': ('litauisk',),
'litauiskere': ('litauisk',),
'litauiskest': ('litauisk',),
'litauiskeste': ('litauisk',),
'litende': ('lite',),
'litt': ('lite',),
'litte': ('lite',),
'lille': ('liten',),
'lita': ('liten',),
'lite': ('liten',),
'liten': ('liten',),
'mindre': ('liten',),
'minst': ('liten',),
'minste': ('liten',),
'små': ('liten',),
'smått': ('liten',),
'vesle': ('liten',),
'litograferende': ('litografere',),
'litografert': ('litografere',),
'litograferte': ('litografere',),
'litografisk': ('litografisk',),
'litografiske': ('litografisk',),
'litografiskere': ('litografisk',),
'litografiskest': ('litografisk',),
'litografiskeste': ('litografisk',),
'litologisk': ('litologisk',),
'litologiske': ('litologisk',),
'litologiskere': ('litologisk',),
'litologiskest': ('litologisk',),
'litologiskeste': ('litologisk',),
'litotisk': ('litotisk',),
'litotiske': ('litotisk',),
'litotiskere': ('litotisk',),
'litotiskest': ('litotisk',),
'litotiskeste': ('litotisk',),
'litt': ('litt',),
'litterær': ('litterær',),
'litterære': ('litterær',),
'litterærere': ('litterær',),
'litterærest': ('litterær',),
'litteræreste': ('litterær',),
'litterært': ('litterær',),
'littisk': ('littisk',),
'littiske': ('littisk',),
'littiskere': ('littisk',),
'littiskest': ('littisk',),
'littiskeste': ('littisk',),
'liturgisk': ('liturgisk',),
'liturgiske': ('liturgisk',),
'liturgiskere': ('liturgisk',),
'liturgiskest': ('liturgisk',),
'liturgiskeste': ('liturgisk',),
'livaktig': ('livaktig',),
'livaktige': ('livaktig',),
'livaktigere': ('livaktig',),
'livaktigst': ('livaktig',),
'livaktigste': ('livaktig',),
'livat': ('livat',),
'livate': ('livat',),
'livatere': ('livat',),
'livatest': ('livat',),
'livateste': ('livat',),
'livberga': ('livberge',),
'livbergede': ('livberge',),
'livbergende': ('livberge',),
'livberget': ('livberge',),
'livbergete': ('livberge',),
'liva': ('live',),
'livede': ('live',),
'livende': ('live',),
'livet': ('live',),
'livete': ('live',),
'livd': ('live',),
'livde': ('live',),
'livende': ('live',),
'live': ('live',),
'livegen': ('livegen',),
'livegent': ('livegen',),
'livegne': ('livegen',),
'livegnere': ('livegen',),
'livegnest': ('livegen',),
'livegneste': ('livegen',),
'livfull': ('livfull',),
'livfulle': ('livfull',),
'livfullere': ('livfull',),
'livfullest': ('livfull',),
'livfulleste': ('livfull',),
'livfullt': ('livfull',),
'livgivende': ('livgivende',),
'livisk': ('livisk',),
'liviske': ('livisk',),
'liviskere': ('livisk',),
'liviskest': ('livisk',),
'liviskeste': ('livisk',),
'livlandsk': ('livlandsk',),
'livlandske': ('livlandsk',),
'livlandskere': ('livlandsk',),
'livlandskest': ('livlandsk',),
'livlandskeste': ('livlandsk',),
'livlaus': ('livlaus',),
'livlause': ('livlaus',),
'livlausere': ('livlaus',),
'livlausest': ('livlaus',),
'livlauseste': ('livlaus',),
'livlaust': ('livlaus',),
'livlig': ('livlig',),
'livlige': ('livlig',),
'livligere': ('livlig',),
'livligst': ('livlig',),
'livligste': ('livlig',),
'livløs': ('livløs',),
'livløse': ('livløs',),
'livløsere': ('livløs',),
'livløsest': ('livløs',),
'livløseste': ('livløs',),
'livløst': ('livløs',),
'livna': ('livne',),
'livnede': ('livne',),
'livnende': ('livne',),
'livnet': ('livne',),
'livnete': ('livne',),
'livnæra': ('livnære',),
'livnærede': ('livnære',),
'livnærende': ('livnære',),
'livnæret': ('livnære',),
'livnærete': ('livnære',),
'livnært': ('livnære',),
'livnærte': ('livnære',),
'livredd': ('livredd',),
'livredde': ('livredd',),
'livreddere': ('livredd',),
'livreddest': ('livredd',),
'livreddeste': ('livredd',),
'livsdyktig': ('livsdyktig',),
'livsdyktige': ('livsdyktig',),
'livsdyktigere': ('livsdyktig',),
'livsdyktigst': ('livsdyktig',),
'livsdyktigste': ('livsdyktig',),
'livsens': ('livsens',),
'livserfaren': ('livserfaren',),
'livserfarent': ('livserfaren',),
'livserfarne': ('livserfaren',),
'livserfarnere': ('livserfaren',),
'livserfarnest': ('livserfaren',),
'livserfarneste': ('livserfaren',),
'livsfarlig': ('livsfarlig',),
'livsfarlige': ('livsfarlig',),
'livsfarligere': ('livsfarlig',),
'livsfarligst': ('livsfarlig',),
'livsfarligste': ('livsfarlig',),
'livsfiendsk': ('livsfiendsk',),
'livsfiendske': ('livsfiendsk',),
'livsfiendskere': ('livsfiendsk',),
'livsfiendskest': ('livsfiendsk',),
'livsfiendskeste': ('livsfiendsk',),
'livsfiendtlig': ('livsfiendtlig',),
'livsfiendtlige': ('livsfiendtlig',),
'livsfiendtligere': ('livsfiendtlig',),
'livsfiendtligst': ('livsfiendtlig',),
'livsfiendtligste': ('livsfiendtlig',),
'livsfjern': ('livsfjern',),
'livsfjerne': ('livsfjern',),
'livsfjernere': ('livsfjern',),
'livsfjernest': ('livsfjern',),
'livsfjerneste': ('livsfjern',),
'livsfjernt': ('livsfjern',),
'livsforsikra': ('livsforsikre',),
'livsforsikrede': ('livsforsikre',),
'livsforsikrende': ('livsforsikre',),
'livsforsikret': ('livsforsikre',),
'livsforsikrete': ('livsforsikre',),
'livsfrisk': ('livsfrisk',),
'livsfriske': ('livsfrisk',),
'livsfriskere': ('livsfrisk',),
'livsfriskest': ('livsfrisk',),
'livsfriskeste': ('livsfrisk',),
'livsfriskt': ('livsfrisk',),
'livsglad': ('livsglad',),
'livsglade': ('livsglad',),
'livsgladere': ('livsglad',),
'livsgladest': ('livsglad',),
'livsgladeste': ('livsglad',),
'livsklok': ('livsklok',),
'livskloke': ('livsklok',),
'livsklokere': ('livsklok',),
'livsklokest': ('livsklok',),
'livsklokeste': ('livsklok',),
'livsklokt': ('livsklok',),
'livskraftig': ('livskraftig',),
'livskraftige': ('livskraftig',),
'livskraftigere': ('livskraftig',),
'livskraftigst': ('livskraftig',),
'livskraftigste': ('livskraftig',),
'livslang': ('livslang',),
'livslange': ('livslang',),
'livslangt': ('livslang',),
'livslenger': ('livslang',),
'livslengre': ('livslang',),
'livslengst': ('livslang',),
'livslengste': ('livslang',),
'livsnær': ('livsnær',),
'livsnære': ('livsnær',),
'livsnærere': ('livsnær',),
'livsnærest': ('livsnær',),
'livsnæreste': ('livsnær',),
'livsnært': ('livsnær',),
'livsnødvendig': ('livsnødvendig',),
'livsnødvendige': ('livsnødvendig',),
'livsnødvendigere': ('livsnødvendig',),
'livsnødvendigst': ('livsnødvendig',),
'livsnødvendigste': ('livsnødvendig',),
'livssynsnøytral': ('livssynsnøytral',),
'livssynsnøytrale': ('livssynsnøytral',),
'livssynsnøytralere': ('livssynsnøytral',),
'livssynsnøytralest': ('livssynsnøytral',),
'livssynsnøytraleste': ('livssynsnøytral',),
'livssynsnøytralt': ('livssynsnøytral',),
'livsvarig': ('livsvarig',),
'livsvarige': ('livsvarig',),
'livsvarigere': ('livsvarig',),
'livsvarigst': ('livsvarig',),
'livsvarigste': ('livsvarig',),
'livsviktig': ('livsviktig',),
'livsviktige': ('livsviktig',),
'livsviktigere': ('livsviktig',),
'livsviktigst': ('livsviktig',),
'livsviktigste': ('livsviktig',),
'ljoma': ('ljome',),
'ljomede': ('ljome',),
'ljomende': ('ljome',),
'ljomet': ('ljome',),
'ljomete': ('ljome',),
'ljugd': ('ljuge',),
'ljugde': ('ljuge',),
'ljugende': ('ljuge',),
'løyen': ('ljuge',),
'løyet': ('ljuge',),
'løyne': ('ljuge',),
'ljugd': ('ljuge',),
'ljugde': ('ljuge',),
'ljugende': ('ljuge',),
'løyen': ('ljuge',),
'løyet': ('ljuge',),
'løyne': ('ljuge',),
'lo': ('lo',),
'lobba': ('lobbe',),
'lobbede': ('lobbe',),
'lobbende': ('lobbe',),
'lobbet': ('lobbe',),
'lobbete': ('lobbe',),
'lodda': ('lodde',),
'loddede': ('lodde',),
'loddende': ('lodde',),
'loddet': ('lodde',),
'loddete': ('lodde',),
'lodda': ('lodde',),
'loddede': ('lodde',),
'loddende': ('lodde',),
'loddet': ('lodde',),
'loddete': ('lodde',),
'lodden': ('lodden',),
'loddent': ('lodden',),
'lodne': ('lodden',),
'lodnere': ('lodden',),
'lodnest': ('lodden',),
'lodneste': ('lodden',),
'loddrett': ('loddrett',),
'loddrette': ('loddrett',),
'loddrettere': ('loddrett',),
'loddrettest': ('loddrett',),
'loddretteste': ('loddrett',),
'loa': ('loe',),
'loede': ('loe',),
'loende': ('loe',),
'loet': ('loe',),
'loete': ('loe',),
'loet': ('loet',),
'loete': ('loet',),
'loetere': ('loet',),
'loetest': ('loet',),
'loeteste': ('loet',),
'loete': ('loete',),
'loffa': ('loffe',),
'loffede': ('loffe',),
'loffende': ('loffe',),
'loffet': ('loffe',),
'loffete': ('loffe',),
'loffa': ('loffe',),
'loffede': ('loffe',),
'loffende': ('loffe',),
'loffet': ('loffe',),
'loffete': ('loffe',),
'logaritmisk': ('logaritmisk',),
'logaritmiske': ('logaritmisk',),
'logaritmiskere': ('logaritmisk',),
'logaritmiskest': ('logaritmisk',),
'logaritmiskeste': ('logaritmisk',),
'loga': ('loge',),
'logede': ('loge',),
'logende': ('loge',),
'loget': ('loge',),
'logete': ('loge',),
'logga': ('logge',),
'loggede': ('logge',),
'loggende': ('logge',),
'logget': ('logge',),
'loggete': ('logge',),
'logisk': ('logisk',),
'logiske': ('logisk',),
'logiskere': ('logisk',),
'logiskest': ('logisk',),
'logiskeste': ('logisk',),
'logn': ('logn',),
'logne': ('logn',),
'lognere': ('logn',),
'lognest': ('logn',),
'logneste': ('logn',),
'lognt': ('logn',),
'logra': ('logre',),
'logrede': ('logre',),
'logrende': ('logre',),
'logret': ('logre',),
'logrete': ('logre',),
'lojal': ('lojal',),
'lojale': ('lojal',),
'lojalere': ('lojal',),
'lojalest': ('lojal',),
'lojaleste': ('lojal',),
'lojalt': ('lojal',),
'lokal': ('lokal',),
'lokale': ('lokal',),
'lokalere': ('lokal',),
'lokalest': ('lokal',),
'lokaleste': ('lokal',),
'lokalt': ('lokal',),
'lokalbedøva': ('lokalbedøve',),
'lokalbedøvd': ('lokalbedøve',),
'lokalbedøvde': ('lokalbedøve',),
'lokalbedøvede': ('lokalbedøve',),
'lokalbedøvende': ('lokalbedøve',),
'lokalbedøvet': ('lokalbedøve',),
'lokalbedøvete': ('lokalbedøve',),
'lokalfarga': ('lokalfarga',),
'lokalfargede': ('lokalfarget',),
'lokalfarget': ('lokalfarget',),
'lokalfargete': ('lokalfarget',),
'lokalfargetere': ('lokalfarget',),
'lokalfargetest': ('lokalfarget',),
'lokalfargeteste': ('lokalfarget',),
'lokaliserende': ('lokalisere',),
'lokalisert': ('lokalisere',),
'lokaliserte': ('lokalisere',),
'lokalkjent': ('lokalkjent',),
'lokalkjente': ('lokalkjent',),
'lokalkjentere': ('lokalkjent',),
'lokalkjentest': ('lokalkjent',),
'lokalkjenteste': ('lokalkjent',),
'lokativisk': ('lokativisk',),
'lokativiske': ('lokativisk',),
'lokativiskere': ('lokativisk',),
'lokativiskest': ('lokativisk',),
'lokativiskeste': ('lokativisk',),
'lokka': ('lokke',),
'lokkede': ('lokke',),
'lokkende': ('lokke',),
'lokket': ('lokke',),
'lokkete': ('lokke',),
'lokka': ('lokke',),
'lokkede': ('lokke',),
'lokkende': ('lokke',),
'lokket': ('lokke',),
'lokkete': ('lokke',),
'lokka': ('lokke',),
'lokkede': ('lokke',),
'lokkende': ('lokke',),
'lokket': ('lokke',),
'lokkete': ('lokke',),
'lokket': ('lokket',),
'lokkete': ('lokket',),
'lokketere': ('lokket',),
'lokketest': ('lokket',),
'lokketeste': ('lokket',),
'lokkete': ('lokkete',),
'lombarderende': ('lombardere',),
'lombardert': ('lombardere',),
'lombarderte': ('lombardere',),
'lommekjent': ('lommekjent',),
'lommekjente': ('lommekjent',),
'lommekjentere': ('lommekjent',),
'lommekjentest': ('lommekjent',),
'lommekjenteste': ('lommekjent',),
'londonsk': ('londonsk',),
'londonske': ('londonsk',),
'londonskere': ('londonsk',),
'londonskest': ('londonsk',),
'londonskeste': ('londonsk',),
'longerende': ('longere',),
'longert': ('longere',),
'longerte': ('longere',),
'longitudinal': ('longitudinal',),
'longitudinale': ('longitudinal',),
'longitudinalere': ('longitudinal',),
'longitudinalest': ('longitudinal',),
'longitudinaleste': ('longitudinal',),
'longitudinalt': ('longitudinal',),
'longitudinell': ('longitudinell',),
'longitudinelle': ('longitudinell',),
'longitudinellere': ('longitudinell',),
'longitudinellest': ('longitudinell',),
'longitudinelleste': ('longitudinell',),
'longitudinelt': ('longitudinell',),
'loopa': ('loope',),
'loopede': ('loope',),
'loopende': ('loope',),
'loopet': ('loope',),
'loopete': ('loope',),
'loppa': ('loppe',),
'loppede': ('loppe',),
'loppende': ('loppe',),
'loppet': ('loppe',),
'loppete': ('loppe',),
'loppet': ('loppet',),
'loppete': ('loppet',),
'loppetere': ('loppet',),
'loppetest': ('loppet',),
'loppeteste': ('loppet',),
'loppete': ('loppete',),
'lorgnetterende': ('lorgnettere',),
'lorgnettert': ('lorgnettere',),
'lorgnetterte': ('lorgnettere',),
'lortet': ('lortet',),
'lortete': ('lortet',),
'lortetere': ('lortet',),
'lortetest': ('lortet',),
'lorteteste': ('lortet',),
'lortete': ('lortete',),
'losa': ('lose',),
'losede': ('lose',),
'losende': ('lose',),
'loset': ('lose',),
'losete': ('lose',),
'lost': ('lose',),
'loste': ('lose',),
'losjerende': ('losjere',),
'losjert': ('losjere',),
'losjerte': ('losjere',),
'loslitt': ('loslitt',),
'loslitte': ('loslitt',),
'loslittere': ('loslitt',),
'loslittest': ('loslitt',),
'loslitteste': ('loslitt',),
'loss': ('loss',),
'lossa': ('losse',),
'lossede': ('losse',),
'lossende': ('losse',),
'losset': ('losse',),
'lossete': ('losse',),
'lovbestemt': ('lovbestemt',),
'lovbestemte': ('lovbestemt',),
'lovbestemtere': ('lovbestemt',),
'lovbestemtest': ('lovbestemt',),
'lovbestemteste': ('lovbestemt',),
'lovende': ('lovende',),
'lovfast': ('lovfast',),
'lovfaste': ('lovfast',),
'lovfastere': ('lovfast',),
'lovfastest': ('lovfast',),
'lovfasteste': ('lovfast',),
'lovfesta': ('lovfeste',),
'lovfestede': ('lovfeste',),
'lovfestende': ('lovfeste',),
'lovfestet': ('lovfeste',),
'lovfestete': ('lovfeste',),
'lovgivende': ('lovgivende',),
'lovgyldig': ('lovgyldig',),
'lovgyldige': ('lovgyldig',),
'lovgyldigere': ('lovgyldig',),
'lovgyldigst': ('lovgyldig',),
'lovgyldigste': ('lovgyldig',),
'lovheimla': ('lovheimle',),
'lovheimlede': ('lovheimle',),
'lovheimlende': ('lovheimle',),
'lovheimlet': ('lovheimle',),
'lovheimlete': ('lovheimle',),
'lovhjemla': ('lovhjemle',),
'lovhjemlede': ('lovhjemle',),
'lovhjemlende': ('lovhjemle',),
'lovhjemlet': ('lovhjemle',),
'lovhjemlete': ('lovhjemle',),
'lovlaus': ('lovlaus',),
'lovlause': ('lovlaus',),
'lovlausere': ('lovlaus',),
'lovlausest': ('lovlaus',),
'lovlauseste': ('lovlaus',),
'lovlaust': ('lovlaus',),
'lovlig': ('lovlig',),
'lovlige': ('lovlig',),
'lovligere': ('lovlig',),
'lovligst': ('lovlig',),
'lovligste': ('lovlig',),
'lovlydig': ('lovlydig',),
'lovlydige': ('lovlydig',),
'lovlydigere': ('lovlydig',),
'lovlydigst': ('lovlydig',),
'lovlydigste': ('lovlydig',),
'lovløs': ('lovløs',),
'lovløse': ('lovløs',),
'lovløsere': ('lovløs',),
'lovløsest': ('lovløs',),
'lovløseste': ('lovløs',),
'lovløst': ('lovløs',),
'lovmessig': ('lovmessig',),
'lovmessige': ('lovmessig',),
'lovmessigere': ('lovmessig',),
'lovmessigst': ('lovmessig',),
'lovmessigste': ('lovmessig',),
'lovprisende': ('lovprise',),
'lovprist': ('lovprise',),
'lovpriste': ('lovprise',),
'lovstridig': ('lovstridig',),
'lovstridige': ('lovstridig',),
'lovstridigere': ('lovstridig',),
'lovstridigst': ('lovstridig',),
'lovstridigste': ('lovstridig',),
'lovsungen': ('lovsynge',),
'lovsunget': ('lovsynge',),
'lovsungne': ('lovsynge',),
'lovsyngende': ('lovsynge',),
'lubben': ('lubben',),
'lubbent': ('lubben',),
'lubne': ('lubben',),
'lubnere': ('lubben',),
'lubnest': ('lubben',),
'lubneste': ('lubben',),
'lua': ('lue',),
'luede': ('lue',),
'luende': ('lue',),
'luet': ('lue',),
'luete': ('lue',),
'luftavkjølt': ('luftavkjølt',),
'luftavkjølte': ('luftavkjølt',),
'luftavkjøltere': ('luftavkjølt',),
'luftavkjøltest': ('luftavkjølt',),
'luftavkjølteste': ('luftavkjølt',),
'luftbåren': ('luftbåren',),
'luftbåret': ('luftbåren',),
'luftbårne': ('luftbåren',),
'luftbårnere': ('luftbåren',),
'luftbårnest': ('luftbåren',),
'luftbårneste': ('luftbåren',),
'luftbåret': ('luftbåret',),
'luftbårne': ('luftbåret',),
'luftbårnere': ('luftbåret',),
'luftbårnest': ('luftbåret',),
'luftbårneste': ('luftbåret',),
'lufta': ('lufte',),
'luftede': ('lufte',),
'luftende': ('lufte',),
'luftet': ('lufte',),
'luftete': ('lufte',),
'luftforma': ('luftforma',),
'luftformede': ('luftformet',),
'luftformet': ('luftformet',),
'luftformete': ('luftformet',),
'luftformetere': ('luftformet',),
'luftformetest': ('luftformet',),
'luftformeteste': ('luftformet',),
'luftformig': ('luftformig',),
'luftformige': ('luftformig',),
'luftformigere': ('luftformig',),
'luftformigst': ('luftformig',),
'luftformigste': ('luftformig',),
'luftig': ('luftig',),
'luftige': ('luftig',),
'luftigere': ('luftig',),
'luftigst': ('luftig',),
'luftigste': ('luftig',),
'luftkjølt': ('luftkjølt',),
'luftkjølte': ('luftkjølt',),
'luftkjøltere': ('luftkjølt',),
'luftkjøltest': ('luftkjølt',),
'luftkjølteste': ('luftkjølt',),
'luftkondisjonert': ('luftkondisjonert',),
'luftkondisjonerte': ('luftkondisjonert',),
'luftkondisjonertere': ('luftkondisjonert',),
'luftkondisjonertest': ('luftkondisjonert',),
'luftkondisjonerteste': ('luftkondisjonert',),
'luftsjuk': ('luftsjuk',),
'luftsjuke': ('luftsjuk',),
'luftsjukere': ('luftsjuk',),
'luftsjukest': ('luftsjuk',),
'luftsjukeste': ('luftsjuk',),
'luftsjukt': ('luftsjuk',),
'luftsyk': ('luftsyk',),
'luftsyke': ('luftsyk',),
'luftsykere': ('luftsyk',),
'luftsykest': ('luftsyk',),
'luftsykeste': ('luftsyk',),
'luftsykt': ('luftsyk',),
'lufttett': ('lufttett',),
'lufttette': ('lufttett',),
'lufttettere': ('lufttett',),
'lufttettest': ('lufttett',),
'lufttetteste': ('lufttett',),
'lufttom': ('lufttom',),
'lufttomme': ('lufttom',),
'lufttommere': ('lufttom',),
'lufttommest': ('lufttom',),
'lufttommeste': ('lufttom',),
'lufttomt': ('lufttom',),
'lufttørka': ('lufttørke',),
'lufttørkede': ('lufttørke',),
'lufttørkende': ('lufttørke',),
'lufttørket': ('lufttørke',),
'lufttørkete': ('lufttørke',),
'lugga': ('lugge',),
'luggede': ('lugge',),
'luggende': ('lugge',),
'lugget': ('lugge',),
'luggete': ('lugge',),
'lugn': ('lugn',),
'lugne': ('lugn',),
'lugnere': ('lugn',),
'lugnest': ('lugn',),
'lugneste': ('lugn',),
'lugnt': ('lugn',),
'lugna': ('lugne',),
'lugnede': ('lugne',),
'lugnende': ('lugne',),
'lugnet': ('lugne',),
'lugnete': ('lugne',),
'lugom': ('lugom',),
'lugome': ('lugom',),
'lugomere': ('lugom',),
'lugomest': ('lugom',),
'lugomeste': ('lugom',),
'lugomt': ('lugom',),
'luguber': ('luguber',),
'lugubert': ('luguber',),
'lugubre': ('luguber',),
'lugubrere': ('luguber',),
'lugubrest': ('luguber',),
'lugubreste': ('luguber',),
'lugum': ('lugum',),
'lugume': ('lugum',),
'lugumere': ('lugum',),
'lugumest': ('lugum',),
'lugumeste': ('lugum',),
'lugumt': ('lugum',),
'lukansk': ('lukansk',),
'lukanske': ('lukansk',),
'lukanskere': ('lukansk',),
'lukanskest': ('lukansk',),
'lukanskeste': ('lukansk',),
'luka': ('luke',),
'lukede': ('luke',),
'lukende': ('luke',),
'luket': ('luke',),
'lukete': ('luke',),
'lukt': ('luke',),
'lukte': ('luke',),
'lukka': ('lukke',),
'lukkede': ('lukke',),
'lukkende': ('lukke',),
'lukket': ('lukke',),
'lukkete': ('lukke',),
'lukrativ': ('lukrativ',),
'lukrative': ('lukrativ',),
'lukrativere': ('lukrativ',),
'lukrativest': ('lukrativ',),
'lukrativeste': ('lukrativ',),
'lukrativt': ('lukrativ',),
'lukrerende': ('lukrere',),
'lukrert': ('lukrere',),
'lukrerte': ('lukrere',),
'lukserende': ('luksere',),
'luksert': ('luksere',),
'lukserte': ('luksere',),
'luksuriøs': ('luksuriøs',),
'luksuriøse': ('luksuriøs',),
'luksuriøsere': ('luksuriøs',),
'luksuriøsest': ('luksuriøs',),
'luksuriøseste': ('luksuriøs',),
'luksuriøst': ('luksuriøs',),
'lukta': ('lukte',),
'luktede': ('lukte',),
'luktende': ('lukte',),
'luktet': ('lukte',),
'luktete': ('lukte',),
'luktfri': ('luktfri',),
'luktfrie': ('luktfri',),
'luktfriere': ('luktfri',),
'luktfriest': ('luktfri',),
'luktfrieste': ('luktfri',),
'luktfritt': ('luktfri',),
'luktlaus': ('luktlaus',),
'luktlause': ('luktlaus',),
'luktlausere': ('luktlaus',),
'luktlausest': ('luktlaus',),
'luktlauseste': ('luktlaus',),
'luktlaust': ('luktlaus',),
'luktløs': ('luktløs',),
'luktløse': ('luktløs',),
'luktløsere': ('luktløs',),
'luktløsest': ('luktløs',),
'luktløseste': ('luktløs',),
'luktløst': ('luktløs',),
'lukullisk': ('lukullisk',),
'lukulliske': ('lukullisk',),
'lukulliskere': ('lukullisk',),
'lukulliskest': ('lukullisk',),
'lukulliskeste': ('lukullisk',),
'lulla': ('lulle',),
'lullede': ('lulle',),
'lullende': ('lulle',),
'lullet': ('lulle',),
'lullete': ('lulle',),
'lummer': ('lummer',),
'lummert': ('lummer',),
'lumre': ('lummer',),
'lumrere': ('lummer',),
'lumrest': ('lummer',),
'lumreste': ('lummer',),
'lumpa': ('lumpe',),
'lumpede': ('lumpe',),
'lumpende': ('lumpe',),
'lumpet': ('lumpe',),
'lumpete': ('lumpe',),
'lumpen': ('lumpen',),
'lumpent': ('lumpen',),
'lumpne': ('lumpen',),
'lumpnere': ('lumpen',),
'lumpnest': ('lumpen',),
'lumpneste': ('lumpen',),
'lumsk': ('lumsk',),
'lumske': ('lumsk',),
'lumskere': ('lumsk',),
'lumskest': ('lumsk',),
'lumskeste': ('lumsk',),
'lumskt': ('lumsk',),
'lun': ('lun',),
'lune': ('lun',),
'lunere': ('lun',),
'lunest': ('lun',),
'luneste': ('lun',),
'lunt': ('lun',),
'luna': ('lune',),
'lunede': ('lune',),
'lunende': ('lune',),
'lunet': ('lune',),
'lunete': ('lune',),
'lunt': ('lune',),
'lunte': ('lune',),
'lunefull': ('lunefull',),
'lunefulle': ('lunefull',),
'lunefullere': ('lunefull',),
'lunefullest': ('lunefull',),
'lunefulleste': ('lunefull',),
'lunefullt': ('lunefull',),
'lunet': ('lunet',),
'lunete': ('lunet',),
'lunetere': ('lunet',),
'lunetest': ('lunet',),
'luneteste': ('lunet',),
'lunete': ('lunete',),
'lunka': ('lunke',),
'lunkede': ('lunke',),
'lunkende': ('lunke',),
'lunket': ('lunke',),
'lunkete': ('lunke',),
'lunka': ('lunke',),
'lunkede': ('lunke',),
'lunkende': ('lunke',),
'lunket': ('lunke',),
'lunkete': ('lunke',),
'lunken': ('lunken',),
'lunkent': ('lunken',),
'lunkne': ('lunken',),
'lunknere': ('lunken',),
'lunknest': ('lunken',),
'lunkneste': ('lunken',),
'lunna': ('lunne',),
'lunnede': ('lunne',),
'lunnende': ('lunne',),
'lunnet': ('lunne',),
'lunnete': ('lunne',),
'lunna': ('lunne',),
'lunnede': ('lunne',),
'lunnende': ('lunne',),
'lunnet': ('lunne',),
'lunnete': ('lunne',),
'lunsja': ('lunsje',),
'lunsjede': ('lunsje',),
'lunsjende': ('lunsje',),
'lunsjet': ('lunsje',),
'lunsjete': ('lunsje',),
'lunta': ('lunte',),
'luntede': ('lunte',),
'luntende': ('lunte',),
'luntet': ('lunte',),
'luntete': ('lunte',),
'lur': ('lur',),
'lure': ('lur',),
'lurere': ('lur',),
'lurest': ('lur',),
'lureste': ('lur',),
'lurt': ('lur',),
'lurende': ('lure',),
'lurt': ('lure',),
'lurte': ('lure',),
'lura': ('lure',),
'lurede': ('lure',),
'lurende': ('lure',),
'luret': ('lure',),
'lurete': ('lure',),
'lurt': ('lure',),
'lurte': ('lure',),
'lurva': ('lurve',),
'lurvede': ('lurve',),
'lurvende': ('lurve',),
'lurvet': ('lurve',),
'lurvete': ('lurve',),
'lurvet': ('lurvet',),
'lurvete': ('lurvet',),
'lurvetere': ('lurvet',),
'lurvetest': ('lurvet',),
'lurveteste': ('lurvet',),
'lurvete': ('lurvete',),
'lusa': ('luse',),
'lusede': ('luse',),
'lusende': ('luse',),
'luset': ('luse',),
'lusete': ('luse',),
'lust': ('luse',),
'luste': ('luse',),
'lusen': ('lusen',),
'lusent': ('lusen',),
'lusne': ('lusen',),
'lusnere': ('lusen',),
'lusnest': ('lusen',),
'lusneste': ('lusen',),
'luset': ('luset',),
'lusete': ('luset',),
'lusetere': ('luset',),
'lusetest': ('luset',),
'luseteste': ('luset',),
'lusete': ('lusete',),
'luska': ('luske',),
'luskede': ('luske',),
'luskende': ('luske',),
'lusket': ('luske',),
'luskete': ('luske',),
'lut': ('lut',),
'lute': ('lut',),
'lutere': ('lut',),
'lutest': ('lut',),
'luteste': ('lut',),
'lutt': ('lut',),
'lutdoven': ('lutdoven',),
'lutdovent': ('lutdoven',),
'lutdovne': ('lutdoven',),
'lutdovnere': ('lutdoven',),
'lutdovnest': ('lutdoven',),
'lutdovneste': ('lutdoven',),
'luta': ('lute',),
'lutede': ('lute',),
'lutende': ('lute',),
'lutet': ('lute',),
'lutete': ('lute',),
'luta': ('lute',),
'lutede': ('lute',),
'lutende': ('lute',),
'lutet': ('lute',),
'lutete': ('lute',),
'lutt': ('lute',),
'lutte': ('lute',),
'luten': ('luten',),
'lutent': ('luten',),
'lutne': ('luten',),
'lutnere': ('luten',),
'lutnest': ('luten',),
'lutneste': ('luten',),
'lutfattig': ('lutfattig',),
'lutfattige': ('lutfattig',),
'lutfattigere': ('lutfattig',),
'lutfattigst': ('lutfattig',),
'lutfattigste': ('lutfattig',),
'luthersk': ('luthersk',),
'lutherske': ('luthersk',),
'lutherskere': ('luthersk',),
'lutherskest': ('luthersk',),
'lutherskeste': ('luthersk',),
'lutlei': ('lutlei',),
'lutleie': ('lutlei',),
'lutleiere': ('lutlei',),
'lutleiest': ('lutlei',),
'lutleieste': ('lutlei',),
'lutleit': ('lutlei',),
'lutleitt': ('lutlei',),
'lutra': ('lutre',),
'lutrede': ('lutre',),
'lutrende': ('lutre',),
'lutret': ('lutre',),
'lutrete': ('lutre',),
'lutrygga': ('lutrygga',),
'lutryggede': ('lutrygget',),
'lutrygget': ('lutrygget',),
'lutryggete': ('lutrygget',),
'lutryggetere': ('lutrygget',),
'lutryggetest': ('lutrygget',),
'lutryggeteste': ('lutrygget',),
'lutter': ('lutter',),
'luv': ('luv',),
'luxembourgsk': ('luxembourgsk',),
'luxembourgske': ('luxembourgsk',),
'luxembourgskere': ('luxembourgsk',),
'luxembourgskest': ('luxembourgsk',),
'luxembourgskeste': ('luxembourgsk',),
'luxemburgsk': ('luxemburgsk',),
'luxemburgske': ('luxemburgsk',),
'luxemburgskere': ('luxemburgsk',),
'luxemburgskest': ('luxemburgsk',),
'luxemburgskeste': ('luxemburgsk',),
'ly': ('ly',),
'lye': ('ly',),
'lyere': ('ly',),
'lyest': ('ly',),
'lyeste': ('ly',),
'lytt': ('ly',),
'ly': ('ly',),
'lye': ('ly',),
'lyere': ('ly',),
'lyest': ('ly',),
'lyeste': ('ly',),
'lytt': ('ly',),
'lybsk': ('lybsk',),
'lybske': ('lybsk',),
'lybskere': ('lybsk',),
'lybskest': ('lybsk',),
'lybskeste': ('lybsk',),
'lydd': ('lyde',),
'lydde': ('lyde',),
'lydende': ('lyde',),
'lydt': ('lyde',),
'lydte': ('lyde',),
'lydd': ('lyde',),
'lydde': ('lyde',),
'lydende': ('lyde',),
'lydt': ('lyde',),
'lydte': ('lyde',),
'lydelig': ('lydelig',),
'lydelige': ('lydelig',),
'lydeligere': ('lydelig',),
'lydeligst': ('lydelig',),
'lydeligste': ('lydelig',),
'lydhermende': ('lydhermende',),
'lydhør': ('lydhør',),
'lydhøre': ('lydhør',),
'lydhørere': ('lydhør',),
'lydhørest': ('lydhør',),
'lydhøreste': ('lydhør',),
'lydhørt': ('lydhør',),
'lydig': ('lydig',),
'lydige': ('lydig',),
'lydigere': ('lydig',),
'lydigst': ('lydig',),
'lydigste': ('lydig',),
'lydisk': ('lydisk',),
'lydiske': ('lydisk',),
'lydiskere': ('lydisk',),
'lydiskest': ('lydisk',),
'lydiskeste': ('lydisk',),
'lydlaus': ('lydlaus',),
'lydlause': ('lydlaus',),
'lydlausere': ('lydlaus',),
'lydlausest': ('lydlaus',),
'lydlauseste': ('lydlaus',),
'lydlaust': ('lydlaus',),
'lydlig': ('lydlig',),
'lydlige': ('lydlig',),
'lydligere': ('lydlig',),
'lydligst': ('lydlig',),
'lydligste': ('lydlig',),
'lydløs': ('lydløs',),
'lydløse': ('lydløs',),
'lydløsere': ('lydløs',),
'lydløsest': ('lydløs',),
'lydløseste': ('lydløs',),
'lydløst': ('lydløs',),
'lydmalende': ('lydmalende',),
'lydtett': ('lydtett',),
'lydtette': ('lydtett',),
'lydtettere': ('lydtett',),
'lydtettest': ('lydtett',),
'lydtetteste': ('lydtett',),
'lydd': ('lye',),
'lydde': ('lye',),
'lyende': ('lye',),
'lya': ('lye',),
'lydd': ('lye',),
'lydde': ('lye',),
'lyede': ('lye',),
'lyende': ('lye',),
'lyet': ('lye',),
'lyete': ('lye',),
'lygende': ('lyge',),
'løyen': ('lyge',),
'løyet': ('lyge',),
'løyne': ('lyge',),
'lygende': ('lyge',),
'løyen': ('lyge',),
'løyet': ('lyge',),
'løyne': ('lyge',),
'lykkelig': ('lykkelig',),
'lykkelige': ('lykkelig',),
'lykkeligere': ('lykkelig',),
'lykkeligst': ('lykkelig',),
'lykkeligste': ('lykkelig',),
'lykksalig': ('lykksalig',),
'lykksalige': ('lykksalig',),
'lykksaligere': ('lykksalig',),
'lykksaligst': ('lykksalig',),
'lykksaligste': ('lykksalig',),
'lykkønska': ('lykkønske',),
'lykkønskede': ('lykkønske',),
'lykkønskende': ('lykkønske',),
'lykkønsket': ('lykkønske',),
'lykkønskete': ('lykkønske',),
'lykkønskt': ('lykkønske',),
'lykkønskte': ('lykkønske',),
'lymfatisk': ('lymfatisk',),
'lymfatiske': ('lymfatisk',),
'lymfatiskere': ('lymfatisk',),
'lymfatiskest': ('lymfatisk',),
'lymfatiskeste': ('lymfatisk',),
'lynende': ('lyne',),
'lynt': ('lyne',),
'lynte': ('lyne',),
'lynende': ('lynende',),
'lynrapp': ('lynrapp',),
'lynrappe': ('lynrapp',),
'lynrappere': ('lynrapp',),
'lynrappest': ('lynrapp',),
'lynrappeste': ('lynrapp',),
'lynrapt': ('lynrapp',),
'lynrask': ('lynrask',),
'lynraske': ('lynrask',),
'lynraskere': ('lynrask',),
'lynraskest': ('lynrask',),
'lynraskeste': ('lynrask',),
'lynraskt': ('lynrask',),
'lynsja': ('lynsje',),
'lynsjede': ('lynsje',),
'lynsjende': ('lynsje',),
'lynsjet': ('lynsje',),
'lynsjete': ('lynsje',),
'lynsnar': ('lynsnar',),
'lynsnare': ('lynsnar',),
'lynsnarere': ('lynsnar',),
'lynsnarest': ('lynsnar',),
'lynsnareste': ('lynsnar',),
'lynsnart': ('lynsnar',),
'lyrisk': ('lyrisk',),
'lyriske': ('lyrisk',),
'lyriskere': ('lyrisk',),
'lyriskest': ('lyrisk',),
'lyriskeste': ('lyrisk',),
'lys': ('lys',),
'lyse': ('lys',),
'lysere': ('lys',),
'lysest': ('lys',),
'lyseste': ('lys',),
'lyst': ('lys',),
'lysbestandig': ('lysbestandig',),
'lysbestandige': ('lysbestandig',),
'lysbestandigere': ('lysbestandig',),
'lysbestandigst': ('lysbestandig',),
'lysbestandigste': ('lysbestandig',),
'lysblond': ('lysblond',),
'lysblonde': ('lysblond',),
'lysblondere': ('lysblond',),
'lysblondest': ('lysblond',),
'lysblondeste': ('lysblond',),
'lysblondt': ('lysblond',),
'lysblå': ('lysblå',),
'lysblåe': ('lysblå',),
'lysblåere': ('lysblå',),
'lysblåest': ('lysblå',),
'lysblåeste': ('lysblå',),
'lysblått': ('lysblå',),
'lysbrun': ('lysbrun',),
'lysbrune': ('lysbrun',),
'lysbrunere': ('lysbrun',),
'lysbrunest': ('lysbrun',),
'lysbruneste': ('lysbrun',),
'lysbrunt': ('lysbrun',),
'lysende': ('lyse',),
'lyst': ('lyse',),
'lyste': ('lyse',),
'lyseblond': ('lyseblond',),
'lyseblonde': ('lyseblond',),
'lyseblondere': ('lyseblond',),
'lyseblondest': ('lyseblond',),
'lyseblondeste': ('lyseblond',),
'lyseblondt': ('lyseblond',),
'lyseblå': ('lyseblå',),
'lyseblåe': ('lyseblå',),
'lyseblåere': ('lyseblå',),
'lyseblåest': ('lyseblå',),
'lyseblåeste': ('lyseblå',),
'lyseblått': ('lyseblå',),
'lysebrun': ('lysebrun',),
'lysebrune': ('lysebrun',),
'lysebrunere': ('lysebrun',),
'lysebrunest': ('lysebrun',),
'lysebruneste': ('lysebrun',),
'lysebrunt': ('lysebrun',),
'lysegrå': ('lysegrå',),
'lysegråe': ('lysegrå',),
'lysegråere': ('lysegrå',),
'lysegråest': ('lysegrå',),
'lysegråeste': ('lysegrå',),
'lysegrått': ('lysegrå',),
'lysegrøn': ('lysegrøn',),
'lysegrøne': ('lysegrøn',),
'lysegrønere': ('lysegrøn',),
'lysegrønest': ('lysegrøn',),
'lysegrøneste': ('lysegrøn',),
'lysegrønt': ('lysegrøn',),
'lysegrønn': ('lysegrønn',),
'lysegrønne': ('lysegrønn',),
'lysegrønnere': ('lysegrønn',),
'lysegrønnest': ('lysegrønn',),
'lysegrønneste': ('lysegrønn',),
'lysegrønt': ('lysegrønn',),
'lysegul': ('lysegul',),
'lysegule': ('lysegul',),
'lysegulere': ('lysegul',),
'lysegulest': ('lysegul',),
'lyseguleste': ('lysegul',),
'lysegult': ('lysegul',),
'lysekte': ('lysekte',),
'lysende': ('lysende',),
'lyserød': ('lyserød',),
'lyserøde': ('lyserød',),
'lyserødere': ('lyserød',),
'lyserødest': ('lyserød',),
'lyserødeste': ('lyserød',),
'lyserødt': ('lyserød',),
'lyserød': ('lyserød',),
'lyserøde': ('lyserød',),
'lyserødere': ('lyserød',),
'lyserødest': ('lyserød',),
'lyserødeste': ('lyserød',),
'lyserødt': ('lyserød',),
'lysfølsom': ('lysfølsom',),
'lysfølsomme': ('lysfølsom',),
'lysfølsommere': ('lysfølsom',),
'lysfølsomst': ('lysfølsom',),
'lysfølsomste': ('lysfølsom',),
'lysfølsomt': ('lysfølsom',),
'lysgrå': ('lysgrå',),
'lysgråe': ('lysgrå',),
'lysgråere': ('lysgrå',),
'lysgråest': ('lysgrå',),
'lysgråeste': ('lysgrå',),
'lysgrått': ('lysgrå',),
'lysgrøn': ('lysgrøn',),
'lysgrøne': ('lysgrøn',),
'lysgrønere': ('lysgrøn',),
'lysgrønest': ('lysgrøn',),
'lysgrøneste': ('lysgrøn',),
'lysgrønt': ('lysgrøn',),
'lysgrønn': ('lysgrønn',),
'lysgrønne': ('lysgrønn',),
'lysgrønnere': ('lysgrønn',),
'lysgrønnest': ('lysgrønn',),
'lysgrønneste': ('lysgrønn',),
'lysgrønt': ('lysgrønn',),
'lysgul': ('lysgul',),
'lysgule': ('lysgul',),
'lysgulere': ('lysgul',),
'lysgulest': ('lysgul',),
'lysguleste': ('lysgul',),
'lysgult': ('lysgul',),
'lyshåra': ('lyshåra',),
'lyshårede': ('lyshåret',),
'lyshåret': ('lyshåret',),
'lyshårete': ('lyshåret',),
'lyshåretere': ('lyshåret',),
'lyshåretest': ('lyshåret',),
'lyshåreteste': ('lyshåret',),
'lyska': ('lyske',),
'lyskede': ('lyske',),
'lyskende': ('lyske',),
'lysket': ('lyske',),
'lyskete': ('lyske',),
'lyskledd': ('lyskledd',),
'lyskledde': ('lyskledd',),
'lyskleddere': ('lyskledd',),
'lyskleddest': ('lyskledd',),
'lyskleddeste': ('lyskledd',),
'lysna': ('lysne',),
'lysnede': ('lysne',),
'lysnende': ('lysne',),
'lysnet': ('lysne',),
'lysnete': ('lysne',),
'lysregulert': ('lysregulert',),
'lysregulerte': ('lysregulert',),
'lysregulertere': ('lysregulert',),
'lysregulertest': ('lysregulert',),
'lysregulerteste': ('lysregulert',),
'lysrød': ('lysrød',),
'lysrøde': ('lysrød',),
'lysrødere': ('lysrød',),
'lysrødest': ('lysrød',),
'lysrødeste': ('lysrød',),
'lysrødt': ('lysrød',),
'lysskjær': ('lysskjær',),
'lysskjære': ('lysskjær',),
'lysskjærere': ('lysskjær',),
'lysskjærest': ('lysskjær',),
'lysskjæreste': ('lysskjær',),
'lysskjært': ('lysskjær',),
'lyssterk': ('lyssterk',),
'lyssterke': ('lyssterk',),
'lyssterkere': ('lyssterk',),
'lyssterkest': ('lyssterk',),
'lyssterkeste': ('lyssterk',),
'lyssterkt': ('lyssterk',),
'lyssvak': ('lyssvak',),
'lyssvake': ('lyssvak',),
'lyssvakere': ('lyssvak',),
'lyssvakest': ('lyssvak',),
'lyssvakeste': ('lyssvak',),
'lyssvakt': ('lyssvak',),
'lystbetona': ('lystbetona',),
'lystbetonede': ('lystbetonet',),
'lystbetonet': ('lystbetonet',),
'lystbetonete': ('lystbetonet',),
'lystbetonetere': ('lystbetonet',),
'lystbetonetest': ('lystbetonet',),
'lystbetoneteste': ('lystbetonet',),
'lystbetont': ('lystbetont',),
'lystbetonte': ('lystbetont',),
'lystbetontere': ('lystbetont',),
'lystbetontest': ('lystbetont',),
'lystbetonteste': ('lystbetont',),
'lysta': ('lyste',),
'lystede': ('lyste',),
'lystende': ('lyste',),
'lystet': ('lyste',),
'lystete': ('lyste',),
'lystelig': ('lystelig',),
'lystelige': ('lystelig',),
'lysteligere': ('lystelig',),
'lysteligst': ('lystelig',),
'lysteligste': ('lystelig',),
'lysten': ('lysten',),
'lystent': ('lysten',),
'lystne': ('lysten',),
'lystnere': ('lysten',),
'lystnest': ('lysten',),
'lystneste': ('lysten',),
'lystett': ('lystett',),
'lystette': ('lystett',),
'lystettere': ('lystett',),
'lystettest': ('lystett',),
'lystetteste': ('lystett',),
'lystig': ('lystig',),
'lystige': ('lystig',),
'lystigere': ('lystig',),
'lystigst': ('lystig',),
'lystigste': ('lystig',),
'lystra': ('lystre',),
'lystrede': ('lystre',),
'lystrende': ('lystre',),
'lystret': ('lystre',),
'lystrete': ('lystre',),
'lystra': ('lystre',),
'lystrede': ('lystre',),
'lystrende': ('lystre',),
'lystret': ('lystre',),
'lystrete': ('lystre',),
'lysvak': ('lysvak',),
'lysvake': ('lysvak',),
'lysvakere': ('lysvak',),
'lysvakest': ('lysvak',),
'lysvakeste': ('lysvak',),
'lysvakt': ('lysvak',),
'lysvaken': ('lysvaken',),
'lysvakent': ('lysvaken',),
'lysvakne': ('lysvaken',),
'lysvaknere': ('lysvaken',),
'lysvaknest': ('lysvaken',),
'lysvakneste': ('lysvaken',),
'lysvåken': ('lysvåken',),
'lysvåkent': ('lysvåken',),
'lysvåkne': ('lysvåken',),
'lysvåknere': ('lysvåken',),
'lysvåknest': ('lysvåken',),
'lysvåkneste': ('lysvåken',),
'lysømfintlig': ('lysømfintlig',),
'lysømfintlige': ('lysømfintlig',),
'lysømfintligere': ('lysømfintlig',),
'lysømfintligst': ('lysømfintlig',),
'lysømfintligste': ('lysømfintlig',),
'lytelaus': ('lytelaus',),
'lytelause': ('lytelaus',),
'lytelausere': ('lytelaus',),
'lytelausest': ('lytelaus',),
'lytelauseste': ('lytelaus',),
'lytelaust': ('lytelaus',),
'lyteløs': ('lyteløs',),
'lyteløse': ('lyteløs',),
'lyteløsere': ('lyteløs',),
'lyteløsest': ('lyteløs',),
'lyteløseste': ('lyteløs',),
'lyteløst': ('lyteløs',),
'lytta': ('lytte',),
'lyttede': ('lytte',),
'lyttende': ('lytte',),
'lyttet': ('lytte',),
'lyttete': ('lytte',),
'lyvende': ('lyve',),
'løyen': ('lyve',),
'løyet': ('lyve',),
'løyne': ('lyve',),
'lyvende': ('lyve',),
'løyen': ('lyve',),
'løyet': ('lyve',),
'løyne': ('lyve',),
'låg': ('låg',),
'låge': ('låg',),
'lågere': ('låg',),
'lågest': ('låg',),
'lågeste': ('låg',),
'lågt': ('låg',),
'lågadelig': ('lågadelig',),
'lågadelige': ('lågadelig',),
'lågadeligere': ('lågadelig',),
'lågadeligst': ('lågadelig',),
'lågadeligste': ('lågadelig',),
'lågereliggende': ('lågereliggende',),
'lågerestående': ('lågerestående',),
'lågfrekvent': ('lågfrekvent',),
'lågfrekvente': ('lågfrekvent',),
'lågfrekventere': ('lågfrekvent',),
'lågfrekventest': ('lågfrekvent',),
'lågfrekventeste': ('lågfrekvent',),
'låghalt': ('låghalt',),
'låghalte': ('låghalt',),
'låghaltere': ('låghalt',),
'låghaltest': ('låghalt',),
'låghalteste': ('låghalt',),
'låghælt': ('låghælt',),
'låghælte': ('låghælt',),
'låghæltere': ('låghælt',),
'låghæltest': ('låghælt',),
'låghælteste': ('låghælt',),
'lågkirkelig': ('lågkirkelig',),
'lågkirkelige': ('lågkirkelig',),
'lågkirkeligere': ('lågkirkelig',),
'lågkirkeligst': ('lågkirkelig',),
'lågkirkeligste': ('lågkirkelig',),
'låglendt': ('låglendt',),
'låglendte': ('låglendt',),
'låglendtere': ('låglendt',),
'låglendtest': ('låglendt',),
'låglendteste': ('låglendt',),
'låglønna': ('låglønna',),
'låglønnede': ('låglønnet',),
'låglønnet': ('låglønnet',),
'låglønnete': ('låglønnet',),
'låglønnetere': ('låglønnet',),
'låglønnetest': ('låglønnet',),
'låglønneteste': ('låglønnet',),
'lågmælt': ('lågmælt',),
'lågmælte': ('lågmælt',),
'lågmæltere': ('lågmælt',),
'lågmæltest': ('lågmælt',),
'lågmælteste': ('lågmælt',),
'lågpanna': ('lågpanna',),
'lågpannede': ('lågpannet',),
'lågpannet': ('lågpannet',),
'lågpannete': ('lågpannet',),
'lågpannetere': ('lågpannet',),
'lågpannetest': ('lågpannet',),
'lågpanneteste': ('lågpannet',),
'lågproduktiv': ('lågproduktiv',),
'lågproduktive': ('lågproduktiv',),
'lågproduktivere': ('lågproduktiv',),
'lågproduktivest': ('lågproduktiv',),
'lågproduktiveste': ('lågproduktiv',),
'lågproduktivt': ('lågproduktiv',),
'lågspent': ('lågspent',),
'lågspente': ('lågspent',),
'lågspentere': ('lågspent',),
'lågspentest': ('lågspent',),
'lågspenteste': ('lågspent',),
'lågtliggende': ('lågtliggende',),
'lågtstående': ('lågtstående',),
'lågtysk': ('lågtysk',),
'lågtyske': ('lågtysk',),
'lågtyskere': ('lågtysk',),
'lågtyskest': ('lågtysk',),
'lågtyskeste': ('lågtysk',),
'låk': ('låk',),
'låke': ('låk',),
'låkere': ('låk',),
'låkest': ('låk',),
'låkeste': ('låk',),
'låkt': ('låk',),
'lånende': ('låne',),
'lånt': ('låne',),
'lånte': ('låne',),
'låntakende': ('lånta',),
'låntatt': ('lånta',),
'låntatte': ('lånta',),
'låra': ('låre',),
'lårede': ('låre',),
'lårende': ('låre',),
'låret': ('låre',),
'lårete': ('låre',),
'lårt': ('låre',),
'lårte': ('låre',),
'lårkort': ('lårkort',),
'lårkorte': ('lårkort',),
'lårkortere': ('lårkort',),
'lårkortest': ('lårkort',),
'lårkorteste': ('lårkort',),
'låsende': ('låse',),
'låst': ('låse',),
'låste': ('låse',),
'låtende': ('låte',),
'lått': ('låte',),
'låtte': ('låte',),
'lægra': ('lægre',),
'lægrede': ('lægre',),
'lægrende': ('lægre',),
'lægret': ('lægre',),
'lægrete': ('lægre',),
'læraktig': ('læraktig',),
'læraktige': ('læraktig',),
'læraktigere': ('læraktig',),
'læraktigst': ('læraktig',),
'læraktigste': ('læraktig',),
'lærd': ('lærd',),
'lærde': ('lærd',),
'lærdere': ('lærd',),
'lærdest': ('lærd',),
'lærdeste': ('lærd',),
'lærende': ('lære',),
'lært': ('lære',),
'lærte': ('lære',),
'lærenem': ('lærenem',),
'lærenemme': ('lærenem',),
'lærenemmere': ('lærenem',),
'lærenemmest': ('lærenem',),
'lærenemmeste': ('lærenem',),
'lærenemt': ('lærenem',),
'lærerik': ('lærerik',),
'lærerike': ('lærerik',),
'lærerikere': ('lærerik',),
'lærerikest': ('lærerik',),
'lærerikeste': ('lærerik',),
'lærerikt': ('lærerik',),
'lærevillig': ('lærevillig',),
'lærevillige': ('lærevillig',),
'lærevilligere': ('lærevillig',),
'lærevilligst': ('lærevillig',),
'lærevilligste': ('lærevillig',),
'lærvillig': ('lærvillig',),
'lærvillige': ('lærvillig',),
'lærvilligere': ('lærvillig',),
'lærvilligst': ('lærvillig',),
'lærvilligste': ('lærvillig',),
'lødd': ('lø',),
'lødde': ('lø',),
'løende': ('lø',),
'lødd': ('lø',),
'lødde': ('lø',),
'løende': ('lø',),
'lødig': ('lødig',),
'lødige': ('lødig',),
'lødigere': ('lødig',),
'lødigst': ('lødig',),
'lødigste': ('lødig',),
'lødd': ('løe',),
'lødde': ('løe',),
'løende': ('løe',),
'lødd': ('løe',),
'lødde': ('løe',),
'løende': ('løe',),
'løen': ('løen',),
'løene': ('løen',),
'løenere': ('løen',),
'løenest': ('løen',),
'løeneste': ('løen',),
'løent': ('løen',),
'løne': ('løen',),
'lønere': ('løen',),
'lønest': ('løen',),
'løneste': ('løen',),
'løfta': ('løfte',),
'løftede': ('løfte',),
'løftende': ('løfte',),
'løftet': ('løfte',),
'løftete': ('løfte',),
'løfterik': ('løfterik',),
'løfterike': ('løfterik',),
'løfterikere': ('løfterik',),
'løfterikest': ('løfterik',),
'løfterikeste': ('løfterik',),
'løfterikt': ('løfterik',),
'løgelig': ('løgelig',),
'løgelige': ('løgelig',),
'løgeligere': ('løgelig',),
'løgeligst': ('løgelig',),
'løgeligste': ('løgelig',),
'løglig': ('løglig',),
'løglige': ('løglig',),
'løgligere': ('løglig',),
'løgligst': ('løglig',),
'løgligste': ('løglig',),
'løgnaktig': ('løgnaktig',),
'løgnaktige': ('løgnaktig',),
'løgnaktigere': ('løgnaktig',),
'løgnaktigst': ('løgnaktig',),
'løgnaktigste': ('løgnaktig',),
'lønna': ('lønna',),
'lønna': ('lønne',),
'lønnede': ('lønne',),
'lønnende': ('lønne',),
'lønnet': ('lønne',),
'lønnete': ('lønne',),
'lønt': ('lønne',),
'lønte': ('lønne',),
'lønnede': ('lønnet',),
'lønnet': ('lønnet',),
'lønnete': ('lønnet',),
'lønnetere': ('lønnet',),
'lønnetest': ('lønnet',),
'lønneteste': ('lønnet',),
'lønnlig': ('lønnlig',),
'lønnlige': ('lønnlig',),
'lønnligere': ('lønnlig',),
'lønnligst': ('lønnlig',),
'lønnligste': ('lønnlig',),
'lønnsom': ('lønnsom',),
'lønnsomme': ('lønnsom',),
'lønnsommere': ('lønnsom',),
'lønnsomst': ('lønnsom',),
'lønnsomste': ('lønnsom',),
'lønnsomt': ('lønnsom',),
'lønsk': ('lønsk',),
'lønske': ('lønsk',),
'lønskere': ('lønsk',),
'lønskest': ('lønsk',),
'lønskeste': ('lønsk',),
'lønt': ('lønt',),
'lønte': ('lønt',),
'løntere': ('lønt',),
'løntest': ('lønt',),
'lønteste': ('lønt',),
'løpende': ('løpe',),
'løpet': ('løpe',),
'løpt': ('løpe',),
'løpte': ('løpe',),
'løpende': ('løpende',),
'løpsk': ('løpsk',),
'løpske': ('løpsk',),
'løpskere': ('løpsk',),
'løpskest': ('løpsk',),
'løpskeste': ('løpsk',),
'lørdagsfri': ('lørdagsfri',),
'lørdagsfrie': ('lørdagsfri',),
'lørdagsfriere': ('lørdagsfri',),
'lørdagsfriest': ('lørdagsfri',),
'lørdagsfrieste': ('lørdagsfri',),
'lørdagsfritt': ('lørdagsfri',),
'løs': ('løs',),
'løse': ('løs',),
'løsere': ('løs',),
'løsest': ('løs',),
'løseste': ('løs',),
'løst': ('løs',),
'løsaktig': ('løsaktig',),
'løsaktige': ('løsaktig',),
'løsaktigere': ('løsaktig',),
'løsaktigst': ('løsaktig',),
'løsaktigste': ('løsaktig',),
'løsende': ('løse',),
'løst': ('løse',),
'løste': ('løse',),
'løselig': ('løselig',),
'løselige': ('løselig',),
'løseligere': ('løselig',),
'løseligst': ('løselig',),
'løseligste': ('løselig',),
'løselig': ('løselig',),
'løselige': ('løselig',),
'løseligere': ('løselig',),
'løseligst': ('løselig',),
'løseligste': ('løselig',),
'løsgiende': ('løsgi',),
'løsgitt': ('løsgi',),
'løsgitte': ('løsgi',),
'løsgivende': ('løsgi',),
'løsgjort': ('løsgjøre',),
'løsgjorte': ('løsgjøre',),
'løsgjørende': ('løsgjøre',),
'løskjefta': ('løskjefta',),
'løskjeftede': ('løskjeftet',),
'løskjeftet': ('løskjeftet',),
'løskjeftete': ('løskjeftet',),
'løskjeftetere': ('løskjeftet',),
'løskjeftetest': ('løskjeftet',),
'løskjefteteste': ('løskjeftet',),
'løslynt': ('løslynt',),
'løslynte': ('løslynt',),
'løslyntere': ('løslynt',),
'løslyntest': ('løslynt',),
'løslynteste': ('løslynt',),
'løsmunna': ('løsmunna',),
'løsmunnede': ('løsmunnet',),
'løsmunnet': ('løsmunnet',),
'løsmunnete': ('løsmunnet',),
'løsmunnetere': ('løsmunnet',),
'løsmunnetest': ('løsmunnet',),
'løsmunneteste': ('løsmunnet',),
'løsna': ('løsne',),
'løsnede': ('løsne',),
'løsnende': ('løsne',),
'løsnet': ('løsne',),
'løsnete': ('løsne',),
'løsreven': ('løsreven',),
'løsrevet': ('løsreven',),
'løsrevne': ('løsreven',),
'løsrevnere': ('løsreven',),
'løsrevnest': ('løsreven',),
'løsrevneste': ('løsreven',),
'løsslupne': ('løssluppen',),
'løsslupnere': ('løssluppen',),
'løsslupnest': ('løssluppen',),
'løsslupneste': ('løssluppen',),
'løssluppen': ('løssluppen',),
'løssluppent': ('løssluppen',),
'løvtynn': ('løvtynn',),
'løvtynne': ('løvtynn',),
'løvtynnere': ('løvtynn',),
'løvtynnest': ('løvtynn',),
'løvtynneste': ('løvtynn',),
'løvtynt': ('løvtynn',),
'løy': ('løy',),
'løye': ('løy',),
'løyere': ('løy',),
'løyest': ('løy',),
'løyeste': ('løy',),
'løyt': ('løy',),
'løytt': ('løy',),
'løya': ('løye',),
'løyede': ('løye',),
'løyende': ('løye',),
'løyet': ('løye',),
'løyete': ('løye',),
'løyen': ('løyen',),
'løyene': ('løyen',),
'løyenere': ('løyen',),
'løyenest': ('løyen',),
'løyeneste': ('løyen',),
'løyenne': ('løyen',),
'løyennere': ('løyen',),
'løyennest': ('løyen',),
'løyenneste': ('løyen',),
'løyent': ('løyen',),
'løyerlig': ('løyerlig',),
'løyerlige': ('løyerlig',),
'løyerligere': ('løyerlig',),
'løyerligst': ('løyerlig',),
'løyerligste': ('løyerlig',),
'løynende': ('løyne',),
'løynt': ('løyne',),
'løynte': ('løyne',),
'løynsk': ('løynsk',),
'løynske': ('løynsk',),
'løynskere': ('løynsk',),
'løynskest': ('løynsk',),
'løynskeste': ('løynsk',),
'løypende': ('løype',),
'løypt': ('løype',),
'løypte': ('løype',),
'løysende': ('løyse',),
'løyst': ('løyse',),
'løyste': ('løyse',),
'løyselig': ('løyselig',),
'løyselige': ('løyselig',),
'løyseligere': ('løyselig',),
'løyseligst': ('løyselig',),
'løyseligste': ('løyselig',),
'løyvd': ('løyve',),
'løyvde': ('løyve',),
'løyvende': ('løyve',),
'machiavellisk': ('machiavellisk',),
'machiavelliske': ('machiavellisk',),
'machiavelliskere': ('machiavellisk',),
'machiavelliskest': ('machiavellisk',),
'machiavelliskeste': ('machiavellisk',),
'macho': ('macho',),
'madagassisk': ('madagassisk',),
'madagassiske': ('madagassisk',),
'madagassiskere': ('madagassisk',),
'madagassiskest': ('madagassisk',),
'madagassiskeste': ('madagassisk',),
'madjarisk': ('madjarisk',),
'madjariske': ('madjarisk',),
'madjariskere': ('madjarisk',),
'madjariskest': ('madjarisk',),
'madjariskeste': ('madjarisk',),
'madjarsk': ('madjarsk',),
'madjarske': ('madjarsk',),
'madjarskere': ('madjarsk',),
'madjarskest': ('madjarsk',),
'madjarskeste': ('madjarsk',),
'magasinerende': ('magasinere',),
'magasinert': ('magasinere',),
'magasinerte': ('magasinere',),
'maga': ('mage',),
'magede': ('mage',),
'magende': ('mage',),
'maget': ('mage',),
'magete': ('mage',),
'mager': ('mager',),
'magert': ('mager',),
'magre': ('mager',),
'magrere': ('mager',),
'magrest': ('mager',),
'magreste': ('mager',),
'magesur': ('magesur',),
'magesure': ('magesur',),
'magesurere': ('magesur',),
'magesurest': ('magesur',),
'magesureste': ('magesur',),
'magesurt': ('magesur',),
'magisk': ('magisk',),
'magiske': ('magisk',),
'magiskere': ('magisk',),
'magiskest': ('magisk',),
'magiskeste': ('magisk',),
'magnetiserende': ('magnetisere',),
'magnetisert': ('magnetisere',),
'magnetiserte': ('magnetisere',),
'magnetisk': ('magnetisk',),
'magnetiske': ('magnetisk',),
'magnetiskere': ('magnetisk',),
'magnetiskest': ('magnetisk',),
'magnetiskeste': ('magnetisk',),
'magnifikk': ('magnifikk',),
'magnifikke': ('magnifikk',),
'magnifikkere': ('magnifikk',),
'magnifikkest': ('magnifikk',),
'magnifikkeste': ('magnifikk',),
'magnifikt': ('magnifikk',),
'magra': ('magre',),
'magrede': ('magre',),
'magrende': ('magre',),
'magret': ('magre',),
'magrete': ('magre',),
'maia': ('maie',),
'maiede': ('maie',),
'maiende': ('maie',),
'maiet': ('maie',),
'maiete': ('maie',),
'majestetisk': ('majestetisk',),
'majestetiske': ('majestetisk',),
'majestetiskere': ('majestetisk',),
'majestetiskest': ('majestetisk',),
'majestetiskeste': ('majestetisk',),
'makaber': ('makaber',),
'makabert': ('makaber',),
'makabre': ('makaber',),
'makabrere': ('makaber',),
'makabrest': ('makaber',),
'makabreste': ('makaber',),
'makadamiserende': ('makadamisere',),
'makadamisert': ('makadamisere',),
'makadamiserte': ('makadamisere',),
'maka': ('make',),
'makede': ('make',),
'makende': ('make',),
'maket': ('make',),
'makete': ('make',),
'makt': ('make',),
'makte': ('make',),
'makedonisk': ('makedonisk',),
'makedoniske': ('makedonisk',),
'makedoniskere': ('makedonisk',),
'makedoniskest': ('makedonisk',),
'makedoniskeste': ('makedonisk',),
'makedonsk': ('makedonsk',),
'makedonske': ('makedonsk',),
'makedonskere': ('makedonsk',),
'makedonskest': ('makedonsk',),
'makedonskeste': ('makedonsk',),
'makelaus': ('makelaus',),
'makelause': ('makelaus',),
'makelausere': ('makelaus',),
'makelausest': ('makelaus',),
'makelauseste': ('makelaus',),
'makelaust': ('makelaus',),
'makelig': ('makelig',),
'makelige': ('makelig',),
'makeligere': ('makelig',),
'makeligst': ('makelig',),
'makeligste': ('makelig',),
'makeløs': ('makeløs',),
'makeløse': ('makeløs',),
'makeløsere': ('makeløs',),
'makeløsest': ('makeløs',),
'makeløseste': ('makeløs',),
'makeløst': ('makeløs',),
'maken': ('maken',),
'makent': ('maken',),
'makne': ('maken',),
'maknere': ('maken',),
'maknest': ('maken',),
'makneste': ('maken',),
'makeskifta': ('makeskifte',),
'makeskiftede': ('makeskifte',),
'makeskiftende': ('makeskifte',),
'makeskiftet': ('makeskifte',),
'makeskiftete': ('makeskifte',),
'makkett': ('makkett',),
'makkette': ('makkett',),
'makkettere': ('makkett',),
'makkettest': ('makkett',),
'makketteste': ('makkett',),
'makkspist': ('makkspist',),
'makkspiste': ('makkspist',),
'makkspistere': ('makkspist',),
'makkspistest': ('makkspist',),
'makkspisteste': ('makkspist',),
'makkstukken': ('makkstukken',),
'makkstukkent': ('makkstukken',),
'makkstukne': ('makkstukken',),
'makkstuknere': ('makkstukken',),
'makkstuknest': ('makkstukken',),
'makkstukneste': ('makkstukken',),
'makroskopisk': ('makroskopisk',),
'makroskopiske': ('makroskopisk',),
'makroskopiskere': ('makroskopisk',),
'makroskopiskest': ('makroskopisk',),
'makroskopiskeste': ('makroskopisk',),
'maksi': ('maksi',),
'maksimal': ('maksimal',),
'maksimale': ('maksimal',),
'maksimalere': ('maksimal',),
'maksimalest': ('maksimal',),
'maksimaleste': ('maksimal',),
'maksimalt': ('maksimal',),
'maksimaliserende': ('maksimalisere',),
'maksimalisert': ('maksimalisere',),
'maksimaliserte': ('maksimalisere',),
'maksimerende': ('maksimere',),
'maksimert': ('maksimere',),
'maksimerte': ('maksimere',),
'maksla': ('maksle',),
'makslede': ('maksle',),
'makslende': ('maksle',),
'makslet': ('maksle',),
'makslete': ('maksle',),
'makta': ('makte',),
'maktede': ('makte',),
'maktende': ('makte',),
'maktet': ('makte',),
'maktete': ('makte',),
'makteslaus': ('makteslaus',),
'makteslause': ('makteslaus',),
'makteslausere': ('makteslaus',),
'makteslausest': ('makteslaus',),
'makteslauseste': ('makteslaus',),
'makteslaust': ('makteslaus',),
'maktesløs': ('maktesløs',),
'maktesløse': ('maktesløs',),
'maktesløsere': ('maktesløs',),
'maktesløsest': ('maktesløs',),
'maktesløseste': ('maktesløs',),
'maktesløst': ('maktesløs',),
'maktglad': ('maktglad',),
'maktglade': ('maktglad',),
'maktgladere': ('maktglad',),
'maktgladest': ('maktglad',),
'maktgladeste': ('maktglad',),
'maktlaus': ('maktlaus',),
'maktlause': ('maktlaus',),
'maktlausere': ('maktlaus',),
'maktlausest': ('maktlaus',),
'maktlauseste': ('maktlaus',),
'maktlaust': ('maktlaus',),
'maktløs': ('maktløs',),
'maktløse': ('maktløs',),
'maktløsere': ('maktløs',),
'maktløsest': ('maktløs',),
'maktløseste': ('maktløs',),
'maktløst': ('maktløs',),
'maktpåliggende': ('maktpåliggende',),
'maktsjuk': ('maktsjuk',),
'maktsjuke': ('maktsjuk',),
'maktsjukere': ('maktsjuk',),
'maktsjukest': ('maktsjuk',),
'maktsjukeste': ('maktsjuk',),
'maktsjukt': ('maktsjuk',),
'maktstjelende': ('maktstjele',),
'maktstjålen': ('maktstjele',),
'maktstjålet': ('maktstjele',),
'maktstjålne': ('maktstjele',),
'maktsyk': ('maktsyk',),
'maktsyke': ('maktsyk',),
'maktsykere': ('maktsyk',),
'maktsykest': ('maktsyk',),
'maktsykeste': ('maktsyk',),
'maktsykt': ('maktsyk',),
'makulerende': ('makulere',),
'makulert': ('makulere',),
'makulerte': ('makulere',),
'malawisk': ('malawisk',),
'malawiske': ('malawisk',),
'malawiskere': ('malawisk',),
'malawiskest': ('malawisk',),
'malawiskeste': ('malawisk',),
'malayisk': ('malayisk',),
'malayiske': ('malayisk',),
'malayiskere': ('malayisk',),
'malayiskest': ('malayisk',),
'malayiskeste': ('malayisk',),
'malaysisk': ('malaysisk',),
'malaysiske': ('malaysisk',),
'malaysiskere': ('malaysisk',),
'malaysiskest': ('malaysisk',),
'malaysiskeste': ('malaysisk',),
'maldivisk': ('maldivisk',),
'maldiviske': ('maldivisk',),
'maldiviskere': ('maldivisk',),
'maldiviskest': ('maldivisk',),
'maldiviskeste': ('maldivisk',),
'malebarisk': ('malebarisk',),
'malebariske': ('malebarisk',),
'malebariskere': ('malebarisk',),
'malebariskest': ('malebarisk',),
'malebariskeste': ('malebarisk',),
'malende': ('malende',),
'malerisk': ('malerisk',),
'maleriske': ('malerisk',),
'maleriskere': ('malerisk',),
'maleriskest': ('malerisk',),
'maleriskeste': ('malerisk',),
'malign': ('malign',),
'maligne': ('malign',),
'malignere': ('malign',),
'malignest': ('malign',),
'maligneste': ('malign',),
'malignt': ('malign',),
'malingslitt': ('malingslitt',),
'malingslitte': ('malingslitt',),
'malingslittere': ('malingslitt',),
'malingslittest': ('malingslitt',),
'malingslitteste': ('malingslitt',),
'malisiøs': ('malisiøs',),
'malisiøse': ('malisiøs',),
'malisiøsere': ('malisiøs',),
'malisiøsest': ('malisiøs',),
'malisiøseste': ('malisiøs',),
'malisiøst': ('malisiøs',),
'malisk': ('malisk',),
'maliske': ('malisk',),
'maliskere': ('malisk',),
'maliskest': ('malisk',),
'maliskeste': ('malisk',),
'mallorcansk': ('mallorcansk',),
'mallorcanske': ('mallorcansk',),
'mallorcanskere': ('mallorcansk',),
'mallorcanskest': ('mallorcansk',),
'mallorcanskeste': ('mallorcansk',),
'mallorkansk': ('mallorkansk',),
'mallorkanske': ('mallorkansk',),
'mallorkanskere': ('mallorkansk',),
'mallorkanskest': ('mallorkansk',),
'mallorkanskeste': ('mallorkansk',),
'malmfull': ('malmfull',),
'malmfulle': ('malmfull',),
'malmfullere': ('malmfull',),
'malmfullest': ('malmfull',),
'malmfulleste': ('malmfull',),
'malmfullt': ('malmfull',),
'malplassert': ('malplassert',),
'malplasserte': ('malplassert',),
'malplassertere': ('malplassert',),
'malplassertest': ('malplassert',),
'malplasserteste': ('malplassert',),
'malta': ('malte',),
'maltede': ('malte',),
'maltende': ('malte',),
'maltet': ('malte',),
'maltete': ('malte',),
'maltesisk': ('maltesisk',),
'maltesiske': ('maltesisk',),
'maltesiskere': ('maltesisk',),
'maltesiskest': ('maltesisk',),
'maltesiskeste': ('maltesisk',),
'maltrakterende': ('maltraktere',),
'maltraktert': ('maltraktere',),
'maltrakterte': ('maltraktere',),
'mammografisk': ('mammografisk',),
'mammografiske': ('mammografisk',),
'mammografiskere': ('mammografisk',),
'mammografiskest': ('mammografisk',),
'mammografiskeste': ('mammografisk',),
'manchurisk': ('manchurisk',),
'manchuriske': ('manchurisk',),
'manchuriskere': ('manchurisk',),
'manchuriskest': ('manchurisk',),
'manchuriskeste': ('manchurisk',),
'mandelforma': ('mandelforma',),
'mandelformede': ('mandelformet',),
'mandelformet': ('mandelformet',),
'mandelformete': ('mandelformet',),
'mandelformetere': ('mandelformet',),
'mandelformetest': ('mandelformet',),
'mandelformeteste': ('mandelformet',),
'mandig': ('mandig',),
'mandige': ('mandig',),
'mandigere': ('mandig',),
'mandigst': ('mandig',),
'mandigste': ('mandig',),
'mandsjurisk': ('mandsjurisk',),
'mandsjuriske': ('mandsjurisk',),
'mandsjuriskere': ('mandsjurisk',),
'mandsjuriskest': ('mandsjurisk',),
'mandsjuriskeste': ('mandsjurisk',),
'mana': ('mane',),
'manede': ('mane',),
'manende': ('mane',),
'manet': ('mane',),
'manete': ('mane',),
'mant': ('mane',),
'mante': ('mane',),
'mangbølt': ('mangbølt',),
'mangbølte': ('mangbølt',),
'mangbøltere': ('mangbølt',),
'mangbøltest': ('mangbølt',),
'mangbølteste': ('mangbølt',),
'fler': ('mange',),
'flere': ('mange',),
'flest': ('mange',),
'fleste': ('mange',),
'mange': ('mange',),
'mangeartede': ('mangeartet',),
'mangeartet': ('mangeartet',),
'mangeartete': ('mangeartet',),
'mangeartetere': ('mangeartet',),
'mangeartetest': ('mangeartet',),
'mangearteteste': ('mangeartet',),
'mangedobbel': ('mangedobbel',),
'mangedobbelt': ('mangedobbel',),
'mangedoble': ('mangedobbel',),
'mangedoblere': ('mangedobbel',),
'mangedoblest': ('mangedobbel',),
'mangedobleste': ('mangedobbel',),
'mangedobbelt': ('mangedobbelt',),
'mangedobbelte': ('mangedobbelt',),
'mangedobbeltere': ('mangedobbelt',),
'mangedobbeltest': ('mangedobbelt',),
'mangedobbelteste': ('mangedobbelt',),
'mangedobla': ('mangedoble',),
'mangedoblede': ('mangedoble',),
'mangedoblende': ('mangedoble',),
'mangedoblet': ('mangedoble',),
'mangedoblete': ('mangedoble',),
'mangehoda': ('mangehoda',),
'mangehodede': ('mangehodet',),
'mangehodet': ('mangehodet',),
'mangehodete': ('mangehodet',),
'mangehodetere': ('mangehodet',),
'mangehodetest': ('mangehodet',),
'mangehodeteste': ('mangehodet',),
'mangelfull': ('mangelfull',),
'mangelfulle': ('mangelfull',),
'mangelfullere': ('mangelfull',),
'mangelfullest': ('mangelfull',),
'mangelfulleste': ('mangelfull',),
'mangelfullt': ('mangelfull',),
'mangesida': ('mangesida',),
'mangesidede': ('mangesidet',),
'mangesidet': ('mangesidet',),
'mangesidete': ('mangesidet',),
'mangesidetere': ('mangesidet',),
'mangesidetest': ('mangesidet',),
'mangesideteste': ('mangesidet',),
'mangesidig': ('mangesidig',),
'mangesidige': ('mangesidig',),
'mangesidigere': ('mangesidig',),
'mangesidigst': ('mangesidig',),
'mangesidigste': ('mangesidig',),
'mangetydig': ('mangetydig',),
'mangetydige': ('mangetydig',),
'mangetydigere': ('mangetydig',),
'mangetydigst': ('mangetydig',),
'mangetydigste': ('mangetydig',),
'mangeårig': ('mangeårig',),
'mangeårige': ('mangeårig',),
'mangeårigere': ('mangeårig',),
'mangeårigst': ('mangeårig',),
'mangeårigste': ('mangeårig',),
'mangfoldig': ('mangfoldig',),
'mangfoldige': ('mangfoldig',),
'mangfoldigere': ('mangfoldig',),
'mangfoldigst': ('mangfoldig',),
'mangfoldigste': ('mangfoldig',),
'mangfoldiggjort': ('mangfoldiggjøre',),
'mangfoldiggjorte': ('mangfoldiggjøre',),
'mangfoldiggjørende': ('mangfoldiggjøre',),
'mangla': ('mangle',),
'manglede': ('mangle',),
'manglende': ('mangle',),
'manglet': ('mangle',),
'manglete': ('mangle',),
'mangla': ('mangle',),
'manglede': ('mangle',),
'manglende': ('mangle',),
'manglet': ('mangle',),
'manglete': ('mangle',),
'mangslungen': ('mangslungen',),
'mangslungent': ('mangslungen',),
'mangslungne': ('mangslungen',),
'mangslungnere': ('mangslungen',),
'mangslungnest': ('mangslungen',),
'mangslungneste': ('mangslungen',),
'maniert': ('maniert',),
'manierte': ('maniert',),
'maniertere': ('maniert',),
'maniertest': ('maniert',),
'manierteste': ('maniert',),
'manifest': ('manifest',),
'manifeste': ('manifest',),
'manifestere': ('manifest',),
'manifestest': ('manifest',),
'manifesteste': ('manifest',),
'manifesterende': ('manifestere',),
'manifestert': ('manifestere',),
'manifesterte': ('manifestere',),
'manikeisk': ('manikeisk',),
'manikeiske': ('manikeisk',),
'manikeiskere': ('manikeisk',),
'manikeiskest': ('manikeisk',),
'manikeiskeste': ('manikeisk',),
'manikyrerende': ('manikyrere',),
'manikyrert': ('manikyrere',),
'manikyrerte': ('manikyrere',),
'manipulatorisk': ('manipulatorisk',),
'manipulatoriske': ('manipulatorisk',),
'manipulatoriskere': ('manipulatorisk',),
'manipulatoriskest': ('manipulatorisk',),
'manipulatoriskeste': ('manipulatorisk',),
'manipulerende': ('manipulere',),
'manipulert': ('manipulere',),
'manipulerte': ('manipulere',),
'manisk': ('manisk',),
'maniske': ('manisk',),
'maniskere': ('manisk',),
'maniskest': ('manisk',),
'maniskeste': ('manisk',),
'manisk-depressiv': ('manisk-depressiv',),
'manisk-depressive': ('manisk-depressiv',),
'manisk-depressivere': ('manisk-depressiv',),
'manisk-depressivest': ('manisk-depressiv',),
'manisk-depressiveste': ('manisk-depressiv',),
'manisk-depressivt': ('manisk-depressiv',),
'mankerende': ('mankere',),
'mankert': ('mankere',),
'mankerte': ('mankere',),
'mannbisk': ('mannbisk',),
'mannbiske': ('mannbisk',),
'mannbiskere': ('mannbisk',),
'mannbiskest': ('mannbisk',),
'mannbiskeste': ('mannbisk',),
'mannbiskt': ('mannbisk',),
'manndauda': ('manndaude',),
'manndaudede': ('manndaude',),
'manndaudende': ('manndaude',),
'manndaudet': ('manndaude',),
'manndaudete': ('manndaude',),
'manna': ('manne',),
'mannede': ('manne',),
'mannende': ('manne',),
'mannet': ('manne',),
'mannete': ('manne',),
'mannedauda': ('mannedaude',),
'mannedaudede': ('mannedaude',),
'mannedaudende': ('mannedaude',),
'mannedaudet': ('mannedaude',),
'mannedaudete': ('mannedaude',),
'mannhaftig': ('mannhaftig',),
'mannhaftige': ('mannhaftig',),
'mannhaftigere': ('mannhaftig',),
'mannhaftigst': ('mannhaftig',),
'mannhaftigste': ('mannhaftig',),
'mannjamn': ('mannjamn',),
'mannjamne': ('mannjamn',),
'mannjamnere': ('mannjamn',),
'mannjamnest': ('mannjamn',),
'mannjamneste': ('mannjamn',),
'mannjamt': ('mannjamn',),
'mannjevn': ('mannjevn',),
'mannjevne': ('mannjevn',),
'mannjevnere': ('mannjevn',),
'mannjevnest': ('mannjevn',),
'mannjevneste': ('mannjevn',),
'mannjevnt': ('mannjevn',),
'mannlig': ('mannlig',),
'mannlige': ('mannlig',),
'mannligere': ('mannlig',),
'mannligst': ('mannlig',),
'mannligste': ('mannlig',),
'mannsdominert': ('mannsdominert',),
'mannsdominerte': ('mannsdominert',),
'mannsdominertere': ('mannsdominert',),
'mannsdominertest': ('mannsdominert',),
'mannsdominerteste': ('mannsdominert',),
'mannsoppdekka': ('mannsoppdekke',),
'mannsoppdekkede': ('mannsoppdekke',),
'mannsoppdekkende': ('mannsoppdekke',),
'mannsoppdekket': ('mannsoppdekke',),
'mannsoppdekkete': ('mannsoppdekke',),
'mannsoppdekt': ('mannsoppdekke',),
'mannsoppdekte': ('mannsoppdekke',),
'mannsterk': ('mannsterk',),
'mannsterke': ('mannsterk',),
'mannsterkere': ('mannsterk',),
'mannsterkest': ('mannsterk',),
'mannsterkeste': ('mannsterk',),
'mannsterkt': ('mannsterk',),
'mannverre': ('mannvond',),
'mannverst': ('mannvond',),
'mannverste': ('mannvond',),
'mannvond': ('mannvond',),
'mannvonde': ('mannvond',),
'mannvondere': ('mannvond',),
'mannvondest': ('mannvond',),
'mannvondeste': ('mannvond',),
'mannvondt': ('mannvond',),
'mansk': ('mansk',),
'manske': ('mansk',),
'manskere': ('mansk',),
'manskest': ('mansk',),
'manskeste': ('mansk',),
'manuduserende': ('manudusere',),
'manudusert': ('manudusere',),
'manuduserte': ('manudusere',),
'manuell': ('manuell',),
'manuelle': ('manuell',),
'manuellere': ('manuell',),
'manuellest': ('manuell',),
'manuelleste': ('manuell',),
'manuelt': ('manuell',),
'manøvrerende': ('manøvrere',),
'manøvrert': ('manøvrere',),
'manøvrerte': ('manøvrere',),
'maoistisk': ('maoistisk',),
'maoistiske': ('maoistisk',),
'maoistiskere': ('maoistisk',),
'maoistiskest': ('maoistisk',),
'maoistiskeste': ('maoistisk',),
'margfull': ('margfull',),
'margfulle': ('margfull',),
'margfullere': ('margfull',),
'margfullest': ('margfull',),
'margfulleste': ('margfull',),
'margfullt': ('margfull',),
'marginal': ('marginal',),
'marginale': ('marginal',),
'marginalere': ('marginal',),
'marginalest': ('marginal',),
'marginaleste': ('marginal',),
'marginalt': ('marginal',),
'marglaus': ('marglaus',),
'marglause': ('marglaus',),
'marglausere': ('marglaus',),
'marglausest': ('marglaus',),
'marglauseste': ('marglaus',),
'marglaust': ('marglaus',),
'marglaus': ('marglaus',),
'marglause': ('marglaus',),
'marglausere': ('marglaus',),
'marglausest': ('marglaus',),
'marglauseste': ('marglaus',),
'marglaust': ('marglaus',),
'marglaus': ('marglaus',),
'marglause': ('marglaus',),
'marglausere': ('marglaus',),
'marglausest': ('marglaus',),
'marglauseste': ('marglaus',),
'marglaust': ('marglaus',),
'margløs': ('margløs',),
'margløse': ('margløs',),
'margløsere': ('margløs',),
'margløsest': ('margløs',),
'margløseste': ('margløs',),
'margløst': ('margløs',),
'margløs': ('margløs',),
'margløse': ('margløs',),
'margløsere': ('margløs',),
'margløsest': ('margløs',),
'margløseste': ('margløs',),
'margløst': ('margløs',),
'margløs': ('margløs',),
'margløse': ('margløs',),
'margløsere': ('margløs',),
'margløsest': ('margløs',),
'margløseste': ('margløs',),
'margløst': ('margløs',),
'margstelende': ('margstele',),
'margstålen': ('margstele',),
'margstålet': ('margstele',),
'margstålne': ('margstele',),
'margstelende': ('margstele',),
'margstålen': ('margstele',),
'margstålet': ('margstele',),
'margstålne': ('margstele',),
'margstjelende': ('margstjele',),
'margstjålen': ('margstjele',),
'margstjålet': ('margstjele',),
'margstjålne': ('margstjele',),
'margstjelende': ('margstjele',),
'margstjålen': ('margstjele',),
'margstjålet': ('margstjele',),
'margstjålne': ('margstjele',),
'marin': ('marin',),
'marine': ('marin',),
'marinere': ('marin',),
'marinest': ('marin',),
'marineste': ('marin',),
'marint': ('marin',),
'marineblå': ('marineblå',),
'marineblåe': ('marineblå',),
'marineblåere': ('marineblå',),
'marineblåest': ('marineblå',),
'marineblåeste': ('marineblå',),
'marineblått': ('marineblå',),
'marinerende': ('marinere',),
'marinert': ('marinere',),
'marinerte': ('marinere',),
'maritim': ('maritim',),
'maritime': ('maritim',),
'maritimere': ('maritim',),
'maritimest': ('maritim',),
'maritimeste': ('maritim',),
'maritimt': ('maritim',),
'markant': ('markant',),
'markante': ('markant',),
'markantere': ('markant',),
'markantest': ('markant',),
'markanteste': ('markant',),
'markedsførende': ('markedsføre',),
'markedsført': ('markedsføre',),
'markedsførte': ('markedsføre',),
'markerende': ('markere',),
'markert': ('markere',),
'markerte': ('markere',),
'markert': ('markert',),
'markerte': ('markert',),
'markertere': ('markert',),
'markertest': ('markert',),
'markerteste': ('markert',),
'markett': ('markett',),
'markette': ('markett',),
'markettere': ('markett',),
'markettest': ('markett',),
'marketteste': ('markett',),
'markinsk': ('markinsk',),
'markinske': ('markinsk',),
'markinskere': ('markinsk',),
'markinskest': ('markinsk',),
'markinskeste': ('markinsk',),
'marknadsførende': ('marknadsføre',),
'marknadsført': ('marknadsføre',),
'marknadsførte': ('marknadsføre',),
'markskrikersk': ('markskrikersk',),
'markskrikerske': ('markskrikersk',),
'markskrikerskere': ('markskrikersk',),
'markskrikerskest': ('markskrikersk',),
'markskrikerskeste': ('markskrikersk',),
'markspist': ('markspist',),
'markspiste': ('markspist',),
'markspistere': ('markspist',),
'markspistest': ('markspist',),
'markspisteste': ('markspist',),
'markstukken': ('markstukken',),
'markstukkent': ('markstukken',),
'markstukne': ('markstukken',),
'markstuknere': ('markstukken',),
'markstuknest': ('markstukken',),
'markstukneste': ('markstukken',),
'marma': ('marme',),
'marmede': ('marme',),
'marmende': ('marme',),
'marmet': ('marme',),
'marmete': ('marme',),
'marmorerende': ('marmorere',),
'marmorert': ('marmorere',),
'marmorerte': ('marmorere',),
'maroder': ('maroder',),
'marodert': ('maroder',),
'marodre': ('maroder',),
'marodrere': ('maroder',),
'marodrest': ('maroder',),
'marodreste': ('maroder',),
'marokkansk': ('marokkansk',),
'marokkanske': ('marokkansk',),
'marokkanskere': ('marokkansk',),
'marokkanskest': ('marokkansk',),
'marokkanskeste': ('marokkansk',),
'marsjerende': ('marsjere',),
'marsjert': ('marsjere',),
'marsjerte': ('marsjere',),
'martialsk': ('martialsk',),
'martialske': ('martialsk',),
'martialskere': ('martialsk',),
'martialskest': ('martialsk',),
'martialskeste': ('martialsk',),
'martra': ('martre',),
'martrede': ('martre',),
'martrende': ('martre',),
'martret': ('martre',),
'martrete': ('martre',),
'marxist-leninistisk': ('marxist-leninistisk',),
'marxist-leninistiske': ('marxist-leninistisk',),
'marxist-leninistiskere': ('marxist-leninistisk',),
'marxist-leninistiskest': ('marxist-leninistisk',),
'marxist-leninistiskeste': ('marxist-leninistisk',),
'marxistisk': ('marxistisk',),
'marxistiske': ('marxistisk',),
'marxistiskere': ('marxistisk',),
'marxistiskest': ('marxistisk',),
'marxistiskeste': ('marxistisk',),
'maset': ('maset',),
'masete': ('maset',),
'masetere': ('maset',),
'masetest': ('maset',),
'maseteste': ('maset',),
'masete': ('masete',),
'maska': ('maske',),
'maskede': ('maske',),
'maskende': ('maske',),
'masket': ('maske',),
'maskete': ('maske',),
'maskerende': ('maskere',),
'maskert': ('maskere',),
'maskerte': ('maskere',),
'maskindrevet': ('maskindrevet',),
'maskindrevne': ('maskindrevet',),
'maskindrevnere': ('maskindrevet',),
'maskindrevnest': ('maskindrevet',),
'maskindrevneste': ('maskindrevet',),
'maskinell': ('maskinell',),
'maskinelle': ('maskinell',),
'maskinellere': ('maskinell',),
'maskinellest': ('maskinell',),
'maskinelleste': ('maskinell',),
'maskinelt': ('maskinell',),
'maskinerende': ('maskinere',),
'maskinert': ('maskinere',),
'maskinerte': ('maskinere',),
'maskinklippa': ('maskinklippe',),
'maskinklippede': ('maskinklippe',),
'maskinklippende': ('maskinklippe',),
'maskinklippet': ('maskinklippe',),
'maskinklippete': ('maskinklippe',),
'maskinklipt': ('maskinklippe',),
'maskinklipte': ('maskinklippe',),
'maskinleselig': ('maskinleselig',),
'maskinleselige': ('maskinleselig',),
'maskinleseligere': ('maskinleselig',),
'maskinleseligst': ('maskinleselig',),
'maskinleseligste': ('maskinleselig',),
'maskinmessig': ('maskinmessig',),
'maskinmessige': ('maskinmessig',),
'maskinmessigere': ('maskinmessig',),
'maskinmessigst': ('maskinmessig',),
'maskinmessigste': ('maskinmessig',),
'maskinorientert': ('maskinorientert',),
'maskinorienterte': ('maskinorientert',),
'maskinorientertere': ('maskinorientert',),
'maskinorientertest': ('maskinorientert',),
'maskinorienterteste': ('maskinorientert',),
'maskinskreven': ('maskinskrive',),
'maskinskrevet': ('maskinskrive',),
'maskinskrevne': ('maskinskrive',),
'maskinskrivende': ('maskinskrive',),
'maskinstrikka': ('maskinstrikke',),
'maskinstrikkede': ('maskinstrikke',),
'maskinstrikkende': ('maskinstrikke',),
'maskinstrikket': ('maskinstrikke',),
'maskinstrikkete': ('maskinstrikke',),
'maskulin': ('maskulin',),
'maskuline': ('maskulin',),
'maskulinere': ('maskulin',),
'maskulinest': ('maskulin',),
'maskulineste': ('maskulin',),
'maskulint': ('maskulin',),
'maskuliniserende': ('maskulinisere',),
'maskulinisert': ('maskulinisere',),
'maskuliniserte': ('maskulinisere',),
'masochistisk': ('masochistisk',),
'masochistiske': ('masochistisk',),
'masochistiskere': ('masochistisk',),
'masochistiskest': ('masochistisk',),
'masochistiskeste': ('masochistisk',),
'massakrerende': ('massakrere',),
'massakrert': ('massakrere',),
'massakrerte': ('massakrere',),
'masseproduserende': ('masseprodusere',),
'masseprodusert': ('masseprodusere',),
'masseproduserte': ('masseprodusere',),
'masserende': ('massere',),
'massert': ('massere',),
'masserte': ('massere',),
'massiv': ('massiv',),
'massive': ('massiv',),
'massivere': ('massiv',),
'massivest': ('massiv',),
'massiveste': ('massiv',),
'massivt': ('massiv',),
'masta': ('maste',),
'mastede': ('maste',),
'mastende': ('maste',),
'mastet': ('maste',),
'mastete': ('maste',),
'masturberende': ('masturbere',),
'masturbert': ('masturbere',),
'masturberte': ('masturbere',),
'matberga': ('matberge',),
'matbergede': ('matberge',),
'matbergende': ('matberge',),
'matberget': ('matberge',),
'matbergete': ('matberge',),
'matcha': ('matche',),
'matchede': ('matche',),
'matchende': ('matche',),
'matchet': ('matche',),
'matchete': ('matche',),
'mata': ('mate',),
'matede': ('mate',),
'matende': ('mate',),
'matet': ('mate',),
'matete': ('mate',),
'matematisk': ('matematisk',),
'matematiske': ('matematisk',),
'matematiskere': ('matematisk',),
'matematiskest': ('matematisk',),
'matematiskeste': ('matematisk',),
'materialiserende': ('materialisere',),
'materialisert': ('materialisere',),
'materialiserte': ('materialisere',),
'materialistisk': ('materialistisk',),
'materialistiske': ('materialistisk',),
'materialistiskere': ('materialistisk',),
'materialistiskest': ('materialistisk',),
'materialistiskeste': ('materialistisk',),
'materiell': ('materiell',),
'materielle': ('materiell',),
'materiellere': ('materiell',),
'materiellest': ('materiell',),
'materielleste': ('materiell',),
'materielt': ('materiell',),
'maternal': ('maternal',),
'maternale': ('maternal',),
'maternalere': ('maternal',),
'maternalest': ('maternal',),
'maternaleste': ('maternal',),
'maternalt': ('maternal',),
'maternell': ('maternell',),
'maternelle': ('maternell',),
'maternellere': ('maternell',),
'maternellest': ('maternell',),
'maternelleste': ('maternell',),
'maternelt': ('maternell',),
'matlei': ('matlei',),
'matleie': ('matlei',),
'matleiere': ('matlei',),
'matleiest': ('matlei',),
'matleieste': ('matlei',),
'matleit': ('matlei',),
'matnyttig': ('matnyttig',),
'matnyttige': ('matnyttig',),
'matnyttigere': ('matnyttig',),
'matnyttigst': ('matnyttig',),
'matnyttigste': ('matnyttig',),
'matriarkalsk': ('matriarkalsk',),
'matriarkalske': ('matriarkalsk',),
'matriarkalskere': ('matriarkalsk',),
'matriarkalskest': ('matriarkalsk',),
'matriarkalskeste': ('matriarkalsk',),
'matrikulerende': ('matrikulere',),
'matrikulert': ('matrikulere',),
'matrikulerte': ('matrikulere',),
'matt': ('matt',),
'matte': ('matt',),
'mattere': ('matt',),
'mattest': ('matt',),
'matteste': ('matt',),
'matta': ('matte',),
'mattede': ('matte',),
'mattende': ('matte',),
'mattet': ('matte',),
'mattete': ('matte',),
'matterende': ('mattere',),
'mattert': ('mattere',),
'matterte': ('mattere',),
'matvand': ('matvand',),
'matvande': ('matvand',),
'matvandere': ('matvand',),
'matvandest': ('matvand',),
'matvandeste': ('matvand',),
'matvandt': ('matvand',),
'maula': ('maule',),
'maulede': ('maule',),
'maulende': ('maule',),
'maulet': ('maule',),
'maulete': ('maule',),
'maura': ('maure',),
'maurede': ('maure',),
'maurende': ('maure',),
'mauret': ('maure',),
'maurete': ('maure',),
'maurflittig': ('maurflittig',),
'maurflittige': ('maurflittig',),
'maurflittigere': ('maurflittig',),
'maurflittigst': ('maurflittig',),
'maurflittigste': ('maurflittig',),
'maurisk': ('maurisk',),
'mauriske': ('maurisk',),
'mauriskere': ('maurisk',),
'mauriskest': ('maurisk',),
'mauriskeste': ('maurisk',),
'mauritansk': ('mauritansk',),
'mauritanske': ('mauritansk',),
'mauritanskere': ('mauritansk',),
'mauritanskest': ('mauritansk',),
'mauritanskeste': ('mauritansk',),
'mauritisk': ('mauritisk',),
'mauritiske': ('mauritisk',),
'mauritiskere': ('mauritisk',),
'mauritiskest': ('mauritisk',),
'mauritiskeste': ('mauritisk',),
'mavesur': ('mavesur',),
'mavesure': ('mavesur',),
'mavesurere': ('mavesur',),
'mavesurest': ('mavesur',),
'mavesureste': ('mavesur',),
'mavesurt': ('mavesur',),
'medansvarlig': ('medansvarlig',),
'medansvarlige': ('medansvarlig',),
'medansvarligere': ('medansvarlig',),
'medansvarligst': ('medansvarlig',),
'medansvarligste': ('medansvarlig',),
'medbestemmende': ('medbestemmende',),
'meddelende': ('meddele',),
'meddelt': ('meddele',),
'meddelte': ('meddele',),
'meddelsom': ('meddelsom',),
'meddelsomme': ('meddelsom',),
'meddelsommere': ('meddelsom',),
'meddelsomst': ('meddelsom',),
'meddelsomste': ('meddelsom',),
'meddelsomt': ('meddelsom',),
'medfødd': ('medfødd',),
'medfødde': ('medfødd',),
'medføddere': ('medfødd',),
'medføddest': ('medfødd',),
'medføddeste': ('medfødd',),
'medfødt': ('medfødt',),
'medfødte': ('medfødt',),
'medfødtere': ('medfødt',),
'medfødtest': ('medfødt',),
'medfødteste': ('medfødt',),
'medførende': ('medføre',),
'medført': ('medføre',),
'medførte': ('medføre',),
'medgiende': ('medgi',),
'medgitt': ('medgi',),
'medgitte': ('medgi',),
'medgivende': ('medgi',),
'medgjørlig': ('medgjørlig',),
'medgjørlige': ('medgjørlig',),
'medgjørligere': ('medgjørlig',),
'medgjørligst': ('medgjørlig',),
'medgjørligste': ('medgjørlig',),
'medial': ('medial',),
'mediale': ('medial',),
'medialere': ('medial',),
'medialest': ('medial',),
'medialeste': ('medial',),
'medialt': ('medial',),
'medikamentell': ('medikamentell',),
'medikamentelle': ('medikamentell',),
'medikamentellere': ('medikamentell',),
'medikamentellest': ('medikamentell',),
'medikamentelleste': ('medikamentell',),
'medikamentelt': ('medikamentell',),
'medisinal': ('medisinal',),
'medisinale': ('medisinal',),
'medisinalere': ('medisinal',),
'medisinalest': ('medisinal',),
'medisinaleste': ('medisinal',),
'medisinalt': ('medisinal',),
'medisinerende': ('medisinere',),
'medisinert': ('medisinere',),
'medisinerte': ('medisinere',),
'medisinsk': ('medisinsk',),
'medisinske': ('medisinsk',),
'medisinskere': ('medisinsk',),
'medisinskest': ('medisinsk',),
'medisinskeste': ('medisinsk',),
'mediterende': ('meditere',),
'meditert': ('meditere',),
'mediterte': ('meditere',),
'mediterran': ('mediterran',),
'mediterrane': ('mediterran',),
'mediterranere': ('mediterran',),
'mediterranest': ('mediterran',),
'mediterraneste': ('mediterran',),
'mediterrant': ('mediterran',),
'medlidende': ('medlidende',),
'medmenneskelig': ('medmenneskelig',),
'medmenneskelige': ('medmenneskelig',),
'medmenneskeligere': ('medmenneskelig',),
'medmenneskeligst': ('medmenneskelig',),
'medmenneskeligste': ('medmenneskelig',),
'medregna': ('medregna',),
'medregnede': ('medregnet',),
'medregnet': ('medregnet',),
'medregnete': ('medregnet',),
'medregnetere': ('medregnet',),
'medregnetest': ('medregnet',),
'medregneteste': ('medregnet',),
'medreisende': ('medreisende',),
'medrekna': ('medrekna',),
'medreknede': ('medreknet',),
'medreknet': ('medreknet',),
'medreknete': ('medreknet',),
'medreknetere': ('medreknet',),
'medreknetest': ('medreknet',),
'medrekneteste': ('medreknet',),
'medsammensvoren': ('medsammensvoren',),
'medsammensvorent': ('medsammensvoren',),
'medsammensvorne': ('medsammensvoren',),
'medsammensvornere': ('medsammensvoren',),
'medsammensvornest': ('medsammensvoren',),
'medsammensvorneste': ('medsammensvoren',),
'medskyldig': ('medskyldig',),
'medskyldige': ('medskyldig',),
'medskyldigere': ('medskyldig',),
'medskyldigst': ('medskyldig',),
'medskyldigste': ('medskyldig',),
'medunderskreven': ('medunderskrive',),
'medunderskrevet': ('medunderskrive',),
'medunderskrevne': ('medunderskrive',),
'medunderskrivende': ('medunderskrive',),
'medveten': ('medveten',),
'medvetent': ('medveten',),
'medvetne': ('medveten',),
'medvetnere': ('medveten',),
'medvetnest': ('medveten',),
'medvetneste': ('medveten',),
'medvirka': ('medvirke',),
'medvirkede': ('medvirke',),
'medvirkende': ('medvirke',),
'medvirket': ('medvirke',),
'medvirkete': ('medvirke',),
'medvirkende': ('medvirkende',),
'medviten': ('medviten',),
'medvitent': ('medviten',),
'medvitne': ('medviten',),
'medvitnere': ('medviten',),
'medvitnest': ('medviten',),
'medvitneste': ('medviten',),
'medvitende': ('medvitende',),
'mefistofelisk': ('mefistofelisk',),
'mefistofeliske': ('mefistofelisk',),
'mefistofeliskere': ('mefistofelisk',),
'mefistofeliskest': ('mefistofelisk',),
'mefistofeliskeste': ('mefistofelisk',),
'megalittisk': ('megalittisk',),
'megalittiske': ('megalittisk',),
'megalittiskere': ('megalittisk',),
'megalittiskest': ('megalittisk',),
'megalittiskeste': ('megalittisk',),
'megetsigende': ('megetsigende',),
'megla': ('megle',),
'meglede': ('megle',),
'meglende': ('megle',),
'meglet': ('megle',),
'meglete': ('megle',),
'meia': ('meie',),
'meid': ('meie',),
'meidd': ('meie',),
'meidde': ('meie',),
'meide': ('meie',),
'meiede': ('meie',),
'meiende': ('meie',),
'meiet': ('meie',),
'meiete': ('meie',),
'meinende': ('meine',),
'meint': ('meine',),
'meinte': ('meine',),
'meiningsberettiga': ('meiningsberettiga',),
'meiningsberettigede': ('meiningsberettiget',),
'meiningsberettiget': ('meiningsberettiget',),
'meiningsberettigete': ('meiningsberettiget',),
'meiningsberettigetere': ('meiningsberettiget',),
'meiningsberettigetest': ('meiningsberettiget',),
'meiningsberettigeteste': ('meiningsberettiget',),
'meiningsforvirrende': ('meiningsforvirrende',),
'meiningsfull': ('meiningsfull',),
'meiningsfulle': ('meiningsfull',),
'meiningsfullere': ('meiningsfull',),
'meiningsfullest': ('meiningsfull',),
'meiningsfulleste': ('meiningsfull',),
'meiningsfullt': ('meiningsfull',),
'meiningsfylt': ('meiningsfylt',),
'meiningsfylte': ('meiningsfylt',),
'meiningsfyltere': ('meiningsfylt',),
'meiningsfyltest': ('meiningsfylt',),
'meiningsfylteste': ('meiningsfylt',),
'meiningslaus': ('meiningslaus',),
'meiningslause': ('meiningslaus',),
'meiningslausere': ('meiningslaus',),
'meiningslausest': ('meiningslaus',),
'meiningslauseste': ('meiningslaus',),
'meiningslaust': ('meiningslaus',),
'meiningsløs': ('meiningsløs',),
'meiningsløse': ('meiningsløs',),
'meiningsløsere': ('meiningsløs',),
'meiningsløsest': ('meiningsløs',),
'meiningsløseste': ('meiningsløs',),
'meiningsløst': ('meiningsløs',),
'meiningstom': ('meiningstom',),
'meiningstomme': ('meiningstom',),
'meiningstommere': ('meiningstom',),
'meiningstommest': ('meiningstom',),
'meiningstommeste': ('meiningstom',),
'meiningstomt': ('meiningstom',),
'meinlaus': ('meinlaus',),
'meinlause': ('meinlaus',),
'meinlausere': ('meinlaus',),
'meinlausest': ('meinlaus',),
'meinlauseste': ('meinlaus',),
'meinlaust': ('meinlaus',),
'meinløs': ('meinløs',),
'meinløse': ('meinløs',),
'meinløsere': ('meinløs',),
'meinløsest': ('meinløs',),
'meinløseste': ('meinløs',),
'meinløst': ('meinløs',),
'meisla': ('meisle',),
'meislede': ('meisle',),
'meislende': ('meisle',),
'meislet': ('meisle',),
'meislete': ('meisle',),
'meita': ('meite',),
'meitede': ('meite',),
'meitende': ('meite',),
'meitet': ('meite',),
'meitete': ('meite',),
'mekaniserende': ('mekanisere',),
'mekanisert': ('mekanisere',),
'mekaniserte': ('mekanisere',),
'mekanisk': ('mekanisk',),
'mekaniske': ('mekanisk',),
'mekaniskere': ('mekanisk',),
'mekaniskest': ('mekanisk',),
'mekaniskeste': ('mekanisk',),
'mekanistisk': ('mekanistisk',),
'mekanistiske': ('mekanistisk',),
'mekanistiskere': ('mekanistisk',),
'mekanistiskest': ('mekanistisk',),
'mekanistiskeste': ('mekanistisk',),
'mekka': ('mekke',),
'mekkede': ('mekke',),
'mekkende': ('mekke',),
'mekket': ('mekke',),
'mekkete': ('mekke',),
'mekla': ('mekle',),
'meklede': ('mekle',),
'meklende': ('mekle',),
'meklet': ('mekle',),
'meklete': ('mekle',),
'mekra': ('mekre',),
'mekrede': ('mekre',),
'mekrende': ('mekre',),
'mekret': ('mekre',),
'mekrete': ('mekre',),
'meksikansk': ('meksikansk',),
'meksikanske': ('meksikansk',),
'meksikanskere': ('meksikansk',),
'meksikanskest': ('meksikansk',),
'meksikanskeste': ('meksikansk',),
'mektig': ('mektig',),
'mektige': ('mektig',),
'mektigere': ('mektig',),
'mektigst': ('mektig',),
'mektigste': ('mektig',),
'melanesisk': ('melanesisk',),
'melanesiske': ('melanesisk',),
'melanesiskere': ('melanesisk',),
'melanesiskest': ('melanesisk',),
'melanesiskeste': ('melanesisk',),
'melankolsk': ('melankolsk',),
'melankolske': ('melankolsk',),
'melankolskere': ('melankolsk',),
'melankolskest': ('melankolsk',),
'melankolskeste': ('melankolsk',),
'meldende': ('melde',),
'meldt': ('melde',),
'meldte': ('melde',),
'mela': ('mele',),
'melede': ('mele',),
'melende': ('mele',),
'melet': ('mele',),
'melete': ('mele',),
'melt': ('mele',),
'melte': ('mele',),
'melen': ('melen',),
'melent': ('melen',),
'melne': ('melen',),
'melnere': ('melen',),
'melnest': ('melen',),
'melneste': ('melen',),
'melerende': ('melere',),
'melert': ('melere',),
'melerte': ('melere',),
'melert': ('melert',),
'melerte': ('melert',),
'melertere': ('melert',),
'melertest': ('melert',),
'melerteste': ('melert',),
'melet': ('melet',),
'melete': ('melet',),
'meletere': ('melet',),
'meletest': ('melet',),
'meleteste': ('melet',),
'melete': ('melete',),
'melka': ('melke',),
'melkede': ('melke',),
'melkende': ('melke',),
'melket': ('melke',),
'melkete': ('melke',),
'melkeblå': ('melkeblå',),
'melkeblåe': ('melkeblå',),
'melkeblåere': ('melkeblå',),
'melkeblåest': ('melkeblå',),
'melkeblåeste': ('melkeblå',),
'melkeblått': ('melkeblå',),
'melkeblå': ('melkeblå',),
'melkeblåe': ('melkeblå',),
'melkeblåere': ('melkeblå',),
'melkeblåest': ('melkeblå',),
'melkeblåeste': ('melkeblå',),
'melkeblått': ('melkeblå',),
'melkehvit': ('melkehvit',),
'melkehvite': ('melkehvit',),
'melkehvitere': ('melkehvit',),
'melkehvitest': ('melkehvit',),
'melkehviteste': ('melkehvit',),
'melkehvitt': ('melkehvit',),
'melkekvit': ('melkekvit',),
'melkekvite': ('melkekvit',),
'melkekvitere': ('melkekvit',),
'melkekvitest': ('melkekvit',),
'melkekviteste': ('melkekvit',),
'melkekvitt': ('melkekvit',),
'melkesprengt': ('melkesprengt',),
'melkesprengte': ('melkesprengt',),
'melkesprengtere': ('melkesprengt',),
'melkesprengtest': ('melkesprengt',),
'melkesprengteste': ('melkesprengt',),
'mellomaldersk': ('mellomaldersk',),
'mellomalderske': ('mellomaldersk',),
'mellomalderskere': ('mellomaldersk',),
'mellomalderskest': ('mellomaldersk',),
'mellomalderskeste': ('mellomaldersk',),
'mellomamerikansk': ('mellomamerikansk',),
'mellomamerikanske': ('mellomamerikansk',),
'mellomamerikanskere': ('mellomamerikansk',),
'mellomamerikanskest': ('mellomamerikansk',),
'mellomamerikanskeste': ('mellomamerikansk',),
'mellombels': ('mellombels',),
'mellomblå': ('mellomblå',),
'mellomblåe': ('mellomblå',),
'mellomblåere': ('mellomblå',),
'mellomblåest': ('mellomblå',),
'mellomblåeste': ('mellomblå',),
'mellomblått': ('mellomblå',),
'mellombrun': ('mellombrun',),
'mellombrune': ('mellombrun',),
'mellombrunere': ('mellombrun',),
'mellombrunest': ('mellombrun',),
'mellombruneste': ('mellombrun',),
'mellombrunt': ('mellombrun',),
'mellomeuropeisk': ('mellomeuropeisk',),
'mellomeuropeiske': ('mellomeuropeisk',),
'mellomeuropeiskere': ('mellomeuropeisk',),
'mellomeuropeiskest': ('mellomeuropeisk',),
'mellomeuropeiskeste': ('mellomeuropeisk',),
'mellomfolkelig': ('mellomfolkelig',),
'mellomfolkelige': ('mellomfolkelig',),
'mellomfolkeligere': ('mellomfolkelig',),
'mellomfolkeligst': ('mellomfolkelig',),
'mellomfolkeligste': ('mellomfolkelig',),
'mellomfornøgd': ('mellomfornøgd',),
'mellomfornøgde': ('mellomfornøgd',),
'mellomfornøgdere': ('mellomfornøgd',),
'mellomfornøgdest': ('mellomfornøgd',),
'mellomfornøgdeste': ('mellomfornøgd',),
'mellomfornøyd': ('mellomfornøyd',),
'mellomfornøyde': ('mellomfornøyd',),
'mellomfornøydere': ('mellomfornøyd',),
'mellomfornøydest': ('mellomfornøyd',),
'mellomfornøydeste': ('mellomfornøyd',),
'mellomkirkelig': ('mellomkirkelig',),
'mellomkirkelige': ('mellomkirkelig',),
'mellomkirkeligere': ('mellomkirkelig',),
'mellomkirkeligst': ('mellomkirkelig',),
'mellomkirkeligste': ('mellomkirkelig',),
'mellomlanda': ('mellomlande',),
'mellomlandede': ('mellomlande',),
'mellomlandende': ('mellomlande',),
'mellomlandet': ('mellomlande',),
'mellomlandete': ('mellomlande',),
'mellomliggende': ('mellomliggende',),
'mellommenneskelig': ('mellommenneskelig',),
'mellommenneskelige': ('mellommenneskelig',),
'mellommenneskeligere': ('mellommenneskelig',),
'mellommenneskeligst': ('mellommenneskelig',),
'mellommenneskeligste': ('mellommenneskelig',),
'mellomnorsk': ('mellomnorsk',),
'mellomnorske': ('mellomnorsk',),
'mellomnorskere': ('mellomnorsk',),
'mellomnorskest': ('mellomnorsk',),
'mellomnorskeste': ('mellomnorsk',),
'mellomst': ('mellomst',),
'mellomste': ('mellomst',),
'mellomstor': ('mellomstor',),
'mellomstore': ('mellomstor',),
'mellomstort': ('mellomstor',),
'mellomstørre': ('mellomstor',),
'mellomstørst': ('mellomstor',),
'mellomstørste': ('mellomstor',),
'melodisk': ('melodisk',),
'melodiske': ('melodisk',),
'melodiskere': ('melodisk',),
'melodiskest': ('melodisk',),
'melodiskeste': ('melodisk',),
'melodiøs': ('melodiøs',),
'melodiøse': ('melodiøs',),
'melodiøsere': ('melodiøs',),
'melodiøsest': ('melodiøs',),
'melodiøseste': ('melodiøs',),
'melodiøst': ('melodiøs',),
'melodramatisk': ('melodramatisk',),
'melodramatiske': ('melodramatisk',),
'melodramatiskere': ('melodramatisk',),
'melodramatiskest': ('melodramatisk',),
'melodramatiskeste': ('melodramatisk',),
'melta': ('melte',),
'meltede': ('melte',),
'meltende': ('melte',),
'meltet': ('melte',),
'meltete': ('melte',),
'memorerende': ('memorere',),
'memorert': ('memorere',),
'memorerte': ('memorere',),
'menende': ('mene',),
'ment': ('mene',),
'mente': ('mene',),
'menga': ('menge',),
'mengede': ('menge',),
'mengende': ('menge',),
'menget': ('menge',),
'mengete': ('menge',),
'mengt': ('menge',),
'mengte': ('menge',),
'menig': ('menig',),
'menige': ('menig',),
'menigere': ('menig',),
'menigst': ('menig',),
'menigste': ('menig',),
'meningsberettiga': ('meningsberettiga',),
'meningsberettigede': ('meningsberettiget',),
'meningsberettiget': ('meningsberettiget',),
'meningsberettigete': ('meningsberettiget',),
'meningsberettigetere': ('meningsberettiget',),
'meningsberettigetest': ('meningsberettiget',),
'meningsberettigeteste': ('meningsberettiget',),
'meningsforvirrende': ('meningsforvirrende',),
'meningsfull': ('meningsfull',),
'meningsfulle': ('meningsfull',),
'meningsfullere': ('meningsfull',),
'meningsfullest': ('meningsfull',),
'meningsfulleste': ('meningsfull',),
'meningsfullt': ('meningsfull',),
'meningsfylt': ('meningsfylt',),
'meningsfylte': ('meningsfylt',),
'meningsfyltere': ('meningsfylt',),
'meningsfyltest': ('meningsfylt',),
'meningsfylteste': ('meningsfylt',),
'meningslaus': ('meningslaus',),
'meningslause': ('meningslaus',),
'meningslausere': ('meningslaus',),
'meningslausest': ('meningslaus',),
'meningslauseste': ('meningslaus',),
'meningslaust': ('meningslaus',),
'meningsløs': ('meningsløs',),
'meningsløse': ('meningsløs',),
'meningsløsere': ('meningsløs',),
'meningsløsest': ('meningsløs',),
'meningsløseste': ('meningsløs',),
'meningsløst': ('meningsløs',),
'meningstom': ('meningstom',),
'meningstomme': ('meningstom',),
'meningstommere': ('meningstom',),
'meningstommest': ('meningstom',),
'meningstommeste': ('meningstom',),
'meningstomt': ('meningstom',),
'menlaus': ('menlaus',),
'menlause': ('menlaus',),
'menlausere': ('menlaus',),
'menlausest': ('menlaus',),
'menlauseste': ('menlaus',),
'menlaust': ('menlaus',),
'menløs': ('menløs',),
'menløse': ('menløs',),
'menløsere': ('menløs',),
'menløsest': ('menløs',),
'menløseste': ('menløs',),
'menløst': ('menløs',),
'menneskekjærlig': ('menneskekjærlig',),
'menneskekjærlige': ('menneskekjærlig',),
'menneskekjærligere': ('menneskekjærlig',),
'menneskekjærligst': ('menneskekjærlig',),
'menneskekjærligste': ('menneskekjærlig',),
'menneskelig': ('menneskelig',),
'menneskelige': ('menneskelig',),
'menneskeligere': ('menneskelig',),
'menneskeligst': ('menneskelig',),
'menneskeligste': ('menneskelig',),
'mennesketom': ('mennesketom',),
'mennesketomme': ('mennesketom',),
'mennesketommere': ('mennesketom',),
'mennesketommest': ('mennesketom',),
'mennesketommeste': ('mennesketom',),
'mennesketomt': ('mennesketom',),
'menneskevennlig': ('menneskevennlig',),
'menneskevennlige': ('menneskevennlig',),
'menneskevennligere': ('menneskevennlig',),
'menneskevennligst': ('menneskevennlig',),
'menneskevennligste': ('menneskevennlig',),
'menneskeverdig': ('menneskeverdig',),
'menneskeverdige': ('menneskeverdig',),
'menneskeverdigere': ('menneskeverdig',),
'menneskeverdigst': ('menneskeverdig',),
'menneskeverdigste': ('menneskeverdig',),
'menstruerende': ('menstruere',),
'menstruert': ('menstruere',),
'menstruerte': ('menstruere',),
'mental': ('mental',),
'mentale': ('mental',),
'mentalere': ('mental',),
'mentalest': ('mental',),
'mentaleste': ('mental',),
'mentalt': ('mental',),
'mentalhygienisk': ('mentalhygienisk',),
'mentalhygieniske': ('mentalhygienisk',),
'mentalhygieniskere': ('mentalhygienisk',),
'mentalhygieniskest': ('mentalhygienisk',),
'mentalhygieniskeste': ('mentalhygienisk',),
'mentalundersøkende': ('mentalundersøke',),
'mentalundersøkt': ('mentalundersøke',),
'mentalundersøkte': ('mentalundersøke',),
'mergfull': ('mergfull',),
'mergfulle': ('mergfull',),
'mergfullere': ('mergfull',),
'mergfullest': ('mergfull',),
'mergfulleste': ('mergfull',),
'mergfullt': ('mergfull',),
'merglaus': ('merglaus',),
'merglause': ('merglaus',),
'merglausere': ('merglaus',),
'merglausest': ('merglaus',),
'merglauseste': ('merglaus',),
'merglaust': ('merglaus',),
'merglaus': ('merglaus',),
'merglause': ('merglaus',),
'merglausere': ('merglaus',),
'merglausest': ('merglaus',),
'merglauseste': ('merglaus',),
'merglaust': ('merglaus',),
'mergla': ('mergle',),
'merglede': ('mergle',),
'merglende': ('mergle',),
'merglet': ('mergle',),
'merglete': ('mergle',),
'mergløs': ('mergløs',),
'mergløse': ('mergløs',),
'mergløsere': ('mergløs',),
'mergløsest': ('mergløs',),
'mergløseste': ('mergløs',),
'mergløst': ('mergløs',),
'mergløs': ('mergløs',),
'mergløse': ('mergløs',),
'mergløsere': ('mergløs',),
'mergløsest': ('mergløs',),
'mergløseste': ('mergløs',),
'mergløst': ('mergløs',),
'mergstelende': ('mergstele',),
'mergstålen': ('mergstele',),
'mergstålet': ('mergstele',),
'mergstålne': ('mergstele',),
'mergstelende': ('mergstele',),
'mergstålen': ('mergstele',),
'mergstålet': ('mergstele',),
'mergstålne': ('mergstele',),
'mergstjelende': ('mergstjele',),
'mergstjålen': ('mergstjele',),
'mergstjålet': ('mergstjele',),
'mergstjålne': ('mergstjele',),
'mergstjelende': ('mergstjele',),
'mergstjålen': ('mergstjele',),
'mergstjålet': ('mergstjele',),
'mergstjålne': ('mergstjele',),
'meritokratisk': ('meritokratisk',),
'meritokratiske': ('meritokratisk',),
'meritokratiskere': ('meritokratisk',),
'meritokratiskest': ('meritokratisk',),
'meritokratiskeste': ('meritokratisk',),
'meritterende': ('merittere',),
'merittert': ('merittere',),
'meritterte': ('merittere',),
'merkantil': ('merkantil',),
'merkantile': ('merkantil',),
'merkantilere': ('merkantil',),
'merkantilest': ('merkantil',),
'merkantileste': ('merkantil',),
'merkantilt': ('merkantil',),
'merkantilistisk': ('merkantilistisk',),
'merkantilistiske': ('merkantilistisk',),
'merkantilistiskere': ('merkantilistisk',),
'merkantilistiskest': ('merkantilistisk',),
'merkantilistiskeste': ('merkantilistisk',),
'merkbar': ('merkbar',),
'merkbare': ('merkbar',),
'merkbarere': ('merkbar',),
'merkbarest': ('merkbar',),
'merkbareste': ('merkbar',),
'merkbart': ('merkbar',),
'merka': ('merke',),
'merkede': ('merke',),
'merkende': ('merke',),
'merket': ('merke',),
'merkete': ('merke',),
'merkelig': ('merkelig',),
'merkelige': ('merkelig',),
'merkeligere': ('merkelig',),
'merkeligst': ('merkelig',),
'merkeligste': ('merkelig',),
'merksam': ('merksam',),
'merksamme': ('merksam',),
'merksammere': ('merksam',),
'merksamst': ('merksam',),
'merksamste': ('merksam',),
'merksamt': ('merksam',),
'merkverdig': ('merkverdig',),
'merkverdige': ('merkverdig',),
'merkverdigere': ('merkverdig',),
'merkverdigst': ('merkverdig',),
'merkverdigste': ('merkverdig',),
'merla': ('merle',),
'merlede': ('merle',),
'merlende': ('merle',),
'merlet': ('merle',),
'merlete': ('merle',),
'merovingisk': ('merovingisk',),
'merovingiske': ('merovingisk',),
'merovingiskere': ('merovingisk',),
'merovingiskest': ('merovingisk',),
'merovingiskeste': ('merovingisk',),
'meska': ('meske',),
'meskede': ('meske',),
'meskende': ('meske',),
'mesket': ('meske',),
'meskete': ('meske',),
'mesolittisk': ('mesolittisk',),
'mesolittiske': ('mesolittisk',),
'mesolittiskere': ('mesolittisk',),
'mesolittiskest': ('mesolittisk',),
'mesolittiskeste': ('mesolittisk',),
'mesopotamisk': ('mesopotamisk',),
'mesopotamiske': ('mesopotamisk',),
'mesopotamiskere': ('mesopotamisk',),
'mesopotamiskest': ('mesopotamisk',),
'mesopotamiskeste': ('mesopotamisk',),
'mesozoisk': ('mesozoisk',),
'mesozoiske': ('mesozoisk',),
'mesozoiskere': ('mesozoisk',),
'mesozoiskest': ('mesozoisk',),
'mesozoiskeste': ('mesozoisk',),
'messa': ('messe',),
'messede': ('messe',),
'messende': ('messe',),
'messet': ('messe',),
'messete': ('messe',),
'messiansk': ('messiansk',),
'messianske': ('messiansk',),
'messianskere': ('messiansk',),
'messianskest': ('messiansk',),
'messianskeste': ('messiansk',),
'mesterlig': ('mesterlig',),
'mesterlige': ('mesterlig',),
'mesterligere': ('mesterlig',),
'mesterligst': ('mesterlig',),
'mesterligste': ('mesterlig',),
'mestra': ('mestre',),
'mestrede': ('mestre',),
'mestrende': ('mestre',),
'mestret': ('mestre',),
'mestrete': ('mestre',),
'metabolsk': ('metabolsk',),
'metabolske': ('metabolsk',),
'metabolskere': ('metabolsk',),
'metabolskest': ('metabolsk',),
'metabolskeste': ('metabolsk',),
'metaforisk': ('metaforisk',),
'metaforiske': ('metaforisk',),
'metaforiskere': ('metaforisk',),
'metaforiskest': ('metaforisk',),
'metaforiskeste': ('metaforisk',),
'metafysisk': ('metafysisk',),
'metafysiske': ('metafysisk',),
'metafysiskere': ('metafysisk',),
'metafysiskest': ('metafysisk',),
'metafysiskeste': ('metafysisk',),
'metallic': ('metallic',),
'metalliserende': ('metallisere',),
'metallisert': ('metallisere',),
'metalliserte': ('metallisere',),
'metallisk': ('metallisk',),
'metalliske': ('metallisk',),
'metalliskere': ('metallisk',),
'metalliskest': ('metallisk',),
'metalliskeste': ('metallisk',),
'metallurgisk': ('metallurgisk',),
'metallurgiske': ('metallurgisk',),
'metallurgiskere': ('metallurgisk',),
'metallurgiskest': ('metallurgisk',),
'metallurgiskeste': ('metallurgisk',),
'metamorf': ('metamorf',),
'metamorfe': ('metamorf',),
'metamorfere': ('metamorf',),
'metamorfest': ('metamorf',),
'metamorfeste': ('metamorf',),
'metamorft': ('metamorf',),
'metamorfisk': ('metamorfisk',),
'metamorfiske': ('metamorfisk',),
'metamorfiskere': ('metamorfisk',),
'metamorfiskest': ('metamorfisk',),
'metamorfiskeste': ('metamorfisk',),
'metaspråklig': ('metaspråklig',),
'metaspråklige': ('metaspråklig',),
'metaspråkligere': ('metaspråklig',),
'metaspråkligst': ('metaspråklig',),
'metaspråkligste': ('metaspråklig',),
'meteorologisk': ('meteorologisk',),
'meteorologiske': ('meteorologisk',),
'meteorologiskere': ('meteorologisk',),
'meteorologiskest': ('meteorologisk',),
'meteorologiskeste': ('meteorologisk',),
'meterdjup': ('meterdjup',),
'meterdjupe': ('meterdjup',),
'meterdjupere': ('meterdjup',),
'meterdjupest': ('meterdjup',),
'meterdjupeste': ('meterdjup',),
'meterdjupt': ('meterdjup',),
'meterdyp': ('meterdyp',),
'meterdype': ('meterdyp',),
'meterdypere': ('meterdyp',),
'meterdypest': ('meterdyp',),
'meterdypeste': ('meterdyp',),
'meterdypt': ('meterdyp',),
'meterhøg': ('meterhøg',),
'meterhøge': ('meterhøg',),
'meterhøgere': ('meterhøg',),
'meterhøgest': ('meterhøg',),
'meterhøgeste': ('meterhøg',),
'meterhøgre': ('meterhøg',),
'meterhøgst': ('meterhøg',),
'meterhøgste': ('meterhøg',),
'meterhøgt': ('meterhøg',),
'meterhøy': ('meterhøy',),
'meterhøye': ('meterhøy',),
'meterhøyere': ('meterhøy',),
'meterhøyest': ('meterhøy',),
'meterhøyeste': ('meterhøy',),
'meterhøyt': ('meterhøy',),
'meterlang': ('meterlang',),
'meterlange': ('meterlang',),
'meterlangt': ('meterlang',),
'meterlenger': ('meterlang',),
'meterlengre': ('meterlang',),
'meterlengst': ('meterlang',),
'meterlengste': ('meterlang',),
'metodisk': ('metodisk',),
'metodiske': ('metodisk',),
'metodiskere': ('metodisk',),
'metodiskest': ('metodisk',),
'metodiskeste': ('metodisk',),
'metodistisk': ('metodistisk',),
'metodistiske': ('metodistisk',),
'metodistiskere': ('metodistisk',),
'metodistiskest': ('metodistisk',),
'metodistiskeste': ('metodistisk',),
'metodologisk': ('metodologisk',),
'metodologiske': ('metodologisk',),
'metodologiskere': ('metodologisk',),
'metodologiskest': ('metodologisk',),
'metodologiskeste': ('metodologisk',),
'metrisk': ('metrisk',),
'metriske': ('metrisk',),
'metriskere': ('metrisk',),
'metriskest': ('metrisk',),
'metriskeste': ('metrisk',),
'metrologisk': ('metrologisk',),
'metrologiske': ('metrologisk',),
'metrologiskere': ('metrologisk',),
'metrologiskest': ('metrologisk',),
'metrologiskeste': ('metrologisk',),
'mett': ('mett',),
'mette': ('mett',),
'mettere': ('mett',),
'mettest': ('mett',),
'metteste': ('mett',),
'metta': ('mette',),
'mettede': ('mette',),
'mettende': ('mette',),
'mettet': ('mette',),
'mettete': ('mette',),
'mexicansk': ('mexicansk',),
'mexicanske': ('mexicansk',),
'mexicanskere': ('mexicansk',),
'mexicanskest': ('mexicansk',),
'mexicanskeste': ('mexicansk',),
'middelaldersk': ('middelaldersk',),
'middelalderske': ('middelaldersk',),
'middelalderskere': ('middelaldersk',),
'middelalderskest': ('middelaldersk',),
'middelalderskeste': ('middelaldersk',),
'middelaldrende': ('middelaldrende',),
'middelbar': ('middelbar',),
'middelbare': ('middelbar',),
'middelbarere': ('middelbar',),
'middelbarest': ('middelbar',),
'middelbareste': ('middelbar',),
'middelbart': ('middelbar',),
'middelhøg': ('middelhøg',),
'middelhøge': ('middelhøg',),
'middelhøgere': ('middelhøg',),
'middelhøgest': ('middelhøg',),
'middelhøgeste': ('middelhøg',),
'middelhøgre': ('middelhøg',),
'middelhøgst': ('middelhøg',),
'middelhøgste': ('middelhøg',),
'middelhøgt': ('middelhøg',),
'middelhøy': ('middelhøy',),
'middelhøye': ('middelhøy',),
'middelhøyere': ('middelhøy',),
'middelhøyest': ('middelhøy',),
'middelhøyeste': ('middelhøy',),
'middelhøyt': ('middelhøy',),
'middelmådig': ('middelmådig',),
'middelmådige': ('middelmådig',),
'middelmådigere': ('middelmådig',),
'middelmådigst': ('middelmådig',),
'middelmådigste': ('middelmådig',),
'middelmåtig': ('middelmåtig',),
'middelmåtige': ('middelmåtig',),
'middelmåtigere': ('middelmåtig',),
'middelmåtigst': ('middelmåtig',),
'middelmåtigste': ('middelmåtig',),
'middels': ('middels',),
'middelshøg': ('middelshøg',),
'middelshøge': ('middelshøg',),
'middelshøgere': ('middelshøg',),
'middelshøgest': ('middelshøg',),
'middelshøgeste': ('middelshøg',),
'middelshøgre': ('middelshøg',),
'middelshøgst': ('middelshøg',),
'middelshøgste': ('middelshøg',),
'middelshøgt': ('middelshøg',),
'middelshøy': ('middelshøy',),
'middelshøye': ('middelshøy',),
'middelshøyere': ('middelshøy',),
'middelshøyest': ('middelshøy',),
'middelshøyeste': ('middelshøy',),
'middelshøyt': ('middelshøy',),
'middelsstor': ('middelsstor',),
'middelsstore': ('middelsstor',),
'middelsstort': ('middelsstor',),
'middelsstørre': ('middelsstor',),
'middelsstørst': ('middelsstor',),
'middelsstørste': ('middelsstor',),
'middelstor': ('middelstor',),
'middelstore': ('middelstor',),
'middelstort': ('middelstor',),
'middelstørre': ('middelstor',),
'middelstørst': ('middelstor',),
'middelstørste': ('middelstor',),
'midi': ('midi',),
'midla': ('midle',),
'midlede': ('midle',),
'midlende': ('midle',),
'midlet': ('midle',),
'midlete': ('midle',),
'midlere': ('midlere',),
'midlertidig': ('midlertidig',),
'midlertidige': ('midlertidig',),
'midlertidigere': ('midlertidig',),
'midlertidigst': ('midlertidig',),
'midlertidigste': ('midlertidig',),
'midterst': ('midterst',),
'midterste': ('midterst',),
'midterst': ('midtre',),
'midterste': ('midtre',),
'midtre': ('midtre',),
'megen': ('mige',),
'meget': ('mige',),
'megne': ('mige',),
'migende': ('mige',),
'migrerende': ('migrere',),
'migrert': ('migrere',),
'migrerte': ('migrere',),
'mikrobiell': ('mikrobiell',),
'mikrobielle': ('mikrobiell',),
'mikrobiellere': ('mikrobiell',),
'mikrobiellest': ('mikrobiell',),
'mikrobielleste': ('mikrobiell',),
'mikrobielt': ('mikrobiell',),
'mikrobiologisk': ('mikrobiologisk',),
'mikrobiologiske': ('mikrobiologisk',),
'mikrobiologiskere': ('mikrobiologisk',),
'mikrobiologiskest': ('mikrobiologisk',),
'mikrobiologiskeste': ('mikrobiologisk',),
'mikroskoperende': ('mikroskopere',),
'mikroskopert': ('mikroskopere',),
'mikroskoperte': ('mikroskopere',),
'mikroskopisk': ('mikroskopisk',),
'mikroskopiske': ('mikroskopisk',),
'mikroskopiskere': ('mikroskopisk',),
'mikroskopiskest': ('mikroskopisk',),
'mikroskopiskeste': ('mikroskopisk',),
'miksa': ('mikse',),
'miksede': ('mikse',),
'miksende': ('mikse',),
'mikset': ('mikse',),
'miksete': ('mikse',),
'milanesisk': ('milanesisk',),
'milanesiske': ('milanesisk',),
'milanesiskere': ('milanesisk',),
'milanesiskest': ('milanesisk',),
'milanesiskeste': ('milanesisk',),
'mild': ('mild',),
'milde': ('mild',),
'mildere': ('mild',),
'mildest': ('mild',),
'mildeste': ('mild',),
'mildt': ('mild',),
'mildna': ('mildne',),
'mildnede': ('mildne',),
'mildnende': ('mildne',),
'mildnet': ('mildne',),
'mildnete': ('mildne',),
'milelang': ('milelang',),
'milelange': ('milelang',),
'milelangt': ('milelang',),
'milelenger': ('milelang',),
'milelengre': ('milelang',),
'milelengst': ('milelang',),
'milelengste': ('milelang',),
'milevid': ('milevid',),
'milevide': ('milevid',),
'milevidere': ('milevid',),
'milevidest': ('milevid',),
'milevideste': ('milevid',),
'milevidt': ('milevid',),
'militant': ('militant',),
'militante': ('militant',),
'militantere': ('militant',),
'militantest': ('militant',),
'militanteste': ('militant',),
'militariserende': ('militarisere',),
'militarisert': ('militarisere',),
'militariserte': ('militarisere',),
'militaristisk': ('militaristisk',),
'militaristiske': ('militaristisk',),
'militaristiskere': ('militaristisk',),
'militaristiskest': ('militaristisk',),
'militaristiskeste': ('militaristisk',),
'militær': ('militær',),
'militære': ('militær',),
'militærere': ('militær',),
'militærest': ('militær',),
'militæreste': ('militær',),
'militært': ('militær',),
'miljøbestemt': ('miljøbestemt',),
'miljøbestemte': ('miljøbestemt',),
'miljøbestemtere': ('miljøbestemt',),
'miljøbestemtest': ('miljøbestemt',),
'miljøbestemteste': ('miljøbestemt',),
'miljøskada': ('miljøskada',),
'miljøskadd': ('miljøskadd',),
'miljøskadde': ('miljøskadd',),
'miljøskaddere': ('miljøskadd',),
'miljøskaddest': ('miljøskadd',),
'miljøskaddeste': ('miljøskadd',),
'miljøskadelig': ('miljøskadelig',),
'miljøskadelige': ('miljøskadelig',),
'miljøskadeligere': ('miljøskadelig',),
'miljøskadeligst': ('miljøskadelig',),
'miljøskadeligste': ('miljøskadelig',),
'miljøskadede': ('miljøskadet',),
'miljøskadet': ('miljøskadet',),
'miljøskadete': ('miljøskadet',),
'miljøskadetere': ('miljøskadet',),
'miljøskadetest': ('miljøskadet',),
'miljøskadeteste': ('miljøskadet',),
'miljøvennlig': ('miljøvennlig',),
'miljøvennlige': ('miljøvennlig',),
'miljøvennligere': ('miljøvennlig',),
'miljøvennligst': ('miljøvennlig',),
'miljøvennligste': ('miljøvennlig',),
'milliarddels': ('milliarddels',),
'milliardte': ('milliardte',),
'milliondels': ('milliondels',),
'millionte': ('millionte',),
'mima': ('mime',),
'mimede': ('mime',),
'mimende': ('mime',),
'mimet': ('mime',),
'mimete': ('mime',),
'mimisk': ('mimisk',),
'mimiske': ('mimisk',),
'mimiskere': ('mimisk',),
'mimiskest': ('mimisk',),
'mimiskeste': ('mimisk',),
'mimra': ('mimre',),
'mimrede': ('mimre',),
'mimrende': ('mimre',),
'mimret': ('mimre',),
'mimrete': ('mimre',),
'mindre': ('mindre',),
'mindreverdig': ('mindreverdig',),
'mindreverdige': ('mindreverdig',),
'mindreverdigere': ('mindreverdig',),
'mindreverdigst': ('mindreverdig',),
'mindreverdigste': ('mindreverdig',),
'mindreårig': ('mindreårig',),
'mindreårige': ('mindreårig',),
'mindreårigere': ('mindreårig',),
'mindreårigst': ('mindreårig',),
'mindreårigste': ('mindreårig',),
'mina': ('mine',),
'minede': ('mine',),
'minende': ('mine',),
'minet': ('mine',),
'minete': ('mine',),
'mint': ('mine',),
'minte': ('mine',),
'minelagt': ('minelegge',),
'minelagte': ('minelegge',),
'mineleggende': ('minelegge',),
'mineralogisk': ('mineralogisk',),
'mineralogiske': ('mineralogisk',),
'mineralogiskere': ('mineralogisk',),
'mineralogiskest': ('mineralogisk',),
'mineralogiskeste': ('mineralogisk',),
'mineralsk': ('mineralsk',),
'mineralske': ('mineralsk',),
'mineralskere': ('mineralsk',),
'mineralskest': ('mineralsk',),
'mineralskeste': ('mineralsk',),
'minerende': ('minere',),
'minert': ('minere',),
'minerte': ('minere',),
'mini': ('mini',),
'miniatyriserende': ('miniatyrisere',),
'miniatyrisert': ('miniatyrisere',),
'miniatyriserte': ('miniatyrisere',),
'minimal': ('minimal',),
'minimale': ('minimal',),
'minimalere': ('minimal',),
'minimalest': ('minimal',),
'minimaleste': ('minimal',),
'minimalt': ('minimal',),
'minimaliserende': ('minimalisere',),
'minimalisert': ('minimalisere',),
'minimaliserte': ('minimalisere',),
'minimerende': ('minimere',),
'minimert': ('minimere',),
'minimerte': ('minimere',),
'ministeriell': ('ministeriell',),
'ministerielle': ('ministeriell',),
'ministeriellere': ('ministeriell',),
'ministeriellest': ('ministeriell',),
'ministerielleste': ('ministeriell',),
'ministerielt': ('ministeriell',),
'minka': ('minke',),
'minkede': ('minke',),
'minkende': ('minke',),
'minket': ('minke',),
'minkete': ('minke',),
'minna': ('minne',),
'minnede': ('minne',),
'minnende': ('minne',),
'minnet': ('minne',),
'minnete': ('minne',),
'mint': ('minne',),
'minte': ('minne',),
'minnelig': ('minnelig',),
'minnelige': ('minnelig',),
'minneligere': ('minnelig',),
'minneligst': ('minnelig',),
'minneligste': ('minnelig',),
'minnerik': ('minnerik',),
'minnerike': ('minnerik',),
'minnerikere': ('minnerik',),
'minnerikest': ('minnerik',),
'minnerikeste': ('minnerik',),
'minnerikt': ('minnerik',),
'minneverdig': ('minneverdig',),
'minneverdige': ('minneverdig',),
'minneverdigere': ('minneverdig',),
'minneverdigst': ('minneverdig',),
'minneverdigste': ('minneverdig',),
'minska': ('minske',),
'minskede': ('minske',),
'minskende': ('minske',),
'minsket': ('minske',),
'minskete': ('minske',),
'minst': ('minst',),
'minste': ('minst',),
'minutiøs': ('minutiøs',),
'minutiøse': ('minutiøs',),
'minutiøsere': ('minutiøs',),
'minutiøsest': ('minutiøs',),
'minutiøseste': ('minutiøs',),
'minutiøst': ('minutiøs',),
'mirakuløs': ('mirakuløs',),
'mirakuløse': ('mirakuløs',),
'mirakuløsere': ('mirakuløs',),
'mirakuløsest': ('mirakuløs',),
'mirakuløseste': ('mirakuløs',),
'mirakuløst': ('mirakuløs',),
'misantropisk': ('misantropisk',),
'misantropiske': ('misantropisk',),
'misantropiskere': ('misantropisk',),
'misantropiskest': ('misantropisk',),
'misantropiskeste': ('misantropisk',),
'misbilliga': ('misbillige',),
'misbilligede': ('misbillige',),
'misbilligende': ('misbillige',),
'misbilliget': ('misbillige',),
'misbilligete': ('misbillige',),
'misbrukende': ('misbruke',),
'misbrukt': ('misbruke',),
'misbrukte': ('misbruke',),
'misdanna': ('misdanna',),
'misdannede': ('misdannet',),
'misdannet': ('misdannet',),
'misdannete': ('misdannet',),
'misdannetere': ('misdannet',),
'misdannetest': ('misdannet',),
'misdanneteste': ('misdannet',),
'miserabel': ('miserabel',),
'miserabelt': ('miserabel',),
'miserable': ('miserabel',),
'miserablere': ('miserabel',),
'miserablest': ('miserabel',),
'miserableste': ('miserabel',),
'misfarende': ('misfare',),
'misfart': ('misfare',),
'misfarte': ('misfare',),
'misfarga': ('misfarge',),
'misfargede': ('misfarge',),
'misfargende': ('misfarge',),
'misfarget': ('misfarge',),
'misfargete': ('misfarge',),
'misfornøgd': ('misfornøgd',),
'misfornøgde': ('misfornøgd',),
'misfornøgdere': ('misfornøgd',),
'misfornøgdest': ('misfornøgd',),
'misfornøgdeste': ('misfornøgd',),
'misfornøyd': ('misfornøyd',),
'misfornøyde': ('misfornøyd',),
'misfornøydere': ('misfornøyd',),
'misfornøydest': ('misfornøyd',),
'misfornøydeste': ('misfornøyd',),
'misforstående': ('misforstå',),
'misforstått': ('misforstå',),
'misforståtte': ('misforstå',),
'mishaga': ('mishage',),
'mishagede': ('mishage',),
'mishagende': ('mishage',),
'mishaget': ('mishage',),
'mishagete': ('mishage',),
'mishandla': ('mishandle',),
'mishandlede': ('mishandle',),
'mishandlende': ('mishandle',),
'mishandlet': ('mishandle',),
'mishandlete': ('mishandle',),
'mishørende': ('mishøre',),
'mishørt': ('mishøre',),
'mishørte': ('mishøre',),
'misjonerende': ('misjonere',),
'misjonert': ('misjonere',),
'misjonerte': ('misjonere',),
'miskjennende': ('miskjenne',),
'miskjent': ('miskjenne',),
'miskjente': ('miskjenne',),
'miskledd': ('miskle',),
'miskledde': ('miskle',),
'miskleende': ('miskle',),
'miskunnende': ('miskunne',),
'miskunt': ('miskunne',),
'miskunte': ('miskunne',),
'miskunnelig': ('miskunnelig',),
'miskunnelige': ('miskunnelig',),
'miskunneligere': ('miskunnelig',),
'miskunneligst': ('miskunnelig',),
'miskunneligste': ('miskunnelig',),
'mislig': ('mislig',),
'mislige': ('mislig',),
'misligere': ('mislig',),
'misligst': ('mislig',),
'misligste': ('mislig',),
'misligholdende': ('misligholde',),
'misligholdt': ('misligholde',),
'misligholdte': ('misligholde',),
'mislikende': ('mislike',),
'mislikt': ('mislike',),
'mislikte': ('mislike',),
'mislykka': ('mislykka',),
'mislykkede': ('mislykket',),
'mislykket': ('mislykket',),
'mislykkete': ('mislykket',),
'mislykketere': ('mislykket',),
'mislykketest': ('mislykket',),
'mislykketeste': ('mislykket',),
'mislykt': ('mislykt',),
'mislykte': ('mislykt',),
'mislyktere': ('mislykt',),
'mislyktest': ('mislykt',),
'mislykteste': ('mislykt',),
'mismodig': ('mismodig',),
'mismodige': ('mismodig',),
'mismodigere': ('mismodig',),
'mismodigst': ('mismodig',),
'mismodigste': ('mismodig',),
'misnøgd': ('misnøgd',),
'misnøgde': ('misnøgd',),
'misnøgdere': ('misnøgd',),
'misnøgdest': ('misnøgd',),
'misnøgdeste': ('misnøgd',),
'misnøyd': ('misnøyd',),
'misnøyde': ('misnøyd',),
'misnøydere': ('misnøyd',),
'misnøydest': ('misnøyd',),
'misnøydeste': ('misnøyd',),
'misoppfatta': ('misoppfatte',),
'misoppfattede': ('misoppfatte',),
'misoppfattende': ('misoppfatte',),
'misoppfattet': ('misoppfatte',),
'misoppfattete': ('misoppfatte',),
'misregna': ('misregne',),
'misregnede': ('misregne',),
'misregnende': ('misregne',),
'misregnet': ('misregne',),
'misregnete': ('misregne',),
'misrekna': ('misrekne',),
'misreknede': ('misrekne',),
'misreknende': ('misrekne',),
'misreknet': ('misrekne',),
'misreknete': ('misrekne',),
'missnakka': ('missnakke',),
'missnakkede': ('missnakke',),
'missnakkende': ('missnakke',),
'missnakket': ('missnakke',),
'missnakkete': ('missnakke',),
'mistakende': ('mista',),
'mistatt': ('mista',),
'mistatte': ('mista',),
'mista': ('miste',),
'mistede': ('miste',),
'mistende': ('miste',),
'mistet': ('miste',),
'mistete': ('miste',),
'mistenkende': ('mistenke',),
'mistenkt': ('mistenke',),
'mistenkte': ('mistenke',),
'mistenkelig': ('mistenkelig',),
'mistenkelige': ('mistenkelig',),
'mistenkeligere': ('mistenkelig',),
'mistenkeligst': ('mistenkelig',),
'mistenkeligste': ('mistenkelig',),
'mistenkeliggjort': ('mistenkeliggjøre',),
'mistenkeliggjorte': ('mistenkeliggjøre',),
'mistenkeliggjørende': ('mistenkeliggjøre',),
'mistenksom': ('mistenksom',),
'mistenksomme': ('mistenksom',),
'mistenksommere': ('mistenksom',),
'mistenksomst': ('mistenksom',),
'mistenksomste': ('mistenksom',),
'mistenksomt': ('mistenksom',),
'mistilpassa': ('mistilpassa',),
'mistilpassede': ('mistilpasset',),
'mistilpasset': ('mistilpasset',),
'mistilpassete': ('mistilpasset',),
'mistilpassetere': ('mistilpasset',),
'mistilpassetest': ('mistilpasset',),
'mistilpasseteste': ('mistilpasset',),
'mistolka': ('mistolke',),
'mistolkede': ('mistolke',),
'mistolkende': ('mistolke',),
'mistolket': ('mistolke',),
'mistolkete': ('mistolke',),
'mistrodd': ('mistro',),
'mistrodde': ('mistro',),
'mistroende': ('mistro',),
'mistroisk': ('mistroisk',),
'mistroiske': ('mistroisk',),
'mistroiskere': ('mistroisk',),
'mistroiskest': ('mistroisk',),
'mistroiskeste': ('mistroisk',),
'mistrudd': ('mistru',),
'mistrudde': ('mistru',),
'mistruende': ('mistru',),
'mistruen': ('mistruen',),
'mistruene': ('mistruen',),
'mistruenere': ('mistruen',),
'mistruenest': ('mistruen',),
'mistrueneste': ('mistruen',),
'mistruenne': ('mistruen',),
'mistruennere': ('mistruen',),
'mistruennest': ('mistruen',),
'mistruenneste': ('mistruen',),
'mistruent': ('mistruen',),
'mistruisk': ('mistruisk',),
'mistruiske': ('mistruisk',),
'mistruiskere': ('mistruisk',),
'mistruiskest': ('mistruisk',),
'mistruiskeste': ('mistruisk',),
'mistrøstig': ('mistrøstig',),
'mistrøstige': ('mistrøstig',),
'mistrøstigere': ('mistrøstig',),
'mistrøstigst': ('mistrøstig',),
'mistrøstigste': ('mistrøstig',),
'misunnede': ('misunne',),
'misunnende': ('misunne',),
'misunnet': ('misunne',),
'misunnete': ('misunne',),
'misunt': ('misunne',),
'misunte': ('misunne',),
'misunnelig': ('misunnelig',),
'misunnelige': ('misunnelig',),
'misunneligere': ('misunnelig',),
'misunneligst': ('misunnelig',),
'misunneligste': ('misunnelig',),
'misunnelsesverdig': ('misunnelsesverdig',),
'misunnelsesverdige': ('misunnelsesverdig',),
'misunnelsesverdigere': ('misunnelsesverdig',),
'misunnelsesverdigst': ('misunnelsesverdig',),
'misunnelsesverdigste': ('misunnelsesverdig',),
'misvisende': ('misvisende',),
'mjaua': ('mjaue',),
'mjauede': ('mjaue',),
'mjauende': ('mjaue',),
'mjauet': ('mjaue',),
'mjauete': ('mjaue',),
'mjuk': ('mjuk',),
'mjuke': ('mjuk',),
'mjukere': ('mjuk',),
'mjukest': ('mjuk',),
'mjukeste': ('mjuk',),
'mjukt': ('mjuk',),
'mjuklanda': ('mjuklande',),
'mjuklandede': ('mjuklande',),
'mjuklandende': ('mjuklande',),
'mjuklandet': ('mjuklande',),
'mjuklandete': ('mjuklande',),
'mjukna': ('mjukne',),
'mjuknede': ('mjukne',),
'mjuknende': ('mjukne',),
'mjuknet': ('mjukne',),
'mjuknete': ('mjukne',),
'mjukna': ('mjukne',),
'mjuknede': ('mjukne',),
'mjuknende': ('mjukne',),
'mjuknet': ('mjukne',),
'mjuknete': ('mjukne',),
'mjå': ('mjå',),
'mjåe': ('mjå',),
'mjåere': ('mjå',),
'mjåest': ('mjå',),
'mjåeste': ('mjå',),
'mjått': ('mjå',),
'mjøla': ('mjøle',),
'mjølede': ('mjøle',),
'mjølende': ('mjøle',),
'mjølet': ('mjøle',),
'mjølete': ('mjøle',),
'mjølt': ('mjøle',),
'mjølte': ('mjøle',),
'mjølen': ('mjølen',),
'mjølent': ('mjølen',),
'mjølne': ('mjølen',),
'mjølnere': ('mjølen',),
'mjølnest': ('mjølen',),
'mjølneste': ('mjølen',),
'mjølet': ('mjølet',),
'mjølete': ('mjølet',),
'mjøletere': ('mjølet',),
'mjøletest': ('mjølet',),
'mjøleteste': ('mjølet',),
'mjølete': ('mjølete',),
'mjølka': ('mjølke',),
'mjølkede': ('mjølke',),
'mjølkende': ('mjølke',),
'mjølket': ('mjølke',),
'mjølkete': ('mjølke',),
'mjølkeblå': ('mjølkeblå',),
'mjølkeblåe': ('mjølkeblå',),
'mjølkeblåere': ('mjølkeblå',),
'mjølkeblåest': ('mjølkeblå',),
'mjølkeblåeste': ('mjølkeblå',),
'mjølkeblått': ('mjølkeblå',),
'mjølkeblå': ('mjølkeblå',),
'mjølkeblåe': ('mjølkeblå',),
'mjølkeblåere': ('mjølkeblå',),
'mjølkeblåest': ('mjølkeblå',),
'mjølkeblåeste': ('mjølkeblå',),
'mjølkeblått': ('mjølkeblå',),
'mjølkehvit': ('mjølkehvit',),
'mjølkehvite': ('mjølkehvit',),
'mjølkehvitere': ('mjølkehvit',),
'mjølkehvitest': ('mjølkehvit',),
'mjølkehviteste': ('mjølkehvit',),
'mjølkehvitt': ('mjølkehvit',),
'mjølkekvit': ('mjølkekvit',),
'mjølkekvite': ('mjølkekvit',),
'mjølkekvitere': ('mjølkekvit',),
'mjølkekvitest': ('mjølkekvit',),
'mjølkekviteste': ('mjølkekvit',),
'mjølkekvitt': ('mjølkekvit',),
'mjølkesprengt': ('mjølkesprengt',),
'mjølkesprengte': ('mjølkesprengt',),
'mjølkesprengtere': ('mjølkesprengt',),
'mjølkesprengtest': ('mjølkesprengt',),
'mjølkesprengteste': ('mjølkesprengt',),
'mjøllen': ('mjøllen',),
'mjøllent': ('mjøllen',),
'mjølne': ('mjøllen',),
'mjølnere': ('mjøllen',),
'mjølnest': ('mjøllen',),
'mjølneste': ('mjøllen',),
'mnemisk': ('mnemisk',),
'mnemiske': ('mnemisk',),
'mnemiskere': ('mnemisk',),
'mnemiskest': ('mnemisk',),
'mnemiskeste': ('mnemisk',),
'mnemoteknisk': ('mnemoteknisk',),
'mnemotekniske': ('mnemoteknisk',),
'mnemotekniskere': ('mnemoteknisk',),
'mnemotekniskest': ('mnemoteknisk',),
'mnemotekniskeste': ('mnemoteknisk',),
'mobba': ('mobbe',),
'mobbede': ('mobbe',),
'mobbende': ('mobbe',),
'mobbet': ('mobbe',),
'mobbete': ('mobbe',),
'mobil': ('mobil',),
'mobile': ('mobil',),
'mobilere': ('mobil',),
'mobilest': ('mobil',),
'mobileste': ('mobil',),
'mobilt': ('mobil',),
'mobiliserende': ('mobilisere',),
'mobilisert': ('mobilisere',),
'mobiliserte': ('mobilisere',),
'mod': ('mod',),
'mode': ('mod',),
'modere': ('mod',),
'modest': ('mod',),
'modeste': ('mod',),
'modal': ('modal',),
'modale': ('modal',),
'modalere': ('modal',),
'modalest': ('modal',),
'modaleste': ('modal',),
'modalt': ('modal',),
'modellerende': ('modellere',),
'modellert': ('modellere',),
'modellerte': ('modellere',),
'moden': ('moden',),
'modent': ('moden',),
'modne': ('moden',),
'modnere': ('moden',),
'modnest': ('moden',),
'modneste': ('moden',),
'moderat': ('moderat',),
'moderate': ('moderat',),
'moderatere': ('moderat',),
'moderatest': ('moderat',),
'moderateste': ('moderat',),
'modererende': ('moderere',),
'moderert': ('moderere',),
'modererte': ('moderere',),
'moderlig': ('moderlig',),
'moderlige': ('moderlig',),
'moderligere': ('moderlig',),
'moderligst': ('moderlig',),
'moderligste': ('moderlig',),
'moderne': ('moderne',),
'moderniserende': ('modernisere',),
'modernisert': ('modernisere',),
'moderniserte': ('modernisere',),
'modernistisk': ('modernistisk',),
'modernistiske': ('modernistisk',),
'modernistiskere': ('modernistisk',),
'modernistiskest': ('modernistisk',),
'modernistiskeste': ('modernistisk',),
'modest': ('modest',),
'modeste': ('modest',),
'modestere': ('modest',),
'modestest': ('modest',),
'modesteste': ('modest',),
'modifiserende': ('modifisere',),
'modifisert': ('modifisere',),
'modifiserte': ('modifisere',),
'modig': ('modig',),
'modige': ('modig',),
'modigere': ('modig',),
'modigst': ('modig',),
'modigste': ('modig',),
'modna': ('modne',),
'modnede': ('modne',),
'modnende': ('modne',),
'modnet': ('modne',),
'modnete': ('modne',),
'modulerende': ('modulere',),
'modulert': ('modulere',),
'modulerte': ('modulere',),
'modulær': ('modulær',),
'modulære': ('modulær',),
'modulærere': ('modulær',),
'modulærest': ('modulær',),
'modulæreste': ('modulær',),
'modulært': ('modulær',),
'mokkafarga': ('mokkafarga',),
'mokkafargede': ('mokkafarget',),
'mokkafarget': ('mokkafarget',),
'mokkafargete': ('mokkafarget',),
'mokkafargetere': ('mokkafarget',),
'mokkafargetest': ('mokkafarget',),
'mokkafargeteste': ('mokkafarget',),
'molboaktig': ('molboaktig',),
'molboaktige': ('molboaktig',),
'molboaktigere': ('molboaktig',),
'molboaktigst': ('molboaktig',),
'molboaktigste': ('molboaktig',),
'molda': ('molde',),
'moldede': ('molde',),
'moldende': ('molde',),
'moldet': ('molde',),
'moldete': ('molde',),
'moldet': ('moldet',),
'moldete': ('moldet',),
'moldetere': ('moldet',),
'moldetest': ('moldet',),
'moldeteste': ('moldet',),
'moldete': ('moldete',),
'moldfattig': ('moldfattig',),
'moldfattige': ('moldfattig',),
'moldfattigere': ('moldfattig',),
'moldfattigst': ('moldfattig',),
'moldfattigste': ('moldfattig',),
'moldovsk': ('moldovsk',),
'moldovske': ('moldovsk',),
'moldovskere': ('moldovsk',),
'moldovskest': ('moldovsk',),
'moldovskeste': ('moldovsk',),
'molefonken': ('molefonken',),
'molefonkent': ('molefonken',),
'molefonkne': ('molefonken',),
'molefonknere': ('molefonken',),
'molefonknest': ('molefonken',),
'molefonkneste': ('molefonken',),
'molekylær': ('molekylær',),
'molekylære': ('molekylær',),
'molekylærere': ('molekylær',),
'molekylærest': ('molekylær',),
'molekylæreste': ('molekylær',),
'molekylært': ('molekylær',),
'molesterende': ('molestere',),
'molestert': ('molestere',),
'molesterte': ('molestere',),
'molukkisk': ('molukkisk',),
'molukkiske': ('molukkisk',),
'molukkiskere': ('molukkisk',),
'molukkiskest': ('molukkisk',),
'molukkiskeste': ('molukkisk',),
'momentan': ('momentan',),
'momentane': ('momentan',),
'momentanere': ('momentan',),
'momentanest': ('momentan',),
'momentaneste': ('momentan',),
'momentant': ('momentan',),
'mompa': ('mompe',),
'mompede': ('mompe',),
'mompende': ('mompe',),
'mompet': ('mompe',),
'mompete': ('mompe',),
'monarkisk': ('monarkisk',),
'monarkiske': ('monarkisk',),
'monarkiskere': ('monarkisk',),
'monarkiskest': ('monarkisk',),
'monarkiskeste': ('monarkisk',),
'monden': ('monden',),
'mondene': ('monden',),
'mondenere': ('monden',),
'mondenest': ('monden',),
'mondeneste': ('monden',),
'mondent': ('monden',),
'monegaskisk': ('monegaskisk',),
'monegaskiske': ('monegaskisk',),
'monegaskiskere': ('monegaskisk',),
'monegaskiskest': ('monegaskisk',),
'monegaskiskeste': ('monegaskisk',),
'monetær': ('monetær',),
'monetære': ('monetær',),
'monetærere': ('monetær',),
'monetærest': ('monetær',),
'monetæreste': ('monetær',),
'monetært': ('monetær',),
'mongoloid': ('mongoloid',),
'mongoloide': ('mongoloid',),
'mongoloidere': ('mongoloid',),
'mongoloidest': ('mongoloid',),
'mongoloideste': ('mongoloid',),
'mongolsk': ('mongolsk',),
'mongolske': ('mongolsk',),
'mongolskere': ('mongolsk',),
'mongolskest': ('mongolsk',),
'mongolskeste': ('mongolsk',),
'monistisk': ('monistisk',),
'monistiske': ('monistisk',),
'monistiskere': ('monistisk',),
'monistiskest': ('monistisk',),
'monistiskeste': ('monistisk',),
'monna': ('monne',),
'monnede': ('monne',),
'monnende': ('monne',),
'monnet': ('monne',),
'monnete': ('monne',),
'monoftongerende': ('monoftongere',),
'monoftongert': ('monoftongere',),
'monoftongerte': ('monoftongere',),
'monogam': ('monogam',),
'monogame': ('monogam',),
'monogamere': ('monogam',),
'monogamest': ('monogam',),
'monogameste': ('monogam',),
'monogamt': ('monogam',),
'monolittisk': ('monolittisk',),
'monolittiske': ('monolittisk',),
'monolittiskere': ('monolittisk',),
'monolittiskest': ('monolittisk',),
'monolittiskeste': ('monolittisk',),
'monologisk': ('monologisk',),
'monologiske': ('monologisk',),
'monologiskere': ('monologisk',),
'monologiskest': ('monologisk',),
'monologiskeste': ('monologisk',),
'monoman': ('monoman',),
'monomane': ('monoman',),
'monomanere': ('monoman',),
'monomanest': ('monoman',),
'monomaneste': ('monoman',),
'monomant': ('monoman',),
'monopoliserende': ('monopolisere',),
'monopolisert': ('monopolisere',),
'monopoliserte': ('monopolisere',),
'monopolistisk': ('monopolistisk',),
'monopolistiske': ('monopolistisk',),
'monopolistiskere': ('monopolistisk',),
'monopolistiskest': ('monopolistisk',),
'monopolistiskeste': ('monopolistisk',),
'monoteistisk': ('monoteistisk',),
'monoteistiske': ('monoteistisk',),
'monoteistiskere': ('monoteistisk',),
'monoteistiskest': ('monoteistisk',),
'monoteistiskeste': ('monoteistisk',),
'monoton': ('monoton',),
'monotone': ('monoton',),
'monotonere': ('monoton',),
'monotonest': ('monoton',),
'monotoneste': ('monoton',),
'monotont': ('monoton',),
'monstrøs': ('monstrøs',),
'monstrøse': ('monstrøs',),
'monstrøsere': ('monstrøs',),
'monstrøsest': ('monstrøs',),
'monstrøseste': ('monstrøs',),
'monstrøst': ('monstrøs',),
'montenegrinsk': ('montenegrinsk',),
'montenegrinske': ('montenegrinsk',),
'montenegrinskere': ('montenegrinsk',),
'montenegrinskest': ('montenegrinsk',),
'montenegrinskeste': ('montenegrinsk',),
'monterende': ('montere',),
'montert': ('montere',),
'monterte': ('montere',),
'monumental': ('monumental',),
'monumentale': ('monumental',),
'monumentalere': ('monumental',),
'monumentalest': ('monumental',),
'monumentaleste': ('monumental',),
'monumentalt': ('monumental',),
'moppa': ('moppe',),
'moppede': ('moppe',),
'moppende': ('moppe',),
'moppet': ('moppe',),
'moppete': ('moppe',),
'moraliserende': ('moralisere',),
'moralisert': ('moralisere',),
'moraliserte': ('moralisere',),
'moralistisk': ('moralistisk',),
'moralistiske': ('moralistisk',),
'moralistiskere': ('moralistisk',),
'moralistiskest': ('moralistisk',),
'moralistiskeste': ('moralistisk',),
'moralsk': ('moralsk',),
'moralske': ('moralsk',),
'moralskere': ('moralsk',),
'moralskest': ('moralsk',),
'moralskeste': ('moralsk',),
'morbid': ('morbid',),
'morbide': ('morbid',),
'morbidere': ('morbid',),
'morbidest': ('morbid',),
'morbideste': ('morbid',),
'morderisk': ('morderisk',),
'morderiske': ('morderisk',),
'morderiskere': ('morderisk',),
'morderiskest': ('morderisk',),
'morderiskeste': ('morderisk',),
'mora': ('more',),
'morede': ('more',),
'morende': ('more',),
'moret': ('more',),
'morete': ('more',),
'mora': ('more',),
'morede': ('more',),
'morende': ('more',),
'moret': ('more',),
'morete': ('more',),
'mort': ('more',),
'morte': ('more',),
'morfologisk': ('morfologisk',),
'morfologiske': ('morfologisk',),
'morfologiskere': ('morfologisk',),
'morfologiskest': ('morfologisk',),
'morfologiskeste': ('morfologisk',),
'morganatisk': ('morganatisk',),
'morganatiske': ('morganatisk',),
'morganatiskere': ('morganatisk',),
'morganatiskest': ('morganatisk',),
'morganatiskeste': ('morganatisk',),
'morgengretne': ('morgengretten',),
'morgengretnere': ('morgengretten',),
'morgengretnest': ('morgengretten',),
'morgengretneste': ('morgengretten',),
'morgengretten': ('morgengretten',),
'morgengrettent': ('morgengretten',),
'morgna': ('morgne',),
'morgnede': ('morgne',),
'morgnende': ('morgne',),
'morgnet': ('morgne',),
'morgnete': ('morgne',),
'morken': ('morken',),
'morkent': ('morken',),
'morkne': ('morken',),
'morknere': ('morken',),
'morknest': ('morken',),
'morkneste': ('morken',),
'morkna': ('morkne',),
'morknede': ('morkne',),
'morknende': ('morkne',),
'morknet': ('morkne',),
'morknete': ('morkne',),
'morlaus': ('morlaus',),
'morlause': ('morlaus',),
'morlausere': ('morlaus',),
'morlausest': ('morlaus',),
'morlauseste': ('morlaus',),
'morlaust': ('morlaus',),
'morløs': ('morløs',),
'morløse': ('morløs',),
'morløsere': ('morløs',),
'morløsest': ('morløs',),
'morløseste': ('morløs',),
'morløst': ('morløs',),
'mormonsk': ('mormonsk',),
'mormonske': ('mormonsk',),
'mormonskere': ('mormonsk',),
'mormonskest': ('mormonsk',),
'mormonskeste': ('mormonsk',),
'moro': ('moro',),
'morosam': ('morosam',),
'morosamme': ('morosam',),
'morosammere': ('morosam',),
'morosamst': ('morosam',),
'morosamste': ('morosam',),
'morosamt': ('morosam',),
'morsa': ('morse',),
'morsede': ('morse',),
'morsende': ('morse',),
'morset': ('morse',),
'morsete': ('morse',),
'morsk': ('morsk',),
'morske': ('morsk',),
'morskere': ('morsk',),
'morskest': ('morsk',),
'morskeste': ('morsk',),
'morskt': ('morsk',),
'morska': ('morske',),
'morskede': ('morske',),
'morskende': ('morske',),
'morsket': ('morske',),
'morskete': ('morske',),
'morsken': ('morsken',),
'morskent': ('morsken',),
'morskne': ('morsken',),
'morsknere': ('morsken',),
'morsknest': ('morsken',),
'morskneste': ('morsken',),
'morsom': ('morsom',),
'morsomme': ('morsom',),
'morsommere': ('morsom',),
'morsomst': ('morsom',),
'morsomste': ('morsom',),
'morsomt': ('morsom',),
'mortifiserende': ('mortifisere',),
'mortifisert': ('mortifisere',),
'mortifiserte': ('mortifisere',),
'mosaisk': ('mosaisk',),
'mosaiske': ('mosaisk',),
'mosaiskere': ('mosaisk',),
'mosaiskest': ('mosaisk',),
'mosaiskeste': ('mosaisk',),
'mosambikisk': ('mosambikisk',),
'mosambikiske': ('mosambikisk',),
'mosambikiskere': ('mosambikisk',),
'mosambikiskest': ('mosambikisk',),
'mosambikiskeste': ('mosambikisk',),
'mosegrodd': ('mosegrodd',),
'mosegrodde': ('mosegrodd',),
'mosegroddere': ('mosegrodd',),
'mosegroddest': ('mosegrodd',),
'mosegroddeste': ('mosegrodd',),
'mosegrøn': ('mosegrøn',),
'mosegrøne': ('mosegrøn',),
'mosegrønere': ('mosegrøn',),
'mosegrønest': ('mosegrøn',),
'mosegrøneste': ('mosegrøn',),
'mosegrønt': ('mosegrøn',),
'mosegrønn': ('mosegrønn',),
'mosegrønne': ('mosegrønn',),
'mosegrønnere': ('mosegrønn',),
'mosegrønnest': ('mosegrønn',),
'mosegrønneste': ('mosegrønn',),
'mosegrønt': ('mosegrønn',),
'moset': ('moset',),
'mosete': ('moset',),
'mosetere': ('moset',),
'mosetest': ('moset',),
'moseteste': ('moset',),
'mosete': ('mosete',),
'mosjonerende': ('mosjonere',),
'mosjonert': ('mosjonere',),
'mosjonerte': ('mosjonere',),
'mota': ('mota',),
'motarbeida': ('motarbeide',),
'motarbeidd': ('motarbeide',),
'motarbeidde': ('motarbeide',),
'motarbeidede': ('motarbeide',),
'motarbeidende': ('motarbeide',),
'motarbeidet': ('motarbeide',),
'motarbeidete': ('motarbeide',),
'motbevisende': ('motbevise',),
'motbevist': ('motbevise',),
'motbeviste': ('motbevise',),
'motbydelig': ('motbydelig',),
'motbydelige': ('motbydelig',),
'motbydeligere': ('motbydelig',),
'motbydeligst': ('motbydelig',),
'motbydeligste': ('motbydelig',),
'motebevisst': ('motebevisst',),
'motebevisste': ('motebevisst',),
'motebevisstere': ('motebevisst',),
'motebevisstest': ('motebevisst',),
'motebevissteste': ('motebevisst',),
'moteriktig': ('moteriktig',),
'moteriktige': ('moteriktig',),
'moteriktigere': ('moteriktig',),
'moteriktigst': ('moteriktig',),
'moteriktigste': ('moteriktig',),
'motfallen': ('motfallen',),
'motfallent': ('motfallen',),
'motfalne': ('motfallen',),
'motfalnere': ('motfallen',),
'motfalnest': ('motfallen',),
'motfalneste': ('motfallen',),
'motgående': ('motgående',),
'motiverende': ('motivere',),
'motivert': ('motivere',),
'motiverte': ('motivere',),
'motivisk': ('motivisk',),
'motiviske': ('motivisk',),
'motiviskere': ('motivisk',),
'motiviskest': ('motivisk',),
'motiviskeste': ('motivisk',),
'motlaus': ('motlaus',),
'motlause': ('motlaus',),
'motlausere': ('motlaus',),
'motlausest': ('motlaus',),
'motlauseste': ('motlaus',),
'motlaust': ('motlaus',),
'motløs': ('motløs',),
'motløse': ('motløs',),
'motløsere': ('motløs',),
'motløsest': ('motløs',),
'motløseste': ('motløs',),
'motløst': ('motløs',),
'motordrevet': ('motordrevet',),
'motordrevne': ('motordrevet',),
'motordrevnere': ('motordrevet',),
'motordrevnest': ('motordrevet',),
'motordrevneste': ('motordrevet',),
'motoriserende': ('motorisere',),
'motorisert': ('motorisere',),
'motoriserte': ('motorisere',),
'motorisk': ('motorisk',),
'motoriske': ('motorisk',),
'motoriskere': ('motorisk',),
'motoriskest': ('motorisk',),
'motoriskeste': ('motorisk',),
'motsatt': ('motsatt',),
'motsatte': ('motsatt',),
'motsattere': ('motsatt',),
'motsattest': ('motsatt',),
'motsatteste': ('motsatt',),
'motsetningsfylt': ('motsetningsfylt',),
'motsetningsfylte': ('motsetningsfylt',),
'motsetningsfyltere': ('motsetningsfylt',),
'motsetningsfyltest': ('motsetningsfylt',),
'motsetningsfylteste': ('motsetningsfylt',),
'motsetningsrik': ('motsetningsrik',),
'motsetningsrike': ('motsetningsrik',),
'motsetningsrikere': ('motsetningsrik',),
'motsetningsrikest': ('motsetningsrik',),
'motsetningsrikeste': ('motsetningsrik',),
'motsetningsrikt': ('motsetningsrik',),
'motsatt': ('motsette',),
'motsatte': ('motsette',),
'motsettende': ('motsette',),
'motstandsdyktig': ('motstandsdyktig',),
'motstandsdyktige': ('motstandsdyktig',),
'motstandsdyktigere': ('motstandsdyktig',),
'motstandsdyktigst': ('motstandsdyktig',),
'motstandsdyktigste': ('motstandsdyktig',),
'motstrebende': ('motstrebende',),
'motstridende': ('motstridende',),
'motstående': ('motstående',),
'motsvara': ('motsvare',),
'motsvarende': ('motsvare',),
'motsvart': ('motsvare',),
'motsvarte': ('motsvare',),
'motsvarende': ('motsvarende',),
'mottakende': ('motta',),
'mottatt': ('motta',),
'mottatte': ('motta',),
'mottakelig': ('mottakelig',),
'mottakelige': ('mottakelig',),
'mottakeligere': ('mottakelig',),
'mottakeligst': ('mottakelig',),
'mottakeligste': ('mottakelig',),
'motvillig': ('motvillig',),
'motvillige': ('motvillig',),
'motvilligere': ('motvillig',),
'motvilligst': ('motvillig',),
'motvilligste': ('motvillig',),
'motvirka': ('motvirke',),
'motvirkede': ('motvirke',),
'motvirkende': ('motvirke',),
'motvirket': ('motvirke',),
'motvirkete': ('motvirke',),
'movarm': ('movarm',),
'movarme': ('movarm',),
'movarmere': ('movarm',),
'movarmest': ('movarm',),
'movarmeste': ('movarm',),
'movarmt': ('movarm',),
'moverende': ('movere',),
'movert': ('movere',),
'moverte': ('movere',),
'mudra': ('mudre',),
'mudrede': ('mudre',),
'mudrende': ('mudre',),
'mudret': ('mudre',),
'mudrete': ('mudre',),
'mudra': ('mudre',),
'mudrede': ('mudre',),
'mudrende': ('mudre',),
'mudret': ('mudre',),
'mudrete': ('mudre',),
'mudret': ('mudret',),
'mudrete': ('mudret',),
'mudretere': ('mudret',),
'mudretest': ('mudret',),
'mudreteste': ('mudret',),
'mudrete': ('mudrete',),
'muga': ('muge',),
'mugede': ('muge',),
'mugende': ('muge',),
'muget': ('muge',),
'mugete': ('muge',),
'mugga': ('mugge',),
'muggede': ('mugge',),
'muggende': ('mugge',),
'mugget': ('mugge',),
'muggete': ('mugge',),
'muggen': ('muggen',),
'muggent': ('muggen',),
'mugne': ('muggen',),
'mugnere': ('muggen',),
'mugnest': ('muggen',),
'mugneste': ('muggen',),
'mugna': ('mugne',),
'mugnede': ('mugne',),
'mugnende': ('mugne',),
'mugnet': ('mugne',),
'mugnete': ('mugne',),
'muhamedansk': ('muhamedansk',),
'muhamedanske': ('muhamedansk',),
'muhamedanskere': ('muhamedansk',),
'muhamedanskest': ('muhamedansk',),
'muhamedanskeste': ('muhamedansk',),
'muhammedansk': ('muhammedansk',),
'muhammedanske': ('muhammedansk',),
'muhammedanskere': ('muhammedansk',),
'muhammedanskest': ('muhammedansk',),
'muhammedanskeste': ('muhammedansk',),
'mukka': ('mukke',),
'mukkede': ('mukke',),
'mukkende': ('mukke',),
'mukket': ('mukke',),
'mukkete': ('mukke',),
'mulda': ('mulde',),
'muldede': ('mulde',),
'muldende': ('mulde',),
'muldet': ('mulde',),
'muldete': ('mulde',),
'muldet': ('muldet',),
'muldete': ('muldet',),
'muldetere': ('muldet',),
'muldetest': ('muldet',),
'muldeteste': ('muldet',),
'muldete': ('muldete',),
'muldfattig': ('muldfattig',),
'muldfattige': ('muldfattig',),
'muldfattigere': ('muldfattig',),
'muldfattigst': ('muldfattig',),
'muldfattigste': ('muldfattig',),
'mulende': ('mule',),
'mult': ('mule',),
'multe': ('mule',),
'mulebindende': ('mulebinde',),
'mulebunden': ('mulebinde',),
'mulebundet': ('mulebinde',),
'mulebundne': ('mulebinde',),
'mulen': ('mulen',),
'mulent': ('mulen',),
'mulne': ('mulen',),
'mulnere': ('mulen',),
'mulnest': ('mulen',),
'mulneste': ('mulen',),
'mulig': ('mulig',),
'mulige': ('mulig',),
'muligere': ('mulig',),
'muligst': ('mulig',),
'muligste': ('mulig',),
'muliggjort': ('muliggjøre',),
'muliggjorte': ('muliggjøre',),
'muliggjørende': ('muliggjøre',),
'muljerende': ('muljere',),
'muljert': ('muljere',),
'muljerte': ('muljere',),
'mulkta': ('mulkte',),
'mulktede': ('mulkte',),
'mulktende': ('mulkte',),
'mulktet': ('mulkte',),
'mulktete': ('mulkte',),
'mulkterende': ('mulktere',),
'mulktert': ('mulktere',),
'mulkterte': ('mulktere',),
'mulla': ('mulle',),
'mullede': ('mulle',),
'mullende': ('mulle',),
'mullet': ('mulle',),
'mullete': ('mulle',),
'mulna': ('mulne',),
'mulnede': ('mulne',),
'mulnende': ('mulne',),
'mulnet': ('mulne',),
'mulnete': ('mulne',),
'mulra': ('mulre',),
'mulrede': ('mulre',),
'mulrende': ('mulre',),
'mulret': ('mulre',),
'mulrete': ('mulre',),
'multilateral': ('multilateral',),
'multilaterale': ('multilateral',),
'multilateralere': ('multilateral',),
'multilateralest': ('multilateral',),
'multilateraleste': ('multilateral',),
'multilateralt': ('multilateral',),
'multinasjonal': ('multinasjonal',),
'multinasjonale': ('multinasjonal',),
'multinasjonalere': ('multinasjonal',),
'multinasjonalest': ('multinasjonal',),
'multinasjonaleste': ('multinasjonal',),
'multinasjonalt': ('multinasjonal',),
'multipleks': ('multipleks',),
'multiplekse': ('multipleks',),
'multipleksere': ('multipleks',),
'multipleksest': ('multipleks',),
'multiplekseste': ('multipleks',),
'multiplekst': ('multipleks',),
'multipliserende': ('multiplisere',),
'multiplisert': ('multiplisere',),
'multipliserte': ('multiplisere',),
'multiple': ('multippel',),
'multiplere': ('multippel',),
'multiplest': ('multippel',),
'multipleste': ('multippel',),
'multippel': ('multippel',),
'multippelt': ('multippel',),
'mumifiserende': ('mumifisere',),
'mumifisert': ('mumifisere',),
'mumifiserte': ('mumifisere',),
'mumiserende': ('mumisere',),
'mumisert': ('mumisere',),
'mumiserte': ('mumisere',),
'mumla': ('mumle',),
'mumlede': ('mumle',),
'mumlende': ('mumle',),
'mumlet': ('mumle',),
'mumlete': ('mumle',),
'mumsa': ('mumse',),
'mumsede': ('mumse',),
'mumsende': ('mumse',),
'mumset': ('mumse',),
'mumsete': ('mumse',),
'munna': ('munne',),
'munnede': ('munne',),
'munnende': ('munne',),
'munnet': ('munne',),
'munnete': ('munne',),
'munnkjapp': ('munnkjapp',),
'munnkjappe': ('munnkjapp',),
'munnkjappere': ('munnkjapp',),
'munnkjappest': ('munnkjapp',),
'munnkjappeste': ('munnkjapp',),
'munnkjapt': ('munnkjapp',),
'munnrapp': ('munnrapp',),
'munnrappe': ('munnrapp',),
'munnrappere': ('munnrapp',),
'munnrappest': ('munnrapp',),
'munnrappeste': ('munnrapp',),
'munnrapt': ('munnrapp',),
'munter': ('munter',),
'muntert': ('munter',),
'muntre': ('munter',),
'muntrere': ('munter',),
'muntrest': ('munter',),
'muntreste': ('munter',),
'muntlig': ('muntlig',),
'muntlige': ('muntlig',),
'muntligere': ('muntlig',),
'muntligst': ('muntlig',),
'muntligste': ('muntlig',),
'muntra': ('muntre',),
'muntrede': ('muntre',),
'muntrende': ('muntre',),
'muntret': ('muntre',),
'muntrete': ('muntre',),
'mura': ('mure',),
'murede': ('mure',),
'murende': ('mure',),
'muret': ('mure',),
'murete': ('mure',),
'murt': ('mure',),
'murte': ('mure',),
'murfast': ('murfast',),
'murfaste': ('murfast',),
'murfastere': ('murfast',),
'murfastest': ('murfast',),
'murfasteste': ('murfast',),
'murmansk': ('murmansk',),
'murmanske': ('murmansk',),
'murmanskere': ('murmansk',),
'murmanskest': ('murmansk',),
'murmanskeste': ('murmansk',),
'murra': ('murre',),
'murrede': ('murre',),
'murrende': ('murre',),
'murret': ('murre',),
'murrete': ('murre',),
'musbrun': ('musbrun',),
'musbrune': ('musbrun',),
'musbrunere': ('musbrun',),
'musbrunest': ('musbrun',),
'musbruneste': ('musbrun',),
'musbrunt': ('musbrun',),
'museal': ('museal',),
'museale': ('museal',),
'musealere': ('museal',),
'musealest': ('museal',),
'musealeste': ('museal',),
'musealt': ('museal',),
'musebrun': ('musebrun',),
'musebrune': ('musebrun',),
'musebrunere': ('musebrun',),
'musebrunest': ('musebrun',),
'musebruneste': ('musebrun',),
'musebrunt': ('musebrun',),
'musegrå': ('musegrå',),
'musegråe': ('musegrå',),
'musegråere': ('musegrå',),
'musegråest': ('musegrå',),
'musegråeste': ('musegrå',),
'musegrått': ('musegrå',),
'musestille': ('musestille',),
'muset': ('muset',),
'musete': ('muset',),
'musetere': ('muset',),
'musetest': ('muset',),
'museteste': ('muset',),
'musete': ('musete',),
'musgrå': ('musgrå',),
'musgråe': ('musgrå',),
'musgråere': ('musgrå',),
'musgråest': ('musgrå',),
'musgråeste': ('musgrå',),
'musgrått': ('musgrå',),
'musikalsk': ('musikalsk',),
'musikalske': ('musikalsk',),
'musikalskere': ('musikalsk',),
'musikalskest': ('musikalsk',),
'musikalskeste': ('musikalsk',),
'musikologisk': ('musikologisk',),
'musikologiske': ('musikologisk',),
'musikologiskere': ('musikologisk',),
'musikologiskest': ('musikologisk',),
'musikologiskeste': ('musikologisk',),
'musiserende': ('musisere',),
'musisert': ('musisere',),
'musiserte': ('musisere',),
'musisk': ('musisk',),
'musiske': ('musisk',),
'musiskere': ('musisk',),
'musiskest': ('musisk',),
'musiskeste': ('musisk',),
'muskulær': ('muskulær',),
'muskulære': ('muskulær',),
'muskulærere': ('muskulær',),
'muskulærest': ('muskulær',),
'muskulæreste': ('muskulær',),
'muskulært': ('muskulær',),
'muskuløs': ('muskuløs',),
'muskuløse': ('muskuløs',),
'muskuløsere': ('muskuløs',),
'muskuløsest': ('muskuløs',),
'muskuløseste': ('muskuløs',),
'muskuløst': ('muskuløs',),
'muslimsk': ('muslimsk',),
'muslimske': ('muslimsk',),
'muslimskere': ('muslimsk',),
'muslimskest': ('muslimsk',),
'muslimskeste': ('muslimsk',),
'musserende': ('mussere',),
'mussert': ('mussere',),
'musserte': ('mussere',),
'mutabel': ('mutabel',),
'mutabelt': ('mutabel',),
'mutable': ('mutabel',),
'mutablere': ('mutabel',),
'mutablest': ('mutabel',),
'mutableste': ('mutabel',),
'mutagen': ('mutagen',),
'mutagene': ('mutagen',),
'mutagenere': ('mutagen',),
'mutagenest': ('mutagen',),
'mutageneste': ('mutagen',),
'mutagent': ('mutagen',),
'mutant': ('mutant',),
'mutante': ('mutant',),
'mutantere': ('mutant',),
'mutantest': ('mutant',),
'mutanteste': ('mutant',),
'muta': ('mute',),
'mutede': ('mute',),
'mutende': ('mute',),
'mutet': ('mute',),
'mutete': ('mute',),
'muta': ('mute',),
'mutede': ('mute',),
'mutende': ('mute',),
'mutet': ('mute',),
'mutete': ('mute',),
'muterende': ('mutere',),
'mutert': ('mutere',),
'muterte': ('mutere',),
'mutt': ('mutt',),
'mutte': ('mutt',),
'muttere': ('mutt',),
'muttest': ('mutt',),
'mutteste': ('mutt',),
'myanmarsk': ('myanmarsk',),
'myanmarske': ('myanmarsk',),
'myanmarskere': ('myanmarsk',),
'myanmarskest': ('myanmarsk',),
'myanmarskeste': ('myanmarsk',),
'mer': ('mye',),
'mere': ('mye',),
'mest': ('mye',),
'meste': ('mye',),
'mye': ('mye',),
'mygla': ('mygle',),
'myglede': ('mygle',),
'myglende': ('mygle',),
'myglet': ('mygle',),
'myglete': ('mygle',),
'myglet': ('myglet',),
'myglete': ('myglet',),
'mygletere': ('myglet',),
'mygletest': ('myglet',),
'mygleteste': ('myglet',),
'myglete': ('myglete',),
'myk': ('myk',),
'myke': ('myk',),
'mykere': ('myk',),
'mykest': ('myk',),
'mykeste': ('myk',),
'mykt': ('myk',),
'myka': ('myke',),
'mykede': ('myke',),
'mykende': ('myke',),
'myket': ('myke',),
'mykete': ('myke',),
'mykt': ('myke',),
'mykte': ('myke',),
'myklanda': ('myklande',),
'myklandede': ('myklande',),
'myklandende': ('myklande',),
'myklandet': ('myklande',),
'myklandete': ('myklande',),
'mykna': ('mykne',),
'myknede': ('mykne',),
'myknende': ('mykne',),
'myknet': ('mykne',),
'myknete': ('mykne',),
'mykna': ('mykne',),
'myknede': ('mykne',),
'myknende': ('mykne',),
'myknet': ('mykne',),
'myknete': ('mykne',),
'mykologisk': ('mykologisk',),
'mykologiske': ('mykologisk',),
'mykologiskere': ('mykologisk',),
'mykologiskest': ('mykologisk',),
'mykologiskeste': ('mykologisk',),
'myldra': ('myldre',),
'myldrede': ('myldre',),
'myldrende': ('myldre',),
'myldret': ('myldre',),
'myldrete': ('myldre',),
'myndig': ('myndig',),
'myndige': ('myndig',),
'myndigere': ('myndig',),
'myndigst': ('myndig',),
'myndigste': ('myndig',),
'mynta': ('mynte',),
'myntede': ('mynte',),
'myntende': ('mynte',),
'myntet': ('mynte',),
'myntete': ('mynte',),
'myopisk': ('myopisk',),
'myopiske': ('myopisk',),
'myopiskere': ('myopisk',),
'myopiskest': ('myopisk',),
'myopiskeste': ('myopisk',),
'myrda': ('myrde',),
'myrdede': ('myrde',),
'myrdende': ('myrde',),
'myrdet': ('myrde',),
'myrdete': ('myrde',),
'myret': ('myret',),
'myrete': ('myret',),
'myretere': ('myret',),
'myretest': ('myret',),
'myreteste': ('myret',),
'myrete': ('myrete',),
'myrlendt': ('myrlendt',),
'myrlendte': ('myrlendt',),
'myrlendtere': ('myrlendt',),
'myrlendtest': ('myrlendt',),
'myrlendteste': ('myrlendt',),
'mysende': ('myse',),
'myst': ('myse',),
'myste': ('myse',),
'mysteriøs': ('mysteriøs',),
'mysteriøse': ('mysteriøs',),
'mysteriøsere': ('mysteriøs',),
'mysteriøsest': ('mysteriøs',),
'mysteriøseste': ('mysteriøs',),
'mysteriøst': ('mysteriøs',),
'mystifiserende': ('mystifisere',),
'mystifisert': ('mystifisere',),
'mystifiserte': ('mystifisere',),
'mystifistisk': ('mystifistisk',),
'mystifistiske': ('mystifistisk',),
'mystifistiskere': ('mystifistisk',),
'mystifistiskest': ('mystifistisk',),
'mystifistiskeste': ('mystifistisk',),
'mystisk': ('mystisk',),
'mystiske': ('mystisk',),
'mystiskere': ('mystisk',),
'mystiskest': ('mystisk',),
'mystiskeste': ('mystisk',),
'myta': ('myte',),
'mytede': ('myte',),
'mytende': ('myte',),
'mytet': ('myte',),
'mytete': ('myte',),
'mytt': ('myte',),
'mytte': ('myte',),
'mytisk': ('mytisk',),
'mytiske': ('mytisk',),
'mytiskere': ('mytisk',),
'mytiskest': ('mytisk',),
'mytiskeste': ('mytisk',),
'mytologisk': ('mytologisk',),
'mytologiske': ('mytologisk',),
'mytologiskere': ('mytologisk',),
'mytologiskest': ('mytologisk',),
'mytologiskeste': ('mytologisk',),
'måka': ('måke',),
'måkede': ('måke',),
'måkende': ('måke',),
'måket': ('måke',),
'måkete': ('måke',),
'måkt': ('måke',),
'måkte': ('måke',),
'målbar': ('målbar',),
'målbare': ('målbar',),
'målbarere': ('målbar',),
'målbarest': ('målbar',),
'målbareste': ('målbar',),
'målbart': ('målbar',),
'målbevisst': ('målbevisst',),
'målbevisste': ('målbevisst',),
'målbevisstere': ('målbevisst',),
'målbevisstest': ('målbevisst',),
'målbevissteste': ('målbevisst',),
'målbindende': ('målbinde',),
'målbunden': ('målbinde',),
'målbundet': ('målbinde',),
'målbundne': ('målbinde',),
'målende': ('måle',),
'målt': ('måle',),
'målte': ('måle',),
'målelig': ('målelig',),
'målelige': ('målelig',),
'måleligere': ('målelig',),
'måleligst': ('målelig',),
'måleligste': ('målelig',),
'mållaus': ('mållaus',),
'mållause': ('mållaus',),
'mållausere': ('mållaus',),
'mållausest': ('mållaus',),
'mållauseste': ('mållaus',),
'mållaust': ('mållaus',),
'mållaus': ('mållaus',),
'mållause': ('mållaus',),
'mållausere': ('mållaus',),
'mållausest': ('mållaus',),
'mållauseste': ('mållaus',),
'mållaust': ('mållaus',),
'målløs': ('målløs',),
'målløse': ('målløs',),
'målløsere': ('målløs',),
'målløsest': ('målløs',),
'målløseste': ('målløs',),
'målløst': ('målløs',),
'målløs': ('målløs',),
'målløse': ('målløs',),
'målløsere': ('målløs',),
'målløsest': ('målløs',),
'målløseste': ('målløs',),
'målløst': ('målløs',),
'målretta': ('målretta',),
'målrettede': ('målrettet',),
'målrettet': ('målrettet',),
'målrettete': ('målrettet',),
'målrettetere': ('målrettet',),
'målrettetest': ('målrettet',),
'målretteteste': ('målrettet',),
'målsøkende': ('målsøkende',),
'månedlig': ('månedlig',),
'månedlige': ('månedlig',),
'månedligere': ('månedlig',),
'månedligst': ('månedlig',),
'månedligste': ('månedlig',),
'månedseldre': ('månedsgammal',),
'månedseldst': ('månedsgammal',),
'månedseldste': ('månedsgammal',),
'månedsgamle': ('månedsgammal',),
'månedsgammal': ('månedsgammal',),
'månedsgammalt': ('månedsgammal',),
'månedseldre': ('månedsgammel',),
'månedseldst': ('månedsgammel',),
'månedseldste': ('månedsgammel',),
'månedsgamle': ('månedsgammel',),
'månedsgammel': ('månedsgammel',),
'månedsgammelt': ('månedsgammel',),
'månemørk': ('månemørk',),
'månemørke': ('månemørk',),
'månemørkere': ('månemørk',),
'månemørkest': ('månemørk',),
'månemørkeste': ('månemørk',),
'månemørkt': ('månemørk',),
'månesjuk': ('månesjuk',),
'månesjuke': ('månesjuk',),
'månesjukere': ('månesjuk',),
'månesjukest': ('månesjuk',),
'månesjukeste': ('månesjuk',),
'månesjukt': ('månesjuk',),
'månesyk': ('månesyk',),
'månesyke': ('månesyk',),
'månesykere': ('månesyk',),
'månesykest': ('månesyk',),
'månesykeste': ('månesyk',),
'månesykt': ('månesyk',),
'måpende': ('måpe',),
'måpt': ('måpe',),
'måpte': ('måpe',),
'måta': ('måte',),
'måtede': ('måte',),
'måtende': ('måte',),
'måtet': ('måte',),
'måtete': ('måte',),
'måteholden': ('måteholden',),
'måteholdent': ('måteholden',),
'måteholdne': ('måteholden',),
'måteholdnere': ('måteholden',),
'måteholdnest': ('måteholden',),
'måteholdneste': ('måteholden',),
'måtelig': ('måtelig',),
'måtelige': ('måtelig',),
'måteligere': ('måtelig',),
'måteligst': ('måtelig',),
'måteligste': ('måtelig',),
'mælende': ('mæle',),
'mælt': ('mæle',),
'mælte': ('mæle',),
'mælende': ('mæle',),
'mælt': ('mæle',),
'mælte': ('mæle',),
'mæt': ('mæt',),
'mæte': ('mæt',),
'mætere': ('mæt',),
'mætest': ('mæt',),
'mæteste': ('mæt',),
'mætt': ('mæt',),
'mætende': ('mæte',),
'mætt': ('mæte',),
'mætte': ('mæte',),
'møblerende': ('møblere',),
'møblert': ('møblere',),
'møblerte': ('møblere',),
'mødig': ('mødig',),
'mødige': ('mødig',),
'mødigere': ('mødig',),
'mødigst': ('mødig',),
'mødigste': ('mødig',),
'mødrene': ('mødrene',),
'møkka': ('møkke',),
'møkkede': ('møkke',),
'møkkende': ('møkke',),
'møkket': ('møkke',),
'møkkete': ('møkke',),
'møkket': ('møkket',),
'møkkete': ('møkket',),
'møkketere': ('møkket',),
'møkketest': ('møkket',),
'møkketeste': ('møkket',),
'møkkete': ('møkkete',),
'møllbehandla': ('møllbehandla',),
'møllbehandlede': ('møllbehandlet',),
'møllbehandlet': ('møllbehandlet',),
'møllbehandlete': ('møllbehandlet',),
'møllbehandletere': ('møllbehandlet',),
'møllbehandletest': ('møllbehandlet',),
'møllbehandleteste': ('møllbehandlet',),
'møllen': ('møllen',),
'møllent': ('møllen',),
'mølne': ('møllen',),
'mølnere': ('møllen',),
'mølnest': ('møllen',),
'mølneste': ('møllen',),
'møllett': ('møllett',),
'møllette': ('møllett',),
'møllettere': ('møllett',),
'møllettest': ('møllett',),
'mølletteste': ('møllett',),
'møllsikker': ('møllsikker',),
'møllsikkert': ('møllsikker',),
'møllsikre': ('møllsikker',),
'møllsikrere': ('møllsikker',),
'møllsikrest': ('møllsikker',),
'møllsikreste': ('møllsikker',),
'mønja': ('mønje',),
'mønjede': ('mønje',),
'mønjende': ('mønje',),
'mønjet': ('mønje',),
'mønjete': ('mønje',),
'mønsterbeskytta': ('mønsterbeskytta',),
'mønsterbeskyttede': ('mønsterbeskyttet',),
'mønsterbeskyttet': ('mønsterbeskyttet',),
'mønsterbeskyttete': ('mønsterbeskyttet',),
'mønsterbeskyttetere': ('mønsterbeskyttet',),
'mønsterbeskyttetest': ('mønsterbeskyttet',),
'mønsterbeskytteteste': ('mønsterbeskyttet',),
'mønstergyldig': ('mønstergyldig',),
'mønstergyldige': ('mønstergyldig',),
'mønstergyldigere': ('mønstergyldig',),
'mønstergyldigst': ('mønstergyldig',),
'mønstergyldigste': ('mønstergyldig',),
'mønsterverdig': ('mønsterverdig',),
'mønsterverdige': ('mønsterverdig',),
'mønsterverdigere': ('mønsterverdig',),
'mønsterverdigst': ('mønsterverdig',),
'mønsterverdigste': ('mønsterverdig',),
'mønstra': ('mønstre',),
'mønstrede': ('mønstre',),
'mønstrende': ('mønstre',),
'mønstret': ('mønstre',),
'mønstrete': ('mønstre',),
'mønstret': ('mønstret',),
'mønstrete': ('mønstret',),
'mønstretere': ('mønstret',),
'mønstretest': ('mønstret',),
'mønstreteste': ('mønstret',),
'mønstrete': ('mønstrete',),
'mør': ('mør',),
'møre': ('mør',),
'mørere': ('mør',),
'mørest': ('mør',),
'møreste': ('mør',),
'mørt': ('mør',),
'mørbanka': ('mørbanke',),
'mørbankede': ('mørbanke',),
'mørbankende': ('mørbanke',),
'mørbanket': ('mørbanke',),
'mørbankete': ('mørbanke',),
'mørk': ('mørk',),
'mørke': ('mørk',),
'mørkere': ('mørk',),
'mørkest': ('mørk',),
'mørkeste': ('mørk',),
'mørkt': ('mørk',),
'mørkblå': ('mørkblå',),
'mørkblåe': ('mørkblå',),
'mørkblåere': ('mørkblå',),
'mørkblåest': ('mørkblå',),
'mørkblåeste': ('mørkblå',),
'mørkblått': ('mørkblå',),
'mørkbrun': ('mørkbrun',),
'mørkbrune': ('mørkbrun',),
'mørkbrunere': ('mørkbrun',),
'mørkbrunest': ('mørkbrun',),
'mørkbruneste': ('mørkbrun',),
'mørkbrunt': ('mørkbrun',),
'mørka': ('mørke',),
'mørkede': ('mørke',),
'mørkende': ('mørke',),
'mørket': ('mørke',),
'mørkete': ('mørke',),
'mørkeblå': ('mørkeblå',),
'mørkeblåe': ('mørkeblå',),
'mørkeblåere': ('mørkeblå',),
'mørkeblåest': ('mørkeblå',),
'mørkeblåeste': ('mørkeblå',),
'mørkeblått': ('mørkeblå',),
'mørkebrun': ('mørkebrun',),
'mørkebrune': ('mørkebrun',),
'mørkebrunere': ('mørkebrun',),
'mørkebrunest': ('mørkebrun',),
'mørkebruneste': ('mørkebrun',),
'mørkebrunt': ('mørkebrun',),
'mørkegrå': ('mørkegrå',),
'mørkegråe': ('mørkegrå',),
'mørkegråere': ('mørkegrå',),
'mørkegråest': ('mørkegrå',),
'mørkegråeste': ('mørkegrå',),
'mørkegrått': ('mørkegrå',),
'mørkegrøn': ('mørkegrøn',),
'mørkegrøne': ('mørkegrøn',),
'mørkegrønere': ('mørkegrøn',),
'mørkegrønest': ('mørkegrøn',),
'mørkegrøneste': ('mørkegrøn',),
'mørkegrønt': ('mørkegrøn',),
'mørkegrønn': ('mørkegrønn',),
'mørkegrønne': ('mørkegrønn',),
'mørkegrønnere': ('mørkegrønn',),
'mørkegrønnest': ('mørkegrønn',),
'mørkegrønneste': ('mørkegrønn',),
'mørkegrønt': ('mørkegrønn',),
'mørkegul': ('mørkegul',),
'mørkegule': ('mørkegul',),
'mørkegulere': ('mørkegul',),
'mørkegulest': ('mørkegul',),
'mørkeguleste': ('mørkegul',),
'mørkegult': ('mørkegul',),
'mørkeredd': ('mørkeredd',),
'mørkeredde': ('mørkeredd',),
'mørkereddere': ('mørkeredd',),
'mørkereddest': ('mørkeredd',),
'mørkereddeste': ('mørkeredd',),
'mørkerød': ('mørkerød',),
'mørkerøde': ('mørkerød',),
'mørkerødere': ('mørkerød',),
'mørkerødest': ('mørkerød',),
'mørkerødeste': ('mørkerød',),
'mørkerødt': ('mørkerød',),
'mørkfiolett': ('mørkfiolett',),
'mørkfiolette': ('mørkfiolett',),
'mørkfiolettere': ('mørkfiolett',),
'mørkfiolettest': ('mørkfiolett',),
'mørkfioletteste': ('mørkfiolett',),
'mørkgrå': ('mørkgrå',),
'mørkgråe': ('mørkgrå',),
'mørkgråere': ('mørkgrå',),
'mørkgråest': ('mørkgrå',),
'mørkgråeste': ('mørkgrå',),
'mørkgrått': ('mørkgrå',),
'mørkgrøn': ('mørkgrøn',),
'mørkgrøne': ('mørkgrøn',),
'mørkgrønere': ('mørkgrøn',),
'mørkgrønest': ('mørkgrøn',),
'mørkgrøneste': ('mørkgrøn',),
'mørkgrønt': ('mørkgrøn',),
'mørkgrønn': ('mørkgrønn',),
'mørkgrønne': ('mørkgrønn',),
'mørkgrønnere': ('mørkgrønn',),
'mørkgrønnest': ('mørkgrønn',),
'mørkgrønneste': ('mørkgrønn',),
'mørkgrønt': ('mørkgrønn',),
'mørkgul': ('mørkgul',),
'mørkgule': ('mørkgul',),
'mørkgulere': ('mørkgul',),
'mørkgulest': ('mørkgul',),
'mørkguleste': ('mørkgul',),
'mørkgult': ('mørkgul',),
'mørkhuda': ('mørkhuda',),
'mørkhudede': ('mørkhudet',),
'mørkhudet': ('mørkhudet',),
'mørkhudete': ('mørkhudet',),
'mørkhudetere': ('mørkhudet',),
'mørkhudetest': ('mørkhudet',),
'mørkhudeteste': ('mørkhudet',),
'mørkhåra': ('mørkhåra',),
'mørkhårede': ('mørkhåret',),
'mørkhåret': ('mørkhåret',),
'mørkhårete': ('mørkhåret',),
'mørkhåretere': ('mørkhåret',),
'mørkhåretest': ('mørkhåret',),
'mørkhåreteste': ('mørkhåret',),
'mørkkledd': ('mørkkledd',),
'mørkkledde': ('mørkkledd',),
'mørkkleddere': ('mørkkledd',),
'mørkkleddest': ('mørkkledd',),
'mørkkleddeste': ('mørkkledd',),
'mørklagt': ('mørklegge',),
'mørklagte': ('mørklegge',),
'mørkleggende': ('mørklegge',),
'mørklett': ('mørklett',),
'mørklette': ('mørklett',),
'mørklettere': ('mørklett',),
'mørklettest': ('mørklett',),
'mørkletteste': ('mørklett',),
'mørkna': ('mørkne',),
'mørknede': ('mørkne',),
'mørknende': ('mørkne',),
'mørknet': ('mørkne',),
'mørknete': ('mørkne',),
'mørkredd': ('mørkredd',),
'mørkredde': ('mørkredd',),
'mørkreddere': ('mørkredd',),
'mørkreddest': ('mørkredd',),
'mørkreddeste': ('mørkredd',),
'mørkrød': ('mørkrød',),
'mørkrøde': ('mørkrød',),
'mørkrødere': ('mørkrød',),
'mørkrødest': ('mørkrød',),
'mørkrødeste': ('mørkrød',),
'mørkrødt': ('mørkrød',),
'mørkøyd': ('mørkøyd',),
'mørkøyde': ('mørkøyd',),
'mørkøydere': ('mørkøyd',),
'mørkøydest': ('mørkøyd',),
'mørkøydeste': ('mørkøyd',),
'mørna': ('mørne',),
'mørnede': ('mørne',),
'mørnende': ('mørne',),
'mørnet': ('mørne',),
'mørnete': ('mørne',),
'møtende': ('møte',),
'møtt': ('møte',),
'møtte': ('møte',),
'møtetrett': ('møtetrett',),
'møtetrette': ('møtetrett',),
'møtetrettere': ('møtetrett',),
'møtetrettest': ('møtetrett',),
'møtetretteste': ('møtetrett',),
'møtetrøtt': ('møtetrøtt',),
'møtetrøtte': ('møtetrøtt',),
'møtetrøttere': ('møtetrøtt',),
'møtetrøttest': ('møtetrøtt',),
'møtetrøtteste': ('møtetrøtt',),
'møysommelig': ('møysommelig',),
'møysommelige': ('møysommelig',),
'møysommeligere': ('møysommelig',),
'møysommeligst': ('møysommelig',),
'møysommeligste': ('møysommelig',),
'n-te': ('n-te',),
'n.': ('n.',),
'naga': ('nage',),
'nagd': ('nage',),
'nagde': ('nage',),
'nagede': ('nage',),
'nagende': ('nage',),
'naget': ('nage',),
'nagete': ('nage',),
'nagla': ('nagle',),
'naglede': ('nagle',),
'naglende': ('nagle',),
'naglet': ('nagle',),
'naglete': ('nagle',),
'naglefast': ('naglefast',),
'naglefaste': ('naglefast',),
'naglefastere': ('naglefast',),
'naglefastest': ('naglefast',),
'naglefasteste': ('naglefast',),
'naiv': ('naiv',),
'naive': ('naiv',),
'naivere': ('naiv',),
'naivest': ('naiv',),
'naiveste': ('naiv',),
'naivt': ('naiv',),
'naivistisk': ('naivistisk',),
'naivistiske': ('naivistisk',),
'naivistiskere': ('naivistisk',),
'naivistiskest': ('naivistisk',),
'naivistiskeste': ('naivistisk',),
'naken': ('naken',),
'nakent': ('naken',),
'nakne': ('naken',),
'naknere': ('naken',),
'naknest': ('naken',),
'nakneste': ('naken',),
'nakenfrøa': ('nakenfrøa',),
'nakenfrøede': ('nakenfrøet',),
'nakenfrøet': ('nakenfrøet',),
'nakenfrøete': ('nakenfrøet',),
'nakenfrøetere': ('nakenfrøet',),
'nakenfrøetest': ('nakenfrøet',),
'nakenfrøeteste': ('nakenfrøet',),
'namibisk': ('namibisk',),
'namibiske': ('namibisk',),
'namibiskere': ('namibisk',),
'namibiskest': ('namibisk',),
'namibiskeste': ('namibisk',),
'namngjeten': ('namngjeten',),
'namngjetent': ('namngjeten',),
'namngjetne': ('namngjeten',),
'namngjetnere': ('namngjeten',),
'namngjetnest': ('namngjeten',),
'namngjetneste': ('namngjeten',),
'napolitansk': ('napolitansk',),
'napolitanske': ('napolitansk',),
'napolitanskere': ('napolitansk',),
'napolitanskest': ('napolitansk',),
'napolitanskeste': ('napolitansk',),
'nappa': ('nappe',),
'nappede': ('nappe',),
'nappende': ('nappe',),
'nappet': ('nappe',),
'nappete': ('nappe',),
'narkoman': ('narkoman',),
'narkomane': ('narkoman',),
'narkomanere': ('narkoman',),
'narkomanest': ('narkoman',),
'narkomaneste': ('narkoman',),
'narkomant': ('narkoman',),
'narkotiserende': ('narkotisere',),
'narkotisert': ('narkotisere',),
'narkotiserte': ('narkotisere',),
'narkotisk': ('narkotisk',),
'narkotiske': ('narkotisk',),
'narkotiskere': ('narkotisk',),
'narkotiskest': ('narkotisk',),
'narkotiskeste': ('narkotisk',),
'narraktig': ('narraktig',),
'narraktige': ('narraktig',),
'narraktigere': ('narraktig',),
'narraktigst': ('narraktig',),
'narraktigste': ('narraktig',),
'narrativ': ('narrativ',),
'narrative': ('narrativ',),
'narrativere': ('narrativ',),
'narrativest': ('narrativ',),
'narrativeste': ('narrativ',),
'narrativt': ('narrativ',),
'narra': ('narre',),
'narrede': ('narre',),
'narrende': ('narre',),
'narret': ('narre',),
'narrete': ('narre',),
'narsissistisk': ('narsissistisk',),
'narsissistiske': ('narsissistisk',),
'narsissistiskere': ('narsissistisk',),
'narsissistiskest': ('narsissistisk',),
'narsissistiskeste': ('narsissistisk',),
'narsistisk': ('narsistisk',),
'narsistiske': ('narsistisk',),
'narsistiskere': ('narsistisk',),
'narsistiskest': ('narsistisk',),
'narsistiskeste': ('narsistisk',),
'nasal': ('nasal',),
'nasale': ('nasal',),
'nasalere': ('nasal',),
'nasalest': ('nasal',),
'nasaleste': ('nasal',),
'nasalt': ('nasal',),
'nasalerende': ('nasalere',),
'nasalert': ('nasalere',),
'nasalerte': ('nasalere',),
'nasjonal': ('nasjonal',),
'nasjonale': ('nasjonal',),
'nasjonalere': ('nasjonal',),
'nasjonalest': ('nasjonal',),
'nasjonaleste': ('nasjonal',),
'nasjonalt': ('nasjonal',),
'nasjonaliserende': ('nasjonalisere',),
'nasjonalisert': ('nasjonalisere',),
'nasjonaliserte': ('nasjonalisere',),
'nasjonalistisk': ('nasjonalistisk',),
'nasjonalistiske': ('nasjonalistisk',),
'nasjonalistiskere': ('nasjonalistisk',),
'nasjonalistiskest': ('nasjonalistisk',),
'nasjonalistiskeste': ('nasjonalistisk',),
'nask': ('nask',),
'naske': ('nask',),
'naskere': ('nask',),
'naskest': ('nask',),
'naskeste': ('nask',),
'naskt': ('nask',),
'naska': ('naske',),
'naskede': ('naske',),
'naskende': ('naske',),
'nasket': ('naske',),
'naskete': ('naske',),
'nata': ('nate',),
'natede': ('nate',),
'natende': ('nate',),
'natet': ('nate',),
'natete': ('nate',),
'nativistisk': ('nativistisk',),
'nativistiske': ('nativistisk',),
'nativistiskere': ('nativistisk',),
'nativistiskest': ('nativistisk',),
'nativistiskeste': ('nativistisk',),
'nattblind': ('nattblind',),
'nattblinde': ('nattblind',),
'nattblindere': ('nattblind',),
'nattblindest': ('nattblind',),
'nattblindeste': ('nattblind',),
'nattblindt': ('nattblind',),
'natta': ('natte',),
'nattede': ('natte',),
'nattende': ('natte',),
'nattet': ('natte',),
'nattete': ('natte',),
'nattevåkt': ('nattevåkt',),
'nattevåkte': ('nattevåkt',),
'nattevåktere': ('nattevåkt',),
'nattevåktest': ('nattevåkt',),
'nattevåkteste': ('nattevåkt',),
'natteldre': ('nattgammal',),
'natteldst': ('nattgammal',),
'natteldste': ('nattgammal',),
'nattgamle': ('nattgammal',),
'nattgammal': ('nattgammal',),
'nattgammalt': ('nattgammal',),
'natteldre': ('nattgammel',),
'natteldst': ('nattgammel',),
'natteldste': ('nattgammel',),
'nattgamle': ('nattgammel',),
'nattgammel': ('nattgammel',),
'nattgammelt': ('nattgammel',),
'nattlig': ('nattlig',),
'nattlige': ('nattlig',),
'nattligere': ('nattlig',),
'nattligst': ('nattlig',),
'nattligste': ('nattlig',),
'naturaliserende': ('naturalisere',),
'naturalisert': ('naturalisere',),
'naturaliserte': ('naturalisere',),
'naturalistisk': ('naturalistisk',),
'naturalistiske': ('naturalistisk',),
'naturalistiskere': ('naturalistisk',),
'naturalistiskest': ('naturalistisk',),
'naturalistiskeste': ('naturalistisk',),
'naturell': ('naturell',),
'naturelle': ('naturell',),
'naturellere': ('naturell',),
'naturellest': ('naturell',),
'naturelleste': ('naturell',),
'naturelt': ('naturell',),
'naturfarga': ('naturfarga',),
'naturfargede': ('naturfarget',),
'naturfarget': ('naturfarget',),
'naturfargete': ('naturfarget',),
'naturfargetere': ('naturfarget',),
'naturfargetest': ('naturfarget',),
'naturfargeteste': ('naturfarget',),
'naturgitt': ('naturgitt',),
'naturgitte': ('naturgitt',),
'naturgittere': ('naturgitt',),
'naturgittest': ('naturgitt',),
'naturgitteste': ('naturgitt',),
'naturlig': ('naturlig',),
'naturlige': ('naturlig',),
'naturligere': ('naturlig',),
'naturligst': ('naturlig',),
'naturligste': ('naturlig',),
'naturnødvendig': ('naturnødvendig',),
'naturnødvendige': ('naturnødvendig',),
'naturnødvendigere': ('naturnødvendig',),
'naturnødvendigst': ('naturnødvendig',),
'naturnødvendigste': ('naturnødvendig',),
'naturstridig': ('naturstridig',),
'naturstridige': ('naturstridig',),
'naturstridigere': ('naturstridig',),
'naturstridigst': ('naturstridig',),
'naturstridigste': ('naturstridig',),
'naturvennlig': ('naturvennlig',),
'naturvennlige': ('naturvennlig',),
'naturvennligere': ('naturvennlig',),
'naturvennligst': ('naturvennlig',),
'naturvennligste': ('naturvennlig',),
'naubedt': ('naube',),
'naubedte': ('naube',),
'naubeende': ('naube',),
'naua': ('naue',),
'naud': ('naue',),
'naude': ('naue',),
'nauede': ('naue',),
'nauende': ('naue',),
'nauet': ('naue',),
'nauete': ('naue',),
'naufin': ('naufin',),
'naufine': ('naufin',),
'naufinere': ('naufin',),
'naufinest': ('naufin',),
'naufineste': ('naufin',),
'naufint': ('naufin',),
'naubedre': ('naugod',),
'naubest': ('naugod',),
'naubeste': ('naugod',),
'naugod': ('naugod',),
'naugode': ('naugod',),
'naugodt': ('naugod',),
'naurisk': ('naurisk',),
'nauriske': ('naurisk',),
'nauriskere': ('naurisk',),
'nauriskest': ('naurisk',),
'nauriskeste': ('naurisk',),
'naurisktt': ('naurisk',),
'nautet': ('nautet',),
'nautete': ('nautet',),
'nautetere': ('nautet',),
'nautetest': ('nautet',),
'nauteteste': ('nautet',),
'nautete': ('nautete',),
'nautisk': ('nautisk',),
'nautiske': ('nautisk',),
'nautiskere': ('nautisk',),
'nautiskest': ('nautisk',),
'nautiskeste': ('nautisk',),
'navigabel': ('navigabel',),
'navigabelt': ('navigabel',),
'navigable': ('navigabel',),
'navigablere': ('navigabel',),
'navigablest': ('navigabel',),
'navigableste': ('navigabel',),
'navigatorisk': ('navigatorisk',),
'navigatoriske': ('navigatorisk',),
'navigatoriskere': ('navigatorisk',),
'navigatoriskest': ('navigatorisk',),
'navigatoriskeste': ('navigatorisk',),
'navigerende': ('navigere',),
'navigert': ('navigere',),
'navigerte': ('navigere',),
'navla': ('navle',),
'navlede': ('navle',),
'navlende': ('navle',),
'navlet': ('navle',),
'navlete': ('navle',),
'navlebeskuende': ('navlebeskuende',),
'navna': ('navne',),
'navnede': ('navne',),
'navnende': ('navne',),
'navnet': ('navne',),
'navnete': ('navne',),
'navnekristen': ('navnekristen',),
'navnekristent': ('navnekristen',),
'navnekristne': ('navnekristen',),
'navnekristnere': ('navnekristen',),
'navnekristnest': ('navnekristen',),
'navnekristneste': ('navnekristen',),
'navngiende': ('navngi',),
'navngitt': ('navngi',),
'navngitte': ('navngi',),
'navngivende': ('navngi',),
'navngjeten': ('navngjeten',),
'navngjetent': ('navngjeten',),
'navngjetne': ('navngjeten',),
'navngjetnere': ('navngjeten',),
'navngjetnest': ('navngjeten',),
'navngjetneste': ('navngjeten',),
'navnkristen': ('navnkristen',),
'navnkristent': ('navnkristen',),
'navnkristne': ('navnkristen',),
'navnkristnere': ('navnkristen',),
'navnkristnest': ('navnkristen',),
'navnkristneste': ('navnkristen',),
'navnkundig': ('navnkundig',),
'navnkundige': ('navnkundig',),
'navnkundigere': ('navnkundig',),
'navnkundigst': ('navnkundig',),
'navnkundigste': ('navnkundig',),
'navnlaus': ('navnlaus',),
'navnlause': ('navnlaus',),
'navnlausere': ('navnlaus',),
'navnlausest': ('navnlaus',),
'navnlauseste': ('navnlaus',),
'navnlaust': ('navnlaus',),
'navnløs': ('navnløs',),
'navnløse': ('navnløs',),
'navnløsere': ('navnløs',),
'navnløsest': ('navnløs',),
'navnløseste': ('navnløs',),
'navnløst': ('navnløs',),
'navnspurt': ('navnspurt',),
'navnspurte': ('navnspurt',),
'navnspurtere': ('navnspurt',),
'navnspurtest': ('navnspurt',),
'navnspurteste': ('navnspurt',),
'nazifiserende': ('nazifisere',),
'nazifisert': ('nazifisere',),
'nazifiserte': ('nazifisere',),
'nazistisk': ('nazistisk',),
'nazistiske': ('nazistisk',),
'nazistiskere': ('nazistisk',),
'nazistiskest': ('nazistisk',),
'nazistiskeste': ('nazistisk',),
'nebbelig': ('nebbelig',),
'nebbelige': ('nebbelig',),
'nebbeligere': ('nebbelig',),
'nebbeligst': ('nebbelig',),
'nebbeligste': ('nebbelig',),
'nebbet': ('nebbet',),
'nebbete': ('nebbet',),
'nebbetere': ('nebbet',),
'nebbetest': ('nebbet',),
'nebbeteste': ('nebbet',),
'nebbete': ('nebbete',),
'nedadgående': ('nedadgående',),
'nedarva': ('nedarva',),
'nedarvede': ('nedarvet',),
'nedarvet': ('nedarvet',),
'nedarvete': ('nedarvet',),
'nedarvetere': ('nedarvet',),
'nedarvetest': ('nedarvet',),
'nedarveteste': ('nedarvet',),
'nedbrutt': ('nedbrutt',),
'nedbrutte': ('nedbrutt',),
'nedbruttere': ('nedbrutt',),
'nedbruttest': ('nedbrutt',),
'nedbrutteste': ('nedbrutt',),
'nedbrytbar': ('nedbrytbar',),
'nedbrytbare': ('nedbrytbar',),
'nedbrytbarere': ('nedbrytbar',),
'nedbrytbarest': ('nedbrytbar',),
'nedbrytbareste': ('nedbrytbar',),
'nedbrytbart': ('nedbrytbar',),
'nedbrutt': ('nedbryte',),
'nedbrutte': ('nedbryte',),
'nedbrytende': ('nedbryte',),
'nedbrytelig': ('nedbrytelig',),
'nedbrytelige': ('nedbrytelig',),
'nedbryteligere': ('nedbrytelig',),
'nedbryteligst': ('nedbrytelig',),
'nedbryteligste': ('nedbrytelig',),
'nedbygd': ('nedbygge',),
'nedbygde': ('nedbygge',),
'nedbygga': ('nedbygge',),
'nedbyggede': ('nedbygge',),
'nedbyggende': ('nedbygge',),
'nedbygget': ('nedbygge',),
'nedbyggete': ('nedbygge',),
'nedbøyd': ('nedbøyd',),
'nedbøyde': ('nedbøyd',),
'nedbøydere': ('nedbøyd',),
'nedbøydest': ('nedbøyd',),
'nedbøydeste': ('nedbøyd',),
'neddemma': ('neddemme',),
'neddemmede': ('neddemme',),
'neddemmende': ('neddemme',),
'neddemmet': ('neddemme',),
'neddemmete': ('neddemme',),
'neddemt': ('neddemme',),
'neddemte': ('neddemme',),
'neddopa': ('neddopa',),
'neddopede': ('neddopet',),
'neddopet': ('neddopet',),
'neddopete': ('neddopet',),
'neddopetere': ('neddopet',),
'neddopetest': ('neddopet',),
'neddopeteste': ('neddopet',),
'neddykka': ('neddykka',),
'neddykkede': ('neddykket',),
'neddykket': ('neddykket',),
'neddykkete': ('neddykket',),
'neddykketere': ('neddykket',),
'neddykketest': ('neddykket',),
'neddykketeste': ('neddykket',),
'nedenstående': ('nedenstående',),
'nederdrektig': ('nederdrektig',),
'nederdrektige': ('nederdrektig',),
'nederdrektigere': ('nederdrektig',),
'nederdrektigst': ('nederdrektig',),
'nederdrektigste': ('nederdrektig',),
'nederlandsk': ('nederlandsk',),
'nederlandske': ('nederlandsk',),
'nederlandskere': ('nederlandsk',),
'nederlandskest': ('nederlandsk',),
'nederlandskeste': ('nederlandsk',),
'nederst': ('nederst',),
'nederste': ('nederst',),
'nederstere': ('nederst',),
'nederstest': ('nederst',),
'nedersteste': ('nederst',),
'nederst': ('nederst',),
'nederste': ('nederst',),
'nederstere': ('nederst',),
'nederstest': ('nederst',),
'nedersteste': ('nederst',),
'nedfellende': ('nedfelle',),
'nedfelt': ('nedfelle',),
'nedfelte': ('nedfelle',),
'nedfor': ('nedfor',),
'nedgravd': ('nedgravd',),
'nedgravde': ('nedgravd',),
'nedgravdere': ('nedgravd',),
'nedgravdest': ('nedgravd',),
'nedgravdeste': ('nedgravd',),
'nedgravede': ('nedgravet',),
'nedgravet': ('nedgravet',),
'nedgravete': ('nedgravet',),
'nedgravetere': ('nedgravet',),
'nedgravetest': ('nedgravet',),
'nedgraveteste': ('nedgravet',),
'nedgrodd': ('nedgrodd',),
'nedgrodde': ('nedgrodd',),
'nedgroddere': ('nedgrodd',),
'nedgroddest': ('nedgrodd',),
'nedgroddeste': ('nedgrodd',),
'nedgående': ('nedgående',),
'nedisa': ('nedisa',),
'nedisede': ('nediset',),
'nediset': ('nediset',),
'nedisete': ('nediset',),
'nedisetere': ('nediset',),
'nedisetest': ('nediset',),
'nediseteste': ('nediset',),
'nedist': ('nedist',),
'nediste': ('nedist',),
'nedistere': ('nedist',),
'nedistest': ('nedist',),
'nedisteste': ('nedist',),
'nedkallende': ('nedkalle',),
'nedkalt': ('nedkalle',),
'nedkalte': ('nedkalle',),
'nedkjempa': ('nedkjempe',),
'nedkjempede': ('nedkjempe',),
'nedkjempende': ('nedkjempe',),
'nedkjempet': ('nedkjempe',),
'nedkjempete': ('nedkjempe',),
'nedkjølende': ('nedkjøle',),
'nedkjølt': ('nedkjøle',),
'nedkjølte': ('nedkjøle',),
'nedkjørende': ('nedkjøre',),
'nedkjørt': ('nedkjøre',),
'nedkjørte': ('nedkjøre',),
'nedkommen': ('nedkomme',),
'nedkommende': ('nedkomme',),
'nedkommet': ('nedkomme',),
'nedkomne': ('nedkomme',),
'nedlatende': ('nedlate',),
'nedlatt': ('nedlate',),
'nedlatte': ('nedlate',),
'nedlatende': ('nedlatende',),
'nedlagt': ('nedlegge',),
'nedlagte': ('nedlegge',),
'nedleggende': ('nedlegge',),
'nedlessa': ('nedlessa',),
'nedlessede': ('nedlesset',),
'nedlesset': ('nedlesset',),
'nedlessete': ('nedlesset',),
'nedlessetere': ('nedlesset',),
'nedlessetest': ('nedlesset',),
'nedlesseteste': ('nedlesset',),
'nedlesst': ('nedlesst',),
'nedlesste': ('nedlesst',),
'nedlesstere': ('nedlesst',),
'nedlesstest': ('nedlesst',),
'nedlessteste': ('nedlesst',),
'nedlåst': ('nedlåst',),
'nedlåste': ('nedlåst',),
'nedlåstere': ('nedlåst',),
'nedlåstest': ('nedlåst',),
'nedlåsteste': ('nedlåst',),
'nedmolda': ('nedmolde',),
'nedmoldede': ('nedmolde',),
'nedmoldende': ('nedmolde',),
'nedmoldet': ('nedmolde',),
'nedmoldete': ('nedmolde',),
'nedmulda': ('nedmulde',),
'nedmuldede': ('nedmulde',),
'nedmuldende': ('nedmulde',),
'nedmuldet': ('nedmulde',),
'nedmuldete': ('nedmulde',),
'nedprioriterende': ('nedprioritere',),
'nedprioritert': ('nedprioritere',),
'nedprioriterte': ('nedprioritere',),
'nederst': ('nedre',),
'nederste': ('nedre',),
'nedre': ('nedre',),
'nedst': ('nedre',),
'nedste': ('nedre',),
'nedrig': ('nedrig',),
'nedrige': ('nedrig',),
'nedrigere': ('nedrig',),
'nedrigst': ('nedrig',),
'nedrigste': ('nedrig',),
'nedringa': ('nedringa',),
'nedringende': ('nedringe',),
'nedringt': ('nedringe',),
'nedringte': ('nedringe',),
'nedringede': ('nedringet',),
'nedringet': ('nedringet',),
'nedringete': ('nedringet',),
'nedringetere': ('nedringet',),
'nedringetest': ('nedringet',),
'nedringeteste': ('nedringet',),
'nedsabla': ('nedsable',),
'nedsablede': ('nedsable',),
'nedsablende': ('nedsable',),
'nedsablet': ('nedsable',),
'nedsablete': ('nedsable',),
'nedsenkbar': ('nedsenkbar',),
'nedsenkbare': ('nedsenkbar',),
'nedsenkbarere': ('nedsenkbar',),
'nedsenkbarest': ('nedsenkbar',),
'nedsenkbareste': ('nedsenkbar',),
'nedsenkbart': ('nedsenkbar',),
'nedsatt': ('nedsette',),
'nedsatte': ('nedsette',),
'nedsettende': ('nedsette',),
'nedsettende': ('nedsettende',),
'nedskreven': ('nedskreven',),
'nedskrevet': ('nedskreven',),
'nedskrevne': ('nedskreven',),
'nedskrevnere': ('nedskreven',),
'nedskrevnest': ('nedskreven',),
'nedskrevneste': ('nedskreven',),
'nedskrevet': ('nedskrevet',),
'nedskrevne': ('nedskrevet',),
'nedskrevnere': ('nedskrevet',),
'nedskrevnest': ('nedskrevet',),
'nedskrevneste': ('nedskrevet',),
'nedskreven': ('nedskrive',),
'nedskrevet': ('nedskrive',),
'nedskrevne': ('nedskrive',),
'nedskrivende': ('nedskrive',),
'nedslitt': ('nedslitt',),
'nedslitte': ('nedslitt',),
'nedslittere': ('nedslitt',),
'nedslittest': ('nedslitt',),
'nedslitteste': ('nedslitt',),
'nedslående': ('nedslående',),
'nedslått': ('nedslått',),
'nedslåtte': ('nedslått',),
'nedslåttere': ('nedslått',),
'nedslåttest': ('nedslått',),
'nedslåtteste': ('nedslått',),
'nedsnødd': ('nedsnødd',),
'nedsnødde': ('nedsnødd',),
'nedsnøddere': ('nedsnødd',),
'nedsnøddest': ('nedsnødd',),
'nedsnøddeste': ('nedsnødd',),
'nedst': ('nedst',),
'nedste': ('nedst',),
'nedstere': ('nedst',),
'nedstest': ('nedst',),
'nedsteste': ('nedst',),
'nedst': ('nedst',),
'nedste': ('nedst',),
'nedstere': ('nedst',),
'nedstest': ('nedst',),
'nedsteste': ('nedst',),
'nedstamma': ('nedstamme',),
'nedstammede': ('nedstamme',),
'nedstammende': ('nedstamme',),
'nedstammet': ('nedstamme',),
'nedstammete': ('nedstamme',),
'nedstemmende': ('nedstemme',),
'nedstemt': ('nedstemme',),
'nedstemte': ('nedstemme',),
'nedstigende': ('nedstigende',),
'nedstilt': ('nedstilt',),
'nedstilte': ('nedstilt',),
'nedstiltere': ('nedstilt',),
'nedstiltest': ('nedstilt',),
'nedstilteste': ('nedstilt',),
'nedsunket': ('nedsunket',),
'nedsunkne': ('nedsunket',),
'nedsunknere': ('nedsunket',),
'nedsunknest': ('nedsunket',),
'nedsunkneste': ('nedsunket',),
'nedsylta': ('nedsylta',),
'nedsyltede': ('nedsyltet',),
'nedsyltet': ('nedsyltet',),
'nedsyltete': ('nedsyltet',),
'nedsyltetere': ('nedsyltet',),
'nedsyltetest': ('nedsyltet',),
'nedsylteteste': ('nedsyltet',),
'nedtegna': ('nedtegne',),
'nedtegnede': ('nedtegne',),
'nedtegnende': ('nedtegne',),
'nedtegnet': ('nedtegne',),
'nedtegnete': ('nedtegne',),
'nedtrappa': ('nedtrappe',),
'nedtrappede': ('nedtrappe',),
'nedtrappende': ('nedtrappe',),
'nedtrappet': ('nedtrappe',),
'nedtrappete': ('nedtrappe',),
'nedtrykt': ('nedtrykt',),
'nedtrykte': ('nedtrykt',),
'nedtryktere': ('nedtrykt',),
'nedtryktest': ('nedtrykt',),
'nedtrykteste': ('nedtrykt',),
'nedtynga': ('nedtynga',),
'nedtyngede': ('nedtynget',),
'nedtynget': ('nedtynget',),
'nedtyngete': ('nedtynget',),
'nedtyngetere': ('nedtynget',),
'nedtyngetest': ('nedtynget',),
'nedtyngeteste': ('nedtynget',),
'nedverdiga': ('nedverdige',),
'nedverdigede': ('nedverdige',),
'nedverdigende': ('nedverdige',),
'nedverdiget': ('nedverdige',),
'nedverdigete': ('nedverdige',),
'nedvurderende': ('nedvurdere',),
'nedvurdert': ('nedvurdere',),
'nedvurderte': ('nedvurdere',),
'negativ': ('negativ',),
'negative': ('negativ',),
'negativere': ('negativ',),
'negativest': ('negativ',),
'negativeste': ('negativ',),
'negativt': ('negativ',),
'negerende': ('negere',),
'negert': ('negere',),
'negerte': ('negere',),
'neglisjerende': ('neglisjere',),
'neglisjert': ('neglisjere',),
'neglisjerte': ('neglisjere',),
'negotiabel': ('negotiabel',),
'negotiabelt': ('negotiabel',),
'negotiable': ('negotiabel',),
'negotiablere': ('negotiabel',),
'negotiablest': ('negotiabel',),
'negotiableste': ('negotiabel',),
'negroid': ('negroid',),
'negroide': ('negroid',),
'negroidere': ('negroid',),
'negroidest': ('negroid',),
'negroideste': ('negroid',),
'neia': ('neie',),
'neid': ('neie',),
'neide': ('neie',),
'neiede': ('neie',),
'neiende': ('neie',),
'neiet': ('neie',),
'neiete': ('neie',),
'neid': ('neie',),
'neide': ('neie',),
'neiede': ('neie',),
'neiende': ('neie',),
'neiet': ('neie',),
'neiete': ('neie',),
'neid': ('neie',),
'neide': ('neie',),
'neiede': ('neie',),
'neiende': ('neie',),
'neiet': ('neie',),
'neiete': ('neie',),
'nekrofil': ('nekrofil',),
'nekrofile': ('nekrofil',),
'nekrofilere': ('nekrofil',),
'nekrofilest': ('nekrofil',),
'nekrofileste': ('nekrofil',),
'nekrofilt': ('nekrofil',),
'nekta': ('nekte',),
'nektede': ('nekte',),
'nektende': ('nekte',),
'nektet': ('nekte',),
'nektete': ('nekte',),
'nem': ('nem',),
'nemme': ('nem',),
'nemmere': ('nem',),
'nemmest': ('nem',),
'nemmeste': ('nem',),
'nemt': ('nem',),
'nenna': ('nenne',),
'nennede': ('nenne',),
'nennende': ('nenne',),
'nennet': ('nenne',),
'nennete': ('nenne',),
'nent': ('nenne',),
'nente': ('nenne',),
'nennsom': ('nennsom',),
'nennsomme': ('nennsom',),
'nennsommere': ('nennsom',),
'nennsomst': ('nennsom',),
'nennsomste': ('nennsom',),
'nennsomt': ('nennsom',),
'neolittisk': ('neolittisk',),
'neolittiske': ('neolittisk',),
'neolittiskere': ('neolittisk',),
'neolittiskest': ('neolittisk',),
'neolittiskeste': ('neolittisk',),
'nepalsk': ('nepalsk',),
'nepalske': ('nepalsk',),
'nepalskere': ('nepalsk',),
'nepalskest': ('nepalsk',),
'nepalskeste': ('nepalsk',),
'nervepirrende': ('nervepirrende',),
'nerveslitende': ('nerveslitende',),
'nervesvak': ('nervesvak',),
'nervesvake': ('nervesvak',),
'nervesvakere': ('nervesvak',),
'nervesvakest': ('nervesvak',),
'nervesvakeste': ('nervesvak',),
'nervesvakt': ('nervesvak',),
'nervøs': ('nervøs',),
'nervøse': ('nervøs',),
'nervøsere': ('nervøs',),
'nervøsest': ('nervøs',),
'nervøseste': ('nervøs',),
'nervøst': ('nervøs',),
'nesevis': ('nesevis',),
'nesevise': ('nesevis',),
'nesevisere': ('nesevis',),
'nesevisest': ('nesevis',),
'neseviseste': ('nesevis',),
'nesevist': ('nesevis',),
'nesta': ('neste',),
'nestede': ('neste',),
'nestende': ('neste',),
'nestet': ('neste',),
'nestete': ('neste',),
'nestekjærlig': ('nestekjærlig',),
'nestekjærlige': ('nestekjærlig',),
'nestekjærligere': ('nestekjærlig',),
'nestekjærligst': ('nestekjærlig',),
'nestekjærligste': ('nestekjærlig',),
'nett': ('nett',),
'nette': ('nett',),
'nettere': ('nett',),
'nettest': ('nett',),
'netteste': ('nett',),
'netta': ('nette',),
'nettede': ('nette',),
'nettende': ('nette',),
'nettet': ('nette',),
'nettete': ('nette',),
'netthendt': ('netthendt',),
'netthendte': ('netthendt',),
'netthendtere': ('netthendt',),
'netthendtest': ('netthendt',),
'netthendteste': ('netthendt',),
'neurologisk': ('neurologisk',),
'neurologiske': ('neurologisk',),
'neurologiskere': ('neurologisk',),
'neurologiskest': ('neurologisk',),
'neurologiskeste': ('neurologisk',),
'neurotisk': ('neurotisk',),
'neurotiske': ('neurotisk',),
'neurotiskere': ('neurotisk',),
'neurotiskest': ('neurotisk',),
'neurotiskeste': ('neurotisk',),
'nevehelsende': ('nevehelse',),
'nevehelst': ('nevehelse',),
'nevehelste': ('nevehelse',),
'nevehilsende': ('nevehilse',),
'nevehilst': ('nevehilse',),
'nevehilste': ('nevehilse',),
'nevenyttig': ('nevenyttig',),
'nevenyttige': ('nevenyttig',),
'nevenyttigere': ('nevenyttig',),
'nevenyttigst': ('nevenyttig',),
'nevenyttigste': ('nevenyttig',),
'nevestor': ('nevestor',),
'nevestore': ('nevestor',),
'nevestort': ('nevestor',),
'nevestørre': ('nevestor',),
'nevestørst': ('nevestor',),
'nevestørste': ('nevestor',),
'nevnende': ('nevne',),
'nevnt': ('nevne',),
'nevnte': ('nevne',),
'nevneverdig': ('nevneverdig',),
'nevneverdige': ('nevneverdig',),
'nevneverdigere': ('nevneverdig',),
'nevneverdigst': ('nevneverdig',),
'nevneverdigste': ('nevneverdig',),
'nevrologisk': ('nevrologisk',),
'nevrologiske': ('nevrologisk',),
'nevrologiskere': ('nevrologisk',),
'nevrologiskest': ('nevrologisk',),
'nevrologiskeste': ('nevrologisk',),
'nevrotisk': ('nevrotisk',),
'nevrotiske': ('nevrotisk',),
'nevrotiskere': ('nevrotisk',),
'nevrotiskest': ('nevrotisk',),
'nevrotiskeste': ('nevrotisk',),
'newfoundlandsk': ('newfoundlandsk',),
'newfoundlandske': ('newfoundlandsk',),
'newfoundlandskere': ('newfoundlandsk',),
'newfoundlandskest': ('newfoundlandsk',),
'newfoundlandskeste': ('newfoundlandsk',),
'newyorksk': ('newyorksk',),
'newyorkske': ('newyorksk',),
'newyorkskere': ('newyorksk',),
'newyorkskest': ('newyorksk',),
'newyorkskeste': ('newyorksk',),
'newzealandsk': ('newzealandsk',),
'newzealandske': ('newzealandsk',),
'newzealandskere': ('newzealandsk',),
'newzealandskest': ('newzealandsk',),
'newzealandskeste': ('newzealandsk',),
'nicaraguansk': ('nicaraguansk',),
'nicaraguanske': ('nicaraguansk',),
'nicaraguanskere': ('nicaraguansk',),
'nicaraguanskest': ('nicaraguansk',),
'nicaraguanskeste': ('nicaraguansk',),
'nidkjær': ('nidkjær',),
'nidkjære': ('nidkjær',),
'nidkjærere': ('nidkjær',),
'nidkjærest': ('nidkjær',),
'nidkjæreste': ('nidkjær',),
'nidkjært': ('nidkjær',),
'nidobbel': ('nidobbel',),
'nidobbelt': ('nidobbel',),
'nidoble': ('nidobbel',),
'nidoblere': ('nidobbel',),
'nidoblest': ('nidobbel',),
'nidobleste': ('nidobbel',),
'nidobbelt': ('nidobbelt',),
'nidobbelte': ('nidobbelt',),
'nidobbeltere': ('nidobbelt',),
'nidobbeltest': ('nidobbelt',),
'nidobbelteste': ('nidobbelt',),
'nidobla': ('nidoble',),
'nidoblede': ('nidoble',),
'nidoblende': ('nidoble',),
'nidoblet': ('nidoble',),
'nidoblete': ('nidoble',),
'nidsk': ('nidsk',),
'nidske': ('nidsk',),
'nidskere': ('nidsk',),
'nidskest': ('nidsk',),
'nidskeste': ('nidsk',),
'niende': ('niende',),
'nifs': ('nifs',),
'nifse': ('nifs',),
'nifsere': ('nifs',),
'nifsest': ('nifs',),
'nifseste': ('nifs',),
'nifst': ('nifs',),
'nigeriansk': ('nigeriansk',),
'nigerianske': ('nigeriansk',),
'nigerianskere': ('nigeriansk',),
'nigerianskest': ('nigeriansk',),
'nigerianskeste': ('nigeriansk',),
'nigersk': ('nigersk',),
'nigerske': ('nigersk',),
'nigerskere': ('nigersk',),
'nigerskest': ('nigersk',),
'nigerskeste': ('nigersk',),
'nihilistisk': ('nihilistisk',),
'nihilistiske': ('nihilistisk',),
'nihilistiskere': ('nihilistisk',),
'nihilistiskest': ('nihilistisk',),
'nihilistiskeste': ('nihilistisk',),
'niholdende': ('niholde',),
'niholdt': ('niholde',),
'niholdte': ('niholde',),
'nikensk': ('nikensk',),
'nikenske': ('nikensk',),
'nikenskere': ('nikensk',),
'nikenskest': ('nikensk',),
'nikenskeste': ('nikensk',),
'nikka': ('nikke',),
'nikkede': ('nikke',),
'nikkende': ('nikke',),
'nikket': ('nikke',),
'nikkete': ('nikke',),
'niks': ('niks',),
'nippa': ('nippe',),
'nippede': ('nippe',),
'nippende': ('nippe',),
'nippet': ('nippe',),
'nippete': ('nippe',),
'nippa': ('nippe',),
'nippede': ('nippe',),
'nippende': ('nippe',),
'nippet': ('nippe',),
'nippete': ('nippe',),
'nissa': ('nisse',),
'nissede': ('nisse',),
'nissende': ('nisse',),
'nisset': ('nisse',),
'nissete': ('nisse',),
'nista': ('niste',),
'nistede': ('niste',),
'nistende': ('niste',),
'nistet': ('niste',),
'nistete': ('niste',),
'nistirra': ('nistirre',),
'nistirrede': ('nistirre',),
'nistirrende': ('nistirre',),
'nistirret': ('nistirre',),
'nistirrete': ('nistirre',),
'niten': ('niten',),
'nitent': ('niten',),
'nitne': ('niten',),
'nitnere': ('niten',),
'nitnest': ('niten',),
'nitneste': ('niten',),
'nitid': ('nitid',),
'nitide': ('nitid',),
'nitidere': ('nitid',),
'nitidest': ('nitid',),
'nitideste': ('nitid',),
'nitrerende': ('nitrere',),
'nitrert': ('nitrere',),
'nitrerte': ('nitrere',),
'nitrifiserende': ('nitrifisere',),
'nitrifisert': ('nitrifisere',),
'nitrifiserte': ('nitrifisere',),
'nitrist': ('nitrist',),
'nitriste': ('nitrist',),
'nitristere': ('nitrist',),
'nitristest': ('nitrist',),
'nitristeste': ('nitrist',),
'nitrøs': ('nitrøs',),
'nitrøse': ('nitrøs',),
'nitrøsere': ('nitrøs',),
'nitrøsest': ('nitrøs',),
'nitrøseste': ('nitrøs',),
'nitrøst': ('nitrøs',),
'nitta': ('nitte',),
'nittede': ('nitte',),
'nittende': ('nitte',),
'nittet': ('nitte',),
'nittete': ('nitte',),
'nittende': ('nittende',),
'nittenårig': ('nittenårig',),
'nittenårige': ('nittenårig',),
'nittenårigere': ('nittenårig',),
'nittenårigst': ('nittenårig',),
'nittenårigste': ('nittenårig',),
'nittenårs': ('nittenårs',),
'nittiende': ('nittiende',),
'nittiårig': ('nittiårig',),
'nittiårige': ('nittiårig',),
'nittiårigere': ('nittiårig',),
'nittiårigst': ('nittiårig',),
'nittiårigste': ('nittiårig',),
'nittiårs': ('nittiårs',),
'nivellerende': ('nivellere',),
'nivellert': ('nivellere',),
'nivellerte': ('nivellere',),
'niårig': ('niårig',),
'niårige': ('niårig',),
'niårigere': ('niårig',),
'niårigst': ('niårig',),
'niårigste': ('niårig',),
'niårs': ('niårs',),
'nobel': ('nobel',),
'nobelt': ('nobel',),
'noble': ('nobel',),
'noblere': ('nobel',),
'noblest': ('nobel',),
'nobleste': ('nobel',),
'nomadiserende': ('nomadisere',),
'nomadisert': ('nomadisere',),
'nomadiserte': ('nomadisere',),
'nomadisk': ('nomadisk',),
'nomadiske': ('nomadisk',),
'nomadiskere': ('nomadisk',),
'nomadiskest': ('nomadisk',),
'nomadiskeste': ('nomadisk',),
'nominal': ('nominal',),
'nominale': ('nominal',),
'nominalere': ('nominal',),
'nominalest': ('nominal',),
'nominaleste': ('nominal',),
'nominalt': ('nominal',),
'nominell': ('nominell',),
'nominelle': ('nominell',),
'nominellere': ('nominell',),
'nominellest': ('nominell',),
'nominelleste': ('nominell',),
'nominelt': ('nominell',),
'nominerende': ('nominere',),
'nominert': ('nominere',),
'nominerte': ('nominere',),
'non profit': ('non profit',),
'nonchalant': ('nonchalant',),
'nonchalante': ('nonchalant',),
'nonchalantere': ('nonchalant',),
'nonchalantest': ('nonchalant',),
'nonchalanteste': ('nonchalant',),
'nonchalerende': ('nonchalere',),
'nonchalert': ('nonchalere',),
'nonchalerte': ('nonchalere',),
'nonfigurativ': ('nonfigurativ',),
'nonfigurative': ('nonfigurativ',),
'nonfigurativere': ('nonfigurativ',),
'nonfigurativest': ('nonfigurativ',),
'nonfigurativeste': ('nonfigurativ',),
'nonfigurativt': ('nonfigurativ',),
'nordafjelsk': ('nordafjelsk',),
'nordafjelske': ('nordafjelsk',),
'nordafjelskere': ('nordafjelsk',),
'nordafjelskest': ('nordafjelsk',),
'nordafjelskeste': ('nordafjelsk',),
'nordamerikansk': ('nordamerikansk',),
'nordamerikanske': ('nordamerikansk',),
'nordamerikanskere': ('nordamerikansk',),
'nordamerikanskest': ('nordamerikansk',),
'nordamerikanskeste': ('nordamerikansk',),
'nordatlantisk': ('nordatlantisk',),
'nordatlantiske': ('nordatlantisk',),
'nordatlantiskere': ('nordatlantisk',),
'nordatlantiskest': ('nordatlantisk',),
'nordatlantiskeste': ('nordatlantisk',),
'nordaustlig': ('nordaustlig',),
'nordaustlige': ('nordaustlig',),
'nordaustligere': ('nordaustlig',),
'nordaustligst': ('nordaustlig',),
'nordaustligste': ('nordaustlig',),
'nordenfjelsk': ('nordenfjelsk',),
'nordenfjelske': ('nordenfjelsk',),
'nordenfjelskere': ('nordenfjelsk',),
'nordenfjelskest': ('nordenfjelsk',),
'nordenfjelskeste': ('nordenfjelsk',),
'nordgående': ('nordgående',),
'nordisk': ('nordisk',),
'nordiske': ('nordisk',),
'nordiskere': ('nordisk',),
'nordiskest': ('nordisk',),
'nordiskeste': ('nordisk',),
'nordkoreansk': ('nordkoreansk',),
'nordkoreanske': ('nordkoreansk',),
'nordkoreanskere': ('nordkoreansk',),
'nordkoreanskest': ('nordkoreansk',),
'nordkoreanskeste': ('nordkoreansk',),
'nordlandsk': ('nordlandsk',),
'nordlandske': ('nordlandsk',),
'nordlandskere': ('nordlandsk',),
'nordlandskest': ('nordlandsk',),
'nordlandskeste': ('nordlandsk',),
'nordlig': ('nordlig',),
'nordlige': ('nordlig',),
'nordligere': ('nordlig',),
'nordligst': ('nordlig',),
'nordligste': ('nordlig',),
'nordmørsk': ('nordmørsk',),
'nordmørske': ('nordmørsk',),
'nordmørskere': ('nordmørsk',),
'nordmørskest': ('nordmørsk',),
'nordmørskeste': ('nordmørsk',),
'nordnorsk': ('nordnorsk',),
'nordnorske': ('nordnorsk',),
'nordnorskere': ('nordnorsk',),
'nordnorskest': ('nordnorsk',),
'nordnorskeste': ('nordnorsk',),
'nordre': ('nordre',),
'nordre': ('nordre',),
'nordsamisk': ('nordsamisk',),
'nordsamiske': ('nordsamisk',),
'nordsamiskere': ('nordsamisk',),
'nordsamiskest': ('nordsamisk',),
'nordsamiskeste': ('nordsamisk',),
'nordvendt': ('nordvendt',),
'nordvendte': ('nordvendt',),
'nordvendtere': ('nordvendt',),
'nordvendtest': ('nordvendt',),
'nordvendteste': ('nordvendt',),
'nordvestlig': ('nordvestlig',),
'nordvestlige': ('nordvestlig',),
'nordvestligere': ('nordvestlig',),
'nordvestligst': ('nordvestlig',),
'nordvestligste': ('nordvestlig',),
'nordyemenittisk': ('nordyemenittisk',),
'nordyemenittiske': ('nordyemenittisk',),
'nordyemenittiskere': ('nordyemenittisk',),
'nordyemenittiskest': ('nordyemenittisk',),
'nordyemenittiskeste': ('nordyemenittisk',),
'nordøstlig': ('nordøstlig',),
'nordøstlige': ('nordøstlig',),
'nordøstligere': ('nordøstlig',),
'nordøstligst': ('nordøstlig',),
'nordøstligste': ('nordøstlig',),
'normal': ('normal',),
'normale': ('normal',),
'normalere': ('normal',),
'normalest': ('normal',),
'normaleste': ('normal',),
'normalt': ('normal',),
'normaliserende': ('normalisere',),
'normalisert': ('normalisere',),
'normaliserte': ('normalisere',),
'normannisk': ('normannisk',),
'normanniske': ('normannisk',),
'normanniskere': ('normannisk',),
'normanniskest': ('normannisk',),
'normanniskeste': ('normannisk',),
'normativ': ('normativ',),
'normative': ('normativ',),
'normativere': ('normativ',),
'normativest': ('normativ',),
'normativeste': ('normativ',),
'normativt': ('normativ',),
'normerende': ('normere',),
'normert': ('normere',),
'normerte': ('normere',),
'normgivende': ('normgivende',),
'normlaus': ('normlaus',),
'normlause': ('normlaus',),
'normlausere': ('normlaus',),
'normlausest': ('normlaus',),
'normlauseste': ('normlaus',),
'normlaust': ('normlaus',),
'normløs': ('normløs',),
'normløse': ('normløs',),
'normløsere': ('normløs',),
'normløsest': ('normløs',),
'normløseste': ('normløs',),
'normløst': ('normløs',),
'norrøn': ('norrøn',),
'norrøne': ('norrøn',),
'norrønere': ('norrøn',),
'norrønest': ('norrøn',),
'norrøneste': ('norrøn',),
'norrønt': ('norrøn',),
'norsk': ('norsk',),
'norske': ('norsk',),
'norskere': ('norsk',),
'norskest': ('norsk',),
'norskeste': ('norsk',),
'norsk-dansk': ('norsk-dansk',),
'norsk-danske': ('norsk-dansk',),
'norsk-danskere': ('norsk-dansk',),
'norsk-danskest': ('norsk-dansk',),
'norsk-danskeste': ('norsk-dansk',),
'norskbygd': ('norskbygd',),
'norskbygde': ('norskbygd',),
'norskbygdere': ('norskbygd',),
'norskbygdest': ('norskbygd',),
'norskbygdeste': ('norskbygd',),
'norska': ('norske',),
'norskede': ('norske',),
'norskende': ('norske',),
'norsket': ('norske',),
'norskete': ('norske',),
'norskfødd': ('norskfødd',),
'norskfødde': ('norskfødd',),
'norskføddere': ('norskfødd',),
'norskføddest': ('norskfødd',),
'norskføddeste': ('norskfødd',),
'norskfødt': ('norskfødt',),
'norskfødte': ('norskfødt',),
'norskfødtere': ('norskfødt',),
'norskfødtest': ('norskfødt',),
'norskfødteste': ('norskfødt',),
'norsknorsk': ('norsknorsk',),
'norsknorske': ('norsknorsk',),
'norsknorskere': ('norsknorsk',),
'norsknorskest': ('norsknorsk',),
'norsknorskeste': ('norsknorsk',),
'norskprodusert': ('norskprodusert',),
'norskproduserte': ('norskprodusert',),
'norskprodusertere': ('norskprodusert',),
'norskprodusertest': ('norskprodusert',),
'norskproduserteste': ('norskprodusert',),
'norsktalende': ('norsktalende',),
'nostalgisk': ('nostalgisk',),
'nostalgiske': ('nostalgisk',),
'nostalgiskere': ('nostalgisk',),
'nostalgiskest': ('nostalgisk',),
'nostalgiskeste': ('nostalgisk',),
'notabel': ('notabel',),
'notabelt': ('notabel',),
'notable': ('notabel',),
'notablere': ('notabel',),
'notablest': ('notabel',),
'notableste': ('notabel',),
'notarial': ('notarial',),
'notariale': ('notarial',),
'notarialere': ('notarial',),
'notarialest': ('notarial',),
'notarialeste': ('notarial',),
'notarialt': ('notarial',),
'noterende': ('notere',),
'notert': ('notere',),
'noterte': ('notere',),
'notifiserende': ('notifisere',),
'notifisert': ('notifisere',),
'notifiserte': ('notifisere',),
'notorisk': ('notorisk',),
'notoriske': ('notorisk',),
'notoriskere': ('notorisk',),
'notoriskest': ('notorisk',),
'notoriskeste': ('notorisk',),
'novellistisk': ('novellistisk',),
'novellistiske': ('novellistisk',),
'novellistiskere': ('novellistisk',),
'novellistiskest': ('novellistisk',),
'novellistiskeste': ('novellistisk',),
'nubba': ('nubbe',),
'nubbede': ('nubbe',),
'nubbende': ('nubbe',),
'nubbet': ('nubbe',),
'nubbete': ('nubbe',),
'nubba': ('nubbe',),
'nubbede': ('nubbe',),
'nubbende': ('nubbe',),
'nubbet': ('nubbe',),
'nubbete': ('nubbe',),
'nubben': ('nubben',),
'nubbent': ('nubben',),
'nubne': ('nubben',),
'nubnere': ('nubben',),
'nubnest': ('nubben',),
'nubneste': ('nubben',),
'nubbet': ('nubbet',),
'nubbete': ('nubbet',),
'nubbetere': ('nubbet',),
'nubbetest': ('nubbet',),
'nubbeteste': ('nubbet',),
'nubbete': ('nubbete',),
'nubisk': ('nubisk',),
'nubiske': ('nubisk',),
'nubiskere': ('nubisk',),
'nubiskest': ('nubisk',),
'nubiskeste': ('nubisk',),
'nudda': ('nudde',),
'nuddede': ('nudde',),
'nuddende': ('nudde',),
'nuddet': ('nudde',),
'nuddete': ('nudde',),
'nudistisk': ('nudistisk',),
'nudistiske': ('nudistisk',),
'nudistiskere': ('nudistisk',),
'nudistiskest': ('nudistisk',),
'nudistiskeste': ('nudistisk',),
'nudistisktt': ('nudistisk',),
'nufsa': ('nufse',),
'nufsede': ('nufse',),
'nufsende': ('nufse',),
'nufset': ('nufse',),
'nufsete': ('nufse',),
'nufst': ('nufse',),
'nufste': ('nufse',),
'nugd': ('nugge',),
'nugde': ('nugge',),
'nugga': ('nugge',),
'nuggede': ('nugge',),
'nuggende': ('nugge',),
'nugget': ('nugge',),
'nuggete': ('nugge',),
'nukleær': ('nukleær',),
'nukleære': ('nukleær',),
'nukleærere': ('nukleær',),
'nukleærest': ('nukleær',),
'nukleæreste': ('nukleær',),
'nukleært': ('nukleær',),
'nulla': ('nulle',),
'nullede': ('nulle',),
'nullende': ('nulle',),
'nullet': ('nulle',),
'nullete': ('nulle',),
'nulte': ('nulte',),
'numerisk': ('numerisk',),
'numeriske': ('numerisk',),
'numeriskere': ('numerisk',),
'numeriskest': ('numerisk',),
'numeriskeste': ('numerisk',),
'numidisk': ('numidisk',),
'numidiske': ('numidisk',),
'numidiskere': ('numidisk',),
'numidiskest': ('numidisk',),
'numidiskeste': ('numidisk',),
'numismatisk': ('numismatisk',),
'numismatiske': ('numismatisk',),
'numismatiskere': ('numismatisk',),
'numismatiskest': ('numismatisk',),
'numismatiskeste': ('numismatisk',),
'nummen': ('nummen',),
'numment': ('nummen',),
'numne': ('nummen',),
'numnere': ('nummen',),
'numnest': ('nummen',),
'numneste': ('nummen',),
'nummererende': ('nummerere',),
'nummerert': ('nummerere',),
'nummererte': ('nummerere',),
'nuppa': ('nuppe',),
'nuppede': ('nuppe',),
'nuppende': ('nuppe',),
'nuppet': ('nuppe',),
'nuppete': ('nuppe',),
'nuppet': ('nuppet',),
'nuppete': ('nuppet',),
'nuppetere': ('nuppet',),
'nuppetest': ('nuppet',),
'nuppeteste': ('nuppet',),
'nuppete': ('nuppete',),
'nupra': ('nupre',),
'nuprede': ('nupre',),
'nuprende': ('nupre',),
'nupret': ('nupre',),
'nuprete': ('nupre',),
'nupret': ('nupret',),
'nuprete': ('nupret',),
'nupretere': ('nupret',),
'nupretest': ('nupret',),
'nupreteste': ('nupret',),
'nuprete': ('nuprete',),
'nurket': ('nurket',),
'nurkete': ('nurket',),
'nurketere': ('nurket',),
'nurketest': ('nurket',),
'nurketeste': ('nurket',),
'nurkete': ('nurkete',),
'nuska': ('nuske',),
'nuskede': ('nuske',),
'nuskende': ('nuske',),
'nusket': ('nuske',),
'nuskete': ('nuske',),
'nusla': ('nusle',),
'nuslede': ('nusle',),
'nuslende': ('nusle',),
'nuslet': ('nusle',),
'nuslete': ('nusle',),
'nussa': ('nusse',),
'nussede': ('nusse',),
'nussende': ('nusse',),
'nusset': ('nusse',),
'nussete': ('nusse',),
'nusselig': ('nusselig',),
'nusselige': ('nusselig',),
'nusseligere': ('nusselig',),
'nusseligst': ('nusselig',),
'nusseligste': ('nusselig',),
'nusset': ('nusset',),
'nussete': ('nusset',),
'nussetere': ('nusset',),
'nussetest': ('nusset',),
'nusseteste': ('nusset',),
'nussete': ('nussete',),
'nuvet': ('nuvet',),
'nuvete': ('nuvet',),
'nuvetere': ('nuvet',),
'nuvetest': ('nuvet',),
'nuveteste': ('nuvet',),
'nuvete': ('nuvete',),
'ny': ('ny',),
'nye': ('ny',),
'nyere': ('ny',),
'nyest': ('ny',),
'nyeste': ('ny',),
'nytt': ('ny',),
'nyankommen': ('nyankommen',),
'nyankomment': ('nyankommen',),
'nyankommet': ('nyankommen',),
'nyankomne': ('nyankommen',),
'nyankomnere': ('nyankommen',),
'nyankomnest': ('nyankommen',),
'nyankomneste': ('nyankommen',),
'nyankommet': ('nyankommet',),
'nyankomne': ('nyankommet',),
'nyankomnere': ('nyankommet',),
'nyankomnest': ('nyankommet',),
'nyankomneste': ('nyankommet',),
'nyanserende': ('nyansere',),
'nyansert': ('nyansere',),
'nyanserte': ('nyansere',),
'nybakt': ('nybakt',),
'nybakte': ('nybakt',),
'nybaktere': ('nybakt',),
'nybaktest': ('nybakt',),
'nybakteste': ('nybakt',),
'nybåren': ('nybåren',),
'nybårent': ('nybåren',),
'nybårne': ('nybåren',),
'nybårnere': ('nybåren',),
'nybårnest': ('nybåren',),
'nybårneste': ('nybåren',),
'nybær': ('nybær',),
'nybære': ('nybær',),
'nybærere': ('nybær',),
'nybærest': ('nybær',),
'nybæreste': ('nybær',),
'nybært': ('nybær',),
'nydanna': ('nydanne',),
'nydannede': ('nydanne',),
'nydannende': ('nydanne',),
'nydannet': ('nydanne',),
'nydannete': ('nydanne',),
'nydelig': ('nydelig',),
'nydelige': ('nydelig',),
'nydeligere': ('nydelig',),
'nydeligst': ('nydelig',),
'nydeligste': ('nydelig',),
'nydyrka': ('nydyrke',),
'nydyrkede': ('nydyrke',),
'nydyrkende': ('nydyrke',),
'nydyrket': ('nydyrke',),
'nydyrkete': ('nydyrke',),
'nya': ('nye',),
'nyede': ('nye',),
'nyende': ('nye',),
'nyet': ('nye',),
'nyete': ('nye',),
'nyfallen': ('nyfallen',),
'nyfallent': ('nyfallen',),
'nyfalne': ('nyfallen',),
'nyfalnere': ('nyfallen',),
'nyfalnest': ('nyfallen',),
'nyfalneste': ('nyfallen',),
'nyfiken': ('nyfiken',),
'nyfikent': ('nyfiken',),
'nyfikne': ('nyfiken',),
'nyfiknere': ('nyfiken',),
'nyfiknest': ('nyfiken',),
'nyfikneste': ('nyfiken',),
'nyfrelst': ('nyfrelst',),
'nyfrelste': ('nyfrelst',),
'nyfrelstere': ('nyfrelst',),
'nyfrelstest': ('nyfrelst',),
'nyfrelsteste': ('nyfrelst',),
'nyfødd': ('nyfødd',),
'nyfødde': ('nyfødd',),
'nyføddere': ('nyfødd',),
'nyføddest': ('nyfødd',),
'nyføddeste': ('nyfødd',),
'nyfødt': ('nyfødt',),
'nyfødte': ('nyfødt',),
'nyfødtere': ('nyfødt',),
'nyfødtest': ('nyfødt',),
'nyfødteste': ('nyfødt',),
'nygift': ('nygift',),
'nygifte': ('nygift',),
'nygiftere': ('nygift',),
'nygiftest': ('nygift',),
'nygifteste': ('nygift',),
'nykka': ('nykke',),
'nykkede': ('nykke',),
'nykkende': ('nykke',),
'nykket': ('nykke',),
'nykkete': ('nykke',),
'nykt': ('nykke',),
'nykte': ('nykke',),
'nykket': ('nykket',),
'nykkete': ('nykket',),
'nykketere': ('nykket',),
'nykketest': ('nykket',),
'nykketeste': ('nykket',),
'nykkete': ('nykkete',),
'nykverna': ('nykverna',),
'nykvernede': ('nykvernet',),
'nykvernet': ('nykvernet',),
'nykvernete': ('nykvernet',),
'nykvernetere': ('nykvernet',),
'nykvernetest': ('nykvernet',),
'nykverneteste': ('nykvernet',),
'nylaga': ('nylaga',),
'nylagd': ('nylagd',),
'nylagde': ('nylagd',),
'nylagdere': ('nylagd',),
'nylagdest': ('nylagd',),
'nylagdeste': ('nylagd',),
'nylagede': ('nylaget',),
'nylaget': ('nylaget',),
'nylagete': ('nylaget',),
'nylagetere': ('nylaget',),
'nylagetest': ('nylaget',),
'nylageteste': ('nylaget',),
'nylagt': ('nylagt',),
'nylagte': ('nylagt',),
'nylagtere': ('nylagt',),
'nylagtest': ('nylagt',),
'nylagteste': ('nylagt',),
'nylonforsterka': ('nylonforsterka',),
'nylonforsterkede': ('nylonforsterket',),
'nylonforsterket': ('nylonforsterket',),
'nylonforsterkete': ('nylonforsterket',),
'nylonforsterketere': ('nylonforsterket',),
'nylonforsterketest': ('nylonforsterket',),
'nylonforsterketeste': ('nylonforsterket',),
'nymalt': ('nymalt',),
'nymalte': ('nymalt',),
'nymaltere': ('nymalt',),
'nymaltest': ('nymalt',),
'nymalteste': ('nymalt',),
'nymfoman': ('nymfoman',),
'nymfomane': ('nymfoman',),
'nymfomanere': ('nymfoman',),
'nymfomanest': ('nymfoman',),
'nymfomaneste': ('nymfoman',),
'nymfomant': ('nymfoman',),
'nymotens': ('nymotens',),
'nynazistisk': ('nynazistisk',),
'nynazistiske': ('nynazistisk',),
'nynazistiskere': ('nynazistisk',),
'nynazistiskest': ('nynazistisk',),
'nynazistiskeste': ('nynazistisk',),
'nynna': ('nynne',),
'nynnede': ('nynne',),
'nynnende': ('nynne',),
'nynnet': ('nynne',),
'nynnete': ('nynne',),
'nynorsk': ('nynorsk',),
'nynorske': ('nynorsk',),
'nynorskere': ('nynorsk',),
'nynorskest': ('nynorsk',),
'nynorskeste': ('nynorsk',),
'nypende': ('nype',),
'nypt': ('nype',),
'nypte': ('nype',),
'nyreforma': ('nyreforma',),
'nyreformede': ('nyreformet',),
'nyreformet': ('nyreformet',),
'nyreformete': ('nyreformet',),
'nyreformetere': ('nyreformet',),
'nyreformetest': ('nyreformet',),
'nyreformeteste': ('nyreformet',),
'nyrik': ('nyrik',),
'nyrike': ('nyrik',),
'nyrikere': ('nyrik',),
'nyrikest': ('nyrik',),
'nyrikeste': ('nyrik',),
'nyrikt': ('nyrik',),
'nyrydda': ('nyrydde',),
'nyryddede': ('nyrydde',),
'nyryddende': ('nyrydde',),
'nyryddet': ('nyrydde',),
'nyryddete': ('nyrydde',),
'nysende': ('nyse',),
'nyst': ('nyse',),
'nyste': ('nyse',),
'nysgjerrig': ('nysgjerrig',),
'nysgjerrige': ('nysgjerrig',),
'nysgjerrigere': ('nysgjerrig',),
'nysgjerrigst': ('nysgjerrig',),
'nysgjerrigste': ('nysgjerrig',),
'nysilt': ('nysilt',),
'nysilte': ('nysilt',),
'nysiltere': ('nysilt',),
'nysiltest': ('nysilt',),
'nysilteste': ('nysilt',),
'nyskapa': ('nyskape',),
'nyskapende': ('nyskape',),
'nyskapt': ('nyskape',),
'nyskapte': ('nyskape',),
'nyskapende': ('nyskapende',),
'nyslått': ('nyslått',),
'nyslåtte': ('nyslått',),
'nyslåttere': ('nyslått',),
'nyslåttest': ('nyslått',),
'nyslåtteste': ('nyslått',),
'nystrøken': ('nystrøken',),
'nystrøket': ('nystrøken',),
'nystrøkne': ('nystrøken',),
'nystrøknere': ('nystrøken',),
'nystrøknest': ('nystrøken',),
'nystrøkneste': ('nystrøken',),
'nystrøket': ('nystrøket',),
'nystrøkne': ('nystrøket',),
'nystrøknere': ('nystrøket',),
'nystrøknest': ('nystrøket',),
'nystrøkneste': ('nystrøket',),
'nysådd': ('nysådd',),
'nysådde': ('nysådd',),
'nysåddere': ('nysådd',),
'nysåddest': ('nysådd',),
'nysåddeste': ('nysådd',),
'nytende': ('nyte',),
'nytt': ('nyte',),
'nytte': ('nyte',),
'nytelseslysten': ('nytelseslysten',),
'nytelseslystent': ('nytelseslysten',),
'nytelseslystne': ('nytelseslysten',),
'nytelseslystnere': ('nytelseslysten',),
'nytelseslystnest': ('nytelseslysten',),
'nytelseslystneste': ('nytelseslysten',),
'nytelsesrik': ('nytelsesrik',),
'nytelsesrike': ('nytelsesrik',),
'nytelsesrikere': ('nytelsesrik',),
'nytelsesrikest': ('nytelsesrik',),
'nytelsesrikeste': ('nytelsesrik',),
'nytelsesrikt': ('nytelsesrik',),
'nytelsessjuk': ('nytelsessjuk',),
'nytelsessjuke': ('nytelsessjuk',),
'nytelsessjukere': ('nytelsessjuk',),
'nytelsessjukest': ('nytelsessjuk',),
'nytelsessjukeste': ('nytelsessjuk',),
'nytelsessjukt': ('nytelsessjuk',),
'nytelsessyk': ('nytelsessyk',),
'nytelsessyke': ('nytelsessyk',),
'nytelsessykere': ('nytelsessyk',),
'nytelsessykest': ('nytelsessyk',),
'nytelsessykeste': ('nytelsessyk',),
'nytelsessykt': ('nytelsessyk',),
'nytestamentlig': ('nytestamentlig',),
'nytestamentlige': ('nytestamentlig',),
'nytestamentligere': ('nytestamentlig',),
'nytestamentligst': ('nytestamentlig',),
'nytestamentligste': ('nytestamentlig',),
'nytingslysten': ('nytingslysten',),
'nytingslystent': ('nytingslysten',),
'nytingslystne': ('nytingslysten',),
'nytingslystnere': ('nytingslysten',),
'nytingslystnest': ('nytingslysten',),
'nytingslystneste': ('nytingslysten',),
'nytingsrik': ('nytingsrik',),
'nytingsrike': ('nytingsrik',),
'nytingsrikere': ('nytingsrik',),
'nytingsrikest': ('nytingsrik',),
'nytingsrikeste': ('nytingsrik',),
'nytingsrikt': ('nytingsrik',),
'nytingssjuk': ('nytingssjuk',),
'nytingssjuke': ('nytingssjuk',),
'nytingssjukere': ('nytingssjuk',),
'nytingssjukest': ('nytingssjuk',),
'nytingssjukeste': ('nytingssjuk',),
'nytingssjukt': ('nytingssjuk',),
'nytingssyk': ('nytingssyk',),
'nytingssyke': ('nytingssyk',),
'nytingssykere': ('nytingssyk',),
'nytingssykest': ('nytingssyk',),
'nytingssykeste': ('nytingssyk',),
'nytingssykt': ('nytingssyk',),
'nytrukken': ('nytrukken',),
'nytrukket': ('nytrukken',),
'nytrukne': ('nytrukken',),
'nytruknere': ('nytrukken',),
'nytruknest': ('nytrukken',),
'nytrukneste': ('nytrukken',),
'nytrukket': ('nytrukket',),
'nytrukne': ('nytrukket',),
'nytruknere': ('nytrukket',),
'nytruknest': ('nytrukket',),
'nytrukneste': ('nytrukket',),
'nyttbar': ('nyttbar',),
'nyttbare': ('nyttbar',),
'nyttbarere': ('nyttbar',),
'nyttbarest': ('nyttbar',),
'nyttbareste': ('nyttbar',),
'nyttbart': ('nyttbar',),
'nytta': ('nytte',),
'nyttede': ('nytte',),
'nyttende': ('nytte',),
'nyttet': ('nytte',),
'nyttete': ('nytte',),
'nyttelaus': ('nyttelaus',),
'nyttelause': ('nyttelaus',),
'nyttelausere': ('nyttelaus',),
'nyttelausest': ('nyttelaus',),
'nyttelauseste': ('nyttelaus',),
'nyttelaust': ('nyttelaus',),
'nytteløs': ('nytteløs',),
'nytteløse': ('nytteløs',),
'nytteløsere': ('nytteløs',),
'nytteløsest': ('nytteløs',),
'nytteløseste': ('nytteløs',),
'nytteløst': ('nytteløs',),
'nyttig': ('nyttig',),
'nyttige': ('nyttig',),
'nyttigere': ('nyttig',),
'nyttigst': ('nyttig',),
'nyttigste': ('nyttig',),
'nyttiggjort': ('nyttiggjøre',),
'nyttiggjorte': ('nyttiggjøre',),
'nyttiggjørende': ('nyttiggjøre',),
'nyutsprungen': ('nyutsprungen',),
'nyutsprunget': ('nyutsprungen',),
'nyutsprungne': ('nyutsprungen',),
'nyutsprungnere': ('nyutsprungen',),
'nyutsprungnest': ('nyutsprungen',),
'nyutsprungneste': ('nyutsprungen',),
'nyutsprunget': ('nyutsprunget',),
'nyutsprungne': ('nyutsprunget',),
'nyutsprungnere': ('nyutsprunget',),
'nyutsprungnest': ('nyutsprunget',),
'nyutsprungneste': ('nyutsprunget',),
'nyvd': ('nyve',),
'nyvde': ('nyve',),
'nyvende': ('nyve',),
'nyzealandsk': ('nyzealandsk',),
'nyzealandske': ('nyzealandsk',),
'nyzealandskere': ('nyzealandsk',),
'nyzealandskest': ('nyzealandsk',),
'nyzealandskeste': ('nyzealandsk',),
'nådd': ('nå',),
'nådde': ('nå',),
'nående': ('nå',),
'nåbleik': ('nåbleik',),
'nåbleike': ('nåbleik',),
'nåbleikere': ('nåbleik',),
'nåbleikest': ('nåbleik',),
'nåbleikeste': ('nåbleik',),
'nåbleikt': ('nåbleik',),
'nådefull': ('nådefull',),
'nådefulle': ('nådefull',),
'nådefullere': ('nådefull',),
'nådefullest': ('nådefull',),
'nådefulleste': ('nådefull',),
'nådefullt': ('nådefull',),
'nådelaus': ('nådelaus',),
'nådelause': ('nådelaus',),
'nådelausere': ('nådelaus',),
'nådelausest': ('nådelaus',),
'nådelauseste': ('nådelaus',),
'nådelaust': ('nådelaus',),
'nådeløs': ('nådeløs',),
'nådeløse': ('nådeløs',),
'nådeløsere': ('nådeløs',),
'nådeløsest': ('nådeløs',),
'nådeløseste': ('nådeløs',),
'nådeløst': ('nådeløs',),
'nådig': ('nådig',),
'nådige': ('nådig',),
'nådigere': ('nådig',),
'nådigst': ('nådig',),
'nådigste': ('nådig',),
'nåen': ('nåen',),
'nåene': ('nåen',),
'nåenere': ('nåen',),
'nåenest': ('nåen',),
'nåeneste': ('nåen',),
'nåent': ('nåen',),
'nåne': ('nåen',),
'nånere': ('nåen',),
'nånest': ('nåen',),
'nåneste': ('nåen',),
'någjeldende': ('någjeldende',),
'nålespiss': ('nålespiss',),
'nålespisse': ('nålespiss',),
'nålespissere': ('nålespiss',),
'nålespissest': ('nålespiss',),
'nålespisseste': ('nålespiss',),
'nålespisst': ('nålespiss',),
'nålevende': ('nålevende',),
'nålspiss': ('nålspiss',),
'nålspisse': ('nålspiss',),
'nålspissere': ('nålspiss',),
'nålspissest': ('nålspiss',),
'nålspisseste': ('nålspiss',),
'nålspisst': ('nålspiss',),
'nåslig': ('nåslig',),
'nåslige': ('nåslig',),
'nåsligere': ('nåslig',),
'nåsligst': ('nåslig',),
'nåsligste': ('nåslig',),
'nåtidig': ('nåtidig',),
'nåtidige': ('nåtidig',),
'nåtidigere': ('nåtidig',),
'nåtidigst': ('nåtidig',),
'nåtidigste': ('nåtidig',),
'nåtla': ('nåtle',),
'nåtlede': ('nåtle',),
'nåtlende': ('nåtle',),
'nåtlet': ('nåtle',),
'nåtlete': ('nåtle',),
'nåværende': ('nåværende',),
'nær': ('nær',),
'nære': ('nær',),
'nærere': ('nær',),
'nærest': ('nær',),
'næreste': ('nær',),
'nærmere': ('nær',),
'nærmest': ('nær',),
'nærmeste': ('nær',),
'nært': ('nær',),
'nær': ('nær',),
'nærere': ('nær',),
'nærest': ('nær',),
'nærmere': ('nær',),
'nærmest': ('nær',),
'nærbeslekta': ('nærbeslekta',),
'nærbeslektede': ('nærbeslektet',),
'nærbeslektet': ('nærbeslektet',),
'nærbeslektete': ('nærbeslektet',),
'nærbeslektetere': ('nærbeslektet',),
'nærbeslektetest': ('nærbeslektet',),
'nærbeslekteteste': ('nærbeslektet',),
'næra': ('nære',),
'nærede': ('nære',),
'nærende': ('nære',),
'næret': ('nære',),
'nærete': ('nære',),
'nært': ('nære',),
'nærte': ('nære',),
'nærende': ('nærende',),
'næreste': ('næreste',),
'nærgående': ('nærgående',),
'nærig': ('nærig',),
'nærige': ('nærig',),
'nærigere': ('nærig',),
'nærigst': ('nærig',),
'nærigste': ('nærig',),
'næringsdrivende': ('næringsdrivende',),
'næringsrik': ('næringsrik',),
'næringsrike': ('næringsrik',),
'næringsrikere': ('næringsrik',),
'næringsrikest': ('næringsrik',),
'næringsrikeste': ('næringsrik',),
'næringsrikt': ('næringsrik',),
'næringssvak': ('næringssvak',),
'næringssvake': ('næringssvak',),
'næringssvakere': ('næringssvak',),
'næringssvakest': ('næringssvak',),
'næringssvakeste': ('næringssvak',),
'næringssvakt': ('næringssvak',),
'nærlesende': ('nærlese',),
'nærlest': ('nærlese',),
'nærleste': ('nærlese',),
'nærliggende': ('nærliggende',),
'nærma': ('nærme',),
'nærmede': ('nærme',),
'nærmende': ('nærme',),
'nærmet': ('nærme',),
'nærmete': ('nærme',),
'nærmere': ('nærmere',),
'nærmeste': ('nærmeste',),
'nærskyld': ('nærskyld',),
'nærskylde': ('nærskyld',),
'nærskyldere': ('nærskyld',),
'nærskyldest': ('nærskyld',),
'nærskyldeste': ('nærskyld',),
'nærskyldt': ('nærskyld',),
'nærskyldt': ('nærskyldt',),
'nærskyldte': ('nærskyldt',),
'nærskyldtere': ('nærskyldt',),
'nærskyldtest': ('nærskyldt',),
'nærskyldteste': ('nærskyldt',),
'nærstående': ('nærstående',),
'nærsynt': ('nærsynt',),
'nærsynte': ('nærsynt',),
'nærsyntere': ('nærsynt',),
'nærsyntest': ('nærsynt',),
'nærsynteste': ('nærsynt',),
'nærtagen': ('nærtagen',),
'nærtagent': ('nærtagen',),
'nærtagne': ('nærtagen',),
'nærtagnere': ('nærtagen',),
'nærtagnest': ('nærtagen',),
'nærtagneste': ('nærtagen',),
'nærtagende': ('nærtagende',),
'nærtaken': ('nærtaken',),
'nærtakent': ('nærtaken',),
'nærtakne': ('nærtaken',),
'nærtaknere': ('nærtaken',),
'nærtaknest': ('nærtaken',),
'nærtakneste': ('nærtaken',),
'nærtakende': ('nærtakende',),
'nærværende': ('nærværende',),
'nødd': ('nø',),
'nødde': ('nø',),
'nøende': ('nø',),
'nødd': ('nø',),
'nødde': ('nø',),
'nøende': ('nø',),
'nøda': ('nøde',),
'nødd': ('nøde',),
'nødde': ('nøde',),
'nødede': ('nøde',),
'nødende': ('nøde',),
'nødet': ('nøde',),
'nødete': ('nøde',),
'nøda': ('nøde',),
'nødd': ('nøde',),
'nødde': ('nøde',),
'nødede': ('nøde',),
'nødende': ('nøde',),
'nødet': ('nøde',),
'nødete': ('nøde',),
'nødig': ('nødig',),
'nødigere': ('nødig',),
'nødigst': ('nødig',),
'nødlanda': ('nødlande',),
'nødlandede': ('nødlande',),
'nødlandende': ('nødlande',),
'nødlandet': ('nødlande',),
'nødlandete': ('nødlande',),
'nødlidende': ('nødlidende',),
'nødsagede': ('nødsaget',),
'nødsaget': ('nødsaget',),
'nødsagete': ('nødsaget',),
'nødsagetere': ('nødsaget',),
'nødsagetest': ('nødsaget',),
'nødsageteste': ('nødsaget',),
'nødslakta': ('nødslakte',),
'nødslaktede': ('nødslakte',),
'nødslaktende': ('nødslakte',),
'nødslaktet': ('nødslakte',),
'nødslaktete': ('nødslakte',),
'nødstedt': ('nødstedt',),
'nødstedte': ('nødstedt',),
'nødstedtere': ('nødstedt',),
'nødstedtest': ('nødstedt',),
'nødstedteste': ('nødstedt',),
'nødstilt': ('nødstilt',),
'nødstilte': ('nødstilt',),
'nødstiltere': ('nødstilt',),
'nødstiltest': ('nødstilt',),
'nødstilteste': ('nødstilt',),
'nødt': ('nødt',),
'nødtvungen': ('nødtvungen',),
'nødtvungent': ('nødtvungen',),
'nødtvungne': ('nødtvungen',),
'nødtvungnere': ('nødtvungen',),
'nødtvungnest': ('nødtvungen',),
'nødtvungneste': ('nødtvungen',),
'nødtørftig': ('nødtørftig',),
'nødtørftige': ('nødtørftig',),
'nødtørftigere': ('nødtørftig',),
'nødtørftigst': ('nødtørftig',),
'nødtørftigste': ('nødtørftig',),
'nødvendig': ('nødvendig',),
'nødvendige': ('nødvendig',),
'nødvendigere': ('nødvendig',),
'nødvendigst': ('nødvendig',),
'nødvendigste': ('nødvendig',),
'nødvendiggjort': ('nødvendiggjøre',),
'nødvendiggjorte': ('nødvendiggjøre',),
'nødvendiggjørende': ('nødvendiggjøre',),
'nøffa': ('nøffe',),
'nøffede': ('nøffe',),
'nøffende': ('nøffe',),
'nøffet': ('nøffe',),
'nøffete': ('nøffe',),
'nøgd': ('nøgd',),
'nøgde': ('nøgd',),
'nøgdere': ('nøgd',),
'nøgdest': ('nøgd',),
'nøgdeste': ('nøgd',),
'nøkkelferdig': ('nøkkelferdig',),
'nøkkelferdige': ('nøkkelferdig',),
'nøkkelferdigere': ('nøkkelferdig',),
'nøkkelferdigst': ('nøkkelferdig',),
'nøkkelferdigste': ('nøkkelferdig',),
'nøktern': ('nøktern',),
'nøkterne': ('nøktern',),
'nøkternere': ('nøktern',),
'nøkternest': ('nøktern',),
'nøkterneste': ('nøktern',),
'nøkternt': ('nøktern',),
'nølende': ('nøle',),
'nølt': ('nøle',),
'nølte': ('nøle',),
'nørdre': ('nørdre',),
'nørdre': ('nørdre',),
'nørdst': ('nørdst',),
'nørdste': ('nørdst',),
'nøra': ('nøre',),
'nørede': ('nøre',),
'nørende': ('nøre',),
'nøret': ('nøre',),
'nørete': ('nøre',),
'nørt': ('nøre',),
'nørte': ('nøre',),
'nøsta': ('nøste',),
'nøstede': ('nøste',),
'nøstende': ('nøste',),
'nøstet': ('nøste',),
'nøstete': ('nøste',),
'nøttebrun': ('nøttebrun',),
'nøttebrune': ('nøttebrun',),
'nøttebrunere': ('nøttebrun',),
'nøttebrunest': ('nøttebrun',),
'nøttebruneste': ('nøttebrun',),
'nøttebrunt': ('nøttebrun',),
'nøyaktig': ('nøyaktig',),
'nøyaktige': ('nøyaktig',),
'nøyaktigere': ('nøyaktig',),
'nøyaktigst': ('nøyaktig',),
'nøyaktigste': ('nøyaktig',),
'nøyd': ('nøyd',),
'nøyde': ('nøyd',),
'nøydere': ('nøyd',),
'nøydest': ('nøyd',),
'nøydeste': ('nøyd',),
'nøyd': ('nøye',),
'nøyde': ('nøye',),
'nøyende': ('nøye',),
'nøye': ('nøye',),
'nøyere': ('nøye',),
'nøyest': ('nøye',),
'nøyeste': ('nøye',),
'nøyeregnende': ('nøyeregnende',),
'nøyereknende': ('nøyereknende',),
'nøysom': ('nøysom',),
'nøysomme': ('nøysom',),
'nøysommere': ('nøysom',),
'nøysomst': ('nøysom',),
'nøysomste': ('nøysom',),
'nøysomt': ('nøysom',),
'nøytende': ('nøyte',),
'nøytt': ('nøyte',),
'nøytte': ('nøyte',),
'nøytral': ('nøytral',),
'nøytrale': ('nøytral',),
'nøytralere': ('nøytral',),
'nøytralest': ('nøytral',),
'nøytraleste': ('nøytral',),
'nøytralt': ('nøytral',),
'nøytraliserende': ('nøytralisere',),
'nøytralisert': ('nøytralisere',),
'nøytraliserte': ('nøytralisere',),
'obduserende': ('obdusere',),
'obdusert': ('obdusere',),
'obduserte': ('obdusere',),
'objektiv': ('objektiv',),
'objektive': ('objektiv',),
'objektivere': ('objektiv',),
'objektivest': ('objektiv',),
'objektiveste': ('objektiv',),
'objektivt': ('objektiv',),
'objektiverende': ('objektivere',),
'objektivert': ('objektivere',),
'objektiverte': ('objektivere',),
'obligat': ('obligat',),
'obligate': ('obligat',),
'obligatere': ('obligat',),
'obligatest': ('obligat',),
'obligateste': ('obligat',),
'obligatorisk': ('obligatorisk',),
'obligatoriske': ('obligatorisk',),
'obligatoriskere': ('obligatorisk',),
'obligatoriskest': ('obligatorisk',),
'obligatoriskeste': ('obligatorisk',),
'oblik': ('oblik',),
'oblike': ('oblik',),
'oblikere': ('oblik',),
'oblikest': ('oblik',),
'oblikeste': ('oblik',),
'oblikt': ('oblik',),
'oblikk': ('oblikk',),
'oblikke': ('oblikk',),
'oblikkere': ('oblikk',),
'oblikkest': ('oblikk',),
'oblikkeste': ('oblikk',),
'oblikt': ('oblikk',),
'obs': ('obs',),
'observant': ('observant',),
'observante': ('observant',),
'observantere': ('observant',),
'observantest': ('observant',),
'observanteste': ('observant',),
'observerende': ('observere',),
'observert': ('observere',),
'observerte': ('observere',),
'obskur': ('obskur',),
'obskure': ('obskur',),
'obskurere': ('obskur',),
'obskurest': ('obskur',),
'obskureste': ('obskur',),
'obskurt': ('obskur',),
'obskurantisk': ('obskurantisk',),
'obskurantiske': ('obskurantisk',),
'obskurantiskere': ('obskurantisk',),
'obskurantiskest': ('obskurantisk',),
'obskurantiskeste': ('obskurantisk',),
'obskøn': ('obskøn',),
'obskøne': ('obskøn',),
'obskønere': ('obskøn',),
'obskønest': ('obskøn',),
'obskøneste': ('obskøn',),
'obskønt': ('obskøn',),
'obstanasig': ('obstanasig',),
'obstanasige': ('obstanasig',),
'obstanasigere': ('obstanasig',),
'obstanasigst': ('obstanasig',),
'obstanasigste': ('obstanasig',),
'obsternasig': ('obsternasig',),
'obsternasige': ('obsternasig',),
'obsternasigere': ('obsternasig',),
'obsternasigst': ('obsternasig',),
'obsternasigste': ('obsternasig',),
'obstruerende': ('obstruere',),
'obstruert': ('obstruere',),
'obstruerte': ('obstruere',),
'odde': ('odde',),
'odelsfri': ('odelsfri',),
'odelsfrie': ('odelsfri',),
'odelsfriere': ('odelsfri',),
'odelsfriest': ('odelsfri',),
'odelsfrieste': ('odelsfri',),
'odelsfritt': ('odelsfri',),
'odiøs': ('odiøs',),
'odiøse': ('odiøs',),
'odiøsere': ('odiøs',),
'odiøsest': ('odiøs',),
'odiøseste': ('odiøs',),
'odiøst': ('odiøs',),
'odla': ('odle',),
'odlede': ('odle',),
'odlende': ('odle',),
'odlet': ('odle',),
'odlete': ('odle',),
'odontologisk': ('odontologisk',),
'odontologiske': ('odontologisk',),
'odontologiskere': ('odontologisk',),
'odontologiskest': ('odontologisk',),
'odontologiskeste': ('odontologisk',),
'offensiv': ('offensiv',),
'offensive': ('offensiv',),
'offensivere': ('offensiv',),
'offensivest': ('offensiv',),
'offensiveste': ('offensiv',),
'offensivt': ('offensiv',),
'offentlig': ('offentlig',),
'offentlige': ('offentlig',),
'offentligere': ('offentlig',),
'offentligst': ('offentlig',),
'offentligste': ('offentlig',),
'offererende': ('offerere',),
'offerert': ('offerere',),
'offererte': ('offerere',),
'offervillig': ('offervillig',),
'offervillige': ('offervillig',),
'offervilligere': ('offervillig',),
'offervilligst': ('offervillig',),
'offervilligste': ('offervillig',),
'offisiell': ('offisiell',),
'offisielle': ('offisiell',),
'offisiellere': ('offisiell',),
'offisiellest': ('offisiell',),
'offisielleste': ('offisiell',),
'offisielt': ('offisiell',),
'offisinell': ('offisinell',),
'offisinelle': ('offisinell',),
'offisinellere': ('offisinell',),
'offisinellest': ('offisinell',),
'offisinelleste': ('offisinell',),
'offisinelt': ('offisinell',),
'offisiøs': ('offisiøs',),
'offisiøse': ('offisiøs',),
'offisiøsere': ('offisiøs',),
'offisiøsest': ('offisiøs',),
'offisiøseste': ('offisiøs',),
'offisiøst': ('offisiøs',),
'offline': ('offline',),
'offshore': ('offshore',),
'offwhite': ('offwhite',),
'ofra': ('ofre',),
'ofrede': ('ofre',),
'ofrende': ('ofre',),
'ofret': ('ofre',),
'ofrete': ('ofre',),
'ofselig': ('ofselig',),
'ofselige': ('ofselig',),
'ofseligere': ('ofselig',),
'ofseligst': ('ofselig',),
'ofseligste': ('ofselig',),
'ofte': ('ofte',),
'oftere': ('ofte',),
'oftest': ('ofte',),
'ohmsk': ('ohmsk',),
'ohmske': ('ohmsk',),
'ohmskere': ('ohmsk',),
'ohmskest': ('ohmsk',),
'ohmskeste': ('ohmsk',),
'oia': ('oie',),
'oiede': ('oie',),
'oiende': ('oie',),
'oiet': ('oie',),
'oiete': ('oie',),
'okergul': ('okergul',),
'okergule': ('okergul',),
'okergulere': ('okergul',),
'okergulest': ('okergul',),
'okerguleste': ('okergul',),
'okergult': ('okergul',),
'okka': ('okke',),
'okkede': ('okke',),
'okkende': ('okke',),
'okket': ('okke',),
'okkete': ('okke',),
'okklusiv': ('okklusiv',),
'okklusive': ('okklusiv',),
'okklusivere': ('okklusiv',),
'okklusivest': ('okklusiv',),
'okklusiveste': ('okklusiv',),
'okklusivt': ('okklusiv',),
'okkult': ('okkult',),
'okkulte': ('okkult',),
'okkultere': ('okkult',),
'okkultest': ('okkult',),
'okkulteste': ('okkult',),
'okkulterende': ('okkultere',),
'okkultert': ('okkultere',),
'okkulterte': ('okkultere',),
'okkuperende': ('okkupere',),
'okkupert': ('okkupere',),
'okkuperte': ('okkupere',),
'oksidativ': ('oksidativ',),
'oksidative': ('oksidativ',),
'oksidativere': ('oksidativ',),
'oksidativest': ('oksidativ',),
'oksidativeste': ('oksidativ',),
'oksidativt': ('oksidativ',),
'oksidental': ('oksidental',),
'oksidentale': ('oksidental',),
'oksidentalere': ('oksidental',),
'oksidentalest': ('oksidental',),
'oksidentaleste': ('oksidental',),
'oksidentalt': ('oksidental',),
'oksiderende': ('oksidere',),
'oksidert': ('oksidere',),
'oksiderte': ('oksidere',),
'oktogonal': ('oktogonal',),
'oktogonale': ('oktogonal',),
'oktogonalere': ('oktogonal',),
'oktogonalest': ('oktogonal',),
'oktogonaleste': ('oktogonal',),
'oktogonalt': ('oktogonal',),
'oktogonisk': ('oktogonisk',),
'oktogoniske': ('oktogonisk',),
'oktogoniskere': ('oktogonisk',),
'oktogoniskest': ('oktogonisk',),
'oktogoniskeste': ('oktogonisk',),
'oktogonisktt': ('oktogonisk',),
'okulerende': ('okulere',),
'okulert': ('okulere',),
'okulerte': ('okulere',),
'oligarkisk': ('oligarkisk',),
'oligarkiske': ('oligarkisk',),
'oligarkiskere': ('oligarkisk',),
'oligarkiskest': ('oligarkisk',),
'oligarkiskeste': ('oligarkisk',),
'oligotrof': ('oligotrof',),
'oligotrofe': ('oligotrof',),
'oligotrofere': ('oligotrof',),
'oligotrofest': ('oligotrof',),
'oligotrofeste': ('oligotrof',),
'oligotroft': ('oligotrof',),
'oliven': ('oliven',),
'olivengrøn': ('olivengrøn',),
'olivengrøne': ('olivengrøn',),
'olivengrønere': ('olivengrøn',),
'olivengrønest': ('olivengrøn',),
'olivengrøneste': ('olivengrøn',),
'olivengrønt': ('olivengrøn',),
'olivengrønn': ('olivengrønn',),
'olivengrønne': ('olivengrønn',),
'olivengrønnere': ('olivengrønn',),
'olivengrønnest': ('olivengrønn',),
'olivengrønneste': ('olivengrønn',),
'olivengrønt': ('olivengrønn',),
'olja': ('olje',),
'oljede': ('olje',),
'oljende': ('olje',),
'oljet': ('olje',),
'oljete': ('olje',),
'oljet': ('oljet',),
'oljete': ('oljet',),
'oljetere': ('oljet',),
'oljetest': ('oljet',),
'oljeteste': ('oljet',),
'oljete': ('oljete',),
'olm': ('olm',),
'olme': ('olm',),
'olmere': ('olm',),
'olmest': ('olm',),
'olmeste': ('olm',),
'olmt': ('olm',),
'olma': ('olme',),
'olmede': ('olme',),
'olmende': ('olme',),
'olmet': ('olme',),
'olmete': ('olme',),
'olympisk': ('olympisk',),
'olympiske': ('olympisk',),
'olympiskere': ('olympisk',),
'olympiskest': ('olympisk',),
'olympiskeste': ('olympisk',),
'omadresserende': ('omadressere',),
'omadressert': ('omadressere',),
'omadresserte': ('omadressere',),
'omansk': ('omansk',),
'omanske': ('omansk',),
'omanskere': ('omansk',),
'omanskest': ('omansk',),
'omanskeste': ('omansk',),
'omarbeida': ('omarbeide',),
'omarbeidd': ('omarbeide',),
'omarbeidde': ('omarbeide',),
'omarbeidede': ('omarbeide',),
'omarbeidende': ('omarbeide',),
'omarbeidet': ('omarbeide',),
'omarbeidete': ('omarbeide',),
'ombestemmende': ('ombestemme',),
'ombestemt': ('ombestemme',),
'ombestemte': ('ombestemme',),
'ombrekkende': ('ombrekke',),
'ombrukken': ('ombrekke',),
'ombrukket': ('ombrekke',),
'ombrukne': ('ombrekke',),
'ombragt': ('ombringe',),
'ombragte': ('ombringe',),
'ombrakt': ('ombringe',),
'ombrakte': ('ombringe',),
'ombringende': ('ombringe',),
'ombygd': ('ombygd',),
'ombygde': ('ombygd',),
'ombygdere': ('ombygd',),
'ombygdest': ('ombygd',),
'ombygdeste': ('ombygd',),
'ombåren': ('ombære',),
'ombåret': ('ombære',),
'ombårne': ('ombære',),
'ombærende': ('ombære',),
'omdanna': ('omdanne',),
'omdannede': ('omdanne',),
'omdannende': ('omdanne',),
'omdannet': ('omdanne',),
'omdannete': ('omdanne',),
'omdiskutert': ('omdiskutert',),
'omdiskuterte': ('omdiskutert',),
'omdiskutertere': ('omdiskutert',),
'omdiskutertest': ('omdiskutert',),
'omdiskuterteste': ('omdiskutert',),
'omfamna': ('omfamne',),
'omfamnede': ('omfamne',),
'omfamnende': ('omfamne',),
'omfamnet': ('omfamne',),
'omfamnete': ('omfamne',),
'omfamna': ('omfamne',),
'omfamnede': ('omfamne',),
'omfamnende': ('omfamne',),
'omfamnet': ('omfamne',),
'omfamnete': ('omfamne',),
'omfangsrik': ('omfangsrik',),
'omfangsrike': ('omfangsrik',),
'omfangsrikere': ('omfangsrik',),
'omfangsrikest': ('omfangsrik',),
'omfangsrikeste': ('omfangsrik',),
'omfangsrikt': ('omfangsrik',),
'omfatta': ('omfatte',),
'omfattede': ('omfatte',),
'omfattende': ('omfatte',),
'omfattet': ('omfatte',),
'omfattete': ('omfatte',),
'omfattende': ('omfattende',),
'omfavna': ('omfavne',),
'omfavnede': ('omfavne',),
'omfavnende': ('omfavne',),
'omfavnet': ('omfavne',),
'omfavnete': ('omfavne',),
'omfavna': ('omfavne',),
'omfavnede': ('omfavne',),
'omfavnende': ('omfavne',),
'omfavnet': ('omfavne',),
'omfavnete': ('omfavne',),
'omflakkende': ('omflakkende',),
'omflødd': ('omflødd',),
'omflødde': ('omflødd',),
'omfløddere': ('omflødd',),
'omfløddest': ('omflødd',),
'omfløddeste': ('omflødd',),
'omforent': ('omforent',),
'omforente': ('omforent',),
'omforentere': ('omforent',),
'omforentest': ('omforent',),
'omforenteste': ('omforent',),
'omforma': ('omforme',),
'omformede': ('omforme',),
'omformende': ('omforme',),
'omformet': ('omforme',),
'omformete': ('omforme',),
'omgiende': ('omgi',),
'omgitt': ('omgi',),
'omgitte': ('omgi',),
'omgivende': ('omgi',),
'omgjengelig': ('omgjengelig',),
'omgjengelige': ('omgjengelig',),
'omgjengeligere': ('omgjengelig',),
'omgjengeligst': ('omgjengelig',),
'omgjengeligste': ('omgjengelig',),
'omgjort': ('omgjøre',),
'omgjorte': ('omgjøre',),
'omgjørende': ('omgjøre',),
'omgående': ('omgå',),
'omgått': ('omgå',),
'omgåtte': ('omgå',),
'omgående': ('omgående',),
'omhandla': ('omhandle',),
'omhandlede': ('omhandle',),
'omhandlende': ('omhandle',),
'omhandlet': ('omhandle',),
'omhandlete': ('omhandle',),
'omhyggelig': ('omhyggelig',),
'omhyggelige': ('omhyggelig',),
'omhyggeligere': ('omhyggelig',),
'omhyggeligst': ('omhyggelig',),
'omhyggeligste': ('omhyggelig',),
'ominnreda': ('ominnrede',),
'ominnredede': ('ominnrede',),
'ominnredende': ('ominnrede',),
'ominnredet': ('ominnrede',),
'ominnredete': ('ominnrede',),
'ominøs': ('ominøs',),
'ominøse': ('ominøs',),
'ominøsere': ('ominøs',),
'ominøsest': ('ominøs',),
'ominøseste': ('ominøs',),
'ominøst': ('ominøs',),
'omkalfatra': ('omkalfatre',),
'omkalfatrede': ('omkalfatre',),
'omkalfatrende': ('omkalfatre',),
'omkalfatret': ('omkalfatre',),
'omkalfatrete': ('omkalfatre',),
'omkommen': ('omkomme',),
'omkommende': ('omkomme',),
'omkommet': ('omkomme',),
'omkomne': ('omkomme',),
'omkommen': ('omkommen',),
'omkomment': ('omkommen',),
'omkomne': ('omkommen',),
'omkomnere': ('omkommen',),
'omkomnest': ('omkommen',),
'omkomneste': ('omkommen',),
'omliggende': ('omliggende',),
'omlydt': ('omlydt',),
'omlydte': ('omlydt',),
'omlydtere': ('omlydt',),
'omlydtest': ('omlydt',),
'omlydteste': ('omlydt',),
'omløpende': ('omløpende',),
'ommøblerende': ('ommøblere',),
'ommøblert': ('ommøblere',),
'ommøblerte': ('ommøblere',),
'omorganiserende': ('omorganisere',),
'omorganisert': ('omorganisere',),
'omorganiserte': ('omorganisere',),
'omplanta': ('omplante',),
'omplantede': ('omplante',),
'omplantende': ('omplante',),
'omplantet': ('omplante',),
'omplantete': ('omplante',),
'ompotta': ('ompotte',),
'ompottede': ('ompotte',),
'ompottende': ('ompotte',),
'ompottet': ('ompotte',),
'ompottete': ('ompotte',),
'omprikla': ('omprikle',),
'ompriklede': ('omprikle',),
'ompriklende': ('omprikle',),
'ompriklet': ('omprikle',),
'ompriklete': ('omprikle',),
'omprioriterende': ('omprioritere',),
'omprioritert': ('omprioritere',),
'omprioriterte': ('omprioritere',),
'omprøvd': ('omprøve',),
'omprøvde': ('omprøve',),
'omprøvende': ('omprøve',),
'omramma': ('omramme',),
'omrammede': ('omramme',),
'omrammende': ('omramme',),
'omrammet': ('omramme',),
'omrammete': ('omramme',),
'omredigerende': ('omredigere',),
'omredigert': ('omredigere',),
'omredigerte': ('omredigere',),
'omregna': ('omregne',),
'omregnede': ('omregne',),
'omregnende': ('omregne',),
'omregnet': ('omregne',),
'omregnete': ('omregne',),
'omrekna': ('omrekne',),
'omreknede': ('omrekne',),
'omreknende': ('omrekne',),
'omreknet': ('omrekne',),
'omreknete': ('omrekne',),
'omringa': ('omringe',),
'omringede': ('omringe',),
'omringende': ('omringe',),
'omringet': ('omringe',),
'omringete': ('omringe',),
'områdd': ('områ',),
'områdde': ('områ',),
'områende': ('områ',),
'omrømma': ('omrømme',),
'omrømmede': ('omrømme',),
'omrømmende': ('omrømme',),
'omrømmet': ('omrømme',),
'omrømmete': ('omrømme',),
'omseggripende': ('omseggripende',),
'omsatt': ('omsette',),
'omsatte': ('omsette',),
'omsettende': ('omsette',),
'omsettelig': ('omsettelig',),
'omsettelige': ('omsettelig',),
'omsetteligere': ('omsettelig',),
'omsetteligst': ('omsettelig',),
'omsetteligste': ('omsettelig',),
'omskapa': ('omskape',),
'omskapende': ('omskape',),
'omskapt': ('omskape',),
'omskapte': ('omskape',),
'omskiftelig': ('omskiftelig',),
'omskiftelige': ('omskiftelig',),
'omskifteligere': ('omskiftelig',),
'omskifteligst': ('omskiftelig',),
'omskifteligste': ('omskiftelig',),
'omskjærende': ('omskjære',),
'omskåren': ('omskjære',),
'omskåret': ('omskjære',),
'omskårne': ('omskjære',),
'omskolende': ('omskole',),
'omskolt': ('omskole',),
'omskolte': ('omskole',),
'omskolerende': ('omskolere',),
'omskolert': ('omskolere',),
'omskolerte': ('omskolere',),
'omskreven': ('omskreven',),
'omskrevet': ('omskreven',),
'omskrevne': ('omskreven',),
'omskrevnere': ('omskreven',),
'omskrevnest': ('omskreven',),
'omskrevneste': ('omskreven',),
'omskrevet': ('omskrevet',),
'omskrevne': ('omskrevet',),
'omskrevnere': ('omskrevet',),
'omskrevnest': ('omskrevet',),
'omskrevneste': ('omskrevet',),
'omskreven': ('omskrive',),
'omskrevet': ('omskrive',),
'omskrevne': ('omskrive',),
'omskrivende': ('omskrive',),
'omslutta': ('omslutte',),
'omsluttede': ('omslutte',),
'omsluttende': ('omslutte',),
'omsluttet': ('omslutte',),
'omsluttete': ('omslutte',),
'omslynga': ('omslynge',),
'omslyngede': ('omslynge',),
'omslyngende': ('omslynge',),
'omslynget': ('omslynge',),
'omslyngete': ('omslynge',),
'omslyngt': ('omslynge',),
'omslyngte': ('omslynge',),
'omsnakka': ('omsnakka',),
'omsnakkede': ('omsnakket',),
'omsnakket': ('omsnakket',),
'omsnakkete': ('omsnakket',),
'omsnakketere': ('omsnakket',),
'omsnakketest': ('omsnakket',),
'omsnakketeste': ('omsnakket',),
'omsnudd': ('omsnudd',),
'omsnudde': ('omsnudd',),
'omsnuddere': ('omsnudd',),
'omsnuddest': ('omsnudd',),
'omsnuddeste': ('omsnudd',),
'omsorgsfull': ('omsorgsfull',),
'omsorgsfulle': ('omsorgsfull',),
'omsorgsfullere': ('omsorgsfull',),
'omsorgsfullest': ('omsorgsfull',),
'omsorgsfulleste': ('omsorgsfull',),
'omsorgsfullt': ('omsorgsfull',),
'omspent': ('omspent',),
'omspente': ('omspent',),
'omspentere': ('omspent',),
'omspentest': ('omspent',),
'omspenteste': ('omspent',),
'omspunne': ('omspunnet',),
'omspunnere': ('omspunnet',),
'omspunnest': ('omspunnet',),
'omspunneste': ('omspunnet',),
'omspunnet': ('omspunnet',),
'omspurt': ('omspurt',),
'omspurte': ('omspurt',),
'omspurtere': ('omspurt',),
'omspurtest': ('omspurt',),
'omspurteste': ('omspurt',),
'omstendelig': ('omstendelig',),
'omstendelige': ('omstendelig',),
'omstendeligere': ('omstendelig',),
'omstendeligst': ('omstendelig',),
'omstendeligste': ('omstendelig',),
'omstillende': ('omstille',),
'omstilt': ('omstille',),
'omstilte': ('omstille',),
'omstridd': ('omstridd',),
'omstridde': ('omstridd',),
'omstriddere': ('omstridd',),
'omstriddest': ('omstridd',),
'omstriddeste': ('omstridd',),
'omstridt': ('omstridt',),
'omstridte': ('omstridt',),
'omstridtere': ('omstridt',),
'omstridtest': ('omstridt',),
'omstridteste': ('omstridt',),
'omstrukturerende': ('omstrukturere',),
'omstrukturert': ('omstrukturere',),
'omstrukturerte': ('omstrukturere',),
'omstyrta': ('omstyrte',),
'omstyrtede': ('omstyrte',),
'omstyrtende': ('omstyrte',),
'omstyrtet': ('omstyrte',),
'omstyrtete': ('omstyrte',),
'omstøtende': ('omstøte',),
'omstøtt': ('omstøte',),
'omstøtte': ('omstøte',),
'omsverma': ('omsverma',),
'omsvermede': ('omsvermet',),
'omsvermet': ('omsvermet',),
'omsvermete': ('omsvermet',),
'omsvermetere': ('omsvermet',),
'omsvermetest': ('omsvermet',),
'omsvermeteste': ('omsvermet',),
'omtala': ('omtale',),
'omtalende': ('omtale',),
'omtalt': ('omtale',),
'omtalte': ('omtale',),
'omtenksom': ('omtenksom',),
'omtenksomme': ('omtenksom',),
'omtenksommere': ('omtenksom',),
'omtenksomst': ('omtenksom',),
'omtenksomste': ('omtenksom',),
'omtenksomt': ('omtenksom',),
'omtrentlig': ('omtrentlig',),
'omtrentlige': ('omtrentlig',),
'omtrentligere': ('omtrentlig',),
'omtrentligst': ('omtrentlig',),
'omtrentligste': ('omtrentlig',),
'omtumla': ('omtumla',),
'omtumlede': ('omtumlet',),
'omtumlet': ('omtumlet',),
'omtumlete': ('omtumlet',),
'omtumletere': ('omtumlet',),
'omtumletest': ('omtumlet',),
'omtumleteste': ('omtumlet',),
'omtvista': ('omtvista',),
'omtvistelig': ('omtvistelig',),
'omtvistelige': ('omtvistelig',),
'omtvisteligere': ('omtvistelig',),
'omtvisteligst': ('omtvistelig',),
'omtvisteligste': ('omtvistelig',),
'omtvistede': ('omtvistet',),
'omtvistet': ('omtvistet',),
'omtvistete': ('omtvistet',),
'omtvistetere': ('omtvistet',),
'omtvistetest': ('omtvistet',),
'omtvisteteste': ('omtvistet',),
'omtykt': ('omtykt',),
'omtykte': ('omtykt',),
'omtyktere': ('omtykt',),
'omtyktest': ('omtykt',),
'omtykteste': ('omtykt',),
'omtåka': ('omtåka',),
'omtåkede': ('omtåket',),
'omtåket': ('omtåket',),
'omtåkete': ('omtåket',),
'omtåketere': ('omtåket',),
'omtåketest': ('omtåket',),
'omtåketeste': ('omtåket',),
'omvandla': ('omvandle',),
'omvandlede': ('omvandle',),
'omvandlende': ('omvandle',),
'omvandlet': ('omvandle',),
'omvandlete': ('omvandle',),
'omvekslende': ('omvekslende',),
'omvelta': ('omvelte',),
'omveltede': ('omvelte',),
'omveltende': ('omvelte',),
'omveltet': ('omvelte',),
'omveltete': ('omvelte',),
'omvendende': ('omvende',),
'omvendt': ('omvende',),
'omvendte': ('omvende',),
'omvendt': ('omvendt',),
'omvendte': ('omvendt',),
'omvendtere': ('omvendt',),
'omvendtest': ('omvendt',),
'omvendteste': ('omvendt',),
'omvurderende': ('omvurdere',),
'omvurdert': ('omvurdere',),
'omvurderte': ('omvurdere',),
'omvølende': ('omvøle',),
'omvølt': ('omvøle',),
'omvølte': ('omvøle',),
'onanerende': ('onanere',),
'onanert': ('onanere',),
'onanerte': ('onanere',),
'ond': ('ond',),
'onde': ('ond',),
'ondere': ('ond',),
'ondest': ('ond',),
'ondeste': ('ond',),
'ondt': ('ond',),
'verre': ('ond',),
'verst': ('ond',),
'verste': ('ond',),
'ondarta': ('ondarta',),
'ondartede': ('ondartet',),
'ondartet': ('ondartet',),
'ondartete': ('ondartet',),
'ondartetere': ('ondartet',),
'ondartetest': ('ondartet',),
'ondarteteste': ('ondartet',),
'ondsinna': ('ondsinna',),
'ondsinnede': ('ondsinnet',),
'ondsinnet': ('ondsinnet',),
'ondsinnete': ('ondsinnet',),
'ondsinnetere': ('ondsinnet',),
'ondsinnetest': ('ondsinnet',),
'ondsinneteste': ('ondsinnet',),
'ondskapsfull': ('ondskapsfull',),
'ondskapsfulle': ('ondskapsfull',),
'ondskapsfullere': ('ondskapsfull',),
'ondskapsfullest': ('ondskapsfull',),
'ondskapsfulleste': ('ondskapsfull',),
'ondskapsfullt': ('ondskapsfull',),
'ondulerende': ('ondulere',),
'ondulert': ('ondulere',),
'ondulerte': ('ondulere',),
'online': ('online',),
'onna': ('onne',),
'onnede': ('onne',),
'onnende': ('onne',),
'onnet': ('onne',),
'onnete': ('onne',),
'onomatopoetisk': ('onomatopoetisk',),
'onomatopoetiske': ('onomatopoetisk',),
'onomatopoetiskere': ('onomatopoetisk',),
'onomatopoetiskest': ('onomatopoetisk',),
'onomatopoetiskeste': ('onomatopoetisk',),
'ontogenetisk': ('ontogenetisk',),
'ontogenetiske': ('ontogenetisk',),
'ontogenetiskere': ('ontogenetisk',),
'ontogenetiskest': ('ontogenetisk',),
'ontogenetiskeste': ('ontogenetisk',),
'ontologisk': ('ontologisk',),
'ontologiske': ('ontologisk',),
'ontologiskere': ('ontologisk',),
'ontologiskest': ('ontologisk',),
'ontologiskeste': ('ontologisk',),
'opak': ('opak',),
'opake': ('opak',),
'opakere': ('opak',),
'opakest': ('opak',),
'opakeste': ('opak',),
'opakt': ('opak',),
'opalescerende': ('opalescere',),
'opalescert': ('opalescere',),
'opalescerte': ('opalescere',),
'opaliserende': ('opalisere',),
'opalisert': ('opalisere',),
'opaliserte': ('opalisere',),
'operasjonaliserende': ('operasjonalisere',),
'operasjonalisert': ('operasjonalisere',),
'operasjonaliserte': ('operasjonalisere',),
'operasjonell': ('operasjonell',),
'operasjonelle': ('operasjonell',),
'operasjonellere': ('operasjonell',),
'operasjonellest': ('operasjonell',),
'operasjonelleste': ('operasjonell',),
'operasjonelt': ('operasjonell',),
'operativ': ('operativ',),
'operative': ('operativ',),
'operativere': ('operativ',),
'operativest': ('operativ',),
'operativeste': ('operativ',),
'operativt': ('operativ',),
'opererende': ('operere',),
'operert': ('operere',),
'opererte': ('operere',),
'opinionsdannende': ('opinionsdannende',),
'oppadgående': ('oppadgående',),
'opparbeida': ('opparbeide',),
'opparbeidd': ('opparbeide',),
'opparbeidde': ('opparbeide',),
'opparbeidede': ('opparbeide',),
'opparbeidende': ('opparbeide',),
'opparbeidet': ('opparbeide',),
'opparbeidete': ('opparbeide',),
'oppast': ('oppast',),
'oppaste': ('oppast',),
'oppastere': ('oppast',),
'oppastest': ('oppast',),
'oppasteste': ('oppast',),
'oppbevarende': ('oppbevare',),
'oppbevart': ('oppbevare',),
'oppbevarte': ('oppbevare',),
'oppblanda': ('oppblanda',),
'oppblandede': ('oppblandet',),
'oppblandet': ('oppblandet',),
'oppblandete': ('oppblandet',),
'oppblandetere': ('oppblandet',),
'oppblandetest': ('oppblandet',),
'oppblandeteste': ('oppblandet',),
'oppblåst': ('oppblåst',),
'oppblåste': ('oppblåst',),
'oppblåstere': ('oppblåst',),
'oppblåstest': ('oppblåst',),
'oppblåsteste': ('oppblåst',),
'oppbrakt': ('oppbrakt',),
'oppbrakte': ('oppbrakt',),
'oppbraktere': ('oppbrakt',),
'oppbraktest': ('oppbrakt',),
'oppbrakteste': ('oppbrakt',),
'oppbragt': ('oppbringe',),
'oppbragte': ('oppbringe',),
'oppbrakt': ('oppbringe',),
'oppbrakte': ('oppbringe',),
'oppbringende': ('oppbringe',),
'oppbygd': ('oppbygge',),
'oppbygde': ('oppbygge',),
'oppbygga': ('oppbygge',),
'oppbyggede': ('oppbygge',),
'oppbyggende': ('oppbygge',),
'oppbygget': ('oppbygge',),
'oppbyggete': ('oppbygge',),
'oppbyggelig': ('oppbyggelig',),
'oppbyggelige': ('oppbyggelig',),
'oppbyggeligere': ('oppbyggelig',),
'oppbyggeligst': ('oppbyggelig',),
'oppbyggeligste': ('oppbyggelig',),
'oppdaga': ('oppdage',),
'oppdagede': ('oppdage',),
'oppdagende': ('oppdage',),
'oppdaget': ('oppdage',),
'oppdagete': ('oppdage',),
'oppdaterende': ('oppdatere',),
'oppdatert': ('oppdatere',),
'oppdaterte': ('oppdatere',),
'oppdikta': ('oppdikta',),
'oppdiktede': ('oppdiktet',),
'oppdiktet': ('oppdiktet',),
'oppdiktete': ('oppdiktet',),
'oppdiktetere': ('oppdiktet',),
'oppdiktetest': ('oppdiktet',),
'oppdikteteste': ('oppdiktet',),
'oppdradd': ('oppdra',),
'oppdradde': ('oppdra',),
'oppdragende': ('oppdra',),
'oppdratt': ('oppdra',),
'oppdratte': ('oppdra',),
'oppdretta': ('oppdrette',),
'oppdrettede': ('oppdrette',),
'oppdrettende': ('oppdrette',),
'oppdrettet': ('oppdrette',),
'oppdrettete': ('oppdrette',),
'oppdrevede': ('oppdrevet',),
'oppdrevet': ('oppdrevet',),
'oppdrevete': ('oppdrevet',),
'oppdrevetere': ('oppdrevet',),
'oppdrevetest': ('oppdrevet',),
'oppdreveteste': ('oppdrevet',),
'oppdyrka': ('oppdyrke',),
'oppdyrkede': ('oppdyrke',),
'oppdyrkende': ('oppdyrke',),
'oppdyrket': ('oppdyrke',),
'oppdyrkete': ('oppdyrke',),
'oppa': ('oppe',),
'oppede': ('oppe',),
'oppende': ('oppe',),
'oppet': ('oppe',),
'oppete': ('oppe',),
'oppebia': ('oppebie',),
'oppebidd': ('oppebie',),
'oppebidde': ('oppebie',),
'oppebiede': ('oppebie',),
'oppebiende': ('oppebie',),
'oppebiet': ('oppebie',),
'oppebiete': ('oppebie',),
'oppegående': ('oppegående',),
'oppelska': ('oppelske',),
'oppelskede': ('oppelske',),
'oppelskende': ('oppelske',),
'oppelsket': ('oppelske',),
'oppelskete': ('oppelske',),
'oppesen': ('oppesen',),
'oppesent': ('oppesen',),
'oppesne': ('oppesen',),
'oppesnere': ('oppesen',),
'oppesnest': ('oppesen',),
'oppesneste': ('oppesen',),
'oppfanga': ('oppfange',),
'oppfangede': ('oppfange',),
'oppfangende': ('oppfange',),
'oppfanget': ('oppfange',),
'oppfangete': ('oppfange',),
'oppfarende': ('oppfarende',),
'oppfatta': ('oppfatte',),
'oppfattede': ('oppfatte',),
'oppfattende': ('oppfatte',),
'oppfattet': ('oppfatte',),
'oppfattete': ('oppfatte',),
'oppfinnende': ('oppfinne',),
'oppfunne': ('oppfinne',),
'oppfunnen': ('oppfinne',),
'oppfunnet': ('oppfinne',),
'oppfinnsom': ('oppfinnsom',),
'oppfinnsomme': ('oppfinnsom',),
'oppfinnsommere': ('oppfinnsom',),
'oppfinnsomst': ('oppfinnsom',),
'oppfinnsomste': ('oppfinnsom',),
'oppfinnsomt': ('oppfinnsom',),
'oppfiska': ('oppfiska',),
'oppfiskede': ('oppfisket',),
'oppfisket': ('oppfisket',),
'oppfiskete': ('oppfisket',),
'oppfisketere': ('oppfisket',),
'oppfisketest': ('oppfisket',),
'oppfisketeste': ('oppfisket',),
'oppflaska': ('oppflaske',),
'oppflaskede': ('oppflaske',),
'oppflaskende': ('oppflaske',),
'oppflasket': ('oppflaske',),
'oppflaskete': ('oppflaske',),
'oppfordra': ('oppfordre',),
'oppfordrede': ('oppfordre',),
'oppfordrende': ('oppfordre',),
'oppfordret': ('oppfordre',),
'oppfordrete': ('oppfordre',),
'oppfostra': ('oppfostre',),
'oppfostrede': ('oppfostre',),
'oppfostrende': ('oppfostre',),
'oppfostret': ('oppfostre',),
'oppfostrete': ('oppfostre',),
'oppfyllende': ('oppfylle',),
'oppfylt': ('oppfylle',),
'oppfylte': ('oppfylle',),
'oppførende': ('oppføre',),
'oppført': ('oppføre',),
'oppførte': ('oppføre',),
'oppgiende': ('oppgi',),
'oppgitt': ('oppgi',),
'oppgitte': ('oppgi',),
'oppgivende': ('oppgi',),
'oppgitt': ('oppgitt',),
'oppgitte': ('oppgitt',),
'oppgittere': ('oppgitt',),
'oppgittest': ('oppgitt',),
'oppgitteste': ('oppgitt',),
'oppgjort': ('oppgjort',),
'oppgjorte': ('oppgjort',),
'oppgjortere': ('oppgjort',),
'oppgjortest': ('oppgjort',),
'oppgjorteste': ('oppgjort',),
'oppglødd': ('oppglødd',),
'oppglødde': ('oppglødd',),
'oppgløddere': ('oppglødd',),
'oppgløddest': ('oppglødd',),
'oppgløddeste': ('oppglødd',),
'opphavlig': ('opphavlig',),
'opphavlige': ('opphavlig',),
'opphavligere': ('opphavlig',),
'opphavligst': ('opphavlig',),
'opphavligste': ('opphavlig',),
'opphengt': ('opphengt',),
'opphengte': ('opphengt',),
'opphengtere': ('opphengt',),
'opphengtest': ('opphengt',),
'opphengteste': ('opphengt',),
'oppheta': ('oppheta',),
'opphetede': ('opphetet',),
'opphetet': ('opphetet',),
'opphetete': ('opphetet',),
'opphetetere': ('opphetet',),
'opphetetest': ('opphetet',),
'oppheteteste': ('opphetet',),
'oppheva': ('oppheve',),
'opphevd': ('oppheve',),
'opphevde': ('oppheve',),
'opphevede': ('oppheve',),
'opphevende': ('oppheve',),
'opphevet': ('oppheve',),
'opphevete': ('oppheve',),
'opphissa': ('opphisse',),
'opphissede': ('opphisse',),
'opphissende': ('opphisse',),
'opphisset': ('opphisse',),
'opphissete': ('opphisse',),
'opphogd': ('opphogd',),
'opphogde': ('opphogd',),
'opphogdere': ('opphogd',),
'opphogdest': ('opphogd',),
'opphogdeste': ('opphogd',),
'oppholdende': ('oppholde',),
'oppholdt': ('oppholde',),
'oppholdte': ('oppholde',),
'opphovna': ('opphovna',),
'opphovnede': ('opphovnet',),
'opphovnet': ('opphovnet',),
'opphovnete': ('opphovnet',),
'opphovnetere': ('opphovnet',),
'opphovnetest': ('opphovnet',),
'opphovneteste': ('opphovnet',),
'opphugd': ('opphugd',),
'opphugde': ('opphugd',),
'opphugdere': ('opphugd',),
'opphugdest': ('opphugd',),
'opphugdeste': ('opphugd',),
'opphørende': ('opphøre',),
'opphørt': ('opphøre',),
'opphørte': ('opphøre',),
'opphøya': ('opphøya',),
'opphøyd': ('opphøyd',),
'opphøyde': ('opphøyd',),
'opphøydere': ('opphøyd',),
'opphøydest': ('opphøyd',),
'opphøydeste': ('opphøyd',),
'opphøya': ('opphøye',),
'opphøyd': ('opphøye',),
'opphøyde': ('opphøye',),
'opphøyede': ('opphøye',),
'opphøyende': ('opphøye',),
'opphøyet': ('opphøye',),
'opphøyete': ('opphøye',),
'opphøyede': ('opphøyet',),
'opphøyet': ('opphøyet',),
'opphøyete': ('opphøyet',),
'opphøyetere': ('opphøyet',),
'opphøyetest': ('opphøyet',),
'opphøyeteste': ('opphøyet',),
'oppildna': ('oppildne',),
'oppildnede': ('oppildne',),
'oppildnende': ('oppildne',),
'oppildnet': ('oppildne',),
'oppildnete': ('oppildne',),
'oppirra': ('oppirre',),
'oppirrede': ('oppirre',),
'oppirrende': ('oppirre',),
'oppirret': ('oppirre',),
'oppirrete': ('oppirre',),
'oppjaga': ('oppjaga',),
'oppjagd': ('oppjagd',),
'oppjagde': ('oppjagd',),
'oppjagdere': ('oppjagd',),
'oppjagdest': ('oppjagd',),
'oppjagdeste': ('oppjagd',),
'oppjagede': ('oppjaget',),
'oppjaget': ('oppjaget',),
'oppjagete': ('oppjaget',),
'oppjagetere': ('oppjaget',),
'oppjagetest': ('oppjaget',),
'oppjageteste': ('oppjaget',),
'oppjusterende': ('oppjustere',),
'oppjustert': ('oppjustere',),
'oppjusterte': ('oppjustere',),
'oppkallende': ('oppkalle',),
'oppkalt': ('oppkalle',),
'oppkalte': ('oppkalle',),
'oppkasta': ('oppkaste',),
'oppkastede': ('oppkaste',),
'oppkastende': ('oppkaste',),
'oppkastet': ('oppkaste',),
'oppkastete': ('oppkaste',),
'oppkava': ('oppkava',),
'oppkavd': ('oppkavd',),
'oppkavde': ('oppkavd',),
'oppkavdere': ('oppkavd',),
'oppkavdest': ('oppkavd',),
'oppkavdeste': ('oppkavd',),
'oppkavede': ('oppkavet',),
'oppkavet': ('oppkavet',),
'oppkavete': ('oppkavet',),
'oppkavetere': ('oppkavet',),
'oppkavetest': ('oppkavet',),
'oppkaveteste': ('oppkavet',),
'oppkjast': ('oppkjast',),
'oppkjaste': ('oppkjast',),
'oppkjastere': ('oppkjast',),
'oppkjastest': ('oppkjast',),
'oppkjasteste': ('oppkjast',),
'oppkjeftig': ('oppkjeftig',),
'oppkjeftige': ('oppkjeftig',),
'oppkjeftigere': ('oppkjeftig',),
'oppkjeftigst': ('oppkjeftig',),
'oppkjeftigste': ('oppkjeftig',),
'oppkjørt': ('oppkjørt',),
'oppkjørte': ('oppkjørt',),
'oppkjørtere': ('oppkjørt',),
'oppkjørtest': ('oppkjørt',),
'oppkjørteste': ('oppkjørt',),
'oppklarende': ('oppklare',),
'oppklart': ('oppklare',),
'oppklarte': ('oppklare',),
'oppkonstruerende': ('oppkonstruere',),
'oppkonstruert': ('oppkonstruere',),
'oppkonstruerte': ('oppkonstruere',),
'oppkvikka': ('oppkvikka',),
'oppkvikkende': ('oppkvikkende',),
'oppkvikket': ('oppkvikket',),
'oppkvikkete': ('oppkvikket',),
'oppkvikketere': ('oppkvikket',),
'oppkvikketest': ('oppkvikket',),
'oppkvikketeste': ('oppkvikket',),
'opplagt': ('opplagt',),
'opplagte': ('opplagt',),
'opplagtere': ('opplagt',),
'opplagtest': ('opplagt',),
'opplagteste': ('opplagt',),
'opplandsk': ('opplandsk',),
'opplandske': ('opplandsk',),
'opplandskere': ('opplandsk',),
'opplandskest': ('opplandsk',),
'opplandskeste': ('opplandsk',),
'opplasta': ('opplasta',),
'opplastede': ('opplastet',),
'opplastet': ('opplastet',),
'opplastete': ('opplastet',),
'opplastetere': ('opplastet',),
'opplastetest': ('opplastet',),
'opplasteteste': ('opplastet',),
'opplatende': ('opplate',),
'opplatt': ('opplate',),
'opplatte': ('opplate',),
'opplatt': ('opplatt',),
'opplatte': ('opplatt',),
'opplattere': ('opplatt',),
'opplattest': ('opplatt',),
'opplatteste': ('opplatt',),
'opplest': ('opplest',),
'oppleste': ('opplest',),
'opplestere': ('opplest',),
'opplestest': ('opplest',),
'opplesteste': ('opplest',),
'opplett': ('opplett',),
'opplette': ('opplett',),
'opplettere': ('opplett',),
'opplettest': ('opplett',),
'oppletteste': ('opplett',),
'opplevd': ('oppleve',),
'opplevde': ('oppleve',),
'opplevende': ('oppleve',),
'oppliva': ('opplive',),
'opplivede': ('opplive',),
'opplivende': ('opplive',),
'opplivet': ('opplive',),
'opplivete': ('opplive',),
'opplysende': ('opplyse',),
'opplyst': ('opplyse',),
'opplyste': ('opplyse',),
'opplyst': ('opplyst',),
'opplyste': ('opplyst',),
'opplystere': ('opplyst',),
'opplystest': ('opplyst',),
'opplysteste': ('opplyst',),
'oppløfta': ('oppløfte',),
'oppløftede': ('oppløfte',),
'oppløftende': ('oppløfte',),
'oppløftet': ('oppløfte',),
'oppløftete': ('oppløfte',),
'oppløpen': ('oppløpen',),
'oppløpent': ('oppløpen',),
'oppløpne': ('oppløpen',),
'oppløpnere': ('oppløpen',),
'oppløpnest': ('oppløpen',),
'oppløpneste': ('oppløpen',),
'oppløsende': ('oppløse',),
'oppløst': ('oppløse',),
'oppløste': ('oppløse',),
'oppløselig': ('oppløselig',),
'oppløselige': ('oppløselig',),
'oppløseligere': ('oppløselig',),
'oppløseligst': ('oppløselig',),
'oppløseligste': ('oppløselig',),
'oppløysende': ('oppløyse',),
'oppløyst': ('oppløyse',),
'oppløyste': ('oppløyse',),
'oppløyselig': ('oppløyselig',),
'oppløyselige': ('oppløyselig',),
'oppløyseligere': ('oppløyselig',),
'oppløyseligst': ('oppløyselig',),
'oppløyseligste': ('oppløyselig',),
'oppmagasinerende': ('oppmagasinere',),
'oppmagasinert': ('oppmagasinere',),
'oppmagasinerte': ('oppmagasinere',),
'oppmalt': ('oppmalt',),
'oppmalte': ('oppmalt',),
'oppmaltere': ('oppmalt',),
'oppmaltest': ('oppmalt',),
'oppmalteste': ('oppmalt',),
'oppmalt': ('oppmalt',),
'oppmalte': ('oppmalt',),
'oppmaltere': ('oppmalt',),
'oppmaltest': ('oppmalt',),
'oppmalteste': ('oppmalt',),
'oppmarsjert': ('oppmarsjert',),
'oppmarsjerte': ('oppmarsjert',),
'oppmarsjertere': ('oppmarsjert',),
'oppmarsjertest': ('oppmarsjert',),
'oppmarsjerteste': ('oppmarsjert',),
'oppmerka': ('oppmerka',),
'oppmerkede': ('oppmerket',),
'oppmerket': ('oppmerket',),
'oppmerkete': ('oppmerket',),
'oppmerketere': ('oppmerket',),
'oppmerketest': ('oppmerket',),
'oppmerketeste': ('oppmerket',),
'oppmerksom': ('oppmerksom',),
'oppmerksomme': ('oppmerksom',),
'oppmerksommere': ('oppmerksom',),
'oppmerksomst': ('oppmerksom',),
'oppmerksomste': ('oppmerksom',),
'oppmerksomt': ('oppmerksom',),
'oppmuntra': ('oppmuntre',),
'oppmuntrede': ('oppmuntre',),
'oppmuntrende': ('oppmuntre',),
'oppmuntret': ('oppmuntre',),
'oppmuntrete': ('oppmuntre',),
'oppnevnende': ('oppnevne',),
'oppnevnt': ('oppnevne',),
'oppnevnte': ('oppnevne',),
'oppnorska': ('oppnorske',),
'oppnorskede': ('oppnorske',),
'oppnorskende': ('oppnorske',),
'oppnorsket': ('oppnorske',),
'oppnorskete': ('oppnorske',),
'oppnådd': ('oppnå',),
'oppnådde': ('oppnå',),
'oppnående': ('oppnå',),
'oppnåelig': ('oppnåelig',),
'oppnåelige': ('oppnåelig',),
'oppnåeligere': ('oppnåelig',),
'oppnåeligst': ('oppnåelig',),
'oppnåeligste': ('oppnåelig',),
'oppofrende': ('oppofrende',),
'opponerende': ('opponere',),
'opponert': ('opponere',),
'opponerte': ('opponere',),
'opportun': ('opportun',),
'opportune': ('opportun',),
'opportunere': ('opportun',),
'opportunest': ('opportun',),
'opportuneste': ('opportun',),
'opportunt': ('opportun',),
'opportunistisk': ('opportunistisk',),
'opportunistiske': ('opportunistisk',),
'opportunistiskere': ('opportunistisk',),
'opportunistiskest': ('opportunistisk',),
'opportunistiskeste': ('opportunistisk',),
'opposisjonell': ('opposisjonell',),
'opposisjonelle': ('opposisjonell',),
'opposisjonellere': ('opposisjonell',),
'opposisjonellest': ('opposisjonell',),
'opposisjonelleste': ('opposisjonell',),
'opposisjonelt': ('opposisjonell',),
'opprakt': ('opprakt',),
'opprakte': ('opprakt',),
'oppraktere': ('opprakt',),
'oppraktest': ('opprakt',),
'opprakteste': ('opprakt',),
'oppredd': ('oppredd',),
'oppredde': ('oppredd',),
'oppreddere': ('oppredd',),
'oppreddest': ('oppredd',),
'oppreddeste': ('oppredd',),
'oppreda': ('opprede',),
'oppredede': ('opprede',),
'oppredende': ('opprede',),
'oppredet': ('opprede',),
'oppredete': ('opprede',),
'oppredt': ('opprede',),
'oppredte': ('opprede',),
'oppreid': ('oppreid',),
'oppreide': ('oppreid',),
'oppreidere': ('oppreid',),
'oppreidest': ('oppreid',),
'oppreideste': ('oppreid',),
'oppreisende': ('oppreise',),
'oppreist': ('oppreise',),
'oppreiste': ('oppreise',),
'oppreist': ('oppreist',),
'oppreiste': ('oppreist',),
'oppreistere': ('oppreist',),
'oppreistest': ('oppreist',),
'oppreisteste': ('oppreist',),
'oppreklamerende': ('oppreklamere',),
'oppreklamert': ('oppreklamere',),
'oppreklamerte': ('oppreklamere',),
'opprett': ('opprett',),
'opprette': ('opprett',),
'opprettere': ('opprett',),
'opprettest': ('opprett',),
'oppretteste': ('opprett',),
'oppretta': ('opprette',),
'opprettede': ('opprette',),
'opprettende': ('opprette',),
'opprettet': ('opprette',),
'opprettete': ('opprette',),
'opprettholdende': ('opprettholde',),
'opprettholdt': ('opprettholde',),
'opprettholdte': ('opprettholde',),
'opprevet': ('opprevet',),
'opprevne': ('opprevet',),
'opprevnere': ('opprevet',),
'opprevnest': ('opprevet',),
'opprevneste': ('opprevet',),
'oppriktig': ('oppriktig',),
'oppriktige': ('oppriktig',),
'oppriktigere': ('oppriktig',),
'oppriktigst': ('oppriktig',),
'oppriktigste': ('oppriktig',),
'opprinnende': ('opprinne',),
'opprunne': ('opprinne',),
'opprunnen': ('opprinne',),
'opprunnet': ('opprinne',),
'opprinnelig': ('opprinnelig',),
'opprinnelige': ('opprinnelig',),
'opprinneligere': ('opprinnelig',),
'opprinneligst': ('opprinnelig',),
'opprinneligste': ('opprinnelig',),
'opprivende': ('opprivende',),
'opprulla': ('opprulla',),
'opprullede': ('opprullet',),
'opprullet': ('opprullet',),
'opprullete': ('opprullet',),
'opprulletere': ('opprullet',),
'opprulletest': ('opprullet',),
'opprulleteste': ('opprullet',),
'opprusta': ('opprusta',),
'opprusta': ('oppruste',),
'opprustede': ('oppruste',),
'opprustende': ('oppruste',),
'opprustet': ('oppruste',),
'opprustete': ('oppruste',),
'opprustede': ('opprustet',),
'opprustet': ('opprustet',),
'opprustete': ('opprustet',),
'opprustetere': ('opprustet',),
'opprustetest': ('opprustet',),
'opprusteteste': ('opprustet',),
'opprådd': ('opprådd',),
'opprådde': ('opprådd',),
'oppråddere': ('opprådd',),
'oppråddest': ('opprådd',),
'oppråddeste': ('opprådd',),
'oppråtna': ('oppråtna',),
'oppråtnede': ('oppråtnet',),
'oppråtnet': ('oppråtnet',),
'oppråtnete': ('oppråtnet',),
'oppråtnetere': ('oppråtnet',),
'oppråtnetest': ('oppråtnet',),
'oppråtneteste': ('oppråtnet',),
'opprømt': ('opprømt',),
'opprømte': ('opprømt',),
'opprømtere': ('opprømt',),
'opprømtest': ('opprømt',),
'opprømteste': ('opprømt',),
'opprørende': ('opprøre',),
'opprørt': ('opprøre',),
'opprørte': ('opprøre',),
'opprørsk': ('opprørsk',),
'opprørske': ('opprørsk',),
'opprørskere': ('opprørsk',),
'opprørskest': ('opprørsk',),
'opprørskeste': ('opprørsk',),
'oppsagt': ('oppsagt',),
'oppsagte': ('oppsagt',),
'oppsagtere': ('oppsagt',),
'oppsagtest': ('oppsagt',),
'oppsagteste': ('oppsagt',),
'oppsatt': ('oppsatt',),
'oppsatte': ('oppsatt',),
'oppsattere': ('oppsatt',),
'oppsattest': ('oppsatt',),
'oppsatteste': ('oppsatt',),
'oppsetsig': ('oppsetsig',),
'oppsetsige': ('oppsetsig',),
'oppsetsigere': ('oppsetsig',),
'oppsetsigst': ('oppsetsig',),
'oppsetsigste': ('oppsetsig',),
'oppsatt': ('oppsette',),
'oppsatte': ('oppsette',),
'oppsettende': ('oppsette',),
'oppsigelig': ('oppsigelig',),
'oppsigelige': ('oppsigelig',),
'oppsigeligere': ('oppsigelig',),
'oppsigeligst': ('oppsigelig',),
'oppsigeligste': ('oppsigelig',),
'oppsiktsvekkende': ('oppsiktsvekkende',),
'oppskaka': ('oppskaka',),
'oppskakende': ('oppskakende',),
'oppskakede': ('oppskaket',),
'oppskaket': ('oppskaket',),
'oppskakete': ('oppskaket',),
'oppskaketere': ('oppskaket',),
'oppskaketest': ('oppskaket',),
'oppskaketeste': ('oppskaket',),
'oppskjørta': ('oppskjørta',),
'oppskjørtede': ('oppskjørtet',),
'oppskjørtet': ('oppskjørtet',),
'oppskjørtete': ('oppskjørtet',),
'oppskjørtetere': ('oppskjørtet',),
'oppskjørtetest': ('oppskjørtet',),
'oppskjørteteste': ('oppskjørtet',),
'oppskremt': ('oppskremt',),
'oppskremte': ('oppskremt',),
'oppskremtere': ('oppskremt',),
'oppskremtest': ('oppskremt',),
'oppskremteste': ('oppskremt',),
'oppskreven': ('oppskreven',),
'oppskrevet': ('oppskreven',),
'oppskrevne': ('oppskreven',),
'oppskrevnere': ('oppskreven',),
'oppskrevnest': ('oppskreven',),
'oppskrevneste': ('oppskreven',),
'oppskrevet': ('oppskrevet',),
'oppskrevne': ('oppskrevet',),
'oppskrevnere': ('oppskrevet',),
'oppskrevnest': ('oppskrevet',),
'oppskrevneste': ('oppskrevet',),
'oppskreven': ('oppskrive',),
'oppskrevet': ('oppskrive',),
'oppskrevne': ('oppskrive',),
'oppskrivende': ('oppskrive',),
'oppskrudd': ('oppskrudd',),
'oppskrudde': ('oppskrudd',),
'oppskruddere': ('oppskrudd',),
'oppskruddest': ('oppskrudd',),
'oppskruddeste': ('oppskrudd',),
'oppskrytt': ('oppskrytt',),
'oppskrytte': ('oppskrytt',),
'oppskryttere': ('oppskrytt',),
'oppskryttest': ('oppskrytt',),
'oppskrytteste': ('oppskrytt',),
'oppskutt': ('oppskutt',),
'oppskutte': ('oppskutt',),
'oppskuttere': ('oppskutt',),
'oppskuttest': ('oppskutt',),
'oppskutteste': ('oppskutt',),
'oppslitende': ('oppslitende',),
'oppslukende': ('oppsluke',),
'oppslukt': ('oppsluke',),
'oppslukte': ('oppsluke',),
'oppslutta': ('oppslutte',),
'oppsluttede': ('oppslutte',),
'oppsluttende': ('oppslutte',),
'oppsluttet': ('oppslutte',),
'oppsluttete': ('oppslutte',),
'oppslått': ('oppslått',),
'oppslåtte': ('oppslått',),
'oppslåttere': ('oppslått',),
'oppslåttest': ('oppslått',),
'oppslåtteste': ('oppslått',),
'oppspart': ('oppspart',),
'oppsparte': ('oppspart',),
'oppspartere': ('oppspart',),
'oppspartest': ('oppspart',),
'oppsparteste': ('oppspart',),
'oppspedd': ('oppspedd',),
'oppspedde': ('oppspedd',),
'oppspeddere': ('oppspedd',),
'oppspeddest': ('oppspedd',),
'oppspeddeste': ('oppspedd',),
'oppspilt': ('oppspilt',),
'oppspilte': ('oppspilt',),
'oppspiltere': ('oppspilt',),
'oppspiltest': ('oppspilt',),
'oppspilteste': ('oppspilt',),
'oppspora': ('oppspore',),
'oppsporede': ('oppspore',),
'oppsporende': ('oppspore',),
'oppsporet': ('oppspore',),
'oppsporete': ('oppspore',),
'oppsport': ('oppspore',),
'oppsporte': ('oppspore',),
'oppstalla': ('oppstalla',),
'oppstallede': ('oppstallet',),
'oppstallet': ('oppstallet',),
'oppstallete': ('oppstallet',),
'oppstalletere': ('oppstallet',),
'oppstalletest': ('oppstallet',),
'oppstalleteste': ('oppstallet',),
'oppstamma': ('oppstamme',),
'oppstammede': ('oppstamme',),
'oppstammende': ('oppstamme',),
'oppstammet': ('oppstamme',),
'oppstammete': ('oppstamme',),
'oppstanden': ('oppstanden',),
'oppstandent': ('oppstanden',),
'oppstandne': ('oppstanden',),
'oppstandnere': ('oppstanden',),
'oppstandnest': ('oppstanden',),
'oppstandneste': ('oppstanden',),
'oppstasa': ('oppstasa',),
'oppstasede': ('oppstaset',),
'oppstaset': ('oppstaset',),
'oppstasete': ('oppstaset',),
'oppstasetere': ('oppstaset',),
'oppstasetest': ('oppstaset',),
'oppstaseteste': ('oppstaset',),
'oppstast': ('oppstast',),
'oppstaste': ('oppstast',),
'oppstastere': ('oppstast',),
'oppstastest': ('oppstast',),
'oppstasteste': ('oppstast',),
'oppstemmende': ('oppstemmende',),
'oppstemt': ('oppstemt',),
'oppstemte': ('oppstemt',),
'oppstemtere': ('oppstemt',),
'oppstemtest': ('oppstemt',),
'oppstemteste': ('oppstemt',),
'oppstigende': ('oppstigende',),
'oppstilt': ('oppstilt',),
'oppstilte': ('oppstilt',),
'oppstiltere': ('oppstilt',),
'oppstiltest': ('oppstilt',),
'oppstilteste': ('oppstilt',),
'oppstilt': ('oppstilt',),
'oppstilte': ('oppstilt',),
'oppstiltere': ('oppstilt',),
'oppstiltest': ('oppstilt',),
'oppstilteste': ('oppstilt',),
'oppstukket': ('oppstukket',),
'oppstukne': ('oppstukket',),
'oppstuknere': ('oppstukket',),
'oppstuknest': ('oppstukket',),
'oppstukneste': ('oppstukket',),
'oppstykka': ('oppstykke',),
'oppstykkede': ('oppstykke',),
'oppstykkende': ('oppstykke',),
'oppstykket': ('oppstykke',),
'oppstykkete': ('oppstykke',),
'oppstykt': ('oppstykke',),
'oppstykte': ('oppstykke',),
'oppstylta': ('oppstylta',),
'oppstyltede': ('oppstyltet',),
'oppstyltet': ('oppstyltet',),
'oppstyltete': ('oppstyltet',),
'oppstyltetere': ('oppstyltet',),
'oppstyltetest': ('oppstyltet',),
'oppstylteteste': ('oppstyltet',),
'oppstyltra': ('oppstyltra',),
'oppstyltrede': ('oppstyltret',),
'oppstyltret': ('oppstyltret',),
'oppstyltrete': ('oppstyltret',),
'oppstyltretere': ('oppstyltret',),
'oppstyltretest': ('oppstyltret',),
'oppstyltreteste': ('oppstyltret',),
'oppstående': ('oppstå',),
'oppstått': ('oppstå',),
'oppståtte': ('oppstå',),
'oppsummerende': ('oppsummere',),
'oppsummert': ('oppsummere',),
'oppsummerte': ('oppsummere',),
'oppsydd': ('oppsydd',),
'oppsydde': ('oppsydd',),
'oppsyddere': ('oppsydd',),
'oppsyddest': ('oppsydd',),
'oppsyddeste': ('oppsydd',),
'oppsøkende': ('oppsøke',),
'oppsøkt': ('oppsøke',),
'oppsøkte': ('oppsøke',),
'opptakende': ('oppta',),
'opptatt': ('oppta',),
'opptatte': ('oppta',),
'opptatt': ('opptatt',),
'opptatte': ('opptatt',),
'opptattere': ('opptatt',),
'opptattest': ('opptatt',),
'opptatteste': ('opptatt',),
'opptegna': ('opptegne',),
'opptegnede': ('opptegne',),
'opptegnende': ('opptegne',),
'opptegnet': ('opptegne',),
'opptegnete': ('opptegne',),
'opptennende': ('opptenne',),
'opptent': ('opptenne',),
'opptente': ('opptenne',),
'opptjenende': ('opptjene',),
'opptjent': ('opptjene',),
'opptjente': ('opptjene',),
'opptrappa': ('opptrappe',),
'opptrappede': ('opptrappe',),
'opptrappende': ('opptrappe',),
'opptrappet': ('opptrappe',),
'opptrappete': ('opptrappe',),
'opptredende': ('opptre',),
'opptrådt': ('opptre',),
'opptrådte': ('opptre',),
'opptråkka': ('opptråkka',),
'opptråkkede': ('opptråkket',),
'opptråkket': ('opptråkket',),
'opptråkkete': ('opptråkket',),
'opptråkketere': ('opptråkket',),
'opptråkketest': ('opptråkket',),
'opptråkketeste': ('opptråkket',),
'oppvakt': ('oppvakt',),
'oppvakte': ('oppvakt',),
'oppvaktere': ('oppvakt',),
'oppvaktest': ('oppvakt',),
'oppvakteste': ('oppvakt',),
'oppvarma': ('oppvarma',),
'oppvarmede': ('oppvarmet',),
'oppvarmet': ('oppvarmet',),
'oppvarmete': ('oppvarmet',),
'oppvarmetere': ('oppvarmet',),
'oppvarmetest': ('oppvarmet',),
'oppvarmeteste': ('oppvarmet',),
'oppvarta': ('oppvarte',),
'oppvartede': ('oppvarte',),
'oppvartende': ('oppvarte',),
'oppvartet': ('oppvarte',),
'oppvartete': ('oppvarte',),
'oppveid': ('oppveid',),
'oppveide': ('oppveid',),
'oppveidere': ('oppveid',),
'oppveidest': ('oppveid',),
'oppveideste': ('oppveid',),
'oppveid': ('oppveie',),
'oppveide': ('oppveie',),
'oppveiede': ('oppveie',),
'oppveiende': ('oppveie',),
'oppveiet': ('oppveie',),
'oppveiete': ('oppveie',),
'oppvekka': ('oppvekke',),
'oppvekkede': ('oppvekke',),
'oppvekkende': ('oppvekke',),
'oppvekket': ('oppvekke',),
'oppvekkete': ('oppvekke',),
'oppvekt': ('oppvekke',),
'oppvekte': ('oppvekke',),
'oppvigla': ('oppvigle',),
'oppviglede': ('oppvigle',),
'oppviglende': ('oppvigle',),
'oppviglet': ('oppvigle',),
'oppviglete': ('oppvigle',),
'oppviglersk': ('oppviglersk',),
'oppviglerske': ('oppviglersk',),
'oppviglerskere': ('oppviglersk',),
'oppviglerskest': ('oppviglersk',),
'oppviglerskeste': ('oppviglersk',),
'oppvisende': ('oppvise',),
'oppvist': ('oppvise',),
'oppviste': ('oppvise',),
'oppvoksende': ('oppvoksende',),
'oppvokst': ('oppvokst',),
'oppvokste': ('oppvokst',),
'oppvokstere': ('oppvokst',),
'oppvokstest': ('oppvokst',),
'oppvoksteste': ('oppvokst',),
'oppvurderende': ('oppvurdere',),
'oppvurdert': ('oppvurdere',),
'oppvurderte': ('oppvurdere',),
'oppvåknende': ('oppvåknende',),
'oppøst': ('oppøst',),
'oppøste': ('oppøst',),
'oppøstere': ('oppøst',),
'oppøstest': ('oppøst',),
'oppøsteste': ('oppøst',),
'oppøva': ('oppøve',),
'oppøvd': ('oppøve',),
'oppøvde': ('oppøve',),
'oppøvede': ('oppøve',),
'oppøvende': ('oppøve',),
'oppøvet': ('oppøve',),
'oppøvete': ('oppøve',),
'opsjonell': ('opsjonell',),
'opsjonelle': ('opsjonell',),
'opsjonellere': ('opsjonell',),
'opsjonellest': ('opsjonell',),
'opsjonelleste': ('opsjonell',),
'opsjonelt': ('opsjonell',),
'opterende': ('optere',),
'optert': ('optere',),
'opterte': ('optere',),
'optimal': ('optimal',),
'optimale': ('optimal',),
'optimalere': ('optimal',),
'optimalest': ('optimal',),
'optimaleste': ('optimal',),
'optimalt': ('optimal',),
'optimaliserende': ('optimalisere',),
'optimalisert': ('optimalisere',),
'optimaliserte': ('optimalisere',),
'optimerende': ('optimere',),
'optimert': ('optimere',),
'optimerte': ('optimere',),
'optimistisk': ('optimistisk',),
'optimistiske': ('optimistisk',),
'optimistiskere': ('optimistisk',),
'optimistiskest': ('optimistisk',),
'optimistiskeste': ('optimistisk',),
'optisk': ('optisk',),
'optiske': ('optisk',),
'optiskere': ('optisk',),
'optiskest': ('optisk',),
'optiskeste': ('optisk',),
'opulent': ('opulent',),
'opulente': ('opulent',),
'opulentere': ('opulent',),
'opulentest': ('opulent',),
'opulenteste': ('opulent',),
'oral': ('oral',),
'orale': ('oral',),
'oralere': ('oral',),
'oralest': ('oral',),
'oraleste': ('oral',),
'oralt': ('oral',),
'oransje': ('oransje',),
'oransjefarga': ('oransjefarga',),
'oransjefargede': ('oransjefarget',),
'oransjefarget': ('oransjefarget',),
'oransjefargete': ('oransjefarget',),
'oransjefargetere': ('oransjefarget',),
'oransjefargetest': ('oransjefarget',),
'oransjefargeteste': ('oransjefarget',),
'oratorisk': ('oratorisk',),
'oratoriske': ('oratorisk',),
'oratoriskere': ('oratorisk',),
'oratoriskest': ('oratorisk',),
'oratoriskeste': ('oratorisk',),
'ordblind': ('ordblind',),
'ordblinde': ('ordblind',),
'ordblindere': ('ordblind',),
'ordblindest': ('ordblind',),
'ordblindeste': ('ordblind',),
'ordblindt': ('ordblind',),
'orda': ('orde',),
'ordede': ('orde',),
'ordende': ('orde',),
'ordet': ('orde',),
'ordete': ('orde',),
'ordentlig': ('ordentlig',),
'ordentlige': ('ordentlig',),
'ordentligere': ('ordentlig',),
'ordentligst': ('ordentlig',),
'ordentligste': ('ordentlig',),
'ordfattig': ('ordfattig',),
'ordfattige': ('ordfattig',),
'ordfattigere': ('ordfattig',),
'ordfattigst': ('ordfattig',),
'ordfattigste': ('ordfattig',),
'ordhag': ('ordhag',),
'ordhage': ('ordhag',),
'ordhagere': ('ordhag',),
'ordhagest': ('ordhag',),
'ordhageste': ('ordhag',),
'ordhagt': ('ordhag',),
'ordhitne': ('ordhitten',),
'ordhitnere': ('ordhitten',),
'ordhitnest': ('ordhitten',),
'ordhitneste': ('ordhitten',),
'ordhitten': ('ordhitten',),
'ordhittent': ('ordhitten',),
'ordholden': ('ordholden',),
'ordholdent': ('ordholden',),
'ordholdne': ('ordholden',),
'ordholdnere': ('ordholden',),
'ordholdnest': ('ordholden',),
'ordholdneste': ('ordholden',),
'ordinerende': ('ordinere',),
'ordinert': ('ordinere',),
'ordinerte': ('ordinere',),
'ordinær': ('ordinær',),
'ordinære': ('ordinær',),
'ordinærere': ('ordinær',),
'ordinærest': ('ordinær',),
'ordinæreste': ('ordinær',),
'ordinært': ('ordinær',),
'ordknapp': ('ordknapp',),
'ordknappe': ('ordknapp',),
'ordknappere': ('ordknapp',),
'ordknappest': ('ordknapp',),
'ordknappeste': ('ordknapp',),
'ordknapt': ('ordknapp',),
'ordlaus': ('ordlaus',),
'ordlause': ('ordlaus',),
'ordlausere': ('ordlaus',),
'ordlausest': ('ordlaus',),
'ordlauseste': ('ordlaus',),
'ordlaust': ('ordlaus',),
'ordlagt': ('ordlegge',),
'ordlagte': ('ordlegge',),
'ordleggende': ('ordlegge',),
'ordløs': ('ordløs',),
'ordløse': ('ordløs',),
'ordløsere': ('ordløs',),
'ordløsest': ('ordløs',),
'ordløseste': ('ordløs',),
'ordløst': ('ordløs',),
'ordna': ('ordne',),
'ordnede': ('ordne',),
'ordnende': ('ordne',),
'ordnet': ('ordne',),
'ordnete': ('ordne',),
'ordovicisk': ('ordovicisk',),
'ordoviciske': ('ordovicisk',),
'ordoviciskere': ('ordovicisk',),
'ordoviciskest': ('ordovicisk',),
'ordoviciskeste': ('ordovicisk',),
'ordrett': ('ordrett',),
'ordrette': ('ordrett',),
'ordrettere': ('ordrett',),
'ordrettest': ('ordrett',),
'ordretteste': ('ordrett',),
'ordrik': ('ordrik',),
'ordrike': ('ordrik',),
'ordrikere': ('ordrik',),
'ordrikest': ('ordrik',),
'ordrikeste': ('ordrik',),
'ordrikt': ('ordrik',),
'oreigna': ('oreigne',),
'oreignede': ('oreigne',),
'oreignende': ('oreigne',),
'oreignet': ('oreigne',),
'oreignete': ('oreigne',),
'organisatorisk': ('organisatorisk',),
'organisatoriske': ('organisatorisk',),
'organisatoriskere': ('organisatorisk',),
'organisatoriskest': ('organisatorisk',),
'organisatoriskeste': ('organisatorisk',),
'organiserende': ('organisere',),
'organisert': ('organisere',),
'organiserte': ('organisere',),
'organisk': ('organisk',),
'organiske': ('organisk',),
'organiskere': ('organisk',),
'organiskest': ('organisk',),
'organiskeste': ('organisk',),
'orgastisk': ('orgastisk',),
'orgastiske': ('orgastisk',),
'orgastiskere': ('orgastisk',),
'orgastiskest': ('orgastisk',),
'orgastiskeste': ('orgastisk',),
'orga': ('orge',),
'orgede': ('orge',),
'orgende': ('orge',),
'orget': ('orge',),
'orgete': ('orge',),
'orgiastisk': ('orgiastisk',),
'orgiastiske': ('orgiastisk',),
'orgiastiskere': ('orgiastisk',),
'orgiastiskest': ('orgiastisk',),
'orgiastiskeste': ('orgiastisk',),
'orientalsk': ('orientalsk',),
'orientalske': ('orientalsk',),
'orientalskere': ('orientalsk',),
'orientalskest': ('orientalsk',),
'orientalskeste': ('orientalsk',),
'orienterende': ('orientere',),
'orientert': ('orientere',),
'orienterte': ('orientere',),
'original': ('original',),
'originale': ('original',),
'originalere': ('original',),
'originalest': ('original',),
'originaleste': ('original',),
'originalt': ('original',),
'originaltappa': ('originaltappa',),
'originaltappede': ('originaltappet',),
'originaltappet': ('originaltappet',),
'originaltappete': ('originaltappet',),
'originaltappetere': ('originaltappet',),
'originaltappetest': ('originaltappet',),
'originaltappeteste': ('originaltappet',),
'orkanaktig': ('orkanaktig',),
'orkanaktige': ('orkanaktig',),
'orkanaktigere': ('orkanaktig',),
'orkanaktigst': ('orkanaktig',),
'orkanaktigste': ('orkanaktig',),
'orka': ('orke',),
'orkede': ('orke',),
'orkende': ('orke',),
'orket': ('orke',),
'orkete': ('orke',),
'orkestral': ('orkestral',),
'orkestrale': ('orkestral',),
'orkestralere': ('orkestral',),
'orkestralest': ('orkestral',),
'orkestraleste': ('orkestral',),
'orkestralt': ('orkestral',),
'orkestrerende': ('orkestrere',),
'orkestrert': ('orkestrere',),
'orkestrerte': ('orkestrere',),
'orknøysk': ('orknøysk',),
'orknøyske': ('orknøysk',),
'orknøyskere': ('orknøysk',),
'orknøyskest': ('orknøysk',),
'orknøyskeste': ('orknøysk',),
'ormdrivende': ('ormdrivende',),
'orma': ('orme',),
'ormede': ('orme',),
'ormende': ('orme',),
'ormet': ('orme',),
'ormete': ('orme',),
'ormstukken': ('ormstukken',),
'ormstukkent': ('ormstukken',),
'ormstukne': ('ormstukken',),
'ormstuknere': ('ormstukken',),
'ormstuknest': ('ormstukken',),
'ormstukneste': ('ormstukken',),
'ornamental': ('ornamental',),
'ornamentale': ('ornamental',),
'ornamentalere': ('ornamental',),
'ornamentalest': ('ornamental',),
'ornamentaleste': ('ornamental',),
'ornamentalt': ('ornamental',),
'ornamenterende': ('ornamentere',),
'ornamentert': ('ornamentere',),
'ornamenterte': ('ornamentere',),
'ornitologisk': ('ornitologisk',),
'ornitologiske': ('ornitologisk',),
'ornitologiskere': ('ornitologisk',),
'ornitologiskest': ('ornitologisk',),
'ornitologiskeste': ('ornitologisk',),
'ortfonisk': ('ortfonisk',),
'ortfoniske': ('ortfonisk',),
'ortfoniskere': ('ortfonisk',),
'ortfoniskest': ('ortfonisk',),
'ortfoniskeste': ('ortfonisk',),
'ortodoks': ('ortodoks',),
'ortodokse': ('ortodoks',),
'ortodoksere': ('ortodoks',),
'ortodoksest': ('ortodoks',),
'ortodokseste': ('ortodoks',),
'ortodokst': ('ortodoks',),
'ortofon': ('ortofon',),
'ortofone': ('ortofon',),
'ortofonere': ('ortofon',),
'ortofonest': ('ortofon',),
'ortofoneste': ('ortofon',),
'ortofont': ('ortofon',),
'ortografisk': ('ortografisk',),
'ortografiske': ('ortografisk',),
'ortografiskere': ('ortografisk',),
'ortografiskest': ('ortografisk',),
'ortografiskeste': ('ortografisk',),
'ortopedisk': ('ortopedisk',),
'ortopediske': ('ortopedisk',),
'ortopediskere': ('ortopedisk',),
'ortopediskest': ('ortopedisk',),
'ortopediskeste': ('ortopedisk',),
'oscillerende': ('oscillere',),
'oscillert': ('oscillere',),
'oscillerte': ('oscillere',),
'osende': ('ose',),
'ost': ('ose',),
'oste': ('ose',),
'oseanisk': ('oseanisk',),
'oseaniske': ('oseanisk',),
'oseaniskere': ('oseanisk',),
'oseaniskest': ('oseanisk',),
'oseaniskeste': ('oseanisk',),
'oskeblond': ('oskeblond',),
'oskeblonde': ('oskeblond',),
'oskeblondere': ('oskeblond',),
'oskeblondest': ('oskeblond',),
'oskeblondeste': ('oskeblond',),
'oskeblondt': ('oskeblond',),
'oskeblond': ('oskeblond',),
'oskeblonde': ('oskeblond',),
'oskeblondere': ('oskeblond',),
'oskeblondest': ('oskeblond',),
'oskeblondeste': ('oskeblond',),
'oskeblondt': ('oskeblond',),
'oskegrå': ('oskegrå',),
'oskegråe': ('oskegrå',),
'oskegråere': ('oskegrå',),
'oskegråest': ('oskegrå',),
'oskegråeste': ('oskegrå',),
'oskegrått': ('oskegrå',),
'oskegrå': ('oskegrå',),
'oskegråe': ('oskegrå',),
'oskegråere': ('oskegrå',),
'oskegråest': ('oskegrå',),
'oskegråeste': ('oskegrå',),
'oskegrått': ('oskegrå',),
'osmansk': ('osmansk',),
'osmanske': ('osmansk',),
'osmanskere': ('osmansk',),
'osmanskest': ('osmansk',),
'osmanskeste': ('osmansk',),
'osmotisk': ('osmotisk',),
'osmotiske': ('osmotisk',),
'osmotiskere': ('osmotisk',),
'osmotiskest': ('osmotisk',),
'osmotiskeste': ('osmotisk',),
'ossetisk': ('ossetisk',),
'ossetiske': ('ossetisk',),
'ossetiskere': ('ossetisk',),
'ossetiskest': ('ossetisk',),
'ossetiskeste': ('ossetisk',),
'osta': ('oste',),
'ostede': ('oste',),
'ostende': ('oste',),
'ostet': ('oste',),
'ostete': ('oste',),
'ostentativ': ('ostentativ',),
'ostentative': ('ostentativ',),
'ostentativere': ('ostentativ',),
'ostentativest': ('ostentativ',),
'ostentativeste': ('ostentativ',),
'ostentativt': ('ostentativ',),
'otra': ('otre',),
'otrede': ('otre',),
'otrende': ('otre',),
'otret': ('otre',),
'otrete': ('otre',),
'ottefull': ('ottefull',),
'ottefulle': ('ottefull',),
'ottefullere': ('ottefull',),
'ottefullest': ('ottefull',),
'ottefulleste': ('ottefull',),
'ottefullt': ('ottefull',),
'ottomansk': ('ottomansk',),
'ottomanske': ('ottomansk',),
'ottomanskere': ('ottomansk',),
'ottomanskest': ('ottomansk',),
'ottomanskeste': ('ottomansk',),
'outrert': ('outrert',),
'outrerte': ('outrert',),
'outrertere': ('outrert',),
'outrertest': ('outrert',),
'outrerteste': ('outrert',),
'oval': ('oval',),
'ovale': ('oval',),
'ovalere': ('oval',),
'ovalest': ('oval',),
'ovaleste': ('oval',),
'ovalt': ('oval',),
'ovennevnt': ('ovennevnt',),
'ovennevnte': ('ovennevnt',),
'ovennevntere': ('ovennevnt',),
'ovennevntest': ('ovennevnt',),
'ovennevnteste': ('ovennevnt',),
'ovenstående': ('ovenstående',),
'overadministrert': ('overadministrert',),
'overadministrerte': ('overadministrert',),
'overadministrertere': ('overadministrert',),
'overadministrertest': ('overadministrert',),
'overadministrerteste': ('overadministrert',),
'overanstrengende': ('overanstrenge',),
'overanstrengt': ('overanstrenge',),
'overanstrengte': ('overanstrenge',),
'overarbeida': ('overarbeida',),
'overarbeidd': ('overarbeidd',),
'overarbeidde': ('overarbeidd',),
'overarbeiddere': ('overarbeidd',),
'overarbeiddest': ('overarbeidd',),
'overarbeiddeste': ('overarbeidd',),
'overarbeidede': ('overarbeidet',),
'overarbeidet': ('overarbeidet',),
'overarbeidete': ('overarbeidet',),
'overarbeidetere': ('overarbeidet',),
'overarbeidetest': ('overarbeidet',),
'overarbeideteste': ('overarbeidet',),
'overbefolka': ('overbefolka',),
'overbefolkede': ('overbefolket',),
'overbefolket': ('overbefolket',),
'overbefolkete': ('overbefolket',),
'overbefolketere': ('overbefolket',),
'overbefolketest': ('overbefolket',),
'overbefolketeste': ('overbefolket',),
'overbelasta': ('overbelaste',),
'overbelastede': ('overbelaste',),
'overbelastende': ('overbelaste',),
'overbelastet': ('overbelaste',),
'overbelastete': ('overbelaste',),
'overbeskatta': ('overbeskatte',),
'overbeskattede': ('overbeskatte',),
'overbeskattende': ('overbeskatte',),
'overbeskattet': ('overbeskatte',),
'overbeskattete': ('overbeskatte',),
'overbeskytta': ('overbeskytte',),
'overbeskyttede': ('overbeskytte',),
'overbeskyttende': ('overbeskytte',),
'overbeskyttet': ('overbeskytte',),
'overbeskyttete': ('overbeskytte',),
'overbetona': ('overbetone',),
'overbetonede': ('overbetone',),
'overbetonende': ('overbetone',),
'overbetonet': ('overbetone',),
'overbetonete': ('overbetone',),
'overbetont': ('overbetone',),
'overbetonte': ('overbetone',),
'overbevisende': ('overbevise',),
'overbevist': ('overbevise',),
'overbeviste': ('overbevise',),
'overbragt': ('overbringe',),
'overbragte': ('overbringe',),
'overbrakt': ('overbringe',),
'overbrakte': ('overbringe',),
'overbringende': ('overbringe',),
'overbroderende': ('overbrodere',),
'overbrodert': ('overbrodere',),
'overbroderte': ('overbrodere',),
'overbygd': ('overbygd',),
'overbygde': ('overbygd',),
'overbygdere': ('overbygd',),
'overbygdest': ('overbygd',),
'overbygdeste': ('overbygd',),
'overbærende': ('overbærende',),
'overdimensjonerende': ('overdimensjonere',),
'overdimensjonert': ('overdimensjonere',),
'overdimensjonerte': ('overdimensjonere',),
'overdradd': ('overdra',),
'overdradde': ('overdra',),
'overdragende': ('overdra',),
'overdratt': ('overdra',),
'overdratte': ('overdra',),
'overdreven': ('overdreven',),
'overdrevent': ('overdreven',),
'overdrevne': ('overdreven',),
'overdrevnere': ('overdreven',),
'overdrevnest': ('overdreven',),
'overdrevneste': ('overdreven',),
'overdynga': ('overdynge',),
'overdyngede': ('overdynge',),
'overdyngende': ('overdynge',),
'overdynget': ('overdynge',),
'overdyngete': ('overdynge',),
'overdådig': ('overdådig',),
'overdådige': ('overdådig',),
'overdådigere': ('overdådig',),
'overdådigst': ('overdådig',),
'overdådigste': ('overdådig',),
'overdøva': ('overdøve',),
'overdøvd': ('overdøve',),
'overdøvde': ('overdøve',),
'overdøvede': ('overdøve',),
'overdøvende': ('overdøve',),
'overdøvet': ('overdøve',),
'overdøvete': ('overdøve',),
'overeksponerende': ('overeksponere',),
'overeksponert': ('overeksponere',),
'overeksponerte': ('overeksponere',),
'overensstemmende': ('overensstemmende',),
'overfladisk': ('overfladisk',),
'overfladiske': ('overfladisk',),
'overfladiskere': ('overfladisk',),
'overfladiskest': ('overfladisk',),
'overfladiskeste': ('overfladisk',),
'overflateaktiv': ('overflateaktiv',),
'overflateaktive': ('overflateaktiv',),
'overflateaktivere': ('overflateaktiv',),
'overflateaktivest': ('overflateaktiv',),
'overflateaktiveste': ('overflateaktiv',),
'overflateaktivt': ('overflateaktiv',),
'overflatisk': ('overflatisk',),
'overflatiske': ('overflatisk',),
'overflatiskere': ('overflatisk',),
'overflatiskest': ('overflatisk',),
'overflatiskeste': ('overflatisk',),
'overflødig': ('overflødig',),
'overflødige': ('overflødig',),
'overflødigere': ('overflødig',),
'overflødigst': ('overflødig',),
'overflødigste': ('overflødig',),
'overflødiggjort': ('overflødiggjøre',),
'overflødiggjorte': ('overflødiggjøre',),
'overflødiggjørende': ('overflødiggjøre',),
'overfløya': ('overfløye',),
'overfløyd': ('overfløye',),
'overfløyde': ('overfløye',),
'overfløyede': ('overfløye',),
'overfløyende': ('overfløye',),
'overfløyet': ('overfløye',),
'overfløyete': ('overfløye',),
'overforsikra': ('overforsikre',),
'overforsikrede': ('overforsikre',),
'overforsikrende': ('overforsikre',),
'overforsikret': ('overforsikre',),
'overforsikrete': ('overforsikre',),
'overfusende': ('overfuse',),
'overfust': ('overfuse',),
'overfuste': ('overfuse',),
'overfylt': ('overfylt',),
'overfylte': ('overfylt',),
'overfyltere': ('overfylt',),
'overfyltest': ('overfylt',),
'overfylteste': ('overfylt',),
'overfølsom': ('overfølsom',),
'overfølsomme': ('overfølsom',),
'overfølsommere': ('overfølsom',),
'overfølsommest': ('overfølsom',),
'overfølsommeste': ('overfølsom',),
'overfølsomt': ('overfølsom',),
'overførende': ('overføre',),
'overført': ('overføre',),
'overførte': ('overføre',),
'overført': ('overført',),
'overførte': ('overført',),
'overførtere': ('overført',),
'overførtest': ('overført',),
'overførteste': ('overført',),
'overgiende': ('overgi',),
'overgitt': ('overgi',),
'overgitte': ('overgi',),
'overgivende': ('overgi',),
'overgitt': ('overgitt',),
'overgitte': ('overgitt',),
'overgittere': ('overgitt',),
'overgittest': ('overgitt',),
'overgitteste': ('overgitt',),
'overgiven': ('overgiven',),
'overgivent': ('overgiven',),
'overgivne': ('overgiven',),
'overgivnere': ('overgiven',),
'overgivnest': ('overgiven',),
'overgivneste': ('overgiven',),
'overgrodd': ('overgrodd',),
'overgrodde': ('overgrodd',),
'overgroddere': ('overgrodd',),
'overgroddest': ('overgrodd',),
'overgroddeste': ('overgrodd',),
'overgående': ('overgå',),
'overgått': ('overgå',),
'overgåtte': ('overgå',),
'overhala': ('overhale',),
'overhalede': ('overhale',),
'overhalende': ('overhale',),
'overhalet': ('overhale',),
'overhalete': ('overhale',),
'overhalt': ('overhale',),
'overhalte': ('overhale',),
'overhandtagende': ('overhandtagende',),
'overhandtakende': ('overhandtakende',),
'overhendig': ('overhendig',),
'overhendige': ('overhendig',),
'overhendigere': ('overhendig',),
'overhendigst': ('overhendig',),
'overhendigste': ('overhendig',),
'overhengende': ('overhengende',),
'overhengt': ('overhengt',),
'overhengte': ('overhengt',),
'overhengtere': ('overhengt',),
'overhengtest': ('overhengt',),
'overhengteste': ('overhengt',),
'overhistorisk': ('overhistorisk',),
'overhistoriske': ('overhistorisk',),
'overhistoriskere': ('overhistorisk',),
'overhistoriskest': ('overhistorisk',),
'overhistoriskeste': ('overhistorisk',),
'overholdende': ('overholde',),
'overholdt': ('overholde',),
'overholdte': ('overholde',),
'overhåndtagende': ('overhåndtagende',),
'overhåndtakende': ('overhåndtakende',),
'overhørende': ('overhøre',),
'overhørt': ('overhøre',),
'overhørte': ('overhøre',),
'overhørig': ('overhørig',),
'overhørige': ('overhørig',),
'overhørigere': ('overhørig',),
'overhørigst': ('overhørig',),
'overhørigste': ('overhørig',),
'overhøvla': ('overhøvle',),
'overhøvlede': ('overhøvle',),
'overhøvlende': ('overhøvle',),
'overhøvlet': ('overhøvle',),
'overhøvlete': ('overhøvle',),
'overilede': ('overilet',),
'overilet': ('overilet',),
'overilete': ('overilet',),
'overiletere': ('overilet',),
'overiletest': ('overilet',),
'overileteste': ('overilet',),
'overilt': ('overilt',),
'overilte': ('overilt',),
'overiltere': ('overilt',),
'overiltest': ('overilt',),
'overilteste': ('overilt',),
'overjordisk': ('overjordisk',),
'overjordiske': ('overjordisk',),
'overjordiskere': ('overjordisk',),
'overjordiskest': ('overjordisk',),
'overjordiskeste': ('overjordisk',),
'overkjørende': ('overkjøre',),
'overkjørt': ('overkjøre',),
'overkjørte': ('overkjøre',),
'overkommen': ('overkomme',),
'overkommende': ('overkomme',),
'overkommet': ('overkomme',),
'overkomne': ('overkomme',),
'overkommelig': ('overkommelig',),
'overkommelige': ('overkommelig',),
'overkommeligere': ('overkommelig',),
'overkommeligst': ('overkommelig',),
'overkommeligste': ('overkommelig',),
'overkompenserende': ('overkompensere',),
'overkompensert': ('overkompensere',),
'overkompenserte': ('overkompensere',),
'overkorrekt': ('overkorrekt',),
'overkorrekte': ('overkorrekt',),
'overkorrektere': ('overkorrekt',),
'overkorrektest': ('overkorrekt',),
'overkorrekteste': ('overkorrekt',),
'overkvalifisert': ('overkvalifisert',),
'overkvalifiserte': ('overkvalifisert',),
'overkvalifisertere': ('overkvalifisert',),
'overkvalifisertest': ('overkvalifisert',),
'overkvalifiserteste': ('overkvalifisert',),
'overlagt': ('overlagt',),
'overlagte': ('overlagt',),
'overlagtere': ('overlagt',),
'overlagtest': ('overlagt',),
'overlagteste': ('overlagt',),
'overlangsynt': ('overlangsynt',),
'overlangsynte': ('overlangsynt',),
'overlangsyntere': ('overlangsynt',),
'overlangsyntest': ('overlangsynt',),
'overlangsynteste': ('overlangsynt',),
'overlappa': ('overlappe',),
'overlappede': ('overlappe',),
'overlappende': ('overlappe',),
'overlappet': ('overlappe',),
'overlappete': ('overlappe',),
'overlasta': ('overlaste',),
'overlastede': ('overlaste',),
'overlastende': ('overlaste',),
'overlastet': ('overlaste',),
'overlastete': ('overlaste',),
'overlatende': ('overlate',),
'overlatt': ('overlate',),
'overlatte': ('overlate',),
'overlegen': ('overlegen',),
'overlegent': ('overlegen',),
'overlegne': ('overlegen',),
'overlegnere': ('overlegen',),
'overlegnest': ('overlegen',),
'overlegneste': ('overlegen',),
'overlagt': ('overlegge',),
'overlagte': ('overlegge',),
'overleggende': ('overlegge',),
'overlessa': ('overlesse',),
'overlessede': ('overlesse',),
'overlessende': ('overlesse',),
'overlesset': ('overlesse',),
'overlessete': ('overlesse',),
'overlest': ('overlesse',),
'overleste': ('overlesse',),
'overlevd': ('overleve',),
'overlevde': ('overleve',),
'overlevende': ('overleve',),
'overlevende': ('overlevende',),
'overleverende': ('overlevere',),
'overlevert': ('overlevere',),
'overleverte': ('overlevere',),
'overlista': ('overliste',),
'overlistede': ('overliste',),
'overlistende': ('overliste',),
'overlistet': ('overliste',),
'overlistete': ('overliste',),
'overmanna': ('overmanne',),
'overmannede': ('overmanne',),
'overmannende': ('overmanne',),
'overmannet': ('overmanne',),
'overmannete': ('overmanne',),
'overmektig': ('overmektig',),
'overmektige': ('overmektig',),
'overmektigere': ('overmektig',),
'overmektigst': ('overmektig',),
'overmektigste': ('overmektig',),
'overmenneskelig': ('overmenneskelig',),
'overmenneskelige': ('overmenneskelig',),
'overmenneskeligere': ('overmenneskelig',),
'overmenneskeligst': ('overmenneskelig',),
'overmenneskeligste': ('overmenneskelig',),
'overmoden': ('overmoden',),
'overmodent': ('overmoden',),
'overmodne': ('overmoden',),
'overmodnere': ('overmoden',),
'overmodnest': ('overmoden',),
'overmodneste': ('overmoden',),
'overmodig': ('overmodig',),
'overmodige': ('overmodig',),
'overmodigere': ('overmodig',),
'overmodigst': ('overmodig',),
'overmodigste': ('overmodig',),
'overmåls': ('overmåls',),
'overnasjonal': ('overnasjonal',),
'overnasjonale': ('overnasjonal',),
'overnasjonalere': ('overnasjonal',),
'overnasjonalest': ('overnasjonal',),
'overnasjonaleste': ('overnasjonal',),
'overnasjonalt': ('overnasjonal',),
'overnatta': ('overnatte',),
'overnattede': ('overnatte',),
'overnattende': ('overnatte',),
'overnattet': ('overnatte',),
'overnattete': ('overnatte',),
'overnaturlig': ('overnaturlig',),
'overnaturlige': ('overnaturlig',),
'overnaturligere': ('overnaturlig',),
'overnaturligst': ('overnaturlig',),
'overnaturligste': ('overnaturlig',),
'overnervøs': ('overnervøs',),
'overnervøse': ('overnervøs',),
'overnervøsere': ('overnervøs',),
'overnervøsest': ('overnervøs',),
'overnervøseste': ('overnervøs',),
'overnervøst': ('overnervøs',),
'overoppheta': ('overopphete',),
'overopphetede': ('overopphete',),
'overopphetende': ('overopphete',),
'overopphetet': ('overopphete',),
'overopphetete': ('overopphete',),
'overordentlig': ('overordentlig',),
'overordentlige': ('overordentlig',),
'overordentligere': ('overordentlig',),
'overordentligst': ('overordentlig',),
'overordentligste': ('overordentlig',),
'overordna': ('overordna',),
'overordnede': ('overordnet',),
'overordnet': ('overordnet',),
'overordnete': ('overordnet',),
'overordnetere': ('overordnet',),
'overordnetest': ('overordnet',),
'overordneteste': ('overordnet',),
'overprøvd': ('overprøve',),
'overprøvde': ('overprøve',),
'overprøvende': ('overprøve',),
'overraska': ('overraske',),
'overraskede': ('overraske',),
'overraskende': ('overraske',),
'overrasket': ('overraske',),
'overraskete': ('overraske',),
'overrakt': ('overrekke',),
'overrakte': ('overrekke',),
'overrekkende': ('overrekke',),
'overrennende': ('overrenne',),
'overrent': ('overrenne',),
'overrente': ('overrenne',),
'overrepresentert': ('overrepresentert',),
'overrepresenterte': ('overrepresentert',),
'overrepresentertere': ('overrepresentert',),
'overrepresentertest': ('overrepresentert',),
'overrepresenterteste': ('overrepresentert',),
'overrisla': ('overrisle',),
'overrislede': ('overrisle',),
'overrislende': ('overrisle',),
'overrislet': ('overrisle',),
'overrislete': ('overrisle',),
'overrumpla': ('overrumple',),
'overrumplede': ('overrumple',),
'overrumplende': ('overrumple',),
'overrumplet': ('overrumple',),
'overrumplete': ('overrumple',),
'oversanselig': ('oversanselig',),
'oversanselige': ('oversanselig',),
'oversanseligere': ('oversanselig',),
'oversanseligst': ('oversanselig',),
'oversanseligste': ('oversanselig',),
'overseende': ('overse',),
'oversett': ('overse',),
'oversette': ('overse',),
'oversendende': ('oversende',),
'oversendt': ('oversende',),
'oversendte': ('oversende',),
'oversatt': ('oversette',),
'oversatte': ('oversette',),
'oversettende': ('oversette',),
'oversiktlig': ('oversiktlig',),
'oversiktlige': ('oversiktlig',),
'oversiktligere': ('oversiktlig',),
'oversiktligst': ('oversiktlig',),
'oversiktligste': ('oversiktlig',),
'oversitne': ('oversitte',),
'oversitten': ('oversitte',),
'oversittende': ('oversitte',),
'oversittet': ('oversitte',),
'oversittende': ('oversittende',),
'oversjøisk': ('oversjøisk',),
'oversjøiske': ('oversjøisk',),
'oversjøiskere': ('oversjøisk',),
'oversjøiskest': ('oversjøisk',),
'oversjøiskeste': ('oversjøisk',),
'overskredet': ('overskride',),
'overskredne': ('overskride',),
'overskridende': ('overskride',),
'overskridt': ('overskride',),
'overskua': ('overskue',),
'overskuede': ('overskue',),
'overskuende': ('overskue',),
'overskuet': ('overskue',),
'overskuete': ('overskue',),
'overskuelig': ('overskuelig',),
'overskuelige': ('overskuelig',),
'overskueligere': ('overskuelig',),
'overskueligst': ('overskuelig',),
'overskueligste': ('overskuelig',),
'overskya': ('overskya',),
'overskyede': ('overskyet',),
'overskyet': ('overskyet',),
'overskyete': ('overskyet',),
'overskyetere': ('overskyet',),
'overskyetest': ('overskyet',),
'overskyeteste': ('overskyet',),
'overskygd': ('overskygge',),
'overskygde': ('overskygge',),
'overskygga': ('overskygge',),
'overskyggede': ('overskygge',),
'overskyggende': ('overskygge',),
'overskygget': ('overskygge',),
'overskyggete': ('overskygge',),
'overskytende': ('overskytende',),
'overspent': ('overspent',),
'overspente': ('overspent',),
'overspentere': ('overspent',),
'overspentest': ('overspent',),
'overspenteste': ('overspent',),
'overspillende': ('overspille',),
'overspilt': ('overspille',),
'overspilte': ('overspille',),
'overstadig': ('overstadig',),
'overstadige': ('overstadig',),
'overstadigere': ('overstadig',),
'overstadigst': ('overstadig',),
'overstadigste': ('overstadig',),
'overstatlig': ('overstatlig',),
'overstatlige': ('overstatlig',),
'overstatligere': ('overstatlig',),
'overstatligst': ('overstatlig',),
'overstatligste': ('overstatlig',),
'overstemmende': ('overstemme',),
'overstemt': ('overstemme',),
'overstemte': ('overstemme',),
'overstegen': ('overstige',),
'oversteget': ('overstige',),
'overstegne': ('overstige',),
'overstigende': ('overstige',),
'overstrøket': ('overstrøket',),
'overstrøkne': ('overstrøket',),
'overstrøknere': ('overstrøket',),
'overstrøknest': ('overstrøket',),
'overstrøkneste': ('overstrøket',),
'overstrømmende': ('overstrømmende',),
'overstyrt': ('overstyrt',),
'overstyrte': ('overstyrt',),
'overstyrtere': ('overstyrt',),
'overstyrtest': ('overstyrt',),
'overstyrteste': ('overstyrt',),
'overstått': ('overstått',),
'overståtte': ('overstått',),
'overståttere': ('overstått',),
'overståttest': ('overstått',),
'overståtteste': ('overstått',),
'oversvømmende': ('oversvømme',),
'oversvømt': ('oversvømme',),
'oversvømte': ('oversvømme',),
'overtakende': ('overta',),
'overtatt': ('overta',),
'overtatte': ('overta',),
'overtalende': ('overtale',),
'overtalt': ('overtale',),
'overtalte': ('overtale',),
'overtallig': ('overtallig',),
'overtallige': ('overtallig',),
'overtalligere': ('overtallig',),
'overtalligst': ('overtallig',),
'overtalligste': ('overtallig',),
'overtegna': ('overtegne',),
'overtegnede': ('overtegne',),
'overtegnende': ('overtegne',),
'overtegnet': ('overtegne',),
'overtegnete': ('overtegne',),
'overtent': ('overtent',),
'overtente': ('overtent',),
'overtentere': ('overtent',),
'overtentest': ('overtent',),
'overtenteste': ('overtent',),
'overtidig': ('overtidig',),
'overtidige': ('overtidig',),
'overtidigere': ('overtidig',),
'overtidigst': ('overtidig',),
'overtidigste': ('overtidig',),
'overtredende': ('overtre',),
'overtrådt': ('overtre',),
'overtrådte': ('overtre',),
'overtreffende': ('overtreffe',),
'overtruffen': ('overtreffe',),
'overtruffet': ('overtreffe',),
'overtrufne': ('overtreffe',),
'overtrekkende': ('overtrekke',),
'overtrukken': ('overtrekke',),
'overtrukket': ('overtrekke',),
'overtrukne': ('overtrekke',),
'overtrena': ('overtrena',),
'overtrenede': ('overtrenet',),
'overtrenet': ('overtrenet',),
'overtrenete': ('overtrenet',),
'overtrenetere': ('overtrenet',),
'overtrenetest': ('overtrenet',),
'overtreneteste': ('overtrenet',),
'overtrent': ('overtrent',),
'overtrente': ('overtrent',),
'overtrentere': ('overtrent',),
'overtrentest': ('overtrent',),
'overtrenteste': ('overtrent',),
'overtrett': ('overtrett',),
'overtrette': ('overtrett',),
'overtrettere': ('overtrett',),
'overtrettest': ('overtrett',),
'overtretteste': ('overtrett',),
'overtroisk': ('overtroisk',),
'overtroiske': ('overtroisk',),
'overtroiskere': ('overtroisk',),
'overtroiskest': ('overtroisk',),
'overtroiskeste': ('overtroisk',),
'overtruisk': ('overtruisk',),
'overtruiske': ('overtruisk',),
'overtruiskere': ('overtruisk',),
'overtruiskest': ('overtruisk',),
'overtruiskeste': ('overtruisk',),
'overtrøtt': ('overtrøtt',),
'overtrøtte': ('overtrøtt',),
'overtrøttere': ('overtrøtt',),
'overtrøttest': ('overtrøtt',),
'overtrøtteste': ('overtrøtt',),
'overtyda': ('overtyde',),
'overtydd': ('overtyde',),
'overtydde': ('overtyde',),
'overtydede': ('overtyde',),
'overtydende': ('overtyde',),
'overtydet': ('overtyde',),
'overtydete': ('overtyde',),
'overutvikla': ('overutvikle',),
'overutviklede': ('overutvikle',),
'overutviklende': ('overutvikle',),
'overutviklet': ('overutvikle',),
'overutviklete': ('overutvikle',),
'overveid': ('overveie',),
'overveide': ('overveie',),
'overveiede': ('overveie',),
'overveiende': ('overveie',),
'overveiet': ('overveie',),
'overveiete': ('overveie',),
'overveiende': ('overveiende',),
'overvektig': ('overvektig',),
'overvektige': ('overvektig',),
'overvektigere': ('overvektig',),
'overvektigst': ('overvektig',),
'overvektigste': ('overvektig',),
'overvelda': ('overvelde',),
'overveldede': ('overvelde',),
'overveldende': ('overvelde',),
'overveldet': ('overvelde',),
'overveldete': ('overvelde',),
'overvinnende': ('overvinne',),
'overvunne': ('overvinne',),
'overvunnen': ('overvinne',),
'overvunnet': ('overvinne',),
'overvintra': ('overvintre',),
'overvintrede': ('overvintre',),
'overvintrende': ('overvintre',),
'overvintret': ('overvintre',),
'overvintrete': ('overvintre',),
'overvurderende': ('overvurdere',),
'overvurdert': ('overvurdere',),
'overvurderte': ('overvurdere',),
'overvåka': ('overvåke',),
'overvåkede': ('overvåke',),
'overvåkende': ('overvåke',),
'overvåket': ('overvåke',),
'overvåkete': ('overvåke',),
'overvåkt': ('overvåke',),
'overvåkte': ('overvåke',),
'overværende': ('overvære',),
'overvært': ('overvære',),
'overværte': ('overvære',),
'overårig': ('overårig',),
'overårige': ('overårig',),
'overårigere': ('overårig',),
'overårigst': ('overårig',),
'overårigste': ('overårig',),
'overømfintlig': ('overømfintlig',),
'overømfintlige': ('overømfintlig',),
'overømfintligere': ('overømfintlig',),
'overømfintligst': ('overømfintlig',),
'overømfintligste': ('overømfintlig',),
'overøsende': ('overøse',),
'overøst': ('overøse',),
'overøste': ('overøse',),
'ovra': ('ovre',),
'ovrede': ('ovre',),
'ovrende': ('ovre',),
'ovret': ('ovre',),
'ovrete': ('ovre',),
'ovstor': ('ovstor',),
'ovstore': ('ovstor',),
'ovstort': ('ovstor',),
'ovstørre': ('ovstor',),
'ovstørst': ('ovstor',),
'ovstørste': ('ovstor',),
'paca': ('pace',),
'pacede': ('pace',),
'pacende': ('pace',),
'pacet': ('pace',),
'pacete': ('pace',),
'pact': ('pace',),
'pacte': ('pace',),
'paddeflat': ('paddeflat',),
'paddeflate': ('paddeflat',),
'paddeflatere': ('paddeflat',),
'paddeflatest': ('paddeflat',),
'paddeflateste': ('paddeflat',),
'paddeflatt': ('paddeflat',),
'padla': ('padle',),
'padlede': ('padle',),
'padlende': ('padle',),
'padlet': ('padle',),
'padlete': ('padle',),
'paff': ('paff',),
'paffe': ('paff',),
'paffere': ('paff',),
'paffest': ('paff',),
'paffeste': ('paff',),
'paft': ('paff',),
'paffa': ('paffe',),
'paffede': ('paffe',),
'paffende': ('paffe',),
'paffet': ('paffe',),
'paffete': ('paffe',),
'pagan': ('pagan',),
'pagane': ('pagan',),
'paganere': ('pagan',),
'paganest': ('pagan',),
'paganeste': ('pagan',),
'pagant': ('pagan',),
'paginerende': ('paginere',),
'paginert': ('paginere',),
'paginerte': ('paginere',),
'paillegul': ('paillegul',),
'paillegule': ('paillegul',),
'paillegulere': ('paillegul',),
'paillegulest': ('paillegul',),
'pailleguleste': ('paillegul',),
'paillegult': ('paillegul',),
'pakistansk': ('pakistansk',),
'pakistanske': ('pakistansk',),
'pakistanskere': ('pakistansk',),
'pakistanskest': ('pakistansk',),
'pakistanskeste': ('pakistansk',),
'pakka': ('pakke',),
'pakkede': ('pakke',),
'pakkende': ('pakke',),
'pakket': ('pakke',),
'pakkete': ('pakke',),
'pakkfull': ('pakkfull',),
'pakkfulle': ('pakkfull',),
'pakkfullere': ('pakkfull',),
'pakkfullest': ('pakkfull',),
'pakkfulleste': ('pakkfull',),
'pakkfullt': ('pakkfull',),
'pakta': ('pakte',),
'paktede': ('pakte',),
'paktende': ('pakte',),
'paktet': ('pakte',),
'paktete': ('pakte',),
'palatal': ('palatal',),
'palatale': ('palatal',),
'palatalere': ('palatal',),
'palatalest': ('palatal',),
'palataleste': ('palatal',),
'palatalt': ('palatal',),
'palataliserende': ('palatalisere',),
'palatalisert': ('palatalisere',),
'palataliserte': ('palatalisere',),
'palende': ('pale',),
'palt': ('pale',),
'palte': ('pale',),
'paleolittisk': ('paleolittisk',),
'paleolittiske': ('paleolittisk',),
'paleolittiskere': ('paleolittisk',),
'paleolittiskest': ('paleolittisk',),
'paleolittiskeste': ('paleolittisk',),
'paleozoisk': ('paleozoisk',),
'paleozoiske': ('paleozoisk',),
'paleozoiskere': ('paleozoisk',),
'paleozoiskest': ('paleozoisk',),
'paleozoiskeste': ('paleozoisk',),
'palestinsk': ('palestinsk',),
'palestinske': ('palestinsk',),
'palestinskere': ('palestinsk',),
'palestinskest': ('palestinsk',),
'palestinskeste': ('palestinsk',),
'palleterende': ('palletere',),
'palletert': ('palletere',),
'palleterte': ('palletere',),
'palliativ': ('palliativ',),
'palliative': ('palliativ',),
'palliativere': ('palliativ',),
'palliativest': ('palliativ',),
'palliativeste': ('palliativ',),
'palliativt': ('palliativ',),
'palma': ('palme',),
'palmede': ('palme',),
'palmende': ('palme',),
'palmet': ('palme',),
'palmete': ('palme',),
'palperende': ('palpere',),
'palpert': ('palpere',),
'palperte': ('palpere',),
'pampet': ('pampet',),
'pampete': ('pampet',),
'pampetere': ('pampet',),
'pampetest': ('pampet',),
'pampeteste': ('pampet',),
'pampettt': ('pampet',),
'pampete': ('pampete',),
'panafrikansk': ('panafrikansk',),
'panafrikanske': ('panafrikansk',),
'panafrikanskere': ('panafrikansk',),
'panafrikanskest': ('panafrikansk',),
'panafrikanskeste': ('panafrikansk',),
'panamansk': ('panamansk',),
'panamanske': ('panamansk',),
'panamanskere': ('panamansk',),
'panamanskest': ('panamansk',),
'panamanskeste': ('panamansk',),
'panasjert': ('panasjert',),
'panasjerte': ('panasjert',),
'panasjertere': ('panasjert',),
'panasjertest': ('panasjert',),
'panasjerteste': ('panasjert',),
'pandemisk': ('pandemisk',),
'pandemiske': ('pandemisk',),
'pandemiskere': ('pandemisk',),
'pandemiskest': ('pandemisk',),
'pandemiskeste': ('pandemisk',),
'panegyrerende': ('panegyrere',),
'panegyrert': ('panegyrere',),
'panegyrerte': ('panegyrere',),
'panegyrisk': ('panegyrisk',),
'panegyriske': ('panegyrisk',),
'panegyriskere': ('panegyrisk',),
'panegyriskest': ('panegyrisk',),
'panegyriskeste': ('panegyrisk',),
'panelende': ('panele',),
'panelt': ('panele',),
'panelte': ('panele',),
'panerende': ('panere',),
'panert': ('panere',),
'panerte': ('panere',),
'panisk': ('panisk',),
'paniske': ('panisk',),
'paniskere': ('panisk',),
'paniskest': ('panisk',),
'paniskeste': ('panisk',),
'pankromatisk': ('pankromatisk',),
'pankromatiske': ('pankromatisk',),
'pankromatiskere': ('pankromatisk',),
'pankromatiskest': ('pankromatisk',),
'pankromatiskeste': ('pankromatisk',),
'panorerende': ('panorere',),
'panorert': ('panorere',),
'panorerte': ('panorere',),
'pansra': ('pansre',),
'pansrede': ('pansre',),
'pansrende': ('pansre',),
'pansret': ('pansre',),
'pansrete': ('pansre',),
'panta': ('pante',),
'pantede': ('pante',),
'pantende': ('pante',),
'pantet': ('pante',),
'pantete': ('pante',),
'panteistisk': ('panteistisk',),
'panteistiske': ('panteistisk',),
'panteistiskere': ('panteistisk',),
'panteistiskest': ('panteistisk',),
'panteistiskeste': ('panteistisk',),
'pantomimisk': ('pantomimisk',),
'pantomimiske': ('pantomimisk',),
'pantomimiskere': ('pantomimisk',),
'pantomimiskest': ('pantomimisk',),
'pantomimiskeste': ('pantomimisk',),
'pantsatt': ('pantsette',),
'pantsatte': ('pantsette',),
'pantsettende': ('pantsette',),
'pantstillende': ('pantstille',),
'pantstilt': ('pantstille',),
'pantstilte': ('pantstille',),
'papirlaus': ('papirlaus',),
'papirlause': ('papirlaus',),
'papirlausere': ('papirlaus',),
'papirlausest': ('papirlaus',),
'papirlauseste': ('papirlaus',),
'papirlaust': ('papirlaus',),
'papirløs': ('papirløs',),
'papirløse': ('papirløs',),
'papirløsere': ('papirløs',),
'papirløsest': ('papirløs',),
'papirløseste': ('papirløs',),
'papirløst': ('papirløs',),
'papistisk': ('papistisk',),
'papistiske': ('papistisk',),
'papistiskere': ('papistisk',),
'papistiskest': ('papistisk',),
'papistiskeste': ('papistisk',),
'pappa': ('pappe',),
'pappede': ('pappe',),
'pappende': ('pappe',),
'pappet': ('pappe',),
'pappete': ('pappe',),
'papuansk': ('papuansk',),
'papuanske': ('papuansk',),
'papuanskere': ('papuansk',),
'papuanskest': ('papuansk',),
'papuanskeste': ('papuansk',),
'parabolsk': ('parabolsk',),
'parabolske': ('parabolsk',),
'parabolskere': ('parabolsk',),
'parabolskest': ('parabolsk',),
'parabolskeste': ('parabolsk',),
'paraderende': ('paradere',),
'paradert': ('paradere',),
'paraderte': ('paradere',),
'paradigmatisk': ('paradigmatisk',),
'paradigmatiske': ('paradigmatisk',),
'paradigmatiskere': ('paradigmatisk',),
'paradigmatiskest': ('paradigmatisk',),
'paradigmatiskeste': ('paradigmatisk',),
'paradisisk': ('paradisisk',),
'paradisiske': ('paradisisk',),
'paradisiskere': ('paradisisk',),
'paradisiskest': ('paradisisk',),
'paradisiskeste': ('paradisisk',),
'paradoksal': ('paradoksal',),
'paradoksale': ('paradoksal',),
'paradoksalere': ('paradoksal',),
'paradoksalest': ('paradoksal',),
'paradoksaleste': ('paradoksal',),
'paradoksalt': ('paradoksal',),
'paraferende': ('parafere',),
'parafert': ('parafere',),
'paraferte': ('parafere',),
'parafinerende': ('parafinere',),
'parafinert': ('parafinere',),
'parafinerte': ('parafinere',),
'parafraserende': ('parafrasere',),
'parafrasert': ('parafrasere',),
'parafraserte': ('parafrasere',),
'paragraferende': ('paragrafere',),
'paragrafert': ('paragrafere',),
'paragraferte': ('paragrafere',),
'paraguayansk': ('paraguayansk',),
'paraguayanske': ('paraguayansk',),
'paraguayanskere': ('paraguayansk',),
'paraguayanskest': ('paraguayansk',),
'paraguayanskeste': ('paraguayansk',),
'parallell': ('parallell',),
'parallelle': ('parallell',),
'parallellere': ('parallell',),
'parallellest': ('parallell',),
'parallelleste': ('parallell',),
'parallelt': ('parallell',),
'parallellforskjøven': ('parallellforskyve',),
'parallellforskjøvet': ('parallellforskyve',),
'parallellforskjøvne': ('parallellforskyve',),
'parallellforskyvd': ('parallellforskyve',),
'parallellforskyvde': ('parallellforskyve',),
'parallellforskyvende': ('parallellforskyve',),
'parallellførende': ('parallellføre',),
'parallellført': ('parallellføre',),
'parallellførte': ('parallellføre',),
'parallelliserende': ('parallellisere',),
'parallellisert': ('parallellisere',),
'parallelliserte': ('parallellisere',),
'paralyserende': ('paralysere',),
'paralysert': ('paralysere',),
'paralyserte': ('paralysere',),
'paralytisk': ('paralytisk',),
'paralytiske': ('paralytisk',),
'paralytiskere': ('paralytisk',),
'paralytiskest': ('paralytisk',),
'paralytiskeste': ('paralytisk',),
'paranoid': ('paranoid',),
'paranoide': ('paranoid',),
'paranoidere': ('paranoid',),
'paranoidest': ('paranoid',),
'paranoideste': ('paranoid',),
'paranoisk': ('paranoisk',),
'paranoiske': ('paranoisk',),
'paranoiskere': ('paranoisk',),
'paranoiskest': ('paranoisk',),
'paranoiskeste': ('paranoisk',),
'parapsykologisk': ('parapsykologisk',),
'parapsykologiske': ('parapsykologisk',),
'parapsykologiskere': ('parapsykologisk',),
'parapsykologiskest': ('parapsykologisk',),
'parapsykologiskeste': ('parapsykologisk',),
'parasitterende': ('parasittere',),
'parasittert': ('parasittere',),
'parasitterte': ('parasittere',),
'parasittisk': ('parasittisk',),
'parasittiske': ('parasittisk',),
'parasittiskere': ('parasittisk',),
'parasittiskest': ('parasittisk',),
'parasittiskeste': ('parasittisk',),
'parat': ('parat',),
'parate': ('parat',),
'paratere': ('parat',),
'paratest': ('parat',),
'parateste': ('parat',),
'parataktisk': ('parataktisk',),
'parataktiske': ('parataktisk',),
'parataktiskere': ('parataktisk',),
'parataktiskest': ('parataktisk',),
'parataktiskeste': ('parataktisk',),
'para': ('pare',),
'parede': ('pare',),
'parende': ('pare',),
'paret': ('pare',),
'parete': ('pare',),
'parentetisk': ('parentetisk',),
'parentetiske': ('parentetisk',),
'parentetiskere': ('parentetisk',),
'parentetiskest': ('parentetisk',),
'parentetiskeste': ('parentetisk',),
'parerende': ('parere',),
'parert': ('parere',),
'parerte': ('parere',),
'parerende': ('parere',),
'parert': ('parere',),
'parerte': ('parere',),
'paretisk': ('paretisk',),
'paretiske': ('paretisk',),
'paretiskere': ('paretisk',),
'paretiskest': ('paretisk',),
'paretiskeste': ('paretisk',),
'parfymerende': ('parfymere',),
'parfymert': ('parfymere',),
'parfymerte': ('parfymere',),
'pari': ('pari',),
'paringsdyktig': ('paringsdyktig',),
'paringsdyktige': ('paringsdyktig',),
'paringsdyktigere': ('paringsdyktig',),
'paringsdyktigst': ('paringsdyktig',),
'paringsdyktigste': ('paringsdyktig',),
'parisisk': ('parisisk',),
'parisiske': ('parisisk',),
'parisiskere': ('parisisk',),
'parisiskest': ('parisisk',),
'parisiskeste': ('parisisk',),
'paritetisk': ('paritetisk',),
'paritetiske': ('paritetisk',),
'paritetiskere': ('paritetisk',),
'paritetiskest': ('paritetisk',),
'paritetiskeste': ('paritetisk',),
'parkerende': ('parkere',),
'parkert': ('parkere',),
'parkerte': ('parkere',),
'parlamentarisk': ('parlamentarisk',),
'parlamentariske': ('parlamentarisk',),
'parlamentariskere': ('parlamentarisk',),
'parlamentariskest': ('parlamentarisk',),
'parlamentariskeste': ('parlamentarisk',),
'parlamenterende': ('parlamentere',),
'parlamentert': ('parlamentere',),
'parlamenterte': ('parlamentere',),
'parlerende': ('parlere',),
'parlert': ('parlere',),
'parlerte': ('parlere',),
'parodierende': ('parodiere',),
'parodiert': ('parodiere',),
'parodierte': ('parodiere',),
'parodisk': ('parodisk',),
'parodiske': ('parodisk',),
'parodiskere': ('parodisk',),
'parodiskest': ('parodisk',),
'parodiskeste': ('parodisk',),
'parsellerende': ('parsellere',),
'parsellert': ('parsellere',),
'parsellerte': ('parsellere',),
'parterende': ('partere',),
'partert': ('partere',),
'parterte': ('partere',),
'partiell': ('partiell',),
'partielle': ('partiell',),
'partiellere': ('partiell',),
'partiellest': ('partiell',),
'partielleste': ('partiell',),
'partielt': ('partiell',),
'partikularistisk': ('partikularistisk',),
'partikularistiske': ('partikularistisk',),
'partikularistiskere': ('partikularistisk',),
'partikularistiskest': ('partikularistisk',),
'partikularistiskeste': ('partikularistisk',),
'partikulær': ('partikulær',),
'partikulære': ('partikulær',),
'partikulærere': ('partikulær',),
'partikulærest': ('partikulær',),
'partikulæreste': ('partikulær',),
'partikulært': ('partikulær',),
'partilaus': ('partilaus',),
'partilause': ('partilaus',),
'partilausere': ('partilaus',),
'partilausest': ('partilaus',),
'partilauseste': ('partilaus',),
'partilaust': ('partilaus',),
'partiløs': ('partiløs',),
'partiløse': ('partiløs',),
'partiløsere': ('partiløs',),
'partiløsest': ('partiløs',),
'partiløseste': ('partiløs',),
'partiløst': ('partiløs',),
'partipolitisk': ('partipolitisk',),
'partipolitiske': ('partipolitisk',),
'partipolitiskere': ('partipolitisk',),
'partipolitiskest': ('partipolitisk',),
'partipolitiskeste': ('partipolitisk',),
'partisiperende': ('partisipere',),
'partisipert': ('partisipere',),
'partisiperte': ('partisipere',),
'partisk': ('partisk',),
'partiske': ('partisk',),
'partiskere': ('partisk',),
'partiskest': ('partisk',),
'partiskeste': ('partisk',),
'partitiv': ('partitiv',),
'partitive': ('partitiv',),
'partitivere': ('partitiv',),
'partitivest': ('partitiv',),
'partitiveste': ('partitiv',),
'partitivt': ('partitiv',),
'partåa': ('partåa',),
'partåede': ('partået',),
'partået': ('partået',),
'partåete': ('partået',),
'partåetere': ('partået',),
'partåetest': ('partået',),
'partåeteste': ('partået',),
'pasifiserende': ('pasifisere',),
'pasifisert': ('pasifisere',),
'pasifiserte': ('pasifisere',),
'pasifistisk': ('pasifistisk',),
'pasifistiske': ('pasifistisk',),
'pasifistiskere': ('pasifistisk',),
'pasifistiskest': ('pasifistisk',),
'pasifistiskeste': ('pasifistisk',),
'pasjonert': ('pasjonert',),
'pasjonerte': ('pasjonert',),
'pasjonertere': ('pasjonert',),
'pasjonertest': ('pasjonert',),
'pasjonerteste': ('pasjonert',),
'passé': ('passé',),
'passée': ('passé',),
'passéere': ('passé',),
'passéest': ('passé',),
'passéeste': ('passé',),
'passabel': ('passabel',),
'passabelt': ('passabel',),
'passable': ('passabel',),
'passablere': ('passabel',),
'passablest': ('passabel',),
'passableste': ('passabel',),
'passa': ('passe',),
'passede': ('passe',),
'passende': ('passe',),
'passet': ('passe',),
'passete': ('passe',),
'passa': ('passe',),
'passede': ('passe',),
'passende': ('passe',),
'passet': ('passe',),
'passete': ('passe',),
'passa': ('passe',),
'passede': ('passe',),
'passende': ('passe',),
'passet': ('passe',),
'passete': ('passe',),
'passa': ('passe',),
'passede': ('passe',),
'passende': ('passe',),
'passet': ('passe',),
'passete': ('passe',),
'passe': ('passe',),
'passelig': ('passelig',),
'passelige': ('passelig',),
'passeligere': ('passelig',),
'passeligst': ('passelig',),
'passeligste': ('passelig',),
'passerende': ('passere',),
'passert': ('passere',),
'passerte': ('passere',),
'passiarende': ('passiare',),
'passiart': ('passiare',),
'passiarte': ('passiare',),
'passiv': ('passiv',),
'passive': ('passiv',),
'passivere': ('passiv',),
'passivest': ('passiv',),
'passiveste': ('passiv',),
'passivt': ('passiv',),
'passiverende': ('passivere',),
'passivert': ('passivere',),
'passiverte': ('passivere',),
'passiviserende': ('passivisere',),
'passivisert': ('passivisere',),
'passiviserte': ('passivisere',),
'pasteuriserende': ('pasteurisere',),
'pasteurisert': ('pasteurisere',),
'pasteuriserte': ('pasteurisere',),
'pastoral': ('pastoral',),
'pastorale': ('pastoral',),
'pastoralere': ('pastoral',),
'pastoralest': ('pastoral',),
'pastoraleste': ('pastoral',),
'pastoralt': ('pastoral',),
'pastos': ('pastos',),
'pastose': ('pastos',),
'pastosere': ('pastos',),
'pastosest': ('pastos',),
'pastoseste': ('pastos',),
'pastost': ('pastos',),
'pastøs': ('pastøs',),
'pastøse': ('pastøs',),
'pastøsere': ('pastøs',),
'pastøsest': ('pastøs',),
'pastøseste': ('pastøs',),
'pastøst': ('pastøs',),
'patent': ('patent',),
'patente': ('patent',),
'patentere': ('patent',),
'patentest': ('patent',),
'patenteste': ('patent',),
'patenterende': ('patentere',),
'patentert': ('patentere',),
'patenterte': ('patentere',),
'patentsøkende': ('patentsøke',),
'patentsøkt': ('patentsøke',),
'patentsøkte': ('patentsøke',),
'paternalistisk': ('paternalistisk',),
'paternalistiske': ('paternalistisk',),
'paternalistiskere': ('paternalistisk',),
'paternalistiskest': ('paternalistisk',),
'paternalistiskeste': ('paternalistisk',),
'patetisk': ('patetisk',),
'patetiske': ('patetisk',),
'patetiskere': ('patetisk',),
'patetiskest': ('patetisk',),
'patetiskeste': ('patetisk',),
'patinerende': ('patinere',),
'patinert': ('patinere',),
'patinerte': ('patinere',),
'patogen': ('patogen',),
'patogene': ('patogen',),
'patogenere': ('patogen',),
'patogenest': ('patogen',),
'patogeneste': ('patogen',),
'patogent': ('patogen',),
'patologisk': ('patologisk',),
'patologiske': ('patologisk',),
'patologiskere': ('patologisk',),
'patologiskest': ('patologisk',),
'patologiskeste': ('patologisk',),
'patriarkalsk': ('patriarkalsk',),
'patriarkalske': ('patriarkalsk',),
'patriarkalskere': ('patriarkalsk',),
'patriarkalskest': ('patriarkalsk',),
'patriarkalskeste': ('patriarkalsk',),
'patriotisk': ('patriotisk',),
'patriotiske': ('patriotisk',),
'patriotiskere': ('patriotisk',),
'patriotiskest': ('patriotisk',),
'patriotiskeste': ('patriotisk',),
'patrisisk': ('patrisisk',),
'patrisiske': ('patrisisk',),
'patrisiskere': ('patrisisk',),
'patrisiskest': ('patrisisk',),
'patrisiskeste': ('patrisisk',),
'patroniserende': ('patronisere',),
'patronisert': ('patronisere',),
'patroniserte': ('patronisere',),
'patronym': ('patronym',),
'patronyme': ('patronym',),
'patronymere': ('patronym',),
'patronymest': ('patronym',),
'patronymeste': ('patronym',),
'patronymt': ('patronym',),
'patronymisk': ('patronymisk',),
'patronymiske': ('patronymisk',),
'patronymiskere': ('patronymisk',),
'patronymiskest': ('patronymisk',),
'patronymiskeste': ('patronymisk',),
'patruljerende': ('patruljere',),
'patruljert': ('patruljere',),
'patruljerte': ('patruljere',),
'patt': ('patt',),
'patta': ('patte',),
'pattede': ('patte',),
'pattende': ('patte',),
'pattet': ('patte',),
'pattete': ('patte',),
'paulinsk': ('paulinsk',),
'paulinske': ('paulinsk',),
'paulinskere': ('paulinsk',),
'paulinskest': ('paulinsk',),
'paulinskeste': ('paulinsk',),
'pauserende': ('pausere',),
'pausert': ('pausere',),
'pauserte': ('pausere',),
'pauvre': ('pauvre',),
'pavelig': ('pavelig',),
'pavelige': ('pavelig',),
'paveligere': ('pavelig',),
'paveligst': ('pavelig',),
'paveligste': ('pavelig',),
'pavet': ('pavet',),
'pavete': ('pavet',),
'pavetere': ('pavet',),
'pavetest': ('pavet',),
'paveteste': ('pavet',),
'pavete': ('pavete',),
'pedagogisk': ('pedagogisk',),
'pedagogiske': ('pedagogisk',),
'pedagogiskere': ('pedagogisk',),
'pedagogiskest': ('pedagogisk',),
'pedagogiskeste': ('pedagogisk',),
'pedantisk': ('pedantisk',),
'pedantiske': ('pedantisk',),
'pedantiskere': ('pedantisk',),
'pedantiskest': ('pedantisk',),
'pedantiskeste': ('pedantisk',),
'pederastisk': ('pederastisk',),
'pederastiske': ('pederastisk',),
'pederastiskere': ('pederastisk',),
'pederastiskest': ('pederastisk',),
'pederastiskeste': ('pederastisk',),
'pediatrisk': ('pediatrisk',),
'pediatriske': ('pediatrisk',),
'pediatriskere': ('pediatrisk',),
'pediatriskest': ('pediatrisk',),
'pediatriskeste': ('pediatrisk',),
'pedofil': ('pedofil',),
'pedofile': ('pedofil',),
'pedofilere': ('pedofil',),
'pedofilest': ('pedofil',),
'pedofileste': ('pedofil',),
'pedofilt': ('pedofil',),
'peila': ('peile',),
'peilede': ('peile',),
'peilende': ('peile',),
'peilet': ('peile',),
'peilete': ('peile',),
'peilt': ('peile',),
'peilte': ('peile',),
'peisa': ('peise',),
'peisede': ('peise',),
'peisende': ('peise',),
'peiset': ('peise',),
'peisete': ('peise',),
'peist': ('peise',),
'peiste': ('peise',),
'pejorativ': ('pejorativ',),
'pejorative': ('pejorativ',),
'pejorativere': ('pejorativ',),
'pejorativest': ('pejorativ',),
'pejorativeste': ('pejorativ',),
'pejorativt': ('pejorativ',),
'pekende': ('peke',),
'pekt': ('peke',),
'pekte': ('peke',),
'pekuniær': ('pekuniær',),
'pekuniære': ('pekuniær',),
'pekuniærere': ('pekuniær',),
'pekuniærest': ('pekuniær',),
'pekuniæreste': ('pekuniær',),
'pekuniært': ('pekuniær',),
'pelagisk': ('pelagisk',),
'pelagiske': ('pelagisk',),
'pelagiskere': ('pelagisk',),
'pelagiskest': ('pelagisk',),
'pelagiskeste': ('pelagisk',),
'pella': ('pelle',),
'pellede': ('pelle',),
'pellende': ('pelle',),
'pellet': ('pelle',),
'pellete': ('pelle',),
'pelt': ('pelle',),
'pelte': ('pelle',),
'pella': ('pelle',),
'pellede': ('pelle',),
'pellende': ('pelle',),
'pellet': ('pelle',),
'pellete': ('pelle',),
'pelt': ('pelle',),
'pelte': ('pelle',),
'pelleterende': ('pelletere',),
'pelletert': ('pelletere',),
'pelleterte': ('pelletere',),
'pelsa': ('pelse',),
'pelsede': ('pelse',),
'pelsende': ('pelse',),
'pelset': ('pelse',),
'pelsete': ('pelse',),
'pen': ('pen',),
'pene': ('pen',),
'penere': ('pen',),
'penest': ('pen',),
'peneste': ('pen',),
'pent': ('pen',),
'pendla': ('pendle',),
'pendlede': ('pendle',),
'pendlende': ('pendle',),
'pendlet': ('pendle',),
'pendlete': ('pendle',),
'penetrerende': ('penetrere',),
'penetrert': ('penetrere',),
'penetrerte': ('penetrere',),
'pengelaus': ('pengelaus',),
'pengelause': ('pengelaus',),
'pengelausere': ('pengelaus',),
'pengelausest': ('pengelaus',),
'pengelauseste': ('pengelaus',),
'pengelaust': ('pengelaus',),
'pengeløs': ('pengeløs',),
'pengeløse': ('pengeløs',),
'pengeløsere': ('pengeløs',),
'pengeløsest': ('pengeløs',),
'pengeløseste': ('pengeløs',),
'pengeløst': ('pengeløs',),
'pengesterk': ('pengesterk',),
'pengesterke': ('pengesterk',),
'pengesterkere': ('pengesterk',),
'pengesterkest': ('pengesterk',),
'pengesterkeste': ('pengesterk',),
'pengesterkt': ('pengesterk',),
'penibel': ('penibel',),
'penibelt': ('penibel',),
'penible': ('penibel',),
'peniblere': ('penibel',),
'peniblest': ('penibel',),
'penibleste': ('penibel',),
'penna': ('penne',),
'pennede': ('penne',),
'pennende': ('penne',),
'pennet': ('penne',),
'pennete': ('penne',),
'pennefør': ('pennefør',),
'penneføre': ('pennefør',),
'penneførere': ('pennefør',),
'penneførest': ('pennefør',),
'penneføreste': ('pennefør',),
'penneført': ('pennefør',),
'pensa': ('pense',),
'pensede': ('pense',),
'pensende': ('pense',),
'penset': ('pense',),
'pensete': ('pense',),
'pensjonerende': ('pensjonere',),
'pensjonert': ('pensjonere',),
'pensjonerte': ('pensjonere',),
'pensla': ('pensle',),
'penslede': ('pensle',),
'penslende': ('pensle',),
'penslet': ('pensle',),
'penslete': ('pensle',),
'pentatonisk': ('pentatonisk',),
'pentatoniske': ('pentatonisk',),
'pentatoniskere': ('pentatonisk',),
'pentatoniskest': ('pentatonisk',),
'pentatoniskeste': ('pentatonisk',),
'pentatoniskt': ('pentatonisk',),
'pepra': ('pepre',),
'peprede': ('pepre',),
'peprende': ('pepre',),
'pepret': ('pepre',),
'peprete': ('pepre',),
'perenn': ('perenn',),
'perenne': ('perenn',),
'perennere': ('perenn',),
'perennest': ('perenn',),
'perenneste': ('perenn',),
'perent': ('perenn',),
'perennerende': ('perennere',),
'perennert': ('perennere',),
'perennerte': ('perennere',),
'perfeksjonerende': ('perfeksjonere',),
'perfeksjonert': ('perfeksjonere',),
'perfeksjonerte': ('perfeksjonere',),
'perfeksjonistisk': ('perfeksjonistisk',),
'perfeksjonistiske': ('perfeksjonistisk',),
'perfeksjonistiskere': ('perfeksjonistisk',),
'perfeksjonistiskest': ('perfeksjonistisk',),
'perfeksjonistiskeste': ('perfeksjonistisk',),
'perfekt': ('perfekt',),
'perfekte': ('perfekt',),
'perfektere': ('perfekt',),
'perfektest': ('perfekt',),
'perfekteste': ('perfekt',),
'perfektibel': ('perfektibel',),
'perfektibelt': ('perfektibel',),
'perfektible': ('perfektibel',),
'perfektiblere': ('perfektibel',),
'perfektiblest': ('perfektibel',),
'perfektibleste': ('perfektibel',),
'perfid': ('perfid',),
'perfide': ('perfid',),
'perfidere': ('perfid',),
'perfidest': ('perfid',),
'perfideste': ('perfid',),
'perforerende': ('perforere',),
'perforert': ('perforere',),
'perforerte': ('perforere',),
'pergamenterende': ('pergamentere',),
'pergamentert': ('pergamentere',),
'pergamenterte': ('pergamentere',),
'perialisert': ('perialisert',),
'perialiserte': ('perialisert',),
'perialisertere': ('perialisert',),
'perialisertest': ('perialisert',),
'perialiserteste': ('perialisert',),
'perifer': ('perifer',),
'perifere': ('perifer',),
'periferere': ('perifer',),
'periferest': ('perifer',),
'perifereste': ('perifer',),
'perifert': ('perifer',),
'periferisk': ('periferisk',),
'periferiske': ('periferisk',),
'periferiskere': ('periferisk',),
'periferiskest': ('periferisk',),
'periferiskeste': ('periferisk',),
'perifrastisk': ('perifrastisk',),
'perifrastiske': ('perifrastisk',),
'perifrastiskere': ('perifrastisk',),
'perifrastiskest': ('perifrastisk',),
'perifrastiskeste': ('perifrastisk',),
'periodisk': ('periodisk',),
'periodiske': ('periodisk',),
'periodiskere': ('periodisk',),
'periodiskest': ('periodisk',),
'periodiskeste': ('periodisk',),
'perkolerende': ('perkolere',),
'perkolert': ('perkolere',),
'perkolerte': ('perkolere',),
'perkuterende': ('perkutere',),
'perkutert': ('perkutere',),
'perkuterte': ('perkutere',),
'perla': ('perle',),
'perlede': ('perle',),
'perlende': ('perle',),
'perlet': ('perle',),
'perlete': ('perle',),
'permanent': ('permanent',),
'permanente': ('permanent',),
'permanentere': ('permanent',),
'permanentest': ('permanent',),
'permanenteste': ('permanent',),
'permeabel': ('permeabel',),
'permeabelt': ('permeabel',),
'permeable': ('permeabel',),
'permeablere': ('permeabel',),
'permeablest': ('permeabel',),
'permeableste': ('permeabel',),
'permisk': ('permisk',),
'permiske': ('permisk',),
'permiskere': ('permisk',),
'permiskest': ('permisk',),
'permiskeste': ('permisk',),
'permitterende': ('permittere',),
'permittert': ('permittere',),
'permitterte': ('permittere',),
'permuterende': ('permutere',),
'permutert': ('permutere',),
'permuterte': ('permutere',),
'pernisiøs': ('pernisiøs',),
'pernisiøse': ('pernisiøs',),
'pernisiøsere': ('pernisiøs',),
'pernisiøsest': ('pernisiøs',),
'pernisiøseste': ('pernisiøs',),
'pernisiøst': ('pernisiøs',),
'perpendikulær': ('perpendikulær',),
'perpendikulære': ('perpendikulær',),
'perpendikulærere': ('perpendikulær',),
'perpendikulærest': ('perpendikulær',),
'perpendikulæreste': ('perpendikulær',),
'perpendikulært': ('perpendikulær',),
'perpleks': ('perpleks',),
'perplekse': ('perpleks',),
'perpleksere': ('perpleks',),
'perpleksest': ('perpleks',),
'perplekseste': ('perpleks',),
'perplekst': ('perpleks',),
'persa': ('perse',),
'persede': ('perse',),
'persende': ('perse',),
'perset': ('perse',),
'persete': ('perse',),
'persa': ('perse',),
'persede': ('perse',),
'persende': ('perse',),
'perset': ('perse',),
'persete': ('perse',),
'perseptibel': ('perseptibel',),
'perseptibelt': ('perseptibel',),
'perseptible': ('perseptibel',),
'perseptiblere': ('perseptibel',),
'perseptiblest': ('perseptibel',),
'perseptibleste': ('perseptibel',),
'perseptuell': ('perseptuell',),
'perseptuelle': ('perseptuell',),
'perseptuellere': ('perseptuell',),
'perseptuellest': ('perseptuell',),
'perseptuelleste': ('perseptuell',),
'perseptuelt': ('perseptuell',),
'persiflerende': ('persiflere',),
'persiflert': ('persiflere',),
'persiflerte': ('persiflere',),
'persiperende': ('persipere',),
'persipert': ('persipere',),
'persiperte': ('persipere',),
'persisk': ('persisk',),
'persiske': ('persisk',),
'persiskere': ('persisk',),
'persiskest': ('persisk',),
'persiskeste': ('persisk',),
'persistent': ('persistent',),
'persistente': ('persistent',),
'persistentere': ('persistent',),
'persistentest': ('persistent',),
'persistenteste': ('persistent',),
'persisterende': ('persistere',),
'persistert': ('persistere',),
'persisterte': ('persistere',),
'personal': ('personal',),
'personale': ('personal',),
'personalere': ('personal',),
'personalest': ('personal',),
'personaleste': ('personal',),
'personalt': ('personal',),
'personell': ('personell',),
'personelle': ('personell',),
'personellere': ('personell',),
'personellest': ('personell',),
'personelleste': ('personell',),
'personelt': ('personell',),
'personifiserende': ('personifisere',),
'personifisert': ('personifisere',),
'personifiserte': ('personifisere',),
'personlig': ('personlig',),
'personlige': ('personlig',),
'personligere': ('personlig',),
'personligst': ('personlig',),
'personligste': ('personlig',),
'personliggjort': ('personliggjøre',),
'personliggjorte': ('personliggjøre',),
'personliggjørende': ('personliggjøre',),
'perspektivisk': ('perspektivisk',),
'perspektiviske': ('perspektivisk',),
'perspektiviskere': ('perspektivisk',),
'perspektiviskest': ('perspektivisk',),
'perspektiviskeste': ('perspektivisk',),
'perspirerende': ('perspirere',),
'perspirert': ('perspirere',),
'perspirerte': ('perspirere',),
'pertentlig': ('pertentlig',),
'pertentlige': ('pertentlig',),
'pertentligere': ('pertentlig',),
'pertentligst': ('pertentlig',),
'pertentligste': ('pertentlig',),
'perturberende': ('perturbere',),
'perturbert': ('perturbere',),
'perturberte': ('perturbere',),
'peruansk': ('peruansk',),
'peruanske': ('peruansk',),
'peruanskere': ('peruansk',),
'peruanskest': ('peruansk',),
'peruanskeste': ('peruansk',),
'pervers': ('pervers',),
'perverse': ('pervers',),
'perversere': ('pervers',),
'perversest': ('pervers',),
'perverseste': ('pervers',),
'perverst': ('pervers',),
'perverterende': ('pervertere',),
'pervertert': ('pervertere',),
'perverterte': ('pervertere',),
'pesende': ('pese',),
'pest': ('pese',),
'peste': ('pese',),
'pessimistisk': ('pessimistisk',),
'pessimistiske': ('pessimistisk',),
'pessimistiskere': ('pessimistisk',),
'pessimistiskest': ('pessimistisk',),
'pessimistiskeste': ('pessimistisk',),
'petrokjemisk': ('petrokjemisk',),
'petrokjemiske': ('petrokjemisk',),
'petrokjemiskere': ('petrokjemisk',),
'petrokjemiskest': ('petrokjemisk',),
'petrokjemiskeste': ('petrokjemisk',),
'petrologisk': ('petrologisk',),
'petrologiske': ('petrologisk',),
'petrologiskere': ('petrologisk',),
'petrologiskest': ('petrologisk',),
'petrologiskeste': ('petrologisk',),
'pianistisk': ('pianistisk',),
'pianistiske': ('pianistisk',),
'pianistiskere': ('pianistisk',),
'pianistiskest': ('pianistisk',),
'pianistiskeste': ('pianistisk',),
'pietetsfull': ('pietetsfull',),
'pietetsfulle': ('pietetsfull',),
'pietetsfullere': ('pietetsfull',),
'pietetsfullest': ('pietetsfull',),
'pietetsfulleste': ('pietetsfull',),
'pietetsfullt': ('pietetsfull',),
'pietistisk': ('pietistisk',),
'pietistiske': ('pietistisk',),
'pietistiskere': ('pietistisk',),
'pietistiskest': ('pietistisk',),
'pietistiskeste': ('pietistisk',),
'piffa': ('piffe',),
'piffede': ('piffe',),
'piffende': ('piffe',),
'piffet': ('piffe',),
'piffete': ('piffe',),
'pigg': ('pigg',),
'pigge': ('pigg',),
'piggere': ('pigg',),
'piggest': ('pigg',),
'piggeste': ('pigg',),
'pigt': ('pigg',),
'pigga': ('pigge',),
'piggede': ('pigge',),
'piggende': ('pigge',),
'pigget': ('pigge',),
'piggete': ('pigge',),
'pigga': ('pigge',),
'piggede': ('pigge',),
'piggende': ('pigge',),
'pigget': ('pigge',),
'piggete': ('pigge',),
'pigget': ('pigget',),
'piggete': ('pigget',),
'piggetere': ('pigget',),
'piggetest': ('pigget',),
'piggeteste': ('pigget',),
'piggete': ('piggete',),
'pigmenterende': ('pigmentere',),
'pigmentert': ('pigmentere',),
'pigmenterte': ('pigmentere',),
'pikant': ('pikant',),
'pikante': ('pikant',),
'pikantere': ('pikant',),
'pikantest': ('pikant',),
'pikanteste': ('pikant',),
'pikerende': ('pikere',),
'pikert': ('pikere',),
'pikerte': ('pikere',),
'pikka': ('pikke',),
'pikkede': ('pikke',),
'pikkende': ('pikke',),
'pikket': ('pikke',),
'pikkete': ('pikke',),
'pilende': ('pile',),
'pilt': ('pile',),
'pilte': ('pile',),
'pilka': ('pilke',),
'pilkede': ('pilke',),
'pilkende': ('pilke',),
'pilket': ('pilke',),
'pilkete': ('pilke',),
'pillen': ('pillen',),
'pillent': ('pillen',),
'pilne': ('pillen',),
'pilnere': ('pillen',),
'pilnest': ('pillen',),
'pilneste': ('pillen',),
'pilsnar': ('pilsnar',),
'pilsnare': ('pilsnar',),
'pilsnarere': ('pilsnar',),
'pilsnarest': ('pilsnar',),
'pilsnareste': ('pilsnar',),
'pilsnart': ('pilsnar',),
'pilta': ('pilte',),
'piltede': ('pilte',),
'piltende': ('pilte',),
'piltet': ('pilte',),
'piltete': ('pilte',),
'pimpa': ('pimpe',),
'pimpede': ('pimpe',),
'pimpende': ('pimpe',),
'pimpet': ('pimpe',),
'pimpete': ('pimpe',),
'pinaktig': ('pinaktig',),
'pinaktige': ('pinaktig',),
'pinaktigere': ('pinaktig',),
'pinaktigst': ('pinaktig',),
'pinaktigste': ('pinaktig',),
'pinende': ('pine',),
'pint': ('pine',),
'pinte': ('pine',),
'pinetrang': ('pinetrang',),
'pinetrange': ('pinetrang',),
'pinetrangere': ('pinetrang',),
'pinetrangest': ('pinetrang',),
'pinetrangeste': ('pinetrang',),
'pinetrangt': ('pinetrang',),
'pinka': ('pinke',),
'pinkede': ('pinke',),
'pinkende': ('pinke',),
'pinket': ('pinke',),
'pinkete': ('pinke',),
'pinka': ('pinke',),
'pinkede': ('pinke',),
'pinkende': ('pinke',),
'pinket': ('pinke',),
'pinkete': ('pinke',),
'pinlig': ('pinlig',),
'pinlige': ('pinlig',),
'pinligere': ('pinlig',),
'pinligst': ('pinlig',),
'pinligste': ('pinlig',),
'pinna': ('pinne',),
'pinnede': ('pinne',),
'pinnende': ('pinne',),
'pinnet': ('pinne',),
'pinnete': ('pinne',),
'pinsa': ('pinse',),
'pinsede': ('pinse',),
'pinsende': ('pinse',),
'pinset': ('pinse',),
'pinsete': ('pinse',),
'pepen': ('pipe',),
'pepet': ('pipe',),
'pepne': ('pipe',),
'pipende': ('pipe',),
'pipet': ('pipet',),
'pipete': ('pipet',),
'pipetere': ('pipet',),
'pipetest': ('pipet',),
'pipeteste': ('pipet',),
'pipete': ('pipete',),
'pipla': ('piple',),
'piplede': ('piple',),
'piplende': ('piple',),
'piplet': ('piple',),
'piplete': ('piple',),
'pippa': ('pippe',),
'pippede': ('pippe',),
'pippende': ('pippe',),
'pippet': ('pippe',),
'pippete': ('pippe',),
'pirka': ('pirke',),
'pirkede': ('pirke',),
'pirkende': ('pirke',),
'pirket': ('pirke',),
'pirkete': ('pirke',),
'pirket': ('pirket',),
'pirkete': ('pirket',),
'pirketere': ('pirket',),
'pirketest': ('pirket',),
'pirketeste': ('pirket',),
'pirkete': ('pirkete',),
'pirra': ('pirre',),
'pirrede': ('pirre',),
'pirrende': ('pirre',),
'pirret': ('pirre',),
'pirrete': ('pirre',),
'piruetterende': ('piruettere',),
'piruettert': ('piruettere',),
'piruetterte': ('piruettere',),
'pirum': ('pirum',),
'piska': ('piske',),
'piskede': ('piske',),
'piskende': ('piske',),
'pisket': ('piske',),
'piskete': ('piske',),
'pissa': ('pisse',),
'pissede': ('pisse',),
'pissende': ('pisse',),
'pisset': ('pisse',),
'pissete': ('pisse',),
'pist': ('pisse',),
'piste': ('pisse',),
'pista': ('piste',),
'pistede': ('piste',),
'pistende': ('piste',),
'pistet': ('piste',),
'pistete': ('piste',),
'pistra': ('pistre',),
'pistrede': ('pistre',),
'pistrende': ('pistre',),
'pistret': ('pistre',),
'pistrete': ('pistre',),
'pistret': ('pistret',),
'pistrete': ('pistret',),
'pistretere': ('pistret',),
'pistretest': ('pistret',),
'pistreteste': ('pistret',),
'pistrete': ('pistrete',),
'pitla': ('pitle',),
'pitlede': ('pitle',),
'pitlende': ('pitle',),
'pitlet': ('pitle',),
'pitlete': ('pitle',),
'pittoresk': ('pittoresk',),
'pittoreske': ('pittoresk',),
'pittoreskere': ('pittoresk',),
'pittoreskest': ('pittoresk',),
'pittoreskeste': ('pittoresk',),
'pjalla': ('pjalle',),
'pjallede': ('pjalle',),
'pjallende': ('pjalle',),
'pjallet': ('pjalle',),
'pjallete': ('pjalle',),
'pjaltet': ('pjaltet',),
'pjaltete': ('pjaltet',),
'pjaltetere': ('pjaltet',),
'pjaltetest': ('pjaltet',),
'pjalteteste': ('pjaltet',),
'pjaltete': ('pjaltete',),
'pjanket': ('pjanket',),
'pjankete': ('pjanket',),
'pjanketere': ('pjanket',),
'pjanketest': ('pjanket',),
'pjanketeste': ('pjanket',),
'pjankete': ('pjankete',),
'pjatta': ('pjatte',),
'pjattede': ('pjatte',),
'pjattende': ('pjatte',),
'pjattet': ('pjatte',),
'pjattete': ('pjatte',),
'pjoltra': ('pjoltre',),
'pjoltrede': ('pjoltre',),
'pjoltrende': ('pjoltre',),
'pjoltret': ('pjoltre',),
'pjoltrete': ('pjoltre',),
'pjusk': ('pjusk',),
'pjuska': ('pjuske',),
'pjuskede': ('pjuske',),
'pjuskende': ('pjuske',),
'pjusket': ('pjuske',),
'pjuskete': ('pjuske',),
'pjusket': ('pjusket',),
'pjuskete': ('pjusket',),
'pjusketere': ('pjusket',),
'pjusketest': ('pjusket',),
'pjusketeste': ('pjusket',),
'pjuskete': ('pjuskete',),
'pjutra': ('pjutre',),
'pjutrede': ('pjutre',),
'pjutrende': ('pjutre',),
'pjutret': ('pjutre',),
'pjutrete': ('pjutre',),
'plaffa': ('plaffe',),
'plaffede': ('plaffe',),
'plaffende': ('plaffe',),
'plaffet': ('plaffe',),
'plaffete': ('plaffe',),
'plaga': ('plage',),
'plagd': ('plage',),
'plagde': ('plage',),
'plagede': ('plage',),
'plagende': ('plage',),
'plaget': ('plage',),
'plagete': ('plage',),
'plagierende': ('plagiere',),
'plagiert': ('plagiere',),
'plagierte': ('plagiere',),
'plagsom': ('plagsom',),
'plagsomme': ('plagsom',),
'plagsommere': ('plagsom',),
'plagsomst': ('plagsom',),
'plagsomste': ('plagsom',),
'plagsomt': ('plagsom',),
'plakat': ('plakat',),
'plan': ('plan',),
'plane': ('plan',),
'planere': ('plan',),
'planest': ('plan',),
'planeste': ('plan',),
'plant': ('plan',),
'plana': ('plane',),
'planede': ('plane',),
'planende': ('plane',),
'planet': ('plane',),
'planete': ('plane',),
'plant': ('plane',),
'plante': ('plane',),
'planerende': ('planere',),
'planert': ('planere',),
'planerte': ('planere',),
'planetarisk': ('planetarisk',),
'planetariske': ('planetarisk',),
'planetariskere': ('planetarisk',),
'planetariskest': ('planetarisk',),
'planetariskeste': ('planetarisk',),
'planetær': ('planetær',),
'planetære': ('planetær',),
'planetærere': ('planetær',),
'planetærest': ('planetær',),
'planetæreste': ('planetær',),
'planetært': ('planetær',),
'planfast': ('planfast',),
'planfaste': ('planfast',),
'planfastere': ('planfast',),
'planfastest': ('planfast',),
'planfasteste': ('planfast',),
'planlaus': ('planlaus',),
'planlause': ('planlaus',),
'planlausere': ('planlaus',),
'planlausest': ('planlaus',),
'planlauseste': ('planlaus',),
'planlaust': ('planlaus',),
'planlagt': ('planlegge',),
'planlagte': ('planlegge',),
'planleggende': ('planlegge',),
'planløs': ('planløs',),
'planløse': ('planløs',),
'planløsere': ('planløs',),
'planløsest': ('planløs',),
'planløseste': ('planløs',),
'planløst': ('planløs',),
'planmessig': ('planmessig',),
'planmessige': ('planmessig',),
'planmessigere': ('planmessig',),
'planmessigst': ('planmessig',),
'planmessigste': ('planmessig',),
'planskilt': ('planskilt',),
'planskilte': ('planskilt',),
'planskiltere': ('planskilt',),
'planskiltest': ('planskilt',),
'planskilteste': ('planskilt',),
'planta': ('plante',),
'plantede': ('plante',),
'plantende': ('plante',),
'plantet': ('plante',),
'plantete': ('plante',),
'plapra': ('plapre',),
'plaprede': ('plapre',),
'plaprende': ('plapre',),
'plapret': ('plapre',),
'plaprete': ('plapre',),
'plaska': ('plaske',),
'plaskede': ('plaske',),
'plaskende': ('plaske',),
'plasket': ('plaske',),
'plaskete': ('plaske',),
'plassbesparende': ('plassbesparende',),
'plasserende': ('plassere',),
'plassert': ('plassere',),
'plasserte': ('plassere',),
'plastisk': ('plastisk',),
'plastiske': ('plastisk',),
'plastiskere': ('plastisk',),
'plastiskest': ('plastisk',),
'plastiskeste': ('plastisk',),
'plastra': ('plastre',),
'plastrede': ('plastre',),
'plastrende': ('plastre',),
'plastret': ('plastre',),
'plastrete': ('plastre',),
'platinerende': ('platinere',),
'platinert': ('platinere',),
'platinerte': ('platinere',),
'platonisk': ('platonisk',),
'platoniske': ('platonisk',),
'platoniskere': ('platonisk',),
'platoniskest': ('platonisk',),
'platoniskeste': ('platonisk',),
'platonsk': ('platonsk',),
'platonske': ('platonsk',),
'platonskere': ('platonsk',),
'platonskest': ('platonsk',),
'platonskeste': ('platonsk',),
'platt': ('platt',),
'platte': ('platt',),
'plattere': ('platt',),
'plattest': ('platt',),
'platteste': ('platt',),
'plattfot': ('plattfot',),
'plattgatta': ('plattgatta',),
'plattgattede': ('plattgattet',),
'plattgattet': ('plattgattet',),
'plattgattete': ('plattgattet',),
'plattgattetere': ('plattgattet',),
'plattgattetest': ('plattgattet',),
'plattgatteteste': ('plattgattet',),
'plausibel': ('plausibel',),
'plausibelt': ('plausibel',),
'plausible': ('plausibel',),
'plausiblere': ('plausibel',),
'plausiblest': ('plausibel',),
'plausibleste': ('plausibel',),
'plebeiisk': ('plebeiisk',),
'plebeiiske': ('plebeiisk',),
'plebeiiskere': ('plebeiisk',),
'plebeiiskest': ('plebeiisk',),
'plebeiiskeste': ('plebeiisk',),
'plederende': ('pledere',),
'pledert': ('pledere',),
'plederte': ('pledere',),
'pleia': ('pleie',),
'pleid': ('pleie',),
'pleidd': ('pleie',),
'pleidde': ('pleie',),
'pleide': ('pleie',),
'pleiede': ('pleie',),
'pleiende': ('pleie',),
'pleiet': ('pleie',),
'pleiete': ('pleie',),
'pleid': ('pleie',),
'pleidd': ('pleie',),
'pleidde': ('pleie',),
'pleide': ('pleie',),
'pleiede': ('pleie',),
'pleiende': ('pleie',),
'pleiet': ('pleie',),
'pleiete': ('pleie',),
'pleietrengende': ('pleietrengende',),
'pleonastisk': ('pleonastisk',),
'pleonastiske': ('pleonastisk',),
'pleonastiskere': ('pleonastisk',),
'pleonastiskest': ('pleonastisk',),
'pleonastiskeste': ('pleonastisk',),
'pletta': ('plette',),
'plettede': ('plette',),
'plettende': ('plette',),
'plettet': ('plette',),
'plettete': ('plette',),
'pletterende': ('plettere',),
'plettert': ('plettere',),
'pletterte': ('plettere',),
'plettfri': ('plettfri',),
'plettfrie': ('plettfri',),
'plettfriere': ('plettfri',),
'plettfriest': ('plettfri',),
'plettfrieste': ('plettfri',),
'plettfritt': ('plettfri',),
'plikta': ('plikte',),
'pliktede': ('plikte',),
'pliktende': ('plikte',),
'pliktet': ('plikte',),
'pliktete': ('plikte',),
'pliktig': ('pliktig',),
'pliktige': ('pliktig',),
'pliktigere': ('pliktig',),
'pliktigst': ('pliktig',),
'pliktigste': ('pliktig',),
'pliktskyldig': ('pliktskyldig',),
'pliktskyldige': ('pliktskyldig',),
'pliktskyldigere': ('pliktskyldig',),
'pliktskyldigst': ('pliktskyldig',),
'pliktskyldigste': ('pliktskyldig',),
'plinga': ('plinge',),
'plingede': ('plinge',),
'plingende': ('plinge',),
'plinget': ('plinge',),
'plingete': ('plinge',),
'plira': ('plire',),
'plirede': ('plire',),
'plirende': ('plire',),
'pliret': ('plire',),
'plirete': ('plire',),
'plirt': ('plire',),
'plirte': ('plire',),
'plisserende': ('plissere',),
'plissert': ('plissere',),
'plisserte': ('plissere',),
'ploga': ('ploge',),
'plogede': ('ploge',),
'plogende': ('ploge',),
'ploget': ('ploge',),
'plogete': ('ploge',),
'plomberende': ('plombere',),
'plombert': ('plombere',),
'plomberte': ('plombere',),
'plotta': ('plotte',),
'plottede': ('plotte',),
'plottende': ('plotte',),
'plottet': ('plotte',),
'plottete': ('plotte',),
'pludra': ('pludre',),
'pludrede': ('pludre',),
'pludrende': ('pludre',),
'pludret': ('pludre',),
'pludrete': ('pludre',),
'plugga': ('plugge',),
'pluggede': ('plugge',),
'pluggende': ('plugge',),
'plugget': ('plugge',),
'pluggete': ('plugge',),
'plukka': ('plukke',),
'plukkede': ('plukke',),
'plukkende': ('plukke',),
'plukket': ('plukke',),
'plukkete': ('plukke',),
'plump': ('plump',),
'plumpe': ('plump',),
'plumpere': ('plump',),
'plumpest': ('plump',),
'plumpeste': ('plump',),
'plumpt': ('plump',),
'plumpa': ('plumpe',),
'plumpede': ('plumpe',),
'plumpende': ('plumpe',),
'plumpet': ('plumpe',),
'plumpete': ('plumpe',),
'plundra': ('plundre',),
'plundrede': ('plundre',),
'plundrende': ('plundre',),
'plundret': ('plundre',),
'plundrete': ('plundre',),
'plundret': ('plundret',),
'plundrete': ('plundret',),
'plundretere': ('plundret',),
'plundretest': ('plundret',),
'plundreteste': ('plundret',),
'plundrete': ('plundrete',),
'pluralistisk': ('pluralistisk',),
'pluralistiske': ('pluralistisk',),
'pluralistiskere': ('pluralistisk',),
'pluralistiskest': ('pluralistisk',),
'pluralistiskeste': ('pluralistisk',),
'pluriform': ('pluriform',),
'pluriforme': ('pluriform',),
'pluriformere': ('pluriform',),
'pluriformest': ('pluriform',),
'pluriformeste': ('pluriform',),
'pluriformt': ('pluriform',),
'plussa': ('plusse',),
'plussede': ('plusse',),
'plussende': ('plusse',),
'plusset': ('plusse',),
'plussete': ('plusse',),
'plutokratisk': ('plutokratisk',),
'plutokratiske': ('plutokratisk',),
'plutokratiskere': ('plutokratisk',),
'plutokratiskest': ('plutokratisk',),
'plutokratiskeste': ('plutokratisk',),
'plutonisk': ('plutonisk',),
'plutoniske': ('plutonisk',),
'plutoniskere': ('plutonisk',),
'plutoniskest': ('plutonisk',),
'plutoniskeste': ('plutonisk',),
'plutonistisk': ('plutonistisk',),
'plutonistiske': ('plutonistisk',),
'plutonistiskere': ('plutonistisk',),
'plutonistiskest': ('plutonistisk',),
'plutonistiskeste': ('plutonistisk',),
'plutselig': ('plutselig',),
'plutselige': ('plutselig',),
'plutseligere': ('plutselig',),
'plutseligst': ('plutselig',),
'plutseligste': ('plutselig',),
'pluvial': ('pluvial',),
'pluviale': ('pluvial',),
'pluvialere': ('pluvial',),
'pluvialest': ('pluvial',),
'pluvialeste': ('pluvial',),
'pluvialt': ('pluvial',),
'plyndra': ('plyndre',),
'plyndrede': ('plyndre',),
'plyndrende': ('plyndre',),
'plyndret': ('plyndre',),
'plyndrete': ('plyndre',),
'plystra': ('plystre',),
'plystrede': ('plystre',),
'plystrende': ('plystre',),
'plystret': ('plystre',),
'plystrete': ('plystre',),
'pløsende': ('pløse',),
'pløst': ('pløse',),
'pløste': ('pløse',),
'pløsen': ('pløsen',),
'pløsent': ('pløsen',),
'pløsne': ('pløsen',),
'pløsnere': ('pløsen',),
'pløsnest': ('pløsen',),
'pløsneste': ('pløsen',),
'pløset': ('pløset',),
'pløsete': ('pløset',),
'pløsetere': ('pløset',),
'pløsetest': ('pløset',),
'pløseteste': ('pløset',),
'pløsete': ('pløsete',),
'pløgd': ('pløye',),
'pløgde': ('pløye',),
'pløyd': ('pløye',),
'pløyde': ('pløye',),
'pløyende': ('pløye',),
'pneumatisk': ('pneumatisk',),
'pneumatiske': ('pneumatisk',),
'pneumatiskere': ('pneumatisk',),
'pneumatiskest': ('pneumatisk',),
'pneumatiskeste': ('pneumatisk',),
'poda': ('pode',),
'podede': ('pode',),
'podende': ('pode',),
'podet': ('pode',),
'podete': ('pode',),
'poda': ('pode',),
'podede': ('pode',),
'podende': ('pode',),
'podet': ('pode',),
'podete': ('pode',),
'poengterende': ('poengtere',),
'poengtert': ('poengtere',),
'poengterte': ('poengtere',),
'poetiserende': ('poetisere',),
'poetisert': ('poetisere',),
'poetiserte': ('poetisere',),
'poetisk': ('poetisk',),
'poetiske': ('poetisk',),
'poetiskere': ('poetisk',),
'poetiskest': ('poetisk',),
'poetiskeste': ('poetisk',),
'pokkers': ('pokkers',),
'pokra': ('pokre',),
'pokrede': ('pokre',),
'pokrende': ('pokre',),
'pokret': ('pokre',),
'pokrete': ('pokre',),
'pokulerende': ('pokulere',),
'pokulert': ('pokulere',),
'pokulerte': ('pokulere',),
'polar': ('polar',),
'polare': ('polar',),
'polarere': ('polar',),
'polarest': ('polar',),
'polareste': ('polar',),
'polart': ('polar',),
'polariserende': ('polarisere',),
'polarisert': ('polarisere',),
'polariserte': ('polarisere',),
'polaroid': ('polaroid',),
'polaroide': ('polaroid',),
'polaroidere': ('polaroid',),
'polaroidest': ('polaroid',),
'polaroideste': ('polaroid',),
'pola': ('pole',),
'polede': ('pole',),
'polende': ('pole',),
'polet': ('pole',),
'polete': ('pole',),
'polt': ('pole',),
'polte': ('pole',),
'polemiserende': ('polemisere',),
'polemisert': ('polemisere',),
'polemiserte': ('polemisere',),
'polemisk': ('polemisk',),
'polemiske': ('polemisk',),
'polemiskere': ('polemisk',),
'polemiskest': ('polemisk',),
'polemiskeste': ('polemisk',),
'polerende': ('polere',),
'polert': ('polere',),
'polerte': ('polere',),
'poliklinisk': ('poliklinisk',),
'polikliniske': ('poliklinisk',),
'polikliniskere': ('poliklinisk',),
'polikliniskest': ('poliklinisk',),
'polikliniskeste': ('poliklinisk',),
'polisk': ('polisk',),
'poliske': ('polisk',),
'poliskere': ('polisk',),
'poliskest': ('polisk',),
'poliskeste': ('polisk',),
'politiserende': ('politisere',),
'politisert': ('politisere',),
'politiserte': ('politisere',),
'politisk': ('politisk',),
'politiske': ('politisk',),
'politiskere': ('politisk',),
'politiskest': ('politisk',),
'politiskeste': ('politisk',),
'pollinerende': ('pollinere',),
'pollinert': ('pollinere',),
'pollinerte': ('pollinere',),
'polsk': ('polsk',),
'polske': ('polsk',),
'polskere': ('polsk',),
'polskest': ('polsk',),
'polskeste': ('polsk',),
'polstra': ('polstre',),
'polstrede': ('polstre',),
'polstrende': ('polstre',),
'polstret': ('polstre',),
'polstrete': ('polstre',),
'polyfon': ('polyfon',),
'polyfone': ('polyfon',),
'polyfonere': ('polyfon',),
'polyfonest': ('polyfon',),
'polyfoneste': ('polyfon',),
'polyfont': ('polyfon',),
'polyfonisk': ('polyfonisk',),
'polyfoniske': ('polyfonisk',),
'polyfoniskere': ('polyfonisk',),
'polyfoniskest': ('polyfonisk',),
'polyfoniskeste': ('polyfonisk',),
'polygam': ('polygam',),
'polygame': ('polygam',),
'polygamere': ('polygam',),
'polygamest': ('polygam',),
'polygameste': ('polygam',),
'polygamt': ('polygam',),
'polyglott': ('polyglott',),
'polyglotte': ('polyglott',),
'polyglottere': ('polyglott',),
'polyglottest': ('polyglott',),
'polyglotteste': ('polyglott',),
'polyglottisk': ('polyglottisk',),
'polyglottiske': ('polyglottisk',),
'polyglottiskere': ('polyglottisk',),
'polyglottiskest': ('polyglottisk',),
'polyglottiskeste': ('polyglottisk',),
'polygon': ('polygon',),
'polygone': ('polygon',),
'polygonere': ('polygon',),
'polygonest': ('polygon',),
'polygoneste': ('polygon',),
'polygont': ('polygon',),
'polygonal': ('polygonal',),
'polygonale': ('polygonal',),
'polygonalere': ('polygonal',),
'polygonalest': ('polygonal',),
'polygonaleste': ('polygonal',),
'polygonalt': ('polygonal',),
'polygyn': ('polygyn',),
'polygyne': ('polygyn',),
'polygynere': ('polygyn',),
'polygynest': ('polygyn',),
'polygyneste': ('polygyn',),
'polygynt': ('polygyn',),
'polykarp': ('polykarp',),
'polykarpe': ('polykarp',),
'polykarpere': ('polykarp',),
'polykarpest': ('polykarp',),
'polykarpeste': ('polykarp',),
'polykarpt': ('polykarp',),
'polykrom': ('polykrom',),
'polykrome': ('polykrom',),
'polykromere': ('polykrom',),
'polykromest': ('polykrom',),
'polykromeste': ('polykrom',),
'polykromt': ('polykrom',),
'polymer': ('polymer',),
'polymere': ('polymer',),
'polymerere': ('polymer',),
'polymerest': ('polymer',),
'polymereste': ('polymer',),
'polymert': ('polymer',),
'polymeriserende': ('polymerisere',),
'polymerisert': ('polymerisere',),
'polymeriserte': ('polymerisere',),
'polymorf': ('polymorf',),
'polymorfe': ('polymorf',),
'polymorfere': ('polymorf',),
'polymorfest': ('polymorf',),
'polymorfeste': ('polymorf',),
'polymorft': ('polymorf',),
'polynesisk': ('polynesisk',),
'polynesiske': ('polynesisk',),
'polynesiskere': ('polynesisk',),
'polynesiskest': ('polynesisk',),
'polynesiskeste': ('polynesisk',),
'polynomisk': ('polynomisk',),
'polynomiske': ('polynomisk',),
'polynomiskere': ('polynomisk',),
'polynomiskest': ('polynomisk',),
'polynomiskeste': ('polynomisk',),
'polyteistisk': ('polyteistisk',),
'polyteistiske': ('polyteistisk',),
'polyteistiskere': ('polyteistisk',),
'polyteistiskest': ('polyteistisk',),
'polyteistiskeste': ('polyteistisk',),
'polyteknisk': ('polyteknisk',),
'polytekniske': ('polyteknisk',),
'polytekniskere': ('polyteknisk',),
'polytekniskest': ('polyteknisk',),
'polytekniskeste': ('polyteknisk',),
'polytonal': ('polytonal',),
'polytonale': ('polytonal',),
'polytonalere': ('polytonal',),
'polytonalest': ('polytonal',),
'polytonaleste': ('polytonal',),
'polytonalt': ('polytonal',),
'polær': ('polær',),
'polære': ('polær',),
'polærere': ('polær',),
'polærest': ('polær',),
'polæreste': ('polær',),
'polært': ('polær',),
'pomadiserende': ('pomadisere',),
'pomadisert': ('pomadisere',),
'pomadiserte': ('pomadisere',),
'pompeiansk': ('pompeiansk',),
'pompeianske': ('pompeiansk',),
'pompeianskere': ('pompeiansk',),
'pompeianskest': ('pompeiansk',),
'pompeianskeste': ('pompeiansk',),
'pompeiisk': ('pompeiisk',),
'pompeiiske': ('pompeiisk',),
'pompeiiskere': ('pompeiisk',),
'pompeiiskest': ('pompeiisk',),
'pompeiiskeste': ('pompeiisk',),
'pompet': ('pompet',),
'pompete': ('pompet',),
'pompetere': ('pompet',),
'pompetest': ('pompet',),
'pompeteste': ('pompet',),
'pompete': ('pompete',),
'pompøs': ('pompøs',),
'pompøse': ('pompøs',),
'pompøsere': ('pompøs',),
'pompøsest': ('pompøs',),
'pompøseste': ('pompøs',),
'pompøst': ('pompøs',),
'poncerende': ('poncere',),
'poncert': ('poncere',),
'poncerte': ('poncere',),
'ponerende': ('ponere',),
'ponert': ('ponere',),
'ponerte': ('ponere',),
'pontifikal': ('pontifikal',),
'pontifikale': ('pontifikal',),
'pontifikalere': ('pontifikal',),
'pontifikalest': ('pontifikal',),
'pontifikaleste': ('pontifikal',),
'pontifikalt': ('pontifikal',),
'pop': ('pop',),
'pope': ('pop',),
'popere': ('pop',),
'popest': ('pop',),
'popeste': ('pop',),
'popt': ('pop',),
'popp': ('popp',),
'poppe': ('popp',),
'poppere': ('popp',),
'poppest': ('popp',),
'poppeste': ('popp',),
'popt': ('popp',),
'poppa': ('poppe',),
'poppede': ('poppe',),
'poppende': ('poppe',),
'poppet': ('poppe',),
'poppete': ('poppe',),
'poppa': ('poppe',),
'poppede': ('poppe',),
'poppende': ('poppe',),
'poppet': ('poppe',),
'poppete': ('poppe',),
'populariserende': ('popularisere',),
'popularisert': ('popularisere',),
'populariserte': ('popularisere',),
'populistisk': ('populistisk',),
'populistiske': ('populistisk',),
'populistiskere': ('populistisk',),
'populistiskest': ('populistisk',),
'populistiskeste': ('populistisk',),
'populær': ('populær',),
'populære': ('populær',),
'populærere': ('populær',),
'populærest': ('populær',),
'populæreste': ('populær',),
'populært': ('populær',),
'populærvitenskapelig': ('populærvitenskapelig',),
'populærvitenskapelige': ('populærvitenskapelig',),
'populærvitenskapeligere': ('populærvitenskapelig',),
'populærvitenskapeligst': ('populærvitenskapelig',),
'populærvitenskapeligste': ('populærvitenskapelig',),
'populærvitskapelig': ('populærvitskapelig',),
'populærvitskapelige': ('populærvitskapelig',),
'populærvitskapeligere': ('populærvitskapelig',),
'populærvitskapeligst': ('populærvitskapelig',),
'populærvitskapeligste': ('populærvitskapelig',),
'poret': ('poret',),
'porete': ('poret',),
'poretere': ('poret',),
'poretest': ('poret',),
'poreteste': ('poret',),
'porete': ('porete',),
'porfyrisk': ('porfyrisk',),
'porfyriske': ('porfyrisk',),
'porfyriskere': ('porfyrisk',),
'porfyriskest': ('porfyrisk',),
'porfyriskeste': ('porfyrisk',),
'pornografisk': ('pornografisk',),
'pornografiske': ('pornografisk',),
'pornografiskere': ('pornografisk',),
'pornografiskest': ('pornografisk',),
'pornografiskeste': ('pornografisk',),
'porsjonerende': ('porsjonere',),
'porsjonert': ('porsjonere',),
'porsjonerte': ('porsjonere',),
'portabel': ('portabel',),
'portabelt': ('portabel',),
'portable': ('portabel',),
'portablere': ('portabel',),
'portablest': ('portabel',),
'portableste': ('portabel',),
'portretterende': ('portrettere',),
'portrettert': ('portrettere',),
'portretterte': ('portrettere',),
'portugisisk': ('portugisisk',),
'portugisiske': ('portugisisk',),
'portugisiskere': ('portugisisk',),
'portugisiskest': ('portugisisk',),
'portugisiskeste': ('portugisisk',),
'porøs': ('porøs',),
'porøse': ('porøs',),
'porøsere': ('porøs',),
'porøsest': ('porøs',),
'porøseste': ('porøs',),
'porøst': ('porøs',),
'posa': ('pose',),
'posede': ('pose',),
'posende': ('pose',),
'poset': ('pose',),
'posete': ('pose',),
'posen': ('posen',),
'posent': ('posen',),
'posne': ('posen',),
'posnere': ('posen',),
'posnest': ('posen',),
'posneste': ('posen',),
'poserende': ('posere',),
'posert': ('posere',),
'poserte': ('posere',),
'poset': ('poset',),
'posete': ('poset',),
'posetere': ('poset',),
'posetest': ('poset',),
'poseteste': ('poset',),
'posete': ('posete',),
'posisjonerende': ('posisjonere',),
'posisjonert': ('posisjonere',),
'posisjonerte': ('posisjonere',),
'positiv': ('positiv',),
'positive': ('positiv',),
'positivere': ('positiv',),
'positivest': ('positiv',),
'positiveste': ('positiv',),
'positivt': ('positiv',),
'positivistisk': ('positivistisk',),
'positivistiske': ('positivistisk',),
'positivistiskere': ('positivistisk',),
'positivistiskest': ('positivistisk',),
'positivistiskeste': ('positivistisk',),
'posjerende': ('posjere',),
'posjert': ('posjere',),
'posjerte': ('posjere',),
'possessiv': ('possessiv',),
'possessive': ('possessiv',),
'possessivere': ('possessiv',),
'possessivest': ('possessiv',),
'possessiveste': ('possessiv',),
'possessivt': ('possessiv',),
'postal': ('postal',),
'postale': ('postal',),
'postalere': ('postal',),
'postalest': ('postal',),
'postaleste': ('postal',),
'postalt': ('postal',),
'postdaterende': ('postdatere',),
'postdatert': ('postdatere',),
'postdaterte': ('postdatere',),
'posta': ('poste',),
'postede': ('poste',),
'postende': ('poste',),
'postet': ('poste',),
'postete': ('poste',),
'posterende': ('postere',),
'postert': ('postere',),
'posterte': ('postere',),
'posterende': ('postere',),
'postert': ('postere',),
'posterte': ('postere',),
'postglasial': ('postglasial',),
'postglasiale': ('postglasial',),
'postglasialere': ('postglasial',),
'postglasialest': ('postglasial',),
'postglasialeste': ('postglasial',),
'postglasialt': ('postglasial',),
'postgymnasial': ('postgymnasial',),
'postgymnasiale': ('postgymnasial',),
'postgymnasialere': ('postgymnasial',),
'postgymnasialest': ('postgymnasial',),
'postgymnasialeste': ('postgymnasial',),
'postgymnasialt': ('postgymnasial',),
'posthum': ('posthum',),
'posthume': ('posthum',),
'posthumere': ('posthum',),
'posthumest': ('posthum',),
'posthumeste': ('posthum',),
'posthumt': ('posthum',),
'postlagt': ('postlegge',),
'postlagte': ('postlegge',),
'postleggende': ('postlegge',),
'postoperativ': ('postoperativ',),
'postoperative': ('postoperativ',),
'postoperativere': ('postoperativ',),
'postoperativest': ('postoperativ',),
'postoperativeste': ('postoperativ',),
'postoperativt': ('postoperativ',),
'poststempla': ('poststemple',),
'poststemplede': ('poststemple',),
'poststemplende': ('poststemple',),
'poststemplet': ('poststemple',),
'poststemplete': ('poststemple',),
'postulerende': ('postulere',),
'postulert': ('postulere',),
'postulerte': ('postulere',),
'pota': ('pote',),
'potede': ('pote',),
'potende': ('pote',),
'potet': ('pote',),
'potete': ('pote',),
'pota': ('pote',),
'potede': ('pote',),
'potende': ('pote',),
'potet': ('pote',),
'potete': ('pote',),
'potenserende': ('potensere',),
'potensert': ('potensere',),
'potenserte': ('potensere',),
'potensial': ('potensial',),
'potensiale': ('potensial',),
'potensialere': ('potensial',),
'potensialest': ('potensial',),
'potensialeste': ('potensial',),
'potensialt': ('potensial',),
'potensiell': ('potensiell',),
'potensielle': ('potensiell',),
'potensiellere': ('potensiell',),
'potensiellest': ('potensiell',),
'potensielleste': ('potensiell',),
'potensielt': ('potensiell',),
'potent': ('potent',),
'potente': ('potent',),
'potentere': ('potent',),
'potentest': ('potent',),
'potenteste': ('potent',),
'potta': ('potte',),
'pottede': ('potte',),
'pottende': ('potte',),
'pottet': ('potte',),
'pottete': ('potte',),
'pottesur': ('pottesur',),
'pottesure': ('pottesur',),
'pottesurere': ('pottesur',),
'pottesurest': ('pottesur',),
'pottesureste': ('pottesur',),
'pottesurt': ('pottesur',),
'pottetett': ('pottetett',),
'pottetette': ('pottetett',),
'pottetettere': ('pottetett',),
'pottetettest': ('pottetett',),
'pottetetteste': ('pottetett',),
'pragmatisk': ('pragmatisk',),
'pragmatiske': ('pragmatisk',),
'pragmatiskere': ('pragmatisk',),
'pragmatiskest': ('pragmatisk',),
'pragmatiskeste': ('pragmatisk',),
'praia': ('praie',),
'praiede': ('praie',),
'praiende': ('praie',),
'praiet': ('praie',),
'praiete': ('praie',),
'prakka': ('prakke',),
'prakkede': ('prakke',),
'prakkende': ('prakke',),
'prakket': ('prakke',),
'prakkete': ('prakke',),
'prakken': ('prakken',),
'prakkent': ('prakken',),
'prakne': ('prakken',),
'praknere': ('prakken',),
'praknest': ('prakken',),
'prakneste': ('prakken',),
'praktfull': ('praktfull',),
'praktfulle': ('praktfull',),
'praktfullere': ('praktfull',),
'praktfullest': ('praktfull',),
'praktfulleste': ('praktfull',),
'praktfullt': ('praktfull',),
'praktglad': ('praktglad',),
'praktglade': ('praktglad',),
'praktgladere': ('praktglad',),
'praktgladest': ('praktglad',),
'praktgladeste': ('praktglad',),
'praktikabel': ('praktikabel',),
'praktikabelt': ('praktikabel',),
'praktikable': ('praktikabel',),
'praktikablere': ('praktikabel',),
'praktikablest': ('praktikabel',),
'praktikableste': ('praktikabel',),
'praktiserende': ('praktisere',),
'praktisert': ('praktisere',),
'praktiserte': ('praktisere',),
'praktisk': ('praktisk',),
'praktiske': ('praktisk',),
'praktiskere': ('praktisk',),
'praktiskest': ('praktisk',),
'praktiskeste': ('praktisk',),
'praktsjuk': ('praktsjuk',),
'praktsjuke': ('praktsjuk',),
'praktsjukere': ('praktsjuk',),
'praktsjukest': ('praktsjuk',),
'praktsjukeste': ('praktsjuk',),
'praktsjukt': ('praktsjuk',),
'praktsyk': ('praktsyk',),
'praktsyke': ('praktsyk',),
'praktsykere': ('praktsyk',),
'praktsykest': ('praktsyk',),
'praktsykeste': ('praktsyk',),
'praktsykt': ('praktsyk',),
'prala': ('prale',),
'pralede': ('prale',),
'pralende': ('prale',),
'pralet': ('prale',),
'pralete': ('prale',),
'pralt': ('prale',),
'pralte': ('prale',),
'pranga': ('prange',),
'prangede': ('prange',),
'prangende': ('prange',),
'pranget': ('prange',),
'prangete': ('prange',),
'pranga': ('prange',),
'prangede': ('prange',),
'prangende': ('prange',),
'pranget': ('prange',),
'prangete': ('prange',),
'pranga': ('prange',),
'prangede': ('prange',),
'prangende': ('prange',),
'pranget': ('prange',),
'prangete': ('prange',),
'prasla': ('prasle',),
'praslede': ('prasle',),
'praslende': ('prasle',),
'praslet': ('prasle',),
'praslete': ('prasle',),
'prata': ('prate',),
'pratede': ('prate',),
'pratende': ('prate',),
'pratet': ('prate',),
'pratete': ('prate',),
'pratsom': ('pratsom',),
'pratsomme': ('pratsom',),
'pratsommere': ('pratsom',),
'pratsomst': ('pratsom',),
'pratsomste': ('pratsom',),
'pratsomt': ('pratsom',),
'predestinerende': ('predestinere',),
'predestinert': ('predestinere',),
'predestinerte': ('predestinere',),
'predeterminerende': ('predeterminere',),
'predeterminert': ('predeterminere',),
'predeterminerte': ('predeterminere',),
'predikativ': ('predikativ',),
'predikative': ('predikativ',),
'predikativere': ('predikativ',),
'predikativest': ('predikativ',),
'predikativeste': ('predikativ',),
'predikativt': ('predikativ',),
'predika': ('predike',),
'predikede': ('predike',),
'predikende': ('predike',),
'prediket': ('predike',),
'predikete': ('predike',),
'predikerende': ('predikere',),
'predikert': ('predikere',),
'predikerte': ('predikere',),
'predisponerende': ('predisponere',),
'predisponert': ('predisponere',),
'predisponerte': ('predisponere',),
'prefabrikkerende': ('prefabrikkere',),
'prefabrikkert': ('prefabrikkere',),
'prefabrikkerte': ('prefabrikkere',),
'prefererende': ('preferere',),
'preferert': ('preferere',),
'prefererte': ('preferere',),
'prega': ('prege',),
'pregede': ('prege',),
'pregende': ('prege',),
'preget': ('prege',),
'pregete': ('prege',),
'preglasial': ('preglasial',),
'preglasiale': ('preglasial',),
'preglasialere': ('preglasial',),
'preglasialest': ('preglasial',),
'preglasialeste': ('preglasial',),
'preglasialt': ('preglasial',),
'preglaus': ('preglaus',),
'preglause': ('preglaus',),
'preglausere': ('preglaus',),
'preglausest': ('preglaus',),
'preglauseste': ('preglaus',),
'preglaust': ('preglaus',),
'pregløs': ('pregløs',),
'pregløse': ('pregløs',),
'pregløsere': ('pregløs',),
'pregløsest': ('pregløs',),
'pregløseste': ('pregløs',),
'pregløst': ('pregløs',),
'pregnant': ('pregnant',),
'pregnante': ('pregnant',),
'pregnantere': ('pregnant',),
'pregnantest': ('pregnant',),
'pregnanteste': ('pregnant',),
'prehistorisk': ('prehistorisk',),
'prehistoriske': ('prehistorisk',),
'prehistoriskere': ('prehistorisk',),
'prehistoriskest': ('prehistorisk',),
'prehistoriskeste': ('prehistorisk',),
'prekaverende': ('prekavere',),
'prekavert': ('prekavere',),
'prekaverte': ('prekavere',),
'prekende': ('preke',),
'prekt': ('preke',),
'prekte': ('preke',),
'preklinisk': ('preklinisk',),
'prekliniske': ('preklinisk',),
'prekliniskere': ('preklinisk',),
'prekliniskest': ('preklinisk',),
'prekliniskeste': ('preklinisk',),
'preklusiv': ('preklusiv',),
'preklusive': ('preklusiv',),
'preklusivere': ('preklusiv',),
'preklusivest': ('preklusiv',),
'preklusiveste': ('preklusiv',),
'preklusivt': ('preklusiv',),
'prekolumbisk': ('prekolumbisk',),
'prekolumbiske': ('prekolumbisk',),
'prekolumbiskere': ('prekolumbisk',),
'prekolumbiskest': ('prekolumbisk',),
'prekolumbiskeste': ('prekolumbisk',),
'prektig': ('prektig',),
'prektige': ('prektig',),
'prektigere': ('prektig',),
'prektigst': ('prektig',),
'prektigste': ('prektig',),
'prekær': ('prekær',),
'prekære': ('prekær',),
'prekærere': ('prekær',),
'prekærest': ('prekær',),
'prekæreste': ('prekær',),
'prekært': ('prekær',),
'preliminær': ('preliminær',),
'preliminære': ('preliminær',),
'preliminærere': ('preliminær',),
'preliminærest': ('preliminær',),
'preliminæreste': ('preliminær',),
'preliminært': ('preliminær',),
'prella': ('prelle',),
'prellede': ('prelle',),
'prellende': ('prelle',),
'prellet': ('prelle',),
'prellete': ('prelle',),
'preluderende': ('preludere',),
'preludert': ('preludere',),
'preluderte': ('preludere',),
'prematur': ('prematur',),
'premature': ('prematur',),
'prematurere': ('prematur',),
'prematurest': ('prematur',),
'prematureste': ('prematur',),
'prematurt': ('prematur',),
'premierende': ('premiere',),
'premiert': ('premiere',),
'premierte': ('premiere',),
'prenatal': ('prenatal',),
'prenatale': ('prenatal',),
'prenatalere': ('prenatal',),
'prenatalest': ('prenatal',),
'prenataleste': ('prenatal',),
'prenatalt': ('prenatal',),
'prenta': ('prente',),
'prentede': ('prente',),
'prentende': ('prente',),
'prentet': ('prente',),
'prentete': ('prente',),
'prenumererende': ('prenumerere',),
'prenumerert': ('prenumerere',),
'prenumererte': ('prenumerere',),
'preparerende': ('preparere',),
'preparert': ('preparere',),
'preparerte': ('preparere',),
'preppa': ('preppe',),
'preppede': ('preppe',),
'preppende': ('preppe',),
'preppet': ('preppe',),
'preppete': ('preppe',),
'presbyteriansk': ('presbyteriansk',),
'presbyterianske': ('presbyteriansk',),
'presbyterianskere': ('presbyteriansk',),
'presbyterianskest': ('presbyteriansk',),
'presbyterianskeste': ('presbyteriansk',),
'present': ('present',),
'presente': ('present',),
'presentere': ('present',),
'presentest': ('present',),
'presenteste': ('present',),
'presentabel': ('presentabel',),
'presentabelt': ('presentabel',),
'presentable': ('presentabel',),
'presentablere': ('presentabel',),
'presentablest': ('presentabel',),
'presentableste': ('presentabel',),
'presenterende': ('presentere',),
'presentert': ('presentere',),
'presenterte': ('presentere',),
'presentisk': ('presentisk',),
'presentiske': ('presentisk',),
'presentiskere': ('presentisk',),
'presentiskest': ('presentisk',),
'presentiskeste': ('presentisk',),
'preseptorisk': ('preseptorisk',),
'preseptoriske': ('preseptorisk',),
'preseptoriskere': ('preseptorisk',),
'preseptoriskest': ('preseptorisk',),
'preseptoriskeste': ('preseptorisk',),
'preservativ': ('preservativ',),
'preservative': ('preservativ',),
'preservativere': ('preservativ',),
'preservativest': ('preservativ',),
'preservativeste': ('preservativ',),
'preservativt': ('preservativ',),
'preserverende': ('preservere',),
'preservert': ('preservere',),
'preserverte': ('preservere',),
'presiderende': ('presidere',),
'presidert': ('presidere',),
'presiderte': ('presidere',),
'presis': ('presis',),
'presise': ('presis',),
'presisere': ('presis',),
'presisest': ('presis',),
'presiseste': ('presis',),
'presist': ('presis',),
'presiserende': ('presisere',),
'presisert': ('presisere',),
'presiserte': ('presisere',),
'presiøs': ('presiøs',),
'presiøse': ('presiøs',),
'presiøsere': ('presiøs',),
'presiøsest': ('presiøs',),
'presiøseste': ('presiøs',),
'presiøst': ('presiøs',),
'preskriberende': ('preskribere',),
'preskribert': ('preskribere',),
'preskriberte': ('preskribere',),
'pressa': ('presse',),
'pressede': ('presse',),
'pressende': ('presse',),
'presset': ('presse',),
'pressete': ('presse',),
'presserende': ('presserende',),
'prestelig': ('prestelig',),
'prestelige': ('prestelig',),
'presteligere': ('prestelig',),
'presteligst': ('prestelig',),
'presteligste': ('prestelig',),
'presterende': ('prestere',),
'prestert': ('prestere',),
'presterte': ('prestere',),
'prestevia': ('prestevie',),
'prestevidd': ('prestevie',),
'prestevidde': ('prestevie',),
'presteviede': ('prestevie',),
'presteviende': ('prestevie',),
'presteviet': ('prestevie',),
'presteviete': ('prestevie',),
'prestevigd': ('prestevie',),
'prestevigde': ('prestevie',),
'presumerende': ('presumere',),
'presumert': ('presumere',),
'presumerte': ('presumere',),
'presumptiv': ('presumptiv',),
'presumptive': ('presumptiv',),
'presumptivere': ('presumptiv',),
'presumptivest': ('presumptiv',),
'presumptiveste': ('presumptiv',),
'presumptivt': ('presumptiv',),
'presupponerende': ('presupponere',),
'presupponert': ('presupponere',),
'presupponerte': ('presupponere',),
'pretenderende': ('pretendere',),
'pretendert': ('pretendere',),
'pretenderte': ('pretendere',),
'pretensiøs': ('pretensiøs',),
'pretensiøse': ('pretensiøs',),
'pretensiøsere': ('pretensiøs',),
'pretensiøsest': ('pretensiøs',),
'pretensiøseste': ('pretensiøs',),
'pretensiøst': ('pretensiøs',),
'pretta': ('prette',),
'prettede': ('prette',),
'prettende': ('prette',),
'prettet': ('prette',),
'prettete': ('prette',),
'preventiv': ('preventiv',),
'preventive': ('preventiv',),
'preventivere': ('preventiv',),
'preventivest': ('preventiv',),
'preventiveste': ('preventiv',),
'preventivt': ('preventiv',),
'prikka': ('prikke',),
'prikkede': ('prikke',),
'prikkende': ('prikke',),
'prikket': ('prikke',),
'prikkete': ('prikke',),
'prikken': ('prikken',),
'prikkent': ('prikken',),
'prikne': ('prikken',),
'priknere': ('prikken',),
'priknest': ('prikken',),
'prikneste': ('prikken',),
'prikket': ('prikket',),
'prikkete': ('prikket',),
'prikketere': ('prikket',),
'prikketest': ('prikket',),
'prikketeste': ('prikket',),
'prikkete': ('prikkete',),
'prikla': ('prikle',),
'priklede': ('prikle',),
'priklende': ('prikle',),
'priklet': ('prikle',),
'priklete': ('prikle',),
'prilla': ('prille',),
'prillede': ('prille',),
'prillende': ('prille',),
'prillet': ('prille',),
'prillete': ('prille',),
'prima': ('prima',),
'prima': ('prime',),
'primede': ('prime',),
'primende': ('prime',),
'primet': ('prime',),
'primete': ('prime',),
'primt': ('prime',),
'primte': ('prime',),
'primitiv': ('primitiv',),
'primitive': ('primitiv',),
'primitivere': ('primitiv',),
'primitivest': ('primitiv',),
'primitiveste': ('primitiv',),
'primitivt': ('primitiv',),
'primo': ('primo',),
'primsigna': ('primsigne',),
'primsignede': ('primsigne',),
'primsignende': ('primsigne',),
'primsignet': ('primsigne',),
'primsignete': ('primsigne',),
'primær': ('primær',),
'primære': ('primær',),
'primærere': ('primær',),
'primærest': ('primær',),
'primæreste': ('primær',),
'primært': ('primær',),
'prinsipal': ('prinsipal',),
'prinsipale': ('prinsipal',),
'prinsipalere': ('prinsipal',),
'prinsipalest': ('prinsipal',),
'prinsipaleste': ('prinsipal',),
'prinsipalt': ('prinsipal',),
'prinsipiell': ('prinsipiell',),
'prinsipielle': ('prinsipiell',),
'prinsipiellere': ('prinsipiell',),
'prinsipiellest': ('prinsipiell',),
'prinsipielleste': ('prinsipiell',),
'prinsipielt': ('prinsipiell',),
'prinsippfast': ('prinsippfast',),
'prinsippfaste': ('prinsippfast',),
'prinsippfastere': ('prinsippfast',),
'prinsippfastest': ('prinsippfast',),
'prinsippfasteste': ('prinsippfast',),
'prinsipplaus': ('prinsipplaus',),
'prinsipplause': ('prinsipplaus',),
'prinsipplausere': ('prinsipplaus',),
'prinsipplausest': ('prinsipplaus',),
'prinsipplauseste': ('prinsipplaus',),
'prinsipplaust': ('prinsipplaus',),
'prinsippløs': ('prinsippløs',),
'prinsippløse': ('prinsippløs',),
'prinsippløsere': ('prinsippløs',),
'prinsippløsest': ('prinsippløs',),
'prinsippløseste': ('prinsippløs',),
'prinsippløst': ('prinsippløs',),
'prioriterende': ('prioritere',),
'prioritert': ('prioritere',),
'prioriterte': ('prioritere',),
'pripne': ('prippen',),
'pripnere': ('prippen',),
'pripnest': ('prippen',),
'pripneste': ('prippen',),
'prippen': ('prippen',),
'prippent': ('prippen',),
'prisbelønna': ('prisbelønne',),
'prisbelønnede': ('prisbelønne',),
'prisbelønnende': ('prisbelønne',),
'prisbelønnet': ('prisbelønne',),
'prisbelønnete': ('prisbelønne',),
'prisbelønt': ('prisbelønne',),
'prisbelønte': ('prisbelønne',),
'prisbevisst': ('prisbevisst',),
'prisbevisste': ('prisbevisst',),
'prisbevisstere': ('prisbevisst',),
'prisbevisstest': ('prisbevisst',),
'prisbevissteste': ('prisbevisst',),
'prisdrivende': ('prisdrivende',),
'prisa': ('prise',),
'prisede': ('prise',),
'prisende': ('prise',),
'priset': ('prise',),
'prisete': ('prise',),
'prisende': ('prise',),
'prist': ('prise',),
'priste': ('prise',),
'prisgiende': ('prisgi',),
'prisgitt': ('prisgi',),
'prisgitte': ('prisgi',),
'prisgivende': ('prisgi',),
'prismatisk': ('prismatisk',),
'prismatiske': ('prismatisk',),
'prismatiskere': ('prismatisk',),
'prismatiskest': ('prismatisk',),
'prismatiskeste': ('prismatisk',),
'prismeforma': ('prismeforma',),
'prismeformede': ('prismeformet',),
'prismeformet': ('prismeformet',),
'prismeformete': ('prismeformet',),
'prismeformetere': ('prismeformet',),
'prismeformetest': ('prismeformet',),
'prismeformeteste': ('prismeformet',),
'prisverdig': ('prisverdig',),
'prisverdige': ('prisverdig',),
'prisverdigere': ('prisverdig',),
'prisverdigst': ('prisverdig',),
'prisverdigste': ('prisverdig',),
'privat': ('privat',),
'private': ('privat',),
'privatere': ('privat',),
'privatest': ('privat',),
'privateste': ('privat',),
'privateid': ('privateid',),
'privateide': ('privateid',),
'privateidere': ('privateid',),
'privateidest': ('privateid',),
'privateideste': ('privateid',),
'privatiserende': ('privatisere',),
'privatisert': ('privatisere',),
'privatiserte': ('privatisere',),
'privativ': ('privativ',),
'privative': ('privativ',),
'privativere': ('privativ',),
'privativest': ('privativ',),
'privativeste': ('privativ',),
'privativt': ('privativ',),
'privatpraktiserende': ('privatpraktiserende',),
'privilegerende': ('privilegere',),
'privilegert': ('privilegere',),
'privilegerte': ('privilegere',),
'probabel': ('probabel',),
'probabelt': ('probabel',),
'probable': ('probabel',),
'probablere': ('probabel',),
'probablest': ('probabel',),
'probableste': ('probabel',),
'probat': ('probat',),
'probate': ('probat',),
'probatere': ('probat',),
'probatest': ('probat',),
'probateste': ('probat',),
'proberende': ('probere',),
'probert': ('probere',),
'proberte': ('probere',),
'problematiserende': ('problematisere',),
'problematisert': ('problematisere',),
'problematiserte': ('problematisere',),
'problematisk': ('problematisk',),
'problematiske': ('problematisk',),
'problematiskere': ('problematisk',),
'problematiskest': ('problematisk',),
'problematiskeste': ('problematisk',),
'problemfylt': ('problemfylt',),
'problemfylte': ('problemfylt',),
'problemfyltere': ('problemfylt',),
'problemfyltest': ('problemfylt',),
'problemfylteste': ('problemfylt',),
'problemorientert': ('problemorientert',),
'problemorienterte': ('problemorientert',),
'problemorientertere': ('problemorientert',),
'problemorientertest': ('problemorientert',),
'problemorienterteste': ('problemorientert',),
'produktiv': ('produktiv',),
'produktive': ('produktiv',),
'produktivere': ('produktiv',),
'produktivest': ('produktiv',),
'produktiveste': ('produktiv',),
'produktivt': ('produktiv',),
'produserende': ('produsere',),
'produsert': ('produsere',),
'produserte': ('produsere',),
'proa': ('proe',),
'proede': ('proe',),
'proende': ('proe',),
'proet': ('proe',),
'proete': ('proe',),
'proa': ('proe',),
'proede': ('proe',),
'proende': ('proe',),
'proet': ('proe',),
'proete': ('proe',),
'profan': ('profan',),
'profane': ('profan',),
'profanere': ('profan',),
'profanest': ('profan',),
'profaneste': ('profan',),
'profant': ('profan',),
'profanerende': ('profanere',),
'profanert': ('profanere',),
'profanerte': ('profanere',),
'profesjonaliserende': ('profesjonalisere',),
'profesjonalisert': ('profesjonalisere',),
'profesjonaliserte': ('profesjonalisere',),
'profesjonell': ('profesjonell',),
'profesjonelle': ('profesjonell',),
'profesjonellere': ('profesjonell',),
'profesjonellest': ('profesjonell',),
'profesjonelleste': ('profesjonell',),
'profesjonelt': ('profesjonell',),
'professoral': ('professoral',),
'professorale': ('professoral',),
'professoralere': ('professoral',),
'professoralest': ('professoral',),
'professoraleste': ('professoral',),
'professoralt': ('professoral',),
'profeterende': ('profetere',),
'profetert': ('profetere',),
'profeterte': ('profetere',),
'profetisk': ('profetisk',),
'profetiske': ('profetisk',),
'profetiskere': ('profetisk',),
'profetiskest': ('profetisk',),
'profetiskeste': ('profetisk',),
'proff': ('proff',),
'proffe': ('proff',),
'proffere': ('proff',),
'proffest': ('proff',),
'proffeste': ('proff',),
'proft': ('proff',),
'profilerende': ('profilere',),
'profilert': ('profilere',),
'profilerte': ('profilere',),
'profitabel': ('profitabel',),
'profitabelt': ('profitabel',),
'profitable': ('profitabel',),
'profitablere': ('profitabel',),
'profitablest': ('profitabel',),
'profitableste': ('profitabel',),
'profitterende': ('profittere',),
'profittert': ('profittere',),
'profitterte': ('profittere',),
'profylaktisk': ('profylaktisk',),
'profylaktiske': ('profylaktisk',),
'profylaktiskere': ('profylaktisk',),
'profylaktiskest': ('profylaktisk',),
'profylaktiskeste': ('profylaktisk',),
'prognoserende': ('prognosere',),
'prognosert': ('prognosere',),
'prognoserte': ('prognosere',),
'prognostiserende': ('prognostisere',),
'prognostisert': ('prognostisere',),
'prognostiserte': ('prognostisere',),
'prognostisk': ('prognostisk',),
'prognostiske': ('prognostisk',),
'prognostiskere': ('prognostisk',),
'prognostiskest': ('prognostisk',),
'prognostiskeste': ('prognostisk',),
'programfesta': ('programfeste',),
'programfestede': ('programfeste',),
'programfestende': ('programfeste',),
'programfestet': ('programfeste',),
'programfestete': ('programfeste',),
'programforplikta': ('programforplikta',),
'programforpliktede': ('programforpliktet',),
'programforpliktet': ('programforpliktet',),
'programforpliktete': ('programforpliktet',),
'programforpliktetere': ('programforpliktet',),
'programforpliktetest': ('programforpliktet',),
'programforplikteteste': ('programforpliktet',),
'programmatisk': ('programmatisk',),
'programmatiske': ('programmatisk',),
'programmatiskere': ('programmatisk',),
'programmatiskest': ('programmatisk',),
'programmatiskeste': ('programmatisk',),
'programmerende': ('programmere',),
'programmert': ('programmere',),
'programmerte': ('programmere',),
'programmessig': ('programmessig',),
'programmessige': ('programmessig',),
'programmessigere': ('programmessig',),
'programmessigst': ('programmessig',),
'programmessigste': ('programmessig',),
'progressiv': ('progressiv',),
'progressive': ('progressiv',),
'progressivere': ('progressiv',),
'progressivest': ('progressiv',),
'progressiveste': ('progressiv',),
'progressivt': ('progressiv',),
'prohibitiv': ('prohibitiv',),
'prohibitive': ('prohibitiv',),
'prohibitivere': ('prohibitiv',),
'prohibitivest': ('prohibitiv',),
'prohibitiveste': ('prohibitiv',),
'prohibitivt': ('prohibitiv',),
'projiserende': ('projisere',),
'projisert': ('projisere',),
'projiserte': ('projisere',),
'proklamerende': ('proklamere',),
'proklamert': ('proklamere',),
'proklamerte': ('proklamere',),
'proksimal': ('proksimal',),
'proksimale': ('proksimal',),
'proksimalere': ('proksimal',),
'proksimalest': ('proksimal',),
'proksimaleste': ('proksimal',),
'proksimalt': ('proksimal',),
'proletariserende': ('proletarisere',),
'proletarisert': ('proletarisere',),
'proletariserte': ('proletarisere',),
'proletarisk': ('proletarisk',),
'proletariske': ('proletarisk',),
'proletariskere': ('proletarisk',),
'proletariskest': ('proletarisk',),
'proletariskeste': ('proletarisk',),
'proletær': ('proletær',),
'proletære': ('proletær',),
'proletærere': ('proletær',),
'proletærest': ('proletær',),
'proletæreste': ('proletær',),
'proletært': ('proletær',),
'prolongerende': ('prolongere',),
'prolongert': ('prolongere',),
'prolongerte': ('prolongere',),
'promenerende': ('promenere',),
'promenert': ('promenere',),
'promenerte': ('promenere',),
'prominent': ('prominent',),
'prominente': ('prominent',),
'prominentere': ('prominent',),
'prominentest': ('prominent',),
'prominenteste': ('prominent',),
'promiskuøs': ('promiskuøs',),
'promiskuøse': ('promiskuøs',),
'promiskuøsere': ('promiskuøs',),
'promiskuøsest': ('promiskuøs',),
'promiskuøseste': ('promiskuøs',),
'promiskuøst': ('promiskuøs',),
'promoverende': ('promovere',),
'promovert': ('promovere',),
'promoverte': ('promovere',),
'prompa': ('prompe',),
'prompede': ('prompe',),
'prompende': ('prompe',),
'prompet': ('prompe',),
'prompete': ('prompe',),
'promulgerende': ('promulgere',),
'promulgert': ('promulgere',),
'promulgerte': ('promulgere',),
'pronerende': ('pronere',),
'pronert': ('pronere',),
'pronerte': ('pronere',),
'pronominal': ('pronominal',),
'pronominale': ('pronominal',),
'pronominalere': ('pronominal',),
'pronominalest': ('pronominal',),
'pronominaleste': ('pronominal',),
'pronominalt': ('pronominal',),
'pronominaliserende': ('pronominalisere',),
'pronominalisert': ('pronominalisere',),
'pronominaliserte': ('pronominalisere',),
'pronominell': ('pronominell',),
'pronominelle': ('pronominell',),
'pronominellere': ('pronominell',),
'pronominellest': ('pronominell',),
'pronominelleste': ('pronominell',),
'pronominelt': ('pronominell',),
'propaganderende': ('propagandere',),
'propagandert': ('propagandere',),
'propaganderte': ('propagandere',),
'propagandistisk': ('propagandistisk',),
'propagandistiske': ('propagandistisk',),
'propagandistiskere': ('propagandistisk',),
'propagandistiskest': ('propagandistisk',),
'propagandistiskeste': ('propagandistisk',),
'propagerende': ('propagere',),
'propagert': ('propagere',),
'propagerte': ('propagere',),
'propedeutisk': ('propedeutisk',),
'propedeutiske': ('propedeutisk',),
'propedeutiskere': ('propedeutisk',),
'propedeutiskest': ('propedeutisk',),
'propedeutiskeste': ('propedeutisk',),
'propedevtisk': ('propedevtisk',),
'propedevtiske': ('propedevtisk',),
'propedevtiskere': ('propedevtisk',),
'propedevtiskest': ('propedevtisk',),
'propedevtiskeste': ('propedevtisk',),
'propelldrevet': ('propelldrevet',),
'propelldrevne': ('propelldrevet',),
'propelldrevnere': ('propelldrevet',),
'propelldrevnest': ('propelldrevet',),
'propelldrevneste': ('propelldrevet',),
'proper': ('proper',),
'propert': ('proper',),
'propre': ('proper',),
'proprere': ('proper',),
'proprest': ('proper',),
'propreste': ('proper',),
'proponerende': ('proponere',),
'proponert': ('proponere',),
'proponerte': ('proponere',),
'proporsjonal': ('proporsjonal',),
'proporsjonale': ('proporsjonal',),
'proporsjonalere': ('proporsjonal',),
'proporsjonalest': ('proporsjonal',),
'proporsjonaleste': ('proporsjonal',),
'proporsjonalt': ('proporsjonal',),
'proporsjonerende': ('proporsjonere',),
'proporsjonert': ('proporsjonere',),
'proporsjonerte': ('proporsjonere',),
'proppa': ('proppe',),
'proppede': ('proppe',),
'proppende': ('proppe',),
'proppet': ('proppe',),
'proppete': ('proppe',),
'proppfull': ('proppfull',),
'proppfulle': ('proppfull',),
'proppfullere': ('proppfull',),
'proppfullest': ('proppfull',),
'proppfulleste': ('proppfull',),
'proppfullt': ('proppfull',),
'proppmett': ('proppmett',),
'proppmette': ('proppmett',),
'proppmettere': ('proppmett',),
'proppmettest': ('proppmett',),
'proppmetteste': ('proppmett',),
'prosaisk': ('prosaisk',),
'prosaiske': ('prosaisk',),
'prosaiskere': ('prosaisk',),
'prosaiskest': ('prosaisk',),
'prosaiskeste': ('prosaisk',),
'prosederende': ('prosedere',),
'prosedert': ('prosedere',),
'prosederte': ('prosedere',),
'prosentisk': ('prosentisk',),
'prosentiske': ('prosentisk',),
'prosentiskere': ('prosentisk',),
'prosentiskest': ('prosentisk',),
'prosentiskeste': ('prosentisk',),
'prosentlønna': ('prosentlønne',),
'prosentlønnede': ('prosentlønne',),
'prosentlønnende': ('prosentlønne',),
'prosentlønnet': ('prosentlønne',),
'prosentlønnete': ('prosentlønne',),
'prosentlønt': ('prosentlønne',),
'prosentlønte': ('prosentlønne',),
'prosentuell': ('prosentuell',),
'prosentuelle': ('prosentuell',),
'prosentuellere': ('prosentuell',),
'prosentuellest': ('prosentuell',),
'prosentuelleste': ('prosentuell',),
'prosentuelt': ('prosentuell',),
'prosesserende': ('prosessere',),
'prosessert': ('prosessere',),
'prosesserte': ('prosessere',),
'prosessuell': ('prosessuell',),
'prosessuelle': ('prosessuell',),
'prosessuellere': ('prosessuell',),
'prosessuellest': ('prosessuell',),
'prosessuelleste': ('prosessuell',),
'prosessuelt': ('prosessuell',),
'prosjekterende': ('prosjektere',),
'prosjektert': ('prosjektere',),
'prosjekterte': ('prosjektere',),
'proskriberende': ('proskribere',),
'proskribert': ('proskribere',),
'proskriberte': ('proskribere',),
'prosodisk': ('prosodisk',),
'prosodiske': ('prosodisk',),
'prosodiskere': ('prosodisk',),
'prosodiskest': ('prosodisk',),
'prosodiskeste': ('prosodisk',),
'prospekterende': ('prospektere',),
'prospektert': ('prospektere',),
'prospekterte': ('prospektere',),
'prospektiv': ('prospektiv',),
'prospektive': ('prospektiv',),
'prospektivere': ('prospektiv',),
'prospektivest': ('prospektiv',),
'prospektiveste': ('prospektiv',),
'prospektivt': ('prospektiv',),
'prostituerende': ('prostituere',),
'prostituert': ('prostituere',),
'prostituerte': ('prostituere',),
'prostituert': ('prostituert',),
'prostituerte': ('prostituert',),
'prostituertere': ('prostituert',),
'prostituertest': ('prostituert',),
'prostituerteste': ('prostituert',),
'proteksjonistisk': ('proteksjonistisk',),
'proteksjonistiske': ('proteksjonistisk',),
'proteksjonistiskere': ('proteksjonistisk',),
'proteksjonistiskest': ('proteksjonistisk',),
'proteksjonistiskeste': ('proteksjonistisk',),
'protesjerende': ('protesjere',),
'protesjert': ('protesjere',),
'protesjerte': ('protesjere',),
'protestantisk': ('protestantisk',),
'protestantiske': ('protestantisk',),
'protestantiskere': ('protestantisk',),
'protestantiskest': ('protestantisk',),
'protestantiskeste': ('protestantisk',),
'protesterende': ('protestere',),
'protestert': ('protestere',),
'protesterte': ('protestere',),
'protokollerende': ('protokollere',),
'protokollert': ('protokollere',),
'protokollerte': ('protokollere',),
'prototypisk': ('prototypisk',),
'prototypiske': ('prototypisk',),
'prototypiskere': ('prototypisk',),
'prototypiskest': ('prototypisk',),
'prototypiskeste': ('prototypisk',),
'protta': ('protte',),
'prottede': ('protte',),
'prottende': ('protte',),
'prottet': ('protte',),
'prottete': ('protte',),
'protta': ('protte',),
'prottede': ('protte',),
'prottende': ('protte',),
'prottet': ('protte',),
'prottete': ('protte',),
'prova': ('prove',),
'provede': ('prove',),
'provende': ('prove',),
'provet': ('prove',),
'provete': ('prove',),
'provençalsk': ('provençalsk',),
'provençalske': ('provençalsk',),
'provençalskere': ('provençalsk',),
'provençalskest': ('provençalsk',),
'provençalskeste': ('provençalsk',),
'proverbiell': ('proverbiell',),
'proverbielle': ('proverbiell',),
'proverbiellere': ('proverbiell',),
'proverbiellest': ('proverbiell',),
'proverbielleste': ('proverbiell',),
'proverbielt': ('proverbiell',),
'provianterende': ('proviantere',),
'proviantert': ('proviantere',),
'provianterte': ('proviantere',),
'providerende': ('providere',),
'providert': ('providere',),
'providerte': ('providere',),
'provinsial': ('provinsial',),
'provinsiale': ('provinsial',),
'provinsialere': ('provinsial',),
'provinsialest': ('provinsial',),
'provinsialeste': ('provinsial',),
'provinsialt': ('provinsial',),
'provinsiell': ('provinsiell',),
'provinsielle': ('provinsiell',),
'provinsiellere': ('provinsiell',),
'provinsiellest': ('provinsiell',),
'provinsielleste': ('provinsiell',),
'provinsielt': ('provinsiell',),
'provisorisk': ('provisorisk',),
'provisoriske': ('provisorisk',),
'provisoriskere': ('provisorisk',),
'provisoriskest': ('provisorisk',),
'provisoriskeste': ('provisorisk',),
'provokativ': ('provokativ',),
'provokative': ('provokativ',),
'provokativere': ('provokativ',),
'provokativest': ('provokativ',),
'provokativeste': ('provokativ',),
'provokativt': ('provokativ',),
'provokatorisk': ('provokatorisk',),
'provokatoriske': ('provokatorisk',),
'provokatoriskere': ('provokatorisk',),
'provokatoriskest': ('provokatorisk',),
'provokatoriskeste': ('provokatorisk',),
'provoserende': ('provosere',),
'provosert': ('provosere',),
'provoserte': ('provosere',),
'prud': ('prud',),
'prude': ('prud',),
'prudere': ('prud',),
'prudest': ('prud',),
'prudeste': ('prud',),
'prunka': ('prunke',),
'prunkede': ('prunke',),
'prunkende': ('prunke',),
'prunket': ('prunke',),
'prunkete': ('prunke',),
'prunklaus': ('prunklaus',),
'prunklause': ('prunklaus',),
'prunklausere': ('prunklaus',),
'prunklausest': ('prunklaus',),
'prunklauseste': ('prunklaus',),
'prunklaust': ('prunklaus',),
'prunkløs': ('prunkløs',),
'prunkløse': ('prunkløs',),
'prunkløsere': ('prunkløs',),
'prunkløsest': ('prunkløs',),
'prunkløseste': ('prunkløs',),
'prunkløst': ('prunkløs',),
'pruppa': ('pruppe',),
'pruppede': ('pruppe',),
'pruppende': ('pruppe',),
'pruppet': ('pruppe',),
'pruppete': ('pruppe',),
'prusta': ('pruste',),
'prustede': ('pruste',),
'prustende': ('pruste',),
'prustet': ('pruste',),
'prustete': ('pruste',),
'pruta': ('prute',),
'prutede': ('prute',),
'prutende': ('prute',),
'prutet': ('prute',),
'prutete': ('prute',),
'pryda': ('pryde',),
'prydede': ('pryde',),
'prydende': ('pryde',),
'prydet': ('pryde',),
'prydete': ('pryde',),
'prydelig': ('prydelig',),
'prydelige': ('prydelig',),
'prydeligere': ('prydelig',),
'prydeligst': ('prydelig',),
'prydeligste': ('prydelig',),
'prylende': ('pryle',),
'prylt': ('pryle',),
'prylte': ('pryle',),
'prøvd': ('prøve',),
'prøvde': ('prøve',),
'prøvende': ('prøve',),
'prøvebora': ('prøvebore',),
'prøveborede': ('prøvebore',),
'prøveborende': ('prøvebore',),
'prøveboret': ('prøvebore',),
'prøveborete': ('prøvebore',),
'prøvefilma': ('prøvefilme',),
'prøvefilmede': ('prøvefilme',),
'prøvefilmende': ('prøvefilme',),
'prøvefilmet': ('prøvefilme',),
'prøvefilmete': ('prøvefilme',),
'prøvekjørende': ('prøvekjøre',),
'prøvekjørt': ('prøvekjøre',),
'prøvekjørte': ('prøvekjøre',),
'prøveskutt': ('prøveskyte',),
'prøveskutte': ('prøveskyte',),
'prøveskytende': ('prøveskyte',),
'prøvede': ('prøvet',),
'prøvet': ('prøvet',),
'prøvete': ('prøvet',),
'prøvetere': ('prøvet',),
'prøvetest': ('prøvet',),
'prøveteste': ('prøvet',),
'prøyssisk': ('prøyssisk',),
'prøyssiske': ('prøyssisk',),
'prøyssiskere': ('prøyssisk',),
'prøyssiskest': ('prøyssisk',),
'prøyssiskeste': ('prøyssisk',),
'pseudonym': ('pseudonym',),
'pseudonyme': ('pseudonym',),
'pseudonymere': ('pseudonym',),
'pseudonymest': ('pseudonym',),
'pseudonymeste': ('pseudonym',),
'pseudonymt': ('pseudonym',),
'psevdonym': ('psevdonym',),
'psevdonyme': ('psevdonym',),
'psevdonymere': ('psevdonym',),
'psevdonymest': ('psevdonym',),
'psevdonymeste': ('psevdonym',),
'psevdonymt': ('psevdonym',),
'psyka': ('psyke',),
'psykede': ('psyke',),
'psykende': ('psyke',),
'psyket': ('psyke',),
'psykete': ('psyke',),
'psykedelisk': ('psykedelisk',),
'psykedeliske': ('psykedelisk',),
'psykedeliskere': ('psykedelisk',),
'psykedeliskest': ('psykedelisk',),
'psykedeliskeste': ('psykedelisk',),
'psykiatrisk': ('psykiatrisk',),
'psykiatriske': ('psykiatrisk',),
'psykiatriskere': ('psykiatrisk',),
'psykiatriskest': ('psykiatrisk',),
'psykiatriskeste': ('psykiatrisk',),
'psykisk': ('psykisk',),
'psykiske': ('psykisk',),
'psykiskere': ('psykisk',),
'psykiskest': ('psykisk',),
'psykiskeste': ('psykisk',),
'psykoanalyserende': ('psykoanalysere',),
'psykoanalysert': ('psykoanalysere',),
'psykoanalyserte': ('psykoanalysere',),
'psykoanalytisk': ('psykoanalytisk',),
'psykoanalytiske': ('psykoanalytisk',),
'psykoanalytiskere': ('psykoanalytisk',),
'psykoanalytiskest': ('psykoanalytisk',),
'psykoanalytiskeste': ('psykoanalytisk',),
'psykogen': ('psykogen',),
'psykogene': ('psykogen',),
'psykogenere': ('psykogen',),
'psykogenest': ('psykogen',),
'psykogeneste': ('psykogen',),
'psykogent': ('psykogen',),
'psykologisk': ('psykologisk',),
'psykologiske': ('psykologisk',),
'psykologiskere': ('psykologisk',),
'psykologiskest': ('psykologisk',),
'psykologiskeste': ('psykologisk',),
'psykopatisk': ('psykopatisk',),
'psykopatiske': ('psykopatisk',),
'psykopatiskere': ('psykopatisk',),
'psykopatiskest': ('psykopatisk',),
'psykopatiskeste': ('psykopatisk',),
'psykosomatisk': ('psykosomatisk',),
'psykosomatiske': ('psykosomatisk',),
'psykosomatiskere': ('psykosomatisk',),
'psykosomatiskest': ('psykosomatisk',),
'psykosomatiskeste': ('psykosomatisk',),
'psykoteknisk': ('psykoteknisk',),
'psykotekniske': ('psykoteknisk',),
'psykotekniskere': ('psykoteknisk',),
'psykotekniskest': ('psykoteknisk',),
'psykotekniskeste': ('psykoteknisk',),
'psykotisk': ('psykotisk',),
'psykotiske': ('psykotisk',),
'psykotiskere': ('psykotisk',),
'psykotiskest': ('psykotisk',),
'psykotiskeste': ('psykotisk',),
'ptolemeisk': ('ptolemeisk',),
'ptolemeiske': ('ptolemeisk',),
'ptolemeiskere': ('ptolemeisk',),
'ptolemeiskest': ('ptolemeisk',),
'ptolemeiskeste': ('ptolemeisk',),
'ptroa': ('ptroe',),
'ptroede': ('ptroe',),
'ptroende': ('ptroe',),
'ptroet': ('ptroe',),
'ptroete': ('ptroe',),
'ptroa': ('ptroe',),
'ptroede': ('ptroe',),
'ptroende': ('ptroe',),
'ptroet': ('ptroe',),
'ptroete': ('ptroe',),
'ptrotta': ('ptrotte',),
'ptrottede': ('ptrotte',),
'ptrottende': ('ptrotte',),
'ptrottet': ('ptrotte',),
'ptrottete': ('ptrotte',),
'ptrotta': ('ptrotte',),
'ptrottede': ('ptrotte',),
'ptrottende': ('ptrotte',),
'ptrottet': ('ptrotte',),
'ptrottete': ('ptrotte',),
'publiserende': ('publisere',),
'publisert': ('publisere',),
'publiserte': ('publisere',),
'pudra': ('pudre',),
'pudrede': ('pudre',),
'pudrende': ('pudre',),
'pudret': ('pudre',),
'pudrete': ('pudre',),
'pueril': ('pueril',),
'puerile': ('pueril',),
'puerilere': ('pueril',),
'puerilest': ('pueril',),
'puerileste': ('pueril',),
'puerilt': ('pueril',),
'puertoricansk': ('puertoricansk',),
'puertoricanske': ('puertoricansk',),
'puertoricanskere': ('puertoricansk',),
'puertoricanskest': ('puertoricansk',),
'puertoricanskeste': ('puertoricansk',),
'puertorikansk': ('puertorikansk',),
'puertorikanske': ('puertorikansk',),
'puertorikanskere': ('puertorikansk',),
'puertorikanskest': ('puertorikansk',),
'puertorikanskeste': ('puertorikansk',),
'puffa': ('puffe',),
'puffede': ('puffe',),
'puffende': ('puffe',),
'puffet': ('puffe',),
'puffete': ('puffe',),
'puffa': ('puffe',),
'puffede': ('puffe',),
'puffende': ('puffe',),
'puffet': ('puffe',),
'puffete': ('puffe',),
'puga': ('puge',),
'pugede': ('puge',),
'pugende': ('puge',),
'puget': ('puge',),
'pugete': ('puge',),
'pugga': ('pugge',),
'puggede': ('pugge',),
'puggende': ('pugge',),
'pugget': ('pugge',),
'puggete': ('pugge',),
'pukka': ('pukke',),
'pukkede': ('pukke',),
'pukkende': ('pukke',),
'pukket': ('pukke',),
'pukkete': ('pukke',),
'pukkelrygga': ('pukkelrygga',),
'pukkelryggede': ('pukkelrygget',),
'pukkelrygget': ('pukkelrygget',),
'pukkelryggete': ('pukkelrygget',),
'pukkelryggetere': ('pukkelrygget',),
'pukkelryggetest': ('pukkelrygget',),
'pukkelryggeteste': ('pukkelrygget',),
'puklet': ('puklet',),
'puklete': ('puklet',),
'pukletere': ('puklet',),
'pukletest': ('puklet',),
'pukleteste': ('puklet',),
'puklete': ('puklete',),
'puldra': ('puldre',),
'puldrede': ('puldre',),
'puldrende': ('puldre',),
'puldret': ('puldre',),
'puldrete': ('puldre',),
'pulende': ('pule',),
'pult': ('pule',),
'pulte': ('pule',),
'pulsa': ('pulse',),
'pulsede': ('pulse',),
'pulsende': ('pulse',),
'pulset': ('pulse',),
'pulsete': ('pulse',),
'pulsa': ('pulse',),
'pulsede': ('pulse',),
'pulsende': ('pulse',),
'pulset': ('pulse',),
'pulsete': ('pulse',),
'pulserende': ('pulsere',),
'pulsert': ('pulsere',),
'pulserte': ('pulsere',),
'pulveriserende': ('pulverisere',),
'pulverisert': ('pulverisere',),
'pulveriserte': ('pulverisere',),
'pumpa': ('pumpe',),
'pumpede': ('pumpe',),
'pumpende': ('pumpe',),
'pumpet': ('pumpe',),
'pumpete': ('pumpe',),
'pumpebremsa': ('pumpebremse',),
'pumpebremsede': ('pumpebremse',),
'pumpebremsende': ('pumpebremse',),
'pumpebremset': ('pumpebremse',),
'pumpebremsete': ('pumpebremse',),
'punch drunk': ('punch drunk',),
'puncha': ('punche',),
'punchede': ('punche',),
'punchende': ('punche',),
'punchet': ('punche',),
'punchete': ('punche',),
'punga': ('punge',),
'pungede': ('punge',),
'pungende': ('punge',),
'punget': ('punge',),
'pungete': ('punge',),
'punisk': ('punisk',),
'puniske': ('punisk',),
'puniskere': ('punisk',),
'puniskest': ('punisk',),
'puniskeste': ('punisk',),
'punkterende': ('punktere',),
'punktert': ('punktere',),
'punkterte': ('punktere',),
'punktlig': ('punktlig',),
'punktlige': ('punktlig',),
'punktligere': ('punktlig',),
'punktligst': ('punktlig',),
'punktligste': ('punktlig',),
'pur': ('pur',),
'pure': ('pur',),
'purere': ('pur',),
'purest': ('pur',),
'pureste': ('pur',),
'purt': ('pur',),
'puristisk': ('puristisk',),
'puristiske': ('puristisk',),
'puristiskere': ('puristisk',),
'puristiskest': ('puristisk',),
'puristiskeste': ('puristisk',),
'puritansk': ('puritansk',),
'puritanske': ('puritansk',),
'puritanskere': ('puritansk',),
'puritanskest': ('puritansk',),
'puritanskeste': ('puritansk',),
'purka': ('purke',),
'purkede': ('purke',),
'purkende': ('purke',),
'purket': ('purke',),
'purkete': ('purke',),
'purkeful': ('purkeful',),
'purkefule': ('purkeful',),
'purkefulere': ('purkeful',),
'purkefulest': ('purkeful',),
'purkefuleste': ('purkeful',),
'purkefult': ('purkeful',),
'purket': ('purket',),
'purkete': ('purket',),
'purketere': ('purket',),
'purketest': ('purket',),
'purketeste': ('purket',),
'purkete': ('purkete',),
'purla': ('purle',),
'purlede': ('purle',),
'purlende': ('purle',),
'purlet': ('purle',),
'purlete': ('purle',),
'purra': ('purre',),
'purrede': ('purre',),
'purrende': ('purre',),
'purret': ('purre',),
'purrete': ('purre',),
'puset': ('puset',),
'pusete': ('puset',),
'pusetere': ('puset',),
'pusetest': ('puset',),
'puseteste': ('puset',),
'pusete': ('pusete',),
'pusha': ('pushe',),
'pushede': ('pushe',),
'pushende': ('pushe',),
'pushet': ('pushe',),
'pushete': ('pushe',),
'pusla': ('pusle',),
'puslede': ('pusle',),
'puslende': ('pusle',),
'puslet': ('pusle',),
'puslete': ('pusle',),
'puslet': ('puslet',),
'puslete': ('puslet',),
'pusletere': ('puslet',),
'pusletest': ('puslet',),
'pusleteste': ('puslet',),
'puslete': ('puslete',),
'pussa': ('pussa',),
'pussa': ('pusse',),
'pussede': ('pusse',),
'pussende': ('pusse',),
'pusset': ('pusse',),
'pussete': ('pusse',),
'pussa': ('pusse',),
'pussede': ('pusse',),
'pussende': ('pusse',),
'pusset': ('pusse',),
'pussete': ('pusse',),
'pussig': ('pussig',),
'pussige': ('pussig',),
'pussigere': ('pussig',),
'pussigst': ('pussig',),
'pussigste': ('pussig',),
'pusta': ('puste',),
'pustede': ('puste',),
'pustende': ('puste',),
'pustet': ('puste',),
'pustete': ('puste',),
'putla': ('putle',),
'putlede': ('putle',),
'putlende': ('putle',),
'putlet': ('putle',),
'putlete': ('putle',),
'putlet': ('putlet',),
'putlete': ('putlet',),
'putletere': ('putlet',),
'putletest': ('putlet',),
'putleteste': ('putlet',),
'putlete': ('putlete',),
'putra': ('putre',),
'putrede': ('putre',),
'putrende': ('putre',),
'putret': ('putre',),
'putrete': ('putre',),
'putta': ('putte',),
'puttede': ('putte',),
'puttende': ('putte',),
'puttet': ('putte',),
'puttete': ('putte',),
'pygmeisk': ('pygmeisk',),
'pygmeiske': ('pygmeisk',),
'pygmeiskere': ('pygmeisk',),
'pygmeiskest': ('pygmeisk',),
'pygmeiskeste': ('pygmeisk',),
'pyknisk': ('pyknisk',),
'pykniske': ('pyknisk',),
'pykniskere': ('pyknisk',),
'pykniskest': ('pyknisk',),
'pykniskeste': ('pyknisk',),
'pynta': ('pynte',),
'pyntede': ('pynte',),
'pyntende': ('pynte',),
'pyntet': ('pynte',),
'pyntete': ('pynte',),
'pyntelig': ('pyntelig',),
'pyntelige': ('pyntelig',),
'pynteligere': ('pyntelig',),
'pynteligst': ('pyntelig',),
'pynteligste': ('pyntelig',),
'pyramidal': ('pyramidal',),
'pyramidale': ('pyramidal',),
'pyramidalere': ('pyramidal',),
'pyramidalest': ('pyramidal',),
'pyramidaleste': ('pyramidal',),
'pyramidalt': ('pyramidal',),
'pyramidalsk': ('pyramidalsk',),
'pyramidalske': ('pyramidalsk',),
'pyramidalskere': ('pyramidalsk',),
'pyramidalskest': ('pyramidalsk',),
'pyramidalskeste': ('pyramidalsk',),
'pysen': ('pysen',),
'pysent': ('pysen',),
'pysne': ('pysen',),
'pysnere': ('pysen',),
'pysnest': ('pysen',),
'pysneste': ('pysen',),
'pyset': ('pyset',),
'pysete': ('pyset',),
'pysetere': ('pyset',),
'pysetest': ('pyset',),
'pyseteste': ('pyset',),
'pysete': ('pysete',),
'pytagoreisk': ('pytagoreisk',),
'pytagoreiske': ('pytagoreisk',),
'pytagoreiskere': ('pytagoreisk',),
'pytagoreiskest': ('pytagoreisk',),
'pytagoreiskeste': ('pytagoreisk',),
'påakta': ('påakte',),
'påaktede': ('påakte',),
'påaktende': ('påakte',),
'påaktet': ('påakte',),
'påaktete': ('påakte',),
'påanka': ('påanke',),
'påankede': ('påanke',),
'påankende': ('påanke',),
'påanket': ('påanke',),
'påankete': ('påanke',),
'påberopende': ('påberope',),
'påberopt': ('påberope',),
'påberopte': ('påberope',),
'påbudt': ('påby',),
'påbudte': ('påby',),
'påbydd': ('påby',),
'påbydde': ('påby',),
'påbyende': ('påby',),
'pådradd': ('pådra',),
'pådradde': ('pådra',),
'pådragende': ('pådra',),
'pådratt': ('pådra',),
'pådratte': ('pådra',),
'pådømmende': ('pådømme',),
'pådømt': ('pådømme',),
'pådømte': ('pådømme',),
'påfallende': ('påfallende',),
'påfriskende': ('påfriskende',),
'påfølgende': ('påfølgende',),
'påførende': ('påføre',),
'påført': ('påføre',),
'påførte': ('påføre',),
'pågjeldende': ('pågjeldende',),
'pågrepen': ('pågripe',),
'pågrepet': ('pågripe',),
'pågrepne': ('pågripe',),
'pågripende': ('pågripe',),
'pågående': ('pågå',),
'pågått': ('pågå',),
'pågåtte': ('pågå',),
'pågående': ('pågående',),
'påholden': ('påholden',),
'påholdent': ('påholden',),
'påholdne': ('påholden',),
'påholdnere': ('påholden',),
'påholdnest': ('påholden',),
'påholdneste': ('påholden',),
'påholdende': ('påholdende',),
'påhvilende': ('påhvile',),
'påhvilt': ('påhvile',),
'påhvilte': ('påhvile',),
'påkallende': ('påkalle',),
'påkalt': ('påkalle',),
'påkalte': ('påkalle',),
'påkjærende': ('påkjære',),
'påkjært': ('påkjære',),
'påkjærte': ('påkjære',),
'påkjørende': ('påkjøre',),
'påkjørt': ('påkjøre',),
'påkjørte': ('påkjøre',),
'påklaga': ('påklage',),
'påklagd': ('påklage',),
'påklagde': ('påklage',),
'påklagede': ('påklage',),
'påklagende': ('påklage',),
'påklaget': ('påklage',),
'påklagete': ('påklage',),
'påkledd': ('påkledd',),
'påkledde': ('påkledd',),
'påkleddere': ('påkledd',),
'påkleddest': ('påkledd',),
'påkleddeste': ('påkledd',),
'påkommende': ('påkommende',),
'påkrevd': ('påkrevd',),
'påkrevde': ('påkrevd',),
'påkrevdere': ('påkrevd',),
'påkrevdest': ('påkrevd',),
'påkrevdeste': ('påkrevd',),
'pålagt': ('pålegge',),
'pålagte': ('pålegge',),
'påleggende': ('pålegge',),
'påliggen': ('påligge',),
'påliggende': ('påligge',),
'påligget': ('påligge',),
'påligne': ('påligge',),
'pålitelig': ('pålitelig',),
'pålitelige': ('pålitelig',),
'påliteligere': ('pålitelig',),
'påliteligst': ('pålitelig',),
'påliteligste': ('pålitelig',),
'pålydende': ('pålydende',),
'påløpende': ('påløpe',),
'påløpet': ('påløpe',),
'påløpt': ('påløpe',),
'påløpte': ('påløpe',),
'påmeldt': ('påmeldt',),
'påmeldte': ('påmeldt',),
'påmeldtere': ('påmeldt',),
'påmeldtest': ('påmeldt',),
'påmeldteste': ('påmeldt',),
'påpasselig': ('påpasselig',),
'påpasselige': ('påpasselig',),
'påpasseligere': ('påpasselig',),
'påpasseligst': ('påpasselig',),
'påpasseligste': ('påpasselig',),
'påpekende': ('påpeke',),
'påpekt': ('påpeke',),
'påpekte': ('påpeke',),
'påregna': ('påregne',),
'påregnede': ('påregne',),
'påregnende': ('påregne',),
'påregnet': ('påregne',),
'påregnete': ('påregne',),
'pårekna': ('pårekne',),
'påreknede': ('pårekne',),
'påreknende': ('pårekne',),
'påreknet': ('pårekne',),
'påreknete': ('pårekne',),
'pårent': ('pårent',),
'pårente': ('pårent',),
'pårentere': ('pårent',),
'pårentest': ('pårent',),
'pårenteste': ('pårent',),
'påsatt': ('påsatt',),
'påsatte': ('påsatt',),
'påsattere': ('påsatt',),
'påsattest': ('påsatt',),
'påsatteste': ('påsatt',),
'påseende': ('påse',),
'påsett': ('påse',),
'påsette': ('påse',),
'påseilede': ('påseilet',),
'påseilet': ('påseilet',),
'påseilete': ('påseilet',),
'påseiletere': ('påseilet',),
'påseiletest': ('påseilet',),
'påseileteste': ('påseilet',),
'påseilt': ('påseilt',),
'påseilte': ('påseilt',),
'påseiltere': ('påseilt',),
'påseiltest': ('påseilt',),
'påseilteste': ('påseilt',),
'påskjønna': ('påskjønne',),
'påskjønnede': ('påskjønne',),
'påskjønnende': ('påskjønne',),
'påskjønnet': ('påskjønne',),
'påskjønnete': ('påskjønne',),
'påskjønt': ('påskjønne',),
'påskjønte': ('påskjønne',),
'påskreven': ('påskreven',),
'påskrevet': ('påskreven',),
'påskrevne': ('påskreven',),
'påskrevnere': ('påskreven',),
'påskrevnest': ('påskreven',),
'påskrevneste': ('påskreven',),
'påskrevet': ('påskrevet',),
'påskrevne': ('påskrevet',),
'påskrevnere': ('påskrevet',),
'påskrevnest': ('påskrevet',),
'påskrevneste': ('påskrevet',),
'påskynda': ('påskynde',),
'påskyndede': ('påskynde',),
'påskyndende': ('påskynde',),
'påskyndet': ('påskynde',),
'påskyndete': ('påskynde',),
'påskyndt': ('påskynde',),
'påskyndte': ('påskynde',),
'påstående': ('påstå',),
'påstått': ('påstå',),
'påståtte': ('påstå',),
'påståelig': ('påståelig',),
'påståelige': ('påståelig',),
'påståeligere': ('påståelig',),
'påståeligst': ('påståelig',),
'påståeligste': ('påståelig',),
'påtakende': ('påta',),
'påtatt': ('påta',),
'påtatte': ('påta',),
'påtakelig': ('påtakelig',),
'påtakelige': ('påtakelig',),
'påtakeligere': ('påtakelig',),
'påtakeligst': ('påtakelig',),
'påtakeligste': ('påtakelig',),
'påtalende': ('påtale',),
'påtalt': ('påtale',),
'påtalte': ('påtale',),
'påtegna': ('påtegne',),
'påtegnede': ('påtegne',),
'påtegnende': ('påtegne',),
'påtegnet': ('påtegne',),
'påtegnete': ('påtegne',),
'påtennende': ('påtenne',),
'påtent': ('påtenne',),
'påtente': ('påtenne',),
'påtreffende': ('påtreffe',),
'påtruffen': ('påtreffe',),
'påtruffet': ('påtreffe',),
'påtrufne': ('påtreffe',),
'påtrengende': ('påtrengende',),
'påtroppende': ('påtroppende',),
'påtvingende': ('påtvinge',),
'påtvungen': ('påtvinge',),
'påtvunget': ('påtvinge',),
'påtvungne': ('påtvinge',),
'påvirka': ('påvirke',),
'påvirkede': ('påvirke',),
'påvirkende': ('påvirke',),
'påvirket': ('påvirke',),
'påvirkete': ('påvirke',),
'påvirkelig': ('påvirkelig',),
'påvirkelige': ('påvirkelig',),
'påvirkeligere': ('påvirkelig',),
'påvirkeligst': ('påvirkelig',),
'påvirkeligste': ('påvirkelig',),
'påvisende': ('påvise',),
'påvist': ('påvise',),
'påviste': ('påvise',),
'påviseviselig': ('påviseviselig',),
'påviseviselige': ('påviseviselig',),
'påviseviseligere': ('påviseviselig',),
'påviseviseligst': ('påviseviselig',),
'påviseviseligste': ('påviseviselig',),
'pæla': ('pæle',),
'pælede': ('pæle',),
'pælende': ('pæle',),
'pælet': ('pæle',),
'pælete': ('pæle',),
'pælt': ('pæle',),
'pælte': ('pæle',),
'pæla': ('pæle',),
'pælede': ('pæle',),
'pælende': ('pæle',),
'pælet': ('pæle',),
'pælete': ('pæle',),
'pælt': ('pæle',),
'pælte': ('pæle',),
'pælma': ('pælme',),
'pælmede': ('pælme',),
'pælmende': ('pælme',),
'pælmet': ('pælme',),
'pælmete': ('pælme',),
'pære': ('pære',),
'pøbelaktig': ('pøbelaktig',),
'pøbelaktige': ('pøbelaktig',),
'pøbelaktigere': ('pøbelaktig',),
'pøbelaktigst': ('pøbelaktig',),
'pøbelaktigste': ('pøbelaktig',),
'pøbla': ('pøble',),
'pøblede': ('pøble',),
'pøblende': ('pøble',),
'pøblet': ('pøble',),
'pøblete': ('pøble',),
'pønsa': ('pønse',),
'pønsede': ('pønse',),
'pønsende': ('pønse',),
'pønset': ('pønse',),
'pønsete': ('pønse',),
'pønska': ('pønske',),
'pønskede': ('pønske',),
'pønskende': ('pønske',),
'pønsket': ('pønske',),
'pønskete': ('pønske',),
'pøsende': ('pøse',),
'pøst': ('pøse',),
'pøste': ('pøse',),
'qatarsk': ('qatarsk',),
'qatarske': ('qatarsk',),
'qatarskere': ('qatarsk',),
'qatarskest': ('qatarsk',),
'qatarskeste': ('qatarsk',),
'rabatterende': ('rabattere',),
'rabattert': ('rabattere',),
'rabatterte': ('rabattere',),
'rabbet': ('rabbet',),
'rabbete': ('rabbet',),
'rabbetere': ('rabbet',),
'rabbetest': ('rabbet',),
'rabbeteste': ('rabbet',),
'rabbete': ('rabbete',),
'rabbinsk': ('rabbinsk',),
'rabbinske': ('rabbinsk',),
'rabbinskere': ('rabbinsk',),
'rabbinskest': ('rabbinsk',),
'rabbinskeste': ('rabbinsk',),
'rabiat': ('rabiat',),
'rabiate': ('rabiat',),
'rabiatere': ('rabiat',),
'rabiatest': ('rabiat',),
'rabiateste': ('rabiat',),
'rabid': ('rabid',),
'rabide': ('rabid',),
'rabidere': ('rabid',),
'rabidest': ('rabid',),
'rabideste': ('rabid',),
'rabla': ('rable',),
'rablede': ('rable',),
'rablende': ('rable',),
'rablet': ('rable',),
'rablete': ('rable',),
'rabla': ('rable',),
'rablede': ('rable',),
'rablende': ('rable',),
'rablet': ('rable',),
'rablete': ('rable',),
'rabulistisk': ('rabulistisk',),
'rabulistiske': ('rabulistisk',),
'rabulistiskere': ('rabulistisk',),
'rabulistiskest': ('rabulistisk',),
'rabulistiskeste': ('rabulistisk',),
'radbrekka': ('radbrekke',),
'radbrekkede': ('radbrekke',),
'radbrekkende': ('radbrekke',),
'radbrekket': ('radbrekke',),
'radbrekkete': ('radbrekke',),
'radbrekt': ('radbrekke',),
'radbrekte': ('radbrekke',),
'rada': ('rade',),
'radede': ('rade',),
'radende': ('rade',),
'radet': ('rade',),
'radete': ('rade',),
'raderende': ('radere',),
'radert': ('radere',),
'raderte': ('radere',),
'radial': ('radial',),
'radiale': ('radial',),
'radialere': ('radial',),
'radialest': ('radial',),
'radialeste': ('radial',),
'radialt': ('radial',),
'radiell': ('radiell',),
'radielle': ('radiell',),
'radiellere': ('radiell',),
'radiellest': ('radiell',),
'radielleste': ('radiell',),
'radielt': ('radiell',),
'radierende': ('radiere',),
'radiert': ('radiere',),
'radierte': ('radiere',),
'radig': ('radig',),
'radige': ('radig',),
'radigere': ('radig',),
'radigst': ('radig',),
'radigste': ('radig',),
'radikal': ('radikal',),
'radikale': ('radikal',),
'radikalere': ('radikal',),
'radikalest': ('radikal',),
'radikaleste': ('radikal',),
'radikalt': ('radikal',),
'radikaliserende': ('radikalisere',),
'radikalisert': ('radikalisere',),
'radikaliserte': ('radikalisere',),
'radikalistisk': ('radikalistisk',),
'radikalistiske': ('radikalistisk',),
'radikalistiskere': ('radikalistisk',),
'radikalistiskest': ('radikalistisk',),
'radikalistiskeste': ('radikalistisk',),
'radioaktiv': ('radioaktiv',),
'radioaktive': ('radioaktiv',),
'radioaktivere': ('radioaktiv',),
'radioaktivest': ('radioaktiv',),
'radioaktiveste': ('radioaktiv',),
'radioaktivt': ('radioaktiv',),
'radiologisk': ('radiologisk',),
'radiologiske': ('radiologisk',),
'radiologiskere': ('radiologisk',),
'radiologiskest': ('radiologisk',),
'radiologiskeste': ('radiologisk',),
'radiær': ('radiær',),
'radiære': ('radiær',),
'radiærere': ('radiær',),
'radiærest': ('radiær',),
'radiæreste': ('radiær',),
'radiært': ('radiær',),
'radmager': ('radmager',),
'radmagert': ('radmager',),
'radmagre': ('radmager',),
'radmagrere': ('radmager',),
'radmagrest': ('radmager',),
'radmagreste': ('radmager',),
'raff': ('raff',),
'raffe': ('raff',),
'raffere': ('raff',),
'raffest': ('raff',),
'raffeste': ('raff',),
'raft': ('raff',),
'raffinerende': ('raffinere',),
'raffinert': ('raffinere',),
'raffinerte': ('raffinere',),
'raffinert': ('raffinert',),
'raffinerte': ('raffinert',),
'raffinertere': ('raffinert',),
'raffinertest': ('raffinert',),
'raffinerteste': ('raffinert',),
'rafsa': ('rafse',),
'rafsede': ('rafse',),
'rafsende': ('rafse',),
'rafset': ('rafse',),
'rafsete': ('rafse',),
'rafta': ('rafte',),
'raftede': ('rafte',),
'raftende': ('rafte',),
'raftet': ('rafte',),
'raftete': ('rafte',),
'rafta': ('rafte',),
'raftede': ('rafte',),
'raftende': ('rafte',),
'raftet': ('rafte',),
'raftete': ('rafte',),
'raga': ('rage',),
'ragede': ('rage',),
'ragende': ('rage',),
'raget': ('rage',),
'ragete': ('rage',),
'raga': ('rage',),
'ragede': ('rage',),
'ragende': ('rage',),
'raget': ('rage',),
'ragete': ('rage',),
'ragget': ('ragget',),
'raggete': ('ragget',),
'raggetere': ('ragget',),
'raggetest': ('ragget',),
'raggeteste': ('ragget',),
'raggete': ('raggete',),
'rak': ('rak',),
'rake': ('rak',),
'rakere': ('rak',),
'rakest': ('rak',),
'rakeste': ('rak',),
'rakt': ('rak',),
'rak': ('rak',),
'rake': ('rak',),
'rakere': ('rak',),
'rakest': ('rak',),
'rakeste': ('rak',),
'rakt': ('rak',),
'raka': ('raka',),
'raka': ('rake',),
'rakede': ('rake',),
'rakende': ('rake',),
'raket': ('rake',),
'rakete': ('rake',),
'raka': ('rake',),
'rakede': ('rake',),
'rakende': ('rake',),
'raket': ('rake',),
'rakete': ('rake',),
'rakt': ('rake',),
'rakte': ('rake',),
'raka': ('rake',),
'rakede': ('rake',),
'rakende': ('rake',),
'raket': ('rake',),
'rakete': ('rake',),
'rakt': ('rake',),
'rakte': ('rake',),
'rakittisk': ('rakittisk',),
'rakittiske': ('rakittisk',),
'rakittiskere': ('rakittisk',),
'rakittiskest': ('rakittisk',),
'rakittiskeste': ('rakittisk',),
'rakka': ('rakke',),
'rakkede': ('rakke',),
'rakkende': ('rakke',),
'rakket': ('rakke',),
'rakkete': ('rakke',),
'rakla': ('rakle',),
'raklede': ('rakle',),
'raklende': ('rakle',),
'raklet': ('rakle',),
'raklete': ('rakle',),
'rakla': ('rakle',),
'raklede': ('rakle',),
'raklende': ('rakle',),
'raklet': ('rakle',),
'raklete': ('rakle',),
'rakna': ('rakne',),
'raknede': ('rakne',),
'raknende': ('rakne',),
'raknet': ('rakne',),
'raknete': ('rakne',),
'rakrygga': ('rakrygga',),
'rakryggede': ('rakrygget',),
'rakrygget': ('rakrygget',),
'rakryggete': ('rakrygget',),
'rakryggetere': ('rakrygget',),
'rakryggetest': ('rakrygget',),
'rakryggeteste': ('rakrygget',),
'raljerende': ('raljere',),
'raljert': ('raljere',),
'raljerte': ('raljere',),
'ralla': ('ralle',),
'rallede': ('ralle',),
'rallende': ('ralle',),
'rallet': ('ralle',),
'rallete': ('ralle',),
'ram': ('ram',),
'ramme': ('ram',),
'rammere': ('ram',),
'rammest': ('ram',),
'rammeste': ('ram',),
'ramt': ('ram',),
'ramla': ('ramle',),
'ramlede': ('ramle',),
'ramlende': ('ramle',),
'ramlet': ('ramle',),
'ramlete': ('ramle',),
'ramma': ('ramme',),
'rammede': ('ramme',),
'rammende': ('ramme',),
'rammet': ('ramme',),
'rammete': ('ramme',),
'ramma': ('ramme',),
'rammede': ('ramme',),
'rammende': ('ramme',),
'rammet': ('ramme',),
'rammete': ('ramme',),
'ramma': ('ramme',),
'rammede': ('ramme',),
'rammende': ('ramme',),
'rammet': ('ramme',),
'rammete': ('ramme',),
'ramnsvart': ('ramnsvart',),
'ramnsvarte': ('ramnsvart',),
'ramnsvartere': ('ramnsvart',),
'ramnsvartest': ('ramnsvart',),
'ramnsvarteste': ('ramnsvart',),
'rampet': ('rampet',),
'rampete': ('rampet',),
'rampetere': ('rampet',),
'rampetest': ('rampet',),
'rampeteste': ('rampet',),
'rampete': ('rampete',),
'ramponerende': ('ramponere',),
'ramponert': ('ramponere',),
'ramponerte': ('ramponere',),
'ramsalt': ('ramsalt',),
'ramsalte': ('ramsalt',),
'ramsaltere': ('ramsalt',),
'ramsaltest': ('ramsalt',),
'ramsalteste': ('ramsalt',),
'ramsalta': ('ramsalte',),
'ramsaltede': ('ramsalte',),
'ramsaltende': ('ramsalte',),
'ramsaltet': ('ramsalte',),
'ramsaltete': ('ramsalte',),
'ramsa': ('ramse',),
'ramsede': ('ramse',),
'ramsende': ('ramse',),
'ramset': ('ramse',),
'ramsete': ('ramse',),
'ramsterk': ('ramsterk',),
'ramsterke': ('ramsterk',),
'ramsterkere': ('ramsterk',),
'ramsterkest': ('ramsterk',),
'ramsterkeste': ('ramsterk',),
'ramsterkt': ('ramsterk',),
'ramsvart': ('ramsvart',),
'ramsvarte': ('ramsvart',),
'ramsvartere': ('ramsvart',),
'ramsvartest': ('ramsvart',),
'ramsvarteste': ('ramsvart',),
'randa': ('rande',),
'randede': ('rande',),
'randende': ('rande',),
'randet': ('rande',),
'randete': ('rande',),
'randet': ('randet',),
'randete': ('randet',),
'randetere': ('randet',),
'randetest': ('randet',),
'randeteste': ('randet',),
'randete': ('randete',),
'randsydd': ('randsy',),
'randsydde': ('randsy',),
'randsyende': ('randsy',),
'rana': ('rane',),
'ranede': ('rane',),
'ranende': ('rane',),
'ranet': ('rane',),
'ranete': ('rane',),
'rant': ('rane',),
'rante': ('rane',),
'rang': ('rang',),
'range': ('rang',),
'rangere': ('rang',),
'rangest': ('rang',),
'rangeste': ('rang',),
'rangt': ('rang',),
'ranga': ('range',),
'rangede': ('range',),
'rangende': ('range',),
'ranget': ('range',),
'rangete': ('range',),
'rangerende': ('rangere',),
'rangert': ('rangere',),
'rangerte': ('rangere',),
'rangla': ('rangle',),
'ranglede': ('rangle',),
'ranglende': ('rangle',),
'ranglet': ('rangle',),
'ranglete': ('rangle',),
'rangla': ('rangle',),
'ranglede': ('rangle',),
'ranglende': ('rangle',),
'ranglet': ('rangle',),
'ranglete': ('rangle',),
'rank': ('rank',),
'ranke': ('rank',),
'rankere': ('rank',),
'rankest': ('rank',),
'rankeste': ('rank',),
'rankt': ('rank',),
'ranka': ('ranke',),
'rankede': ('ranke',),
'rankende': ('ranke',),
'ranket': ('ranke',),
'rankete': ('ranke',),
'ranka': ('ranke',),
'rankede': ('ranke',),
'rankende': ('ranke',),
'ranket': ('ranke',),
'rankete': ('ranke',),
'ransaka': ('ransake',),
'ransakede': ('ransake',),
'ransakende': ('ransake',),
'ransaket': ('ransake',),
'ransakete': ('ransake',),
'ransakt': ('ransake',),
'ransakte': ('ransake',),
'rapa': ('rape',),
'rapede': ('rape',),
'rapende': ('rape',),
'rapet': ('rape',),
'rapete': ('rape',),
'rapt': ('rape',),
'rapte': ('rape',),
'rapa': ('rape',),
'rapede': ('rape',),
'rapende': ('rape',),
'rapet': ('rape',),
'rapete': ('rape',),
'rapt': ('rape',),
'rapte': ('rape',),
'rapid': ('rapid',),
'rapide': ('rapid',),
'rapidere': ('rapid',),
'rapidest': ('rapid',),
'rapideste': ('rapid',),
'rapp': ('rapp',),
'rappe': ('rapp',),
'rappere': ('rapp',),
'rappest': ('rapp',),
'rappeste': ('rapp',),
'rapt': ('rapp',),
'rappa': ('rappe',),
'rappede': ('rappe',),
'rappende': ('rappe',),
'rappet': ('rappe',),
'rappete': ('rappe',),
'rappa': ('rappe',),
'rappede': ('rappe',),
'rappende': ('rappe',),
'rappet': ('rappe',),
'rappete': ('rappe',),
'rappa': ('rappe',),
'rappede': ('rappe',),
'rappende': ('rappe',),
'rappet': ('rappe',),
'rappete': ('rappe',),
'rappa': ('rappe',),
'rappede': ('rappe',),
'rappende': ('rappe',),
'rappet': ('rappe',),
'rappete': ('rappe',),
'rappa': ('rappe',),
'rappede': ('rappe',),
'rappende': ('rappe',),
'rappet': ('rappe',),
'rappete': ('rappe',),
'rappa': ('rappe',),
'rappede': ('rappe',),
'rappende': ('rappe',),
'rappet': ('rappe',),
'rappete': ('rappe',),
'rappellerende': ('rappellere',),
'rappellert': ('rappellere',),
'rappellerte': ('rappellere',),
'rappfota': ('rappfota',),
'rappfotede': ('rappfotet',),
'rappfotet': ('rappfotet',),
'rappfotete': ('rappfotet',),
'rappfotetere': ('rappfotet',),
'rappfotetest': ('rappfotet',),
'rappfoteteste': ('rappfotet',),
'rappføtt': ('rappføtt',),
'rappføtte': ('rappføtt',),
'rappføttere': ('rappføtt',),
'rappføttest': ('rappføtt',),
'rappføtteste': ('rappføtt',),
'rappkjefta': ('rappkjefta',),
'rappkjeftede': ('rappkjeftet',),
'rappkjeftet': ('rappkjeftet',),
'rappkjeftete': ('rappkjeftet',),
'rappkjeftetere': ('rappkjeftet',),
'rappkjeftetest': ('rappkjeftet',),
'rappkjefteteste': ('rappkjeftet',),
'rapporterende': ('rapportere',),
'rapportert': ('rapportere',),
'rapporterte': ('rapportere',),
'rapsa': ('rapse',),
'rapsede': ('rapse',),
'rapsende': ('rapse',),
'rapset': ('rapse',),
'rapsete': ('rapse',),
'rapsodisk': ('rapsodisk',),
'rapsodiske': ('rapsodisk',),
'rapsodiskere': ('rapsodisk',),
'rapsodiskest': ('rapsodisk',),
'rapsodiskeste': ('rapsodisk',),
'rar': ('rar',),
'rare': ('rar',),
'rarere': ('rar',),
'rarest': ('rar',),
'rareste': ('rar',),
'rart': ('rar',),
'rasa': ('rase',),
'rasende': ('rase',),
'rast': ('rase',),
'raste': ('rase',),
'raserende': ('rasere',),
'rasert': ('rasere',),
'raserte': ('rasere',),
'raserein': ('raserein',),
'rasereine': ('raserein',),
'rasereinere': ('raserein',),
'rasereinest': ('raserein',),
'rasereineste': ('raserein',),
'rasereint': ('raserein',),
'raseren': ('raseren',),
'raserene': ('raseren',),
'raserenere': ('raseren',),
'raserenest': ('raseren',),
'rasereneste': ('raseren',),
'raserent': ('raseren',),
'rasistisk': ('rasistisk',),
'rasistiske': ('rasistisk',),
'rasistiskere': ('rasistisk',),
'rasistiskest': ('rasistisk',),
'rasistiskeste': ('rasistisk',),
'rasjonal': ('rasjonal',),
'rasjonale': ('rasjonal',),
'rasjonalere': ('rasjonal',),
'rasjonalest': ('rasjonal',),
'rasjonaleste': ('rasjonal',),
'rasjonalt': ('rasjonal',),
'rasjonaliserende': ('rasjonalisere',),
'rasjonalisert': ('rasjonalisere',),
'rasjonaliserte': ('rasjonalisere',),
'rasjonalistisk': ('rasjonalistisk',),
'rasjonalistiske': ('rasjonalistisk',),
'rasjonalistiskere': ('rasjonalistisk',),
'rasjonalistiskest': ('rasjonalistisk',),
'rasjonalistiskeste': ('rasjonalistisk',),
'rasjonell': ('rasjonell',),
'rasjonelle': ('rasjonell',),
'rasjonellere': ('rasjonell',),
'rasjonellest': ('rasjonell',),
'rasjonelleste': ('rasjonell',),
'rasjonelt': ('rasjonell',),
'rasjonerende': ('rasjonere',),
'rasjonert': ('rasjonere',),
'rasjonerte': ('rasjonere',),
'rask': ('rask',),
'raske': ('rask',),
'raskere': ('rask',),
'raskest': ('rask',),
'raskeste': ('rask',),
'raskt': ('rask',),
'raska': ('raske',),
'raskede': ('raske',),
'raskende': ('raske',),
'rasket': ('raske',),
'raskete': ('raske',),
'raska': ('raske',),
'raskede': ('raske',),
'raskende': ('raske',),
'rasket': ('raske',),
'raskete': ('raske',),
'rasla': ('rasle',),
'raslede': ('rasle',),
'raslende': ('rasle',),
'raslet': ('rasle',),
'raslete': ('rasle',),
'raspa': ('raspe',),
'raspede': ('raspe',),
'raspende': ('raspe',),
'raspet': ('raspe',),
'raspete': ('raspe',),
'rasta': ('raste',),
'rastede': ('raste',),
'rastende': ('raste',),
'rastet': ('raste',),
'rastete': ('raste',),
'rastlaus': ('rastlaus',),
'rastlause': ('rastlaus',),
'rastlausere': ('rastlaus',),
'rastlausest': ('rastlaus',),
'rastlauseste': ('rastlaus',),
'rastlaust': ('rastlaus',),
'rastløs': ('rastløs',),
'rastløse': ('rastløs',),
'rastløsere': ('rastløs',),
'rastløsest': ('rastløs',),
'rastløseste': ('rastløs',),
'rastløst': ('rastløs',),
'ratifiserende': ('ratifisere',),
'ratifisert': ('ratifisere',),
'ratifiserte': ('ratifisere',),
'ratla': ('ratle',),
'ratlede': ('ratle',),
'ratlende': ('ratle',),
'ratlet': ('ratle',),
'ratlete': ('ratle',),
'ratta': ('ratte',),
'rattede': ('ratte',),
'rattende': ('ratte',),
'rattet': ('ratte',),
'rattete': ('ratte',),
'rauka': ('rauke',),
'raukede': ('rauke',),
'raukende': ('rauke',),
'rauket': ('rauke',),
'raukete': ('rauke',),
'raus': ('raus',),
'rause': ('raus',),
'rausere': ('raus',),
'rausest': ('raus',),
'rauseste': ('raus',),
'raust': ('raus',),
'rausa': ('rause',),
'rausede': ('rause',),
'rausende': ('rause',),
'rauset': ('rause',),
'rausete': ('rause',),
'raust': ('rause',),
'rauste': ('rause',),
'rauta': ('raute',),
'rautede': ('raute',),
'rautende': ('raute',),
'rautet': ('raute',),
'rautete': ('raute',),
'rava': ('rave',),
'ravede': ('rave',),
'ravende': ('rave',),
'ravet': ('rave',),
'ravete': ('rave',),
'ravgal': ('ravgal',),
'ravgale': ('ravgal',),
'ravgalere': ('ravgal',),
'ravgalest': ('ravgal',),
'ravgaleste': ('ravgal',),
'ravgalt': ('ravgal',),
'ravgalen': ('ravgalen',),
'ravgalent': ('ravgalen',),
'ravgalne': ('ravgalen',),
'ravgalnere': ('ravgalen',),
'ravgalnest': ('ravgalen',),
'ravgalneste': ('ravgalen',),
'ravgul': ('ravgul',),
'ravgule': ('ravgul',),
'ravgulere': ('ravgul',),
'ravgulest': ('ravgul',),
'ravguleste': ('ravgul',),
'ravgult': ('ravgul',),
'ravmørk': ('ravmørk',),
'ravmørke': ('ravmørk',),
'ravmørkere': ('ravmørk',),
'ravmørkest': ('ravmørk',),
'ravmørkeste': ('ravmørk',),
'ravmørkt': ('ravmørk',),
'ravnorsk': ('ravnorsk',),
'ravnorske': ('ravnorsk',),
'ravnorskere': ('ravnorsk',),
'ravnorskest': ('ravnorsk',),
'ravnorskeste': ('ravnorsk',),
'ravnsvart': ('ravnsvart',),
'ravnsvarte': ('ravnsvart',),
'ravnsvartere': ('ravnsvart',),
'ravnsvartest': ('ravnsvart',),
'ravnsvarteste': ('ravnsvart',),
'redd': ('re',),
'redde': ('re',),
'reende': ('re',),
'reagerende': ('reagere',),
'reagert': ('reagere',),
'reagerte': ('reagere',),
'reaksjonsdrevet': ('reaksjonsdrevet',),
'reaksjonsdrevne': ('reaksjonsdrevet',),
'reaksjonsdrevnere': ('reaksjonsdrevet',),
'reaksjonsdrevnest': ('reaksjonsdrevet',),
'reaksjonsdrevneste': ('reaksjonsdrevet',),
'reaksjonær': ('reaksjonær',),
'reaksjonære': ('reaksjonær',),
'reaksjonærere': ('reaksjonær',),
'reaksjonærest': ('reaksjonær',),
'reaksjonæreste': ('reaksjonær',),
'reaksjonært': ('reaksjonær',),
'reaktiverende': ('reaktivere',),
'reaktivert': ('reaktivere',),
'reaktiverte': ('reaktivere',),
'real': ('real',),
'reale': ('real',),
'realere': ('real',),
'realest': ('real',),
'realeste': ('real',),
'realt': ('real',),
'real': ('real',),
'reale': ('real',),
'realere': ('real',),
'realest': ('real',),
'realeste': ('real',),
'realt': ('real',),
'realisabel': ('realisabel',),
'realisabelt': ('realisabel',),
'realisable': ('realisabel',),
'realisablere': ('realisabel',),
'realisablest': ('realisabel',),
'realisableste': ('realisabel',),
'realiserbar': ('realiserbar',),
'realiserbare': ('realiserbar',),
'realiserbarere': ('realiserbar',),
'realiserbarest': ('realiserbar',),
'realiserbareste': ('realiserbar',),
'realiserbart': ('realiserbar',),
'realiserende': ('realisere',),
'realisert': ('realisere',),
'realiserte': ('realisere',),
'realistisk': ('realistisk',),
'realistiske': ('realistisk',),
'realistiskere': ('realistisk',),
'realistiskest': ('realistisk',),
'realistiskeste': ('realistisk',),
'realitetsbehandla': ('realitetsbehandle',),
'realitetsbehandlede': ('realitetsbehandle',),
'realitetsbehandlende': ('realitetsbehandle',),
'realitetsbehandlet': ('realitetsbehandle',),
'realitetsbehandlete': ('realitetsbehandle',),
'reassurerende': ('reassurere',),
'reassurert': ('reassurere',),
'reassurerte': ('reassurere',),
'rebellerende': ('rebellere',),
'rebellert': ('rebellere',),
'rebellerte': ('rebellere',),
'rebelsk': ('rebelsk',),
'rebelske': ('rebelsk',),
'rebelskere': ('rebelsk',),
'rebelskest': ('rebelsk',),
'rebelskeste': ('rebelsk',),
'recenserende': ('recensere',),
'recensert': ('recensere',),
'recenserte': ('recensere',),
'recessiv': ('recessiv',),
'recessive': ('recessiv',),
'recessivere': ('recessiv',),
'recessivest': ('recessiv',),
'recessiveste': ('recessiv',),
'recessivt': ('recessiv',),
'rechts': ('rechts',),
'rechtse': ('rechts',),
'rechtsere': ('rechts',),
'rechtsest': ('rechts',),
'rechtseste': ('rechts',),
'redaksjonell': ('redaksjonell',),
'redaksjonelle': ('redaksjonell',),
'redaksjonellere': ('redaksjonell',),
'redaksjonellest': ('redaksjonell',),
'redaksjonelleste': ('redaksjonell',),
'redaksjonelt': ('redaksjonell',),
'redd': ('redd',),
'redde': ('redd',),
'reddere': ('redd',),
'reddest': ('redd',),
'reddeste': ('redd',),
'redda': ('redde',),
'reddede': ('redde',),
'reddende': ('redde',),
'reddet': ('redde',),
'reddete': ('redde',),
'reddsom': ('reddsom',),
'reddsomme': ('reddsom',),
'reddsommere': ('reddsom',),
'reddsomst': ('reddsom',),
'reddsomste': ('reddsom',),
'reddsomt': ('reddsom',),
'reda': ('rede',),
'redede': ('rede',),
'redende': ('rede',),
'redet': ('rede',),
'redete': ('rede',),
'rede': ('rede',),
'redebon': ('redebon',),
'redebonne': ('redebon',),
'redebonnere': ('redebon',),
'redebonnest': ('redebon',),
'redebonneste': ('redebon',),
'redebont': ('redebon',),
'redegjort': ('redegjøre',),
'redegjorte': ('redegjøre',),
'redegjørende': ('redegjøre',),
'redelig': ('redelig',),
'redelige': ('redelig',),
'redeligere': ('redelig',),
'redeligst': ('redelig',),
'redeligste': ('redelig',),
'redigerende': ('redigere',),
'redigert': ('redigere',),
'redigerte': ('redigere',),
'redningslaus': ('redningslaus',),
'redningslause': ('redningslaus',),
'redningslausere': ('redningslaus',),
'redningslausest': ('redningslaus',),
'redningslauseste': ('redningslaus',),
'redningslaust': ('redningslaus',),
'redningsløs': ('redningsløs',),
'redningsløse': ('redningsløs',),
'redningsløsere': ('redningsløs',),
'redningsløsest': ('redningsløs',),
'redningsløseste': ('redningsløs',),
'redningsløst': ('redningsløs',),
'redobla': ('redoble',),
'redoblede': ('redoble',),
'redoblende': ('redoble',),
'redoblet': ('redoble',),
'redoblete': ('redoble',),
'redselsfull': ('redselsfull',),
'redselsfulle': ('redselsfull',),
'redselsfullere': ('redselsfull',),
'redselsfullest': ('redselsfull',),
'redselsfulleste': ('redselsfull',),
'redselsfullt': ('redselsfull',),
'redselslagen': ('redselslagen',),
'redselslagent': ('redselslagen',),
'redselslagne': ('redselslagen',),
'redselslagnere': ('redselslagen',),
'redselslagnest': ('redselslagen',),
'redselslagneste': ('redselslagen',),
'reduksjonistisk': ('reduksjonistisk',),
'reduksjonistiske': ('reduksjonistisk',),
'reduksjonistiskere': ('reduksjonistisk',),
'reduksjonistiskest': ('reduksjonistisk',),
'reduksjonistiskeste': ('reduksjonistisk',),
'reduktiv': ('reduktiv',),
'reduktive': ('reduktiv',),
'reduktivere': ('reduktiv',),
'reduktivest': ('reduktiv',),
'reduktiveste': ('reduktiv',),
'reduktivt': ('reduktiv',),
'redundant': ('redundant',),
'redundante': ('redundant',),
'redundantere': ('redundant',),
'redundantest': ('redundant',),
'redundanteste': ('redundant',),
'redupliserende': ('reduplisere',),
'reduplisert': ('reduplisere',),
'redupliserte': ('reduplisere',),
'reduserende': ('redusere',),
'redusert': ('redusere',),
'reduserte': ('redusere',),
'reell': ('reell',),
'reelle': ('reell',),
'reellere': ('reell',),
'reellest': ('reell',),
'reelleste': ('reell',),
'reelt': ('reell',),
'refererende': ('referere',),
'referert': ('referere',),
'refererte': ('referere',),
'refleksiv': ('refleksiv',),
'refleksive': ('refleksiv',),
'refleksivere': ('refleksiv',),
'refleksivest': ('refleksiv',),
'refleksiveste': ('refleksiv',),
'refleksivt': ('refleksiv',),
'reflekterende': ('reflektere',),
'reflektert': ('reflektere',),
'reflekterte': ('reflektere',),
'reflektorisk': ('reflektorisk',),
'reflektoriske': ('reflektorisk',),
'reflektoriskere': ('reflektorisk',),
'reflektoriskest': ('reflektorisk',),
'reflektoriskeste': ('reflektorisk',),
'reformatorisk': ('reformatorisk',),
'reformatoriske': ('reformatorisk',),
'reformatoriskere': ('reformatorisk',),
'reformatoriskest': ('reformatorisk',),
'reformatoriskeste': ('reformatorisk',),
'reformerende': ('reformere',),
'reformert': ('reformere',),
'reformerte': ('reformere',),
'reformistisk': ('reformistisk',),
'reformistiske': ('reformistisk',),
'reformistiskere': ('reformistisk',),
'reformistiskest': ('reformistisk',),
'reformistiskeste': ('reformistisk',),
'refsa': ('refse',),
'refsede': ('refse',),
'refsende': ('refse',),
'refset': ('refse',),
'refsete': ('refse',),
'refst': ('refse',),
'refste': ('refse',),
'refunderende': ('refundere',),
'refundert': ('refundere',),
'refunderte': ('refundere',),
'refuserende': ('refusere',),
'refusert': ('refusere',),
'refuserte': ('refusere',),
'regalerende': ('regalere',),
'regalert': ('regalere',),
'regalerte': ('regalere',),
'regelbundet': ('regelbundet',),
'regelbundne': ('regelbundet',),
'regelbundnere': ('regelbundet',),
'regelbundnest': ('regelbundet',),
'regelbundneste': ('regelbundet',),
'regelmessig': ('regelmessig',),
'regelmessige': ('regelmessig',),
'regelmessigere': ('regelmessig',),
'regelmessigst': ('regelmessig',),
'regelmessigste': ('regelmessig',),
'regelrett': ('regelrett',),
'regelrette': ('regelrett',),
'regelrettere': ('regelrett',),
'regelrettest': ('regelrett',),
'regelretteste': ('regelrett',),
'regenererende': ('regenerere',),
'regenerert': ('regenerere',),
'regenererte': ('regenerere',),
'regional': ('regional',),
'regionale': ('regional',),
'regionalere': ('regional',),
'regionalest': ('regional',),
'regionaleste': ('regional',),
'regionalt': ('regional',),
'regisserende': ('regissere',),
'regissert': ('regissere',),
'regisserte': ('regissere',),
'registrerende': ('registrere',),
'registrert': ('registrere',),
'registrerte': ('registrere',),
'regjerende': ('regjere',),
'regjert': ('regjere',),
'regjerte': ('regjere',),
'reglementarisk': ('reglementarisk',),
'reglementariske': ('reglementarisk',),
'reglementariskere': ('reglementarisk',),
'reglementariskest': ('reglementarisk',),
'reglementariskeste': ('reglementarisk',),
'reglementerende': ('reglementere',),
'reglementert': ('reglementere',),
'reglementerte': ('reglementere',),
'regna': ('regne',),
'regnede': ('regne',),
'regnende': ('regne',),
'regnet': ('regne',),
'regnete': ('regne',),
'regna': ('regne',),
'regnede': ('regne',),
'regnende': ('regne',),
'regnet': ('regne',),
'regnete': ('regne',),
'regna': ('regne',),
'regnede': ('regne',),
'regnende': ('regne',),
'regnet': ('regne',),
'regnete': ('regne',),
'regnt': ('regne',),
'regnte': ('regne',),
'regnfull': ('regnfull',),
'regnfulle': ('regnfull',),
'regnfullere': ('regnfull',),
'regnfullest': ('regnfull',),
'regnfulleste': ('regnfull',),
'regnfullt': ('regnfull',),
'regningssvarende': ('regningssvarende',),
'regningssvarende': ('regningssvarende',),
'regntung': ('regntung',),
'regntunge': ('regntung',),
'regntungere': ('regntung',),
'regntungest': ('regntung',),
'regntungeste': ('regntung',),
'regntungt': ('regntung',),
'regntyngre': ('regntung',),
'regntyngst': ('regntung',),
'regntyngste': ('regntung',),
'regressiv': ('regressiv',),
'regressive': ('regressiv',),
'regressivere': ('regressiv',),
'regressivest': ('regressiv',),
'regressiveste': ('regressiv',),
'regressivt': ('regressiv',),
'regulariserende': ('regularisere',),
'regularisert': ('regularisere',),
'regulariserte': ('regularisere',),
'regulerende': ('regulere',),
'regulert': ('regulere',),
'regulerte': ('regulere',),
'regulær': ('regulær',),
'regulære': ('regulær',),
'regulærere': ('regulær',),
'regulærest': ('regulær',),
'regulæreste': ('regulær',),
'regulært': ('regulær',),
'regummierende': ('regummiere',),
'regummiert': ('regummiere',),
'regummierte': ('regummiere',),
'rehabiliterende': ('rehabilitere',),
'rehabilitert': ('rehabilitere',),
'rehabiliterte': ('rehabilitere',),
'reid': ('reie',),
'reidd': ('reie',),
'reidde': ('reie',),
'reide': ('reie',),
'reiende': ('reie',),
'reika': ('reike',),
'reikede': ('reike',),
'reikende': ('reike',),
'reiket': ('reike',),
'reikete': ('reike',),
'reikt': ('reike',),
'reikte': ('reike',),
'rein': ('rein',),
'reine': ('rein',),
'reinere': ('rein',),
'reinest': ('rein',),
'reineste': ('rein',),
'reint': ('rein',),
'reindyrka': ('reindyrke',),
'reindyrkede': ('reindyrke',),
'reindyrkende': ('reindyrke',),
'reindyrket': ('reindyrke',),
'reindyrkete': ('reindyrke',),
'reinferdig': ('reinferdig',),
'reinferdige': ('reinferdig',),
'reinferdigere': ('reinferdig',),
'reinferdigst': ('reinferdig',),
'reinferdigste': ('reinferdig',),
'reingjort': ('reingjøre',),
'reingjorte': ('reingjøre',),
'reingjørende': ('reingjøre',),
'reinhekla': ('reinhekla',),
'reinhårig': ('reinhårig',),
'reinhårige': ('reinhårig',),
'reinhårigere': ('reinhårig',),
'reinhårigst': ('reinhårig',),
'reinhårigste': ('reinhårig',),
'reinskreven': ('reinskrive',),
'reinskrevet': ('reinskrive',),
'reinskrevne': ('reinskrive',),
'reinskrivende': ('reinskrive',),
'reinslig': ('reinslig',),
'reinslige': ('reinslig',),
'reinsligere': ('reinslig',),
'reinsligst': ('reinslig',),
'reinsligste': ('reinslig',),
'reinspikka': ('reinspikka',),
'reinvaska': ('reinvaske',),
'reinvaskede': ('reinvaske',),
'reinvaskende': ('reinvaske',),
'reinvasket': ('reinvaske',),
'reinvaskete': ('reinvaske',),
'reinvesterende': ('reinvestere',),
'reinvestert': ('reinvestere',),
'reinvesterte': ('reinvestere',),
'reipa': ('reipe',),
'reipede': ('reipe',),
'reipende': ('reipe',),
'reipet': ('reipe',),
'reipete': ('reipe',),
'reisende': ('reise',),
'reist': ('reise',),
'reiste': ('reise',),
'reisende': ('reise',),
'reist': ('reise',),
'reiste': ('reise',),
'reiva': ('reive',),
'reivd': ('reive',),
'reivde': ('reive',),
'reivede': ('reive',),
'reivende': ('reive',),
'reivet': ('reive',),
'reivete': ('reive',),
'rejiserende': ('rejisere',),
'rejisert': ('rejisere',),
'rejiserte': ('rejisere',),
'rekapitulerende': ('rekapitulere',),
'rekapitulert': ('rekapitulere',),
'rekapitulerte': ('rekapitulere',),
'rekende': ('reke',),
'rekt': ('reke',),
'rekte': ('reke',),
'reklamerende': ('reklamere',),
'reklamert': ('reklamere',),
'reklamerte': ('reklamere',),
'rekna': ('rekne',),
'reknede': ('rekne',),
'reknende': ('rekne',),
'reknet': ('rekne',),
'reknete': ('rekne',),
'rekna': ('rekne',),
'reknede': ('rekne',),
'reknende': ('rekne',),
'reknet': ('rekne',),
'reknete': ('rekne',),
'rekningssvarende': ('rekningssvarende',),
'rekognoserende': ('rekognosere',),
'rekognosert': ('rekognosere',),
'rekognoserte': ('rekognosere',),
'rekommanderende': ('rekommandere',),
'rekommandert': ('rekommandere',),
'rekommanderte': ('rekommandere',),
'rekonstruerende': ('rekonstruere',),
'rekonstruert': ('rekonstruere',),
'rekonstruerte': ('rekonstruere',),
'rekordarta': ('rekordarta',),
'rekordartede': ('rekordartet',),
'rekordartet': ('rekordartet',),
'rekordartete': ('rekordartet',),
'rekordartetere': ('rekordartet',),
'rekordartetest': ('rekordartet',),
'rekordarteteste': ('rekordartet',),
'rekordforbedra': ('rekordforbedre',),
'rekordforbedrede': ('rekordforbedre',),
'rekordforbedrende': ('rekordforbedre',),
'rekordforbedret': ('rekordforbedre',),
'rekordforbedrete': ('rekordforbedre',),
'rekreerende': ('rekreere',),
'rekreert': ('rekreere',),
'rekreerte': ('rekreere',),
'rekrutterende': ('rekruttere',),
'rekruttert': ('rekruttere',),
'rekrutterte': ('rekruttere',),
'rektangulær': ('rektangulær',),
'rektangulære': ('rektangulær',),
'rektangulærere': ('rektangulær',),
'rektangulærest': ('rektangulær',),
'rektangulæreste': ('rektangulær',),
'rektangulært': ('rektangulær',),
'rektifiserende': ('rektifisere',),
'rektifisert': ('rektifisere',),
'rektifiserte': ('rektifisere',),
'rekursiv': ('rekursiv',),
'rekursive': ('rekursiv',),
'rekursivere': ('rekursiv',),
'rekursivest': ('rekursiv',),
'rekursiveste': ('rekursiv',),
'rekursivt': ('rekursiv',),
'rekvirerende': ('rekvirere',),
'rekvirert': ('rekvirere',),
'rekvirerte': ('rekvirere',),
'rekylfri': ('rekylfri',),
'rekylfrie': ('rekylfri',),
'rekylfriere': ('rekylfri',),
'rekylfriest': ('rekylfri',),
'rekylfrieste': ('rekylfri',),
'rekylfritt': ('rekylfri',),
'relaterende': ('relatere',),
'relatert': ('relatere',),
'relaterte': ('relatere',),
'relativ': ('relativ',),
'relative': ('relativ',),
'relativere': ('relativ',),
'relativest': ('relativ',),
'relativeste': ('relativ',),
'relativt': ('relativ',),
'relativiserende': ('relativisere',),
'relativisert': ('relativisere',),
'relativiserte': ('relativisere',),
'relativistisk': ('relativistisk',),
'relativistiske': ('relativistisk',),
'relativistiskere': ('relativistisk',),
'relativistiskest': ('relativistisk',),
'relativistiskeste': ('relativistisk',),
'relegerende': ('relegere',),
'relegert': ('relegere',),
'relegerte': ('relegere',),
'relevant': ('relevant',),
'relevante': ('relevant',),
'relevantere': ('relevant',),
'relevantest': ('relevant',),
'relevanteste': ('relevant',),
'religiøs': ('religiøs',),
'religiøse': ('religiøs',),
'religiøsere': ('religiøs',),
'religiøsest': ('religiøs',),
'religiøseste': ('religiøs',),
'religiøst': ('religiøs',),
'relikt': ('relikt',),
'relikte': ('relikt',),
'reliktere': ('relikt',),
'reliktest': ('relikt',),
'relikteste': ('relikt',),
'relokerbar': ('relokerbar',),
'relokerbare': ('relokerbar',),
'relokerbarere': ('relokerbar',),
'relokerbarest': ('relokerbar',),
'relokerbareste': ('relokerbar',),
'relokerbart': ('relokerbar',),
'relokerende': ('relokere',),
'relokert': ('relokere',),
'relokerte': ('relokere',),
'remburserende': ('rembursere',),
'rembursert': ('rembursere',),
'remburserte': ('rembursere',),
'reminiserende': ('reminisere',),
'reminisert': ('reminisere',),
'reminiserte': ('reminisere',),
'remis': ('remis',),
'remiserende': ('remisere',),
'remisert': ('remisere',),
'remiserte': ('remisere',),
'remitterende': ('remittere',),
'remittert': ('remittere',),
'remitterte': ('remittere',),
'remja': ('remje',),
'remjede': ('remje',),
'remjende': ('remje',),
'remjet': ('remje',),
'remjete': ('remje',),
'remonterende': ('remontere',),
'remontert': ('remontere',),
'remonterte': ('remontere',),
'remplasserende': ('remplassere',),
'remplassert': ('remplassere',),
'remplasserte': ('remplassere',),
'remsa': ('remse',),
'remsede': ('remse',),
'remsende': ('remse',),
'remset': ('remse',),
'remsete': ('remse',),
'ren': ('ren',),
'rene': ('ren',),
'renere': ('ren',),
'renest': ('ren',),
'reneste': ('ren',),
'rent': ('ren',),
'rendyrka': ('rendyrke',),
'rendyrkede': ('rendyrke',),
'rendyrkende': ('rendyrke',),
'rendyrket': ('rendyrke',),
'rendyrkete': ('rendyrke',),
'renferdig': ('renferdig',),
'renferdige': ('renferdig',),
'renferdigere': ('renferdig',),
'renferdigst': ('renferdig',),
'renferdigste': ('renferdig',),
'rengjort': ('rengjøre',),
'rengjorte': ('rengjøre',),
'rengjørende': ('rengjøre',),
'renhårig': ('renhårig',),
'renhårige': ('renhårig',),
'renhårigere': ('renhårig',),
'renhårigst': ('renhårig',),
'renhårigste': ('renhårig',),
'renommert': ('renommert',),
'renommerte': ('renommert',),
'renommertere': ('renommert',),
'renommertest': ('renommert',),
'renommerteste': ('renommert',),
'renons': ('renons',),
'renonserende': ('renonsere',),
'renonsert': ('renonsere',),
'renonserte': ('renonsere',),
'renoverende': ('renovere',),
'renovert': ('renovere',),
'renoverte': ('renovere',),
'rensa': ('rense',),
'rensede': ('rense',),
'rensende': ('rense',),
'renset': ('rense',),
'rensete': ('rense',),
'renska': ('renske',),
'renskede': ('renske',),
'renskende': ('renske',),
'rensket': ('renske',),
'renskete': ('renske',),
'renskreven': ('renskrive',),
'renskrevet': ('renskrive',),
'renskrevne': ('renskrive',),
'renskrivende': ('renskrive',),
'renslig': ('renslig',),
'renslige': ('renslig',),
'rensligere': ('renslig',),
'rensligst': ('renslig',),
'rensligste': ('renslig',),
'rentabel': ('rentabel',),
'rentabelt': ('rentabel',),
'rentable': ('rentabel',),
'rentablere': ('rentabel',),
'rentablest': ('rentabel',),
'rentableste': ('rentabel',),
'rentemarginal': ('rentemarginal',),
'rentemarginale': ('rentemarginal',),
'rentemarginalere': ('rentemarginal',),
'rentemarginalest': ('rentemarginal',),
'rentemarginaleste': ('rentemarginal',),
'rentemarginalt': ('rentemarginal',),
'renvaska': ('renvaske',),
'renvaskede': ('renvaske',),
'renvaskende': ('renvaske',),
'renvasket': ('renvaske',),
'renvaskete': ('renvaske',),
'reorganiserende': ('reorganisere',),
'reorganisert': ('reorganisere',),
'reorganiserte': ('reorganisere',),
'reparativ': ('reparativ',),
'reparative': ('reparativ',),
'reparativere': ('reparativ',),
'reparativest': ('reparativ',),
'reparativeste': ('reparativ',),
'reparativt': ('reparativ',),
'reparerende': ('reparere',),
'reparert': ('reparere',),
'reparerte': ('reparere',),
'repatrierende': ('repatriere',),
'repatriert': ('repatriere',),
'repatrierte': ('repatriere',),
'repeterende': ('repetere',),
'repetert': ('repetere',),
'repeterte': ('repetere',),
'repliserende': ('replisere',),
'replisert': ('replisere',),
'repliserte': ('replisere',),
'representativ': ('representativ',),
'representative': ('representativ',),
'representativere': ('representativ',),
'representativest': ('representativ',),
'representativeste': ('representativ',),
'representativt': ('representativ',),
'representerende': ('representere',),
'representert': ('representere',),
'representerte': ('representere',),
'repressiv': ('repressiv',),
'repressive': ('repressiv',),
'repressivere': ('repressiv',),
'repressivest': ('repressiv',),
'repressiveste': ('repressiv',),
'repressivt': ('repressiv',),
'reproduserende': ('reprodusere',),
'reprodusert': ('reprodusere',),
'reproduserte': ('reprodusere',),
'republikansk': ('republikansk',),
'republikanske': ('republikansk',),
'republikanskere': ('republikansk',),
'republikanskest': ('republikansk',),
'republikanskeste': ('republikansk',),
'reputerlig': ('reputerlig',),
'reputerlige': ('reputerlig',),
'reputerligere': ('reputerlig',),
'reputerligst': ('reputerlig',),
'reputerligste': ('reputerlig',),
'reseptiv': ('reseptiv',),
'reseptive': ('reseptiv',),
'reseptivere': ('reseptiv',),
'reseptivest': ('reseptiv',),
'reseptiveste': ('reseptiv',),
'reseptivt': ('reseptiv',),
'reservasjonslaus': ('reservasjonslaus',),
'reservasjonslause': ('reservasjonslaus',),
'reservasjonslausere': ('reservasjonslaus',),
'reservasjonslausest': ('reservasjonslaus',),
'reservasjonslauseste': ('reservasjonslaus',),
'reservasjonslaust': ('reservasjonslaus',),
'reservasjonsløs': ('reservasjonsløs',),
'reservasjonsløse': ('reservasjonsløs',),
'reservasjonsløsere': ('reservasjonsløs',),
'reservasjonsløsest': ('reservasjonsløs',),
'reservasjonsløseste': ('reservasjonsløs',),
'reservasjonsløst': ('reservasjonsløs',),
'reserverende': ('reservere',),
'reservert': ('reservere',),
'reserverte': ('reservere',),
'reservert': ('reservert',),
'reserverte': ('reservert',),
'reservertere': ('reservert',),
'reservertest': ('reservert',),
'reserverteste': ('reservert',),
'reservespekka': ('reservespekka',),
'reservespekkede': ('reservespekket',),
'reservespekket': ('reservespekket',),
'reservespekkete': ('reservespekket',),
'reservespekketere': ('reservespekket',),
'reservespekketest': ('reservespekket',),
'reservespekketeste': ('reservespekket',),
'residerende': ('residere',),
'residert': ('residere',),
'residerte': ('residere',),
'residiverende': ('residivere',),
'residivert': ('residivere',),
'residiverte': ('residivere',),
'resignerende': ('resignere',),
'resignert': ('resignere',),
'resignerte': ('resignere',),
'resiperende': ('resipere',),
'resipert': ('resipere',),
'resiperte': ('resipere',),
'resiprok': ('resiprok',),
'resiproke': ('resiprok',),
'resiprokere': ('resiprok',),
'resiprokest': ('resiprok',),
'resiprokeste': ('resiprok',),
'resiprokt': ('resiprok',),
'resirkulerende': ('resirkulere',),
'resirkulert': ('resirkulere',),
'resirkulerte': ('resirkulere',),
'resistent': ('resistent',),
'resistente': ('resistent',),
'resistentere': ('resistent',),
'resistentest': ('resistent',),
'resistenteste': ('resistent',),
'resisterende': ('resistere',),
'resistert': ('resistere',),
'resisterte': ('resistere',),
'resiterende': ('resitere',),
'resitert': ('resitere',),
'resiterte': ('resitere',),
'resolutt': ('resolutt',),
'resolutte': ('resolutt',),
'resoluttere': ('resolutt',),
'resoluttest': ('resolutt',),
'resolutteste': ('resolutt',),
'resolverende': ('resolvere',),
'resolvert': ('resolvere',),
'resolverte': ('resolvere',),
'resonnabel': ('resonnabel',),
'resonnabelt': ('resonnabel',),
'resonnable': ('resonnabel',),
'resonnablere': ('resonnabel',),
'resonnablest': ('resonnabel',),
'resonnableste': ('resonnabel',),
'resonnerende': ('resonnere',),
'resonnert': ('resonnere',),
'resonnerte': ('resonnere',),
'resorberende': ('resorbere',),
'resorbert': ('resorbere',),
'resorberte': ('resorbere',),
'resosialiserende': ('resosialisere',),
'resosialisert': ('resosialisere',),
'resosialiserte': ('resosialisere',),
'respektabel': ('respektabel',),
'respektabelt': ('respektabel',),
'respektable': ('respektabel',),
'respektablere': ('respektabel',),
'respektablest': ('respektabel',),
'respektableste': ('respektabel',),
'respekterende': ('respektere',),
'respektert': ('respektere',),
'respekterte': ('respektere',),
'respektiv': ('respektiv',),
'respektive': ('respektiv',),
'respektivere': ('respektiv',),
'respektivest': ('respektiv',),
'respektiveste': ('respektiv',),
'respektivt': ('respektiv',),
'respiratorisk': ('respiratorisk',),
'respiratoriske': ('respiratorisk',),
'respiratoriskere': ('respiratorisk',),
'respiratoriskest': ('respiratorisk',),
'respiratoriskeste': ('respiratorisk',),
'respirerende': ('respirere',),
'respirert': ('respirere',),
'respirerte': ('respirere',),
'responderende': ('respondere',),
'respondert': ('respondere',),
'responderte': ('respondere',),
'ressurssterk': ('ressurssterk',),
'ressurssterke': ('ressurssterk',),
'ressurssterkere': ('ressurssterk',),
'ressurssterkest': ('ressurssterk',),
'ressurssterkeste': ('ressurssterk',),
'ressurssterkt': ('ressurssterk',),
'ressurssvak': ('ressurssvak',),
'ressurssvake': ('ressurssvak',),
'ressurssvakere': ('ressurssvak',),
'ressurssvakest': ('ressurssvak',),
'ressurssvakeste': ('ressurssvak',),
'ressurssvakt': ('ressurssvak',),
'restaurerende': ('restaurere',),
'restaurert': ('restaurere',),
'restaurerte': ('restaurere',),
'resterende': ('restere',),
'restert': ('restere',),
'resterte': ('restere',),
'restituerende': ('restituere',),
'restituert': ('restituere',),
'restituerte': ('restituere',),
'restlaus': ('restlaus',),
'restlause': ('restlaus',),
'restlausere': ('restlaus',),
'restlausest': ('restlaus',),
'restlauseste': ('restlaus',),
'restlaust': ('restlaus',),
'restløs': ('restløs',),
'restløse': ('restløs',),
'restløsere': ('restløs',),
'restløsest': ('restløs',),
'restløseste': ('restløs',),
'restløst': ('restløs',),
'restriktiv': ('restriktiv',),
'restriktive': ('restriktiv',),
'restriktivere': ('restriktiv',),
'restriktivest': ('restriktiv',),
'restriktiveste': ('restriktiv',),
'restriktivt': ('restriktiv',),
'resultatlaus': ('resultatlaus',),
'resultatlause': ('resultatlaus',),
'resultatlausere': ('resultatlaus',),
'resultatlausest': ('resultatlaus',),
'resultatlauseste': ('resultatlaus',),
'resultatlaust': ('resultatlaus',),
'resultatløs': ('resultatløs',),
'resultatløse': ('resultatløs',),
'resultatløsere': ('resultatløs',),
'resultatløsest': ('resultatløs',),
'resultatløseste': ('resultatløs',),
'resultatløst': ('resultatløs',),
'resulterende': ('resultere',),
'resultert': ('resultere',),
'resulterte': ('resultere',),
'resurssterk': ('resurssterk',),
'resurssterke': ('resurssterk',),
'resurssterkere': ('resurssterk',),
'resurssterkest': ('resurssterk',),
'resurssterkeste': ('resurssterk',),
'resurssterkt': ('resurssterk',),
'resurssvak': ('resurssvak',),
'resurssvake': ('resurssvak',),
'resurssvakere': ('resurssvak',),
'resurssvakest': ('resurssvak',),
'resurssvakeste': ('resurssvak',),
'resurssvakt': ('resurssvak',),
'resyklisk': ('resyklisk',),
'resykliske': ('resyklisk',),
'resykliskere': ('resyklisk',),
'resykliskest': ('resyklisk',),
'resykliskeste': ('resyklisk',),
'resymerende': ('resymere',),
'resymert': ('resymere',),
'resymerte': ('resymere',),
'retarderende': ('retardere',),
'retardert': ('retardere',),
'retarderte': ('retardere',),
'retinerende': ('retinere',),
'retinert': ('retinere',),
'retinerte': ('retinere',),
'retirerende': ('retirere',),
'retirert': ('retirere',),
'retirerte': ('retirere',),
'retningsgivende': ('retningsgivende',),
'retorisk': ('retorisk',),
'retoriske': ('retorisk',),
'retoriskere': ('retorisk',),
'retoriskest': ('retorisk',),
'retoriskeste': ('retorisk',),
'retoromansk': ('retoromansk',),
'retoromanske': ('retoromansk',),
'retoromanskere': ('retoromansk',),
'retoromanskest': ('retoromansk',),
'retoromanskeste': ('retoromansk',),
'retroaktiv': ('retroaktiv',),
'retroaktive': ('retroaktiv',),
'retroaktivere': ('retroaktiv',),
'retroaktivest': ('retroaktiv',),
'retroaktiveste': ('retroaktiv',),
'retroaktivt': ('retroaktiv',),
'retrofleks': ('retrofleks',),
'retroflekse': ('retrofleks',),
'retrofleksere': ('retrofleks',),
'retrofleksest': ('retrofleks',),
'retroflekseste': ('retrofleks',),
'retroflekst': ('retrofleks',),
'retrograd': ('retrograd',),
'retrograde': ('retrograd',),
'retrogradere': ('retrograd',),
'retrogradest': ('retrograd',),
'retrogradeste': ('retrograd',),
'retrospektiv': ('retrospektiv',),
'retrospektive': ('retrospektiv',),
'retrospektivere': ('retrospektiv',),
'retrospektivest': ('retrospektiv',),
'retrospektiveste': ('retrospektiv',),
'retrospektivt': ('retrospektiv',),
'rett': ('rett',),
'rette': ('rett',),
'rettere': ('rett',),
'rettest': ('rett',),
'retteste': ('rett',),
'rett-tenkende': ('rett-tenkende',),
'rett-tidig': ('rett-tidig',),
'rett-tidige': ('rett-tidig',),
'rett-tidigere': ('rett-tidig',),
'rett-tidigst': ('rett-tidig',),
'rett-tidigste': ('rett-tidig',),
'rett-troende': ('rett-troende',),
'retta': ('rette',),
'rettede': ('rette',),
'rettende': ('rette',),
'rettet': ('rette',),
'rettete': ('rette',),
'rettelig': ('rettelig',),
'rettelige': ('rettelig',),
'retteligere': ('rettelig',),
'retteligst': ('rettelig',),
'retteligste': ('rettelig',),
'rettenkende': ('rettenkende',),
'rettferdig': ('rettferdig',),
'rettferdige': ('rettferdig',),
'rettferdigere': ('rettferdig',),
'rettferdigst': ('rettferdig',),
'rettferdigste': ('rettferdig',),
'rettferdiggjort': ('rettferdiggjøre',),
'rettferdiggjorte': ('rettferdiggjøre',),
'rettferdiggjørende': ('rettferdiggjøre',),
'retthaversk': ('retthaversk',),
'retthaverske': ('retthaversk',),
'retthaverskere': ('retthaversk',),
'retthaverskest': ('retthaversk',),
'retthaverskeste': ('retthaversk',),
'rettidig': ('rettidig',),
'rettidige': ('rettidig',),
'rettidigere': ('rettidig',),
'rettidigst': ('rettidig',),
'rettidigste': ('rettidig',),
'rettkjennende': ('rettkjenne',),
'rettkjent': ('rettkjenne',),
'rettkjente': ('rettkjenne',),
'rettkommen': ('rettkommen',),
'rettkomment': ('rettkommen',),
'rettkomne': ('rettkommen',),
'rettkomnere': ('rettkommen',),
'rettkomnest': ('rettkommen',),
'rettkomneste': ('rettkommen',),
'rettlaus': ('rettlaus',),
'rettlause': ('rettlaus',),
'rettlausere': ('rettlaus',),
'rettlausest': ('rettlaus',),
'rettlauseste': ('rettlaus',),
'rettlaust': ('rettlaus',),
'rettleda': ('rettlede',),
'rettledede': ('rettlede',),
'rettledende': ('rettlede',),
'rettledet': ('rettlede',),
'rettledete': ('rettlede',),
'rettleid': ('rettleie',),
'rettleide': ('rettleie',),
'rettleiede': ('rettleie',),
'rettleiende': ('rettleie',),
'rettleiet': ('rettleie',),
'rettleiete': ('rettleie',),
'rettlinja': ('rettlinja',),
'rettlinjede': ('rettlinjet',),
'rettlinjet': ('rettlinjet',),
'rettlinjete': ('rettlinjet',),
'rettlinjetere': ('rettlinjet',),
'rettlinjetest': ('rettlinjet',),
'rettlinjeteste': ('rettlinjet',),
'rettløs': ('rettløs',),
'rettløse': ('rettløs',),
'rettløsere': ('rettløs',),
'rettløsest': ('rettløs',),
'rettløseste': ('rettløs',),
'rettløst': ('rettløs',),
'rettmessig': ('rettmessig',),
'rettmessige': ('rettmessig',),
'rettmessigere': ('rettmessig',),
'rettmessigst': ('rettmessig',),
'rettmessigste': ('rettmessig',),
'rettroende': ('rettroende',),
'rettsgyldig': ('rettsgyldig',),
'rettsgyldige': ('rettsgyldig',),
'rettsgyldigere': ('rettsgyldig',),
'rettsgyldigst': ('rettsgyldig',),
'rettsgyldigste': ('rettsgyldig',),
'rettsindig': ('rettsindig',),
'rettsindige': ('rettsindig',),
'rettsindigere': ('rettsindig',),
'rettsindigst': ('rettsindig',),
'rettsindigste': ('rettsindig',),
'rettskaffen': ('rettskaffen',),
'rettskaffent': ('rettskaffen',),
'rettskafne': ('rettskaffen',),
'rettskafnere': ('rettskaffen',),
'rettskafnest': ('rettskaffen',),
'rettskafneste': ('rettskaffen',),
'rettskraftig': ('rettskraftig',),
'rettskraftige': ('rettskraftig',),
'rettskraftigere': ('rettskraftig',),
'rettskraftigst': ('rettskraftig',),
'rettskraftigste': ('rettskraftig',),
'rettslaus': ('rettslaus',),
'rettslause': ('rettslaus',),
'rettslausere': ('rettslaus',),
'rettslausest': ('rettslaus',),
'rettslauseste': ('rettslaus',),
'rettslaust': ('rettslaus',),
'rettslig': ('rettslig',),
'rettslige': ('rettslig',),
'rettsligere': ('rettslig',),
'rettsligst': ('rettslig',),
'rettsligste': ('rettslig',),
'rettslærd': ('rettslærd',),
'rettslærde': ('rettslærd',),
'rettslærdere': ('rettslærd',),
'rettslærdest': ('rettslærd',),
'rettslærdeste': ('rettslærd',),
'rettsløs': ('rettsløs',),
'rettsløse': ('rettsløs',),
'rettsløsere': ('rettsløs',),
'rettsløsest': ('rettsløs',),
'rettsløseste': ('rettsløs',),
'rettsløst': ('rettsløs',),
'rettsstridig': ('rettsstridig',),
'rettsstridige': ('rettsstridig',),
'rettsstridigere': ('rettsstridig',),
'rettsstridigst': ('rettsstridig',),
'rettsstridigste': ('rettsstridig',),
'rettvinkla': ('rettvinkla',),
'rettvinklede': ('rettvinklet',),
'rettvinklet': ('rettvinklet',),
'rettvinklete': ('rettvinklet',),
'rettvinkletere': ('rettvinklet',),
'rettvinkletest': ('rettvinklet',),
'rettvinkleteste': ('rettvinklet',),
'rettvis': ('rettvis',),
'rettvise': ('rettvis',),
'rettvisere': ('rettvis',),
'rettvisest': ('rettvis',),
'rettviseste': ('rettvis',),
'rettvist': ('rettvis',),
'returnerende': ('returnere',),
'returnert': ('returnere',),
'returnerte': ('returnere',),
'retusjerende': ('retusjere',),
'retusjert': ('retusjere',),
'retusjerte': ('retusjere',),
'reumatisk': ('reumatisk',),
'reumatiske': ('reumatisk',),
'reumatiskere': ('reumatisk',),
'reumatiskest': ('reumatisk',),
'reumatiskeste': ('reumatisk',),
'revaluerende': ('revaluere',),
'revaluert': ('revaluere',),
'revaluerte': ('revaluere',),
'revansjerende': ('revansjere',),
'revansjert': ('revansjere',),
'revansjerte': ('revansjere',),
'revansjistisk': ('revansjistisk',),
'revansjistiske': ('revansjistisk',),
'revansjistiskere': ('revansjistisk',),
'revansjistiskest': ('revansjistisk',),
'revansjistiskeste': ('revansjistisk',),
'reva': ('reve',),
'revd': ('reve',),
'revde': ('reve',),
'revede': ('reve',),
'revende': ('reve',),
'revet': ('reve',),
'revete': ('reve',),
'reverserende': ('reversere',),
'reversert': ('reversere',),
'reverserte': ('reversere',),
'reversibel': ('reversibel',),
'reversibelt': ('reversibel',),
'reversible': ('reversibel',),
'reversiblere': ('reversibel',),
'reversiblest': ('reversibel',),
'reversibleste': ('reversibel',),
'reviderende': ('revidere',),
'revidert': ('revidere',),
'reviderte': ('revidere',),
'revisjonistisk': ('revisjonistisk',),
'revisjonistiske': ('revisjonistisk',),
'revisjonistiskere': ('revisjonistisk',),
'revisjonistiskest': ('revisjonistisk',),
'revisjonistiskeste': ('revisjonistisk',),
'revmatisk': ('revmatisk',),
'revmatiske': ('revmatisk',),
'revmatiskere': ('revmatisk',),
'revmatiskest': ('revmatisk',),
'revmatiskeste': ('revmatisk',),
'revna': ('revne',),
'revnede': ('revne',),
'revnende': ('revne',),
'revnet': ('revne',),
'revnete': ('revne',),
'revna': ('revne',),
'revnede': ('revne',),
'revnende': ('revne',),
'revnet': ('revne',),
'revnete': ('revne',),
'revolterende': ('revoltere',),
'revoltert': ('revoltere',),
'revolterte': ('revoltere',),
'revolusjonerende': ('revolusjonere',),
'revolusjonert': ('revolusjonere',),
'revolusjonerte': ('revolusjonere',),
'revolusjonistisk': ('revolusjonistisk',),
'revolusjonistiske': ('revolusjonistisk',),
'revolusjonistiskere': ('revolusjonistisk',),
'revolusjonistiskest': ('revolusjonistisk',),
'revolusjonistiskeste': ('revolusjonistisk',),
'revolusjonær': ('revolusjonær',),
'revolusjonære': ('revolusjonær',),
'revolusjonærere': ('revolusjonær',),
'revolusjonærest': ('revolusjonær',),
'revolusjonæreste': ('revolusjonær',),
'revolusjonært': ('revolusjonær',),
'rhesusnegativ': ('rhesusnegativ',),
'rhesusnegative': ('rhesusnegativ',),
'rhesusnegativere': ('rhesusnegativ',),
'rhesusnegativest': ('rhesusnegativ',),
'rhesusnegativeste': ('rhesusnegativ',),
'rhesusnegativt': ('rhesusnegativ',),
'rhesuspositiv': ('rhesuspositiv',),
'rhesuspositive': ('rhesuspositiv',),
'rhesuspositivere': ('rhesuspositiv',),
'rhesuspositivest': ('rhesuspositiv',),
'rhesuspositiveste': ('rhesuspositiv',),
'rhesuspositivt': ('rhesuspositiv',),
'rhodesisk': ('rhodesisk',),
'rhodesiske': ('rhodesisk',),
'rhodesiskere': ('rhodesisk',),
'rhodesiskest': ('rhodesisk',),
'rhodesiskeste': ('rhodesisk',),
'ridd': ('ri',),
'ridde': ('ri',),
'riende': ('ri',),
'ribba': ('ribbe',),
'ribbede': ('ribbe',),
'ribbende': ('ribbe',),
'ribbet': ('ribbe',),
'ribbete': ('ribbe',),
'ribbet': ('ribbet',),
'ribbete': ('ribbet',),
'ribbetere': ('ribbet',),
'ribbetest': ('ribbet',),
'ribbeteste': ('ribbet',),
'ribbettt': ('ribbet',),
'ribbete': ('ribbete',),
'ridderlig': ('ridderlig',),
'ridderlige': ('ridderlig',),
'ridderligere': ('ridderlig',),
'ridderligst': ('ridderlig',),
'ridderligste': ('ridderlig',),
'ridd': ('ride',),
'ridde': ('ride',),
'ridende': ('ride',),
'rifla': ('rifle',),
'riflede': ('rifle',),
'riflende': ('rifle',),
'riflet': ('rifle',),
'riflete': ('rifle',),
'riflet': ('riflet',),
'riflete': ('riflet',),
'rifletere': ('riflet',),
'rifletest': ('riflet',),
'rifleteste': ('riflet',),
'riflete': ('riflete',),
'rigga': ('rigge',),
'riggede': ('rigge',),
'riggende': ('rigge',),
'rigget': ('rigge',),
'riggete': ('rigge',),
'rigid': ('rigid',),
'rigide': ('rigid',),
'rigidere': ('rigid',),
'rigidest': ('rigid',),
'rigideste': ('rigid',),
'rigorøs': ('rigorøs',),
'rigorøse': ('rigorøs',),
'rigorøsere': ('rigorøs',),
'rigorøsest': ('rigorøs',),
'rigorøseste': ('rigorøs',),
'rigorøst': ('rigorøs',),
'rik': ('rik',),
'rike': ('rik',),
'rikere': ('rik',),
'rikest': ('rik',),
'rikeste': ('rik',),
'rikt': ('rik',),
'rikelig': ('rikelig',),
'rikelige': ('rikelig',),
'rikeligere': ('rikelig',),
'rikeligst': ('rikelig',),
'rikeligste': ('rikelig',),
'rikholdig': ('rikholdig',),
'rikholdige': ('rikholdig',),
'rikholdigere': ('rikholdig',),
'rikholdigst': ('rikholdig',),
'rikholdigste': ('rikholdig',),
'rikka': ('rikke',),
'rikkede': ('rikke',),
'rikkende': ('rikke',),
'rikket': ('rikke',),
'rikkete': ('rikke',),
'rikla': ('rikle',),
'riklede': ('rikle',),
'riklende': ('rikle',),
'riklet': ('rikle',),
'riklete': ('rikle',),
'rikosjetterende': ('rikosjettere',),
'rikosjettert': ('rikosjettere',),
'rikosjetterte': ('rikosjettere',),
'riksa': ('rikse',),
'riksede': ('rikse',),
'riksende': ('rikse',),
'rikset': ('rikse',),
'riksete': ('rikse',),
'rikta': ('rikte',),
'riktede': ('rikte',),
'riktende': ('rikte',),
'riktet': ('rikte',),
'riktete': ('rikte',),
'riktig': ('riktig',),
'riktige': ('riktig',),
'riktigere': ('riktig',),
'riktigst': ('riktig',),
'riktigste': ('riktig',),
'rima': ('rime',),
'rimede': ('rime',),
'rimende': ('rime',),
'rimet': ('rime',),
'rimete': ('rime',),
'rima': ('rime',),
'rimede': ('rime',),
'rimende': ('rime',),
'rimet': ('rime',),
'rimete': ('rime',),
'rimt': ('rime',),
'rimte': ('rime',),
'rimelig': ('rimelig',),
'rimelige': ('rimelig',),
'rimeligere': ('rimelig',),
'rimeligst': ('rimelig',),
'rimeligste': ('rimelig',),
'rimet': ('rimet',),
'rimete': ('rimet',),
'rimetere': ('rimet',),
'rimetest': ('rimet',),
'rimeteste': ('rimet',),
'rimete': ('rimete',),
'rinende': ('rine',),
'rint': ('rine',),
'rinte': ('rine',),
'ring': ('ring',),
'ringe': ('ring',),
'ringere': ('ring',),
'ringest': ('ring',),
'ringeste': ('ring',),
'ringt': ('ring',),
'ringa': ('ringe',),
'ringede': ('ringe',),
'ringende': ('ringe',),
'ringet': ('ringe',),
'ringete': ('ringe',),
'ringende': ('ringe',),
'ringt': ('ringe',),
'ringte': ('ringe',),
'ringe': ('ringe',),
'ringeakta': ('ringeakte',),
'ringeaktede': ('ringeakte',),
'ringeaktende': ('ringeakte',),
'ringeaktet': ('ringeakte',),
'ringeaktete': ('ringeakte',),
'ringforlova': ('ringforlova',),
'ringforlovede': ('ringforlovet',),
'ringforlovet': ('ringforlovet',),
'ringforlovete': ('ringforlovet',),
'ringforlovetere': ('ringforlovet',),
'ringforlovetest': ('ringforlovet',),
'ringforloveteste': ('ringforlovet',),
'ringla': ('ringle',),
'ringlede': ('ringle',),
'ringlende': ('ringle',),
'ringlet': ('ringle',),
'ringlete': ('ringle',),
'ringla': ('ringle',),
'ringlede': ('ringle',),
'ringlende': ('ringle',),
'ringlet': ('ringle',),
'ringlete': ('ringle',),
'ringmerka': ('ringmerke',),
'ringmerkede': ('ringmerke',),
'ringmerkende': ('ringmerke',),
'ringmerket': ('ringmerke',),
'ringmerkete': ('ringmerke',),
'rinnende': ('rinne',),
'runne': ('rinne',),
'runnen': ('rinne',),
'runnet': ('rinne',),
'ripa': ('ripe',),
'ripede': ('ripe',),
'ripende': ('ripe',),
'ripet': ('ripe',),
'ripete': ('ripe',),
'ript': ('ripe',),
'ripte': ('ripe',),
'ripet': ('ripet',),
'ripete': ('ripet',),
'ripetere': ('ripet',),
'ripetest': ('ripet',),
'ripeteste': ('ripet',),
'ripete': ('ripete',),
'riposterende': ('ripostere',),
'ripostert': ('ripostere',),
'riposterte': ('ripostere',),
'rippa': ('rippe',),
'rippede': ('rippe',),
'rippende': ('rippe',),
'rippet': ('rippe',),
'rippete': ('rippe',),
'risende': ('rise',),
'rist': ('rise',),
'riste': ('rise',),
'risikabel': ('risikabel',),
'risikabelt': ('risikabel',),
'risikable': ('risikabel',),
'risikablere': ('risikabel',),
'risikablest': ('risikabel',),
'risikableste': ('risikabel',),
'risikerende': ('risikere',),
'risikert': ('risikere',),
'risikerte': ('risikere',),
'risikovillig': ('risikovillig',),
'risikovillige': ('risikovillig',),
'risikovilligere': ('risikovillig',),
'risikovilligst': ('risikovillig',),
'risikovilligste': ('risikovillig',),
'risla': ('risle',),
'rislede': ('risle',),
'rislende': ('risle',),
'rislet': ('risle',),
'rislete': ('risle',),
'rispa': ('rispe',),
'rispede': ('rispe',),
'rispende': ('rispe',),
'rispet': ('rispe',),
'rispete': ('rispe',),
'rissa': ('risse',),
'rissede': ('risse',),
'rissende': ('risse',),
'risset': ('risse',),
'rissete': ('risse',),
'rista': ('riste',),
'ristede': ('riste',),
'ristende': ('riste',),
'ristet': ('riste',),
'ristete': ('riste',),
'rista': ('riste',),
'ristede': ('riste',),
'ristende': ('riste',),
'ristet': ('riste',),
'ristete': ('riste',),
'rista': ('riste',),
'ristede': ('riste',),
'ristende': ('riste',),
'ristet': ('riste',),
'ristete': ('riste',),
'ristornerende': ('ristornere',),
'ristornert': ('ristornere',),
'ristornerte': ('ristornere',),
'rita': ('rite',),
'ritede': ('rite',),
'ritende': ('rite',),
'ritet': ('rite',),
'ritete': ('rite',),
'ritualiserende': ('ritualisere',),
'ritualisert': ('ritualisere',),
'ritualiserte': ('ritualisere',),
'rituell': ('rituell',),
'rituelle': ('rituell',),
'rituellere': ('rituell',),
'rituellest': ('rituell',),
'rituelleste': ('rituell',),
'rituelt': ('rituell',),
'rivaliserende': ('rivalisere',),
'rivalisert': ('rivalisere',),
'rivaliserte': ('rivalisere',),
'reven': ('rive',),
'revet': ('rive',),
'revne': ('rive',),
'rivende': ('rive',),
'reven': ('rive',),
'revet': ('rive',),
'revne': ('rive',),
'rivende': ('rive',),
'rivende': ('rivende',),
'rivna': ('rivne',),
'rivnede': ('rivne',),
'rivnende': ('rivne',),
'rivnet': ('rivne',),
'rivnete': ('rivne',),
'rivna': ('rivne',),
'rivnede': ('rivne',),
'rivnende': ('rivne',),
'rivnet': ('rivne',),
'rivnete': ('rivne',),
'rodd': ('ro',),
'rodde': ('ro',),
'roende': ('ro',),
'robba': ('robbe',),
'robbede': ('robbe',),
'robbende': ('robbe',),
'robbet': ('robbe',),
'robbete': ('robbe',),
'robotiserende': ('robotisere',),
'robotisert': ('robotisere',),
'robotiserte': ('robotisere',),
'robust': ('robust',),
'robuste': ('robust',),
'robustere': ('robust',),
'robustest': ('robust',),
'robusteste': ('robust',),
'rocka': ('rocke',),
'rockede': ('rocke',),
'rockende': ('rocke',),
'rocket': ('rocke',),
'rockete': ('rocke',),
'roa': ('roe',),
'roede': ('roe',),
'roende': ('roe',),
'roet': ('roe',),
'roete': ('roe',),
'rojalistisk': ('rojalistisk',),
'rojalistiske': ('rojalistisk',),
'rojalistiskere': ('rojalistisk',),
'rojalistiskest': ('rojalistisk',),
'rojalistiskeste': ('rojalistisk',),
'rokerende': ('rokere',),
'rokert': ('rokere',),
'rokerte': ('rokere',),
'rokka': ('rokke',),
'rokkede': ('rokke',),
'rokkende': ('rokke',),
'rokket': ('rokke',),
'rokkete': ('rokke',),
'rolig': ('rolig',),
'rolige': ('rolig',),
'roligere': ('rolig',),
'roligst': ('rolig',),
'roligste': ('rolig',),
'rolla': ('rolle',),
'rollede': ('rolle',),
'rollende': ('rolle',),
'rollet': ('rolle',),
'rollete': ('rolle',),
'rom': ('rom',),
'romme': ('rom',),
'rommere': ('rom',),
'rommest': ('rom',),
'rommeste': ('rom',),
'romt': ('rom',),
'romaniserende': ('romanisere',),
'romanisert': ('romanisere',),
'romaniserte': ('romanisere',),
'romanistisk': ('romanistisk',),
'romanistiske': ('romanistisk',),
'romanistiskere': ('romanistisk',),
'romanistiskest': ('romanistisk',),
'romanistiskeste': ('romanistisk',),
'romansk': ('romansk',),
'romanske': ('romansk',),
'romanskere': ('romansk',),
'romanskest': ('romansk',),
'romanskeste': ('romansk',),
'romantiserende': ('romantisere',),
'romantisert': ('romantisere',),
'romantiserte': ('romantisere',),
'romantisk': ('romantisk',),
'romantiske': ('romantisk',),
'romantiskere': ('romantisk',),
'romantiskest': ('romantisk',),
'romantiskeste': ('romantisk',),
'rombisk': ('rombisk',),
'rombiske': ('rombisk',),
'rombiskere': ('rombisk',),
'rombiskest': ('rombisk',),
'rombiskeste': ('rombisk',),
'romersk': ('romersk',),
'romerske': ('romersk',),
'romerskere': ('romersk',),
'romerskest': ('romersk',),
'romerskeste': ('romersk',),
'romersk-katolsk': ('romersk-katolsk',),
'romersk-katolske': ('romersk-katolsk',),
'romersk-katolskere': ('romersk-katolsk',),
'romersk-katolskest': ('romersk-katolsk',),
'romersk-katolskeste': ('romersk-katolsk',),
'romhendt': ('romhendt',),
'romhendte': ('romhendt',),
'romhendtere': ('romhendt',),
'romhendtest': ('romhendt',),
'romhendteste': ('romhendt',),
'romlig': ('romlig',),
'romlige': ('romlig',),
'romligere': ('romlig',),
'romligst': ('romlig',),
'romligste': ('romlig',),
'romma': ('romme',),
'rommede': ('romme',),
'rommende': ('romme',),
'rommet': ('romme',),
'rommete': ('romme',),
'rommelig': ('rommelig',),
'rommelige': ('rommelig',),
'rommeligere': ('rommelig',),
'rommeligst': ('rommelig',),
'rommeligste': ('rommelig',),
'romskinna': ('romskinna',),
'romskinnede': ('romskinnet',),
'romskinnet': ('romskinnet',),
'romskinnete': ('romskinnet',),
'romskinnetere': ('romskinnet',),
'romskinnetest': ('romskinnet',),
'romskinneteste': ('romskinnet',),
'romslig': ('romslig',),
'romslige': ('romslig',),
'romsligere': ('romslig',),
'romsligst': ('romslig',),
'romsligste': ('romslig',),
'romsterende': ('romstere',),
'romstert': ('romstere',),
'romsterte': ('romstere',),
'romtent': ('romtent',),
'romtente': ('romtent',),
'romtentere': ('romtent',),
'romtentest': ('romtent',),
'romtenteste': ('romtent',),
'ropende': ('rope',),
'ropt': ('rope',),
'ropte': ('rope',),
'rosa': ('rosa',),
'rosende': ('rose',),
'rost': ('rose',),
'roste': ('rose',),
'rosemalende': ('rosemale',),
'rosemalt': ('rosemale',),
'rosemalte': ('rosemale',),
'rosenrød': ('rosenrød',),
'rosenrøde': ('rosenrød',),
'rosenrødere': ('rosenrød',),
'rosenrødest': ('rosenrød',),
'rosenrødeste': ('rosenrød',),
'rosenrødt': ('rosenrød',),
'roserød': ('roserød',),
'roserøde': ('roserød',),
'roserødere': ('roserød',),
'roserødest': ('roserød',),
'roserødeste': ('roserød',),
'roserødt': ('roserød',),
'roset': ('roset',),
'rosete': ('roset',),
'rosetere': ('roset',),
'rosetest': ('roset',),
'roseteste': ('roset',),
'rosete': ('rosete',),
'rosta': ('roste',),
'rostede': ('roste',),
'rostende': ('roste',),
'rostet': ('roste',),
'rostete': ('roste',),
'rosta': ('roste',),
'rostede': ('roste',),
'rostende': ('roste',),
'rostet': ('roste',),
'rostete': ('roste',),
'rosverdig': ('rosverdig',),
'rosverdige': ('rosverdig',),
'rosverdigere': ('rosverdig',),
'rosverdigst': ('rosverdig',),
'rosverdigste': ('rosverdig',),
'rota': ('rote',),
'rotede': ('rote',),
'rotende': ('rote',),
'rotet': ('rote',),
'rotete': ('rote',),
'rota': ('rote',),
'rotede': ('rote',),
'rotende': ('rote',),
'rotet': ('rote',),
'rotete': ('rote',),
'rotekte': ('rotekte',),
'roterende': ('rotere',),
'rotert': ('rotere',),
'roterte': ('rotere',),
'rotet': ('rotet',),
'rotete': ('rotet',),
'rotetere': ('rotet',),
'rotetest': ('rotet',),
'roteteste': ('rotet',),
'rotete': ('rotete',),
'rotfast': ('rotfast',),
'rotfaste': ('rotfast',),
'rotfastere': ('rotfast',),
'rotfastest': ('rotfast',),
'rotfasteste': ('rotfast',),
'rotfesta': ('rotfeste',),
'rotfestede': ('rotfeste',),
'rotfestende': ('rotfeste',),
'rotfestet': ('rotfeste',),
'rotfestete': ('rotfeste',),
'rotfyllende': ('rotfylle',),
'rotfylt': ('rotfylle',),
'rotfylte': ('rotfylle',),
'rotlaus': ('rotlaus',),
'rotlause': ('rotlaus',),
'rotlausere': ('rotlaus',),
'rotlausest': ('rotlaus',),
'rotlauseste': ('rotlaus',),
'rotlaust': ('rotlaus',),
'rotløs': ('rotløs',),
'rotløse': ('rotløs',),
'rotløsere': ('rotløs',),
'rotløsest': ('rotløs',),
'rotløseste': ('rotløs',),
'rotløst': ('rotløs',),
'rotta': ('rotte',),
'rottede': ('rotte',),
'rottende': ('rotte',),
'rottet': ('rotte',),
'rottete': ('rotte',),
'ru': ('ru',),
'rue': ('ru',),
'ruere': ('ru',),
'ruest': ('ru',),
'rueste': ('ru',),
'rutt': ('ru',),
'rubba': ('rubbe',),
'rubbede': ('rubbe',),
'rubbende': ('rubbe',),
'rubbet': ('rubbe',),
'rubbete': ('rubbe',),
'rubben': ('rubben',),
'rubbent': ('rubben',),
'rubne': ('rubben',),
'rubnere': ('rubben',),
'rubnest': ('rubben',),
'rubneste': ('rubben',),
'rubbet': ('rubbet',),
'rubbete': ('rubbet',),
'rubbetere': ('rubbet',),
'rubbetest': ('rubbet',),
'rubbeteste': ('rubbet',),
'rubbete': ('rubbete',),
'rubinrød': ('rubinrød',),
'rubinrøde': ('rubinrød',),
'rubinrødere': ('rubinrød',),
'rubinrødest': ('rubinrød',),
'rubinrødeste': ('rubinrød',),
'rubinrødt': ('rubinrød',),
'rubriserende': ('rubrisere',),
'rubrisert': ('rubrisere',),
'rubriserte': ('rubrisere',),
'rudimentær': ('rudimentær',),
'rudimentære': ('rudimentær',),
'rudimentærere': ('rudimentær',),
'rudimentærest': ('rudimentær',),
'rudimentæreste': ('rudimentær',),
'rudimentært': ('rudimentær',),
'rufsa': ('rufse',),
'rufsede': ('rufse',),
'rufsende': ('rufse',),
'rufset': ('rufse',),
'rufsete': ('rufse',),
'rufsen': ('rufsen',),
'rufsent': ('rufsen',),
'rufsne': ('rufsen',),
'rufsnere': ('rufsen',),
'rufsnest': ('rufsen',),
'rufsneste': ('rufsen',),
'rufset': ('rufset',),
'rufsete': ('rufset',),
'rufsetere': ('rufset',),
'rufsetest': ('rufset',),
'rufseteste': ('rufset',),
'rufsete': ('rufsete',),
'ruga': ('ruge',),
'rugede': ('ruge',),
'rugende': ('ruge',),
'ruget': ('ruge',),
'rugete': ('ruge',),
'rugga': ('rugge',),
'ruggede': ('rugge',),
'ruggende': ('rugge',),
'rugget': ('rugge',),
'ruggete': ('rugge',),
'rugla': ('rugle',),
'ruglede': ('rugle',),
'ruglende': ('rugle',),
'ruglet': ('rugle',),
'ruglete': ('rugle',),
'ruglet': ('ruglet',),
'ruglete': ('ruglet',),
'rugletere': ('ruglet',),
'rugletest': ('ruglet',),
'rugleteste': ('ruglet',),
'ruglet': ('ruglet',),
'ruglete': ('ruglet',),
'rugletere': ('ruglet',),
'rugletest': ('ruglet',),
'rugleteste': ('ruglet',),
'ruglete': ('ruglete',),
'ruglete': ('ruglete',),
'ruhåra': ('ruhåra',),
'ruhårede': ('ruhåret',),
'ruhåret': ('ruhåret',),
'ruhårete': ('ruhåret',),
'ruhåretere': ('ruhåret',),
'ruhåretest': ('ruhåret',),
'ruhåreteste': ('ruhåret',),
'ruinerende': ('ruinere',),
'ruinert': ('ruinere',),
'ruinerte': ('ruinere',),
'rukka': ('rukke',),
'rukkede': ('rukke',),
'rukkende': ('rukke',),
'rukket': ('rukke',),
'rukkete': ('rukke',),
'rukket': ('rukket',),
'rukkete': ('rukket',),
'rukketere': ('rukket',),
'rukketest': ('rukket',),
'rukketeste': ('rukket',),
'rukkete': ('rukkete',),
'ruklet': ('ruklet',),
'ruklete': ('ruklet',),
'rukletere': ('ruklet',),
'rukletest': ('ruklet',),
'rukleteste': ('ruklet',),
'ruklete': ('ruklete',),
'rulla': ('rulle',),
'rullede': ('rulle',),
'rullende': ('rulle',),
'rullet': ('rulle',),
'rullete': ('rulle',),
'rulleførende': ('rulleføre',),
'rulleført': ('rulleføre',),
'rulleførte': ('rulleføre',),
'rullerende': ('rullere',),
'rullert': ('rullere',),
'rullerte': ('rullere',),
'rulta': ('rulte',),
'rultede': ('rulte',),
'rultende': ('rulte',),
'rultet': ('rulte',),
'rultete': ('rulte',),
'rulten': ('rulten',),
'rultent': ('rulten',),
'rultne': ('rulten',),
'rultnere': ('rulten',),
'rultnest': ('rulten',),
'rultneste': ('rulten',),
'rumensk': ('rumensk',),
'rumenske': ('rumensk',),
'rumenskere': ('rumensk',),
'rumenskest': ('rumensk',),
'rumenskeste': ('rumensk',),
'rumla': ('rumle',),
'rumlede': ('rumle',),
'rumlende': ('rumle',),
'rumlet': ('rumle',),
'rumlete': ('rumle',),
'rund': ('rund',),
'runde': ('rund',),
'rundere': ('rund',),
'rundest': ('rund',),
'rundeste': ('rund',),
'rundt': ('rund',),
'runda': ('runde',),
'rundede': ('runde',),
'rundende': ('runde',),
'rundet': ('runde',),
'rundete': ('runde',),
'rundelig': ('rundelig',),
'rundelige': ('rundelig',),
'rundeligere': ('rundelig',),
'rundeligst': ('rundelig',),
'rundeligste': ('rundelig',),
'rundhanda': ('rundhanda',),
'rundhandede': ('rundhandet',),
'rundhandet': ('rundhandet',),
'rundhandete': ('rundhandet',),
'rundhandetere': ('rundhandet',),
'rundhandetest': ('rundhandet',),
'rundhandeteste': ('rundhandet',),
'rundhånda': ('rundhånda',),
'rundhåndede': ('rundhåndet',),
'rundhåndet': ('rundhåndet',),
'rundhåndete': ('rundhåndet',),
'rundhåndetere': ('rundhåndet',),
'rundhåndetest': ('rundhåndet',),
'rundhåndeteste': ('rundhåndet',),
'rundjulende': ('rundjule',),
'rundjult': ('rundjule',),
'rundjulte': ('rundjule',),
'rundstelende': ('rundstele',),
'rundstålen': ('rundstele',),
'rundstålet': ('rundstele',),
'rundstålne': ('rundstele',),
'rundstjelende': ('rundstjele',),
'rundstjålen': ('rundstjele',),
'rundstjålet': ('rundstjele',),
'rundstjålne': ('rundstjele',),
'rundvaska': ('rundvaske',),
'rundvaskede': ('rundvaske',),
'rundvaskende': ('rundvaske',),
'rundvasket': ('rundvaske',),
'rundvaskete': ('rundvaske',),
'runa': ('rune',),
'runede': ('rune',),
'runende': ('rune',),
'runet': ('rune',),
'runete': ('rune',),
'runga': ('runge',),
'rungede': ('runge',),
'rungende': ('runge',),
'runget': ('runge',),
'rungete': ('runge',),
'runka': ('runke',),
'runkede': ('runke',),
'runkende': ('runke',),
'runket': ('runke',),
'runkete': ('runke',),
'runologisk': ('runologisk',),
'runologiske': ('runologisk',),
'runologiskere': ('runologisk',),
'runologiskest': ('runologisk',),
'runologiskeste': ('runologisk',),
'rural': ('rural',),
'rurale': ('rural',),
'ruralere': ('rural',),
'ruralest': ('rural',),
'ruraleste': ('rural',),
'ruralt': ('rural',),
'rusa': ('ruse',),
'rusede': ('ruse',),
'rusende': ('ruse',),
'ruset': ('ruse',),
'rusete': ('ruse',),
'rusa': ('ruse',),
'rusede': ('ruse',),
'rusende': ('ruse',),
'ruset': ('ruse',),
'rusete': ('ruse',),
'rust': ('ruse',),
'ruste': ('ruse',),
'rusha': ('rushe',),
'rushede': ('rushe',),
'rushende': ('rushe',),
'rushet': ('rushe',),
'rushete': ('rushe',),
'rusk': ('rusk',),
'ruska': ('ruske',),
'ruskede': ('ruske',),
'ruskende': ('ruske',),
'rusket': ('ruske',),
'ruskete': ('ruske',),
'ruska': ('ruske',),
'ruskede': ('ruske',),
'ruskende': ('ruske',),
'rusket': ('ruske',),
'ruskete': ('ruske',),
'rusket': ('rusket',),
'ruskete': ('rusket',),
'rusketere': ('rusket',),
'rusketest': ('rusket',),
'rusketeste': ('rusket',),
'ruskete': ('ruskete',),
'rusla': ('rusle',),
'ruslede': ('rusle',),
'ruslende': ('rusle',),
'ruslet': ('rusle',),
'ruslete': ('rusle',),
'rusla': ('rusle',),
'ruslede': ('rusle',),
'ruslende': ('rusle',),
'ruslet': ('rusle',),
'ruslete': ('rusle',),
'russifiserende': ('russifisere',),
'russifisert': ('russifisere',),
'russifiserte': ('russifisere',),
'russisk': ('russisk',),
'russiske': ('russisk',),
'russiskere': ('russisk',),
'russiskest': ('russisk',),
'russiskeste': ('russisk',),
'rustbehandla': ('rustbehandle',),
'rustbehandlede': ('rustbehandle',),
'rustbehandlende': ('rustbehandle',),
'rustbehandlet': ('rustbehandle',),
'rustbehandlete': ('rustbehandle',),
'rusta': ('ruste',),
'rustede': ('ruste',),
'rustende': ('ruste',),
'rustet': ('ruste',),
'rustete': ('ruste',),
'rusta': ('ruste',),
'rustede': ('ruste',),
'rustende': ('ruste',),
'rustet': ('ruste',),
'rustete': ('ruste',),
'rusten': ('rusten',),
'rustent': ('rusten',),
'rustne': ('rusten',),
'rustnere': ('rusten',),
'rustnest': ('rusten',),
'rustneste': ('rusten',),
'rustfarga': ('rustfarga',),
'rustfargede': ('rustfarget',),
'rustfarget': ('rustfarget',),
'rustfargete': ('rustfarget',),
'rustfargetere': ('rustfarget',),
'rustfargetest': ('rustfarget',),
'rustfargeteste': ('rustfarget',),
'rustifiserende': ('rustifisere',),
'rustifisert': ('rustifisere',),
'rustifiserte': ('rustifisere',),
'rustikk': ('rustikk',),
'rustikke': ('rustikk',),
'rustikkere': ('rustikk',),
'rustikkest': ('rustikk',),
'rustikkeste': ('rustikk',),
'rustikt': ('rustikk',),
'rustna': ('rustne',),
'rustnede': ('rustne',),
'rustnende': ('rustne',),
'rustnet': ('rustne',),
'rustnete': ('rustne',),
'rustrød': ('rustrød',),
'rustrøde': ('rustrød',),
'rustrødere': ('rustrød',),
'rustrødest': ('rustrød',),
'rustrødeste': ('rustrød',),
'rustrødt': ('rustrød',),
'ruta': ('rute',),
'rutede': ('rute',),
'rutende': ('rute',),
'rutet': ('rute',),
'rutete': ('rute',),
'rutegående': ('rutegående',),
'rutet': ('rutet',),
'rutete': ('rutet',),
'rutetere': ('rutet',),
'rutetest': ('rutet',),
'ruteteste': ('rutet',),
'rutete': ('rutete',),
'rutinert': ('rutinert',),
'rutinerte': ('rutinert',),
'rutinertere': ('rutinert',),
'rutinertest': ('rutinert',),
'rutinerteste': ('rutinert',),
'rutla': ('rutle',),
'rutlede': ('rutle',),
'rutlende': ('rutle',),
'rutlet': ('rutle',),
'rutlete': ('rutle',),
'rutsja': ('rutsje',),
'rutsjede': ('rutsje',),
'rutsjende': ('rutsje',),
'rutsjet': ('rutsje',),
'rutsjete': ('rutsje',),
'rutta': ('rutte',),
'ruttede': ('rutte',),
'ruttende': ('rutte',),
'ruttet': ('rutte',),
'ruttete': ('rutte',),
'ruva': ('ruve',),
'ruvd': ('ruve',),
'ruvde': ('ruve',),
'ruvede': ('ruve',),
'ruvende': ('ruve',),
'ruvet': ('ruve',),
'ruvete': ('ruve',),
'rwandisk': ('rwandisk',),
'rwandiske': ('rwandisk',),
'rwandiskere': ('rwandisk',),
'rwandiskest': ('rwandisk',),
'rwandiskeste': ('rwandisk',),
'rydd': ('ry',),
'rydde': ('ry',),
'ryende': ('ry',),
'rydda': ('rydde',),
'ryddede': ('rydde',),
'ryddende': ('rydde',),
'ryddet': ('rydde',),
'ryddete': ('rydde',),
'ryddig': ('ryddig',),
'ryddige': ('ryddig',),
'ryddigere': ('ryddig',),
'ryddigst': ('ryddig',),
'ryddigste': ('ryddig',),
'rygga': ('rygge',),
'ryggede': ('rygge',),
'ryggende': ('rygge',),
'rygget': ('rygge',),
'ryggete': ('rygge',),
'ryggesløs': ('ryggesløs',),
'ryggesløse': ('ryggesløs',),
'ryggesløsere': ('ryggesløs',),
'ryggesløsest': ('ryggesløs',),
'ryggesløseste': ('ryggesløs',),
'ryggesløst': ('ryggesløs',),
'rykende': ('ryke',),
'røken': ('ryke',),
'røket': ('ryke',),
'røkne': ('ryke',),
'rykka': ('rykke',),
'rykkede': ('rykke',),
'rykkende': ('rykke',),
'rykket': ('rykke',),
'rykkete': ('rykke',),
'rykt': ('rykke',),
'rykte': ('rykke',),
'rykket': ('rykket',),
'rykkete': ('rykket',),
'rykketere': ('rykket',),
'rykketest': ('rykket',),
'rykketeste': ('rykket',),
'rykkete': ('rykkete',),
'rynka': ('rynke',),
'rynkede': ('rynke',),
'rynkende': ('rynke',),
'rynket': ('rynke',),
'rynkete': ('rynke',),
'rynket': ('rynket',),
'rynkete': ('rynket',),
'rynketere': ('rynket',),
'rynketest': ('rynket',),
'rynketeste': ('rynket',),
'rynkete': ('rynkete',),
'ryr': ('ryr',),
'ryre': ('ryr',),
'ryrere': ('ryr',),
'ryrest': ('ryr',),
'ryreste': ('ryr',),
'ryrt': ('ryr',),
'rysta': ('ryste',),
'rystede': ('ryste',),
'rystende': ('ryste',),
'rystet': ('ryste',),
'rystete': ('ryste',),
'rystende': ('rystende',),
'rytende': ('ryte',),
'rytt': ('ryte',),
'rytte': ('ryte',),
'rytmisk': ('rytmisk',),
'rytmiske': ('rytmisk',),
'rytmiskere': ('rytmisk',),
'rytmiskest': ('rytmisk',),
'rytmiskeste': ('rytmisk',),
'rådd': ('rå',),
'rådde': ('rå',),
'rående': ('rå',),
'rå': ('rå',),
'råe': ('rå',),
'råere': ('rå',),
'råest': ('rå',),
'råeste': ('rå',),
'rått': ('rå',),
'råbarka': ('råbarka',),
'råbarkede': ('råbarket',),
'råbarket': ('råbarket',),
'råbarkete': ('råbarket',),
'råbarketere': ('råbarket',),
'råbarketest': ('råbarket',),
'råbarketeste': ('råbarket',),
'råda': ('råde',),
'rådd': ('råde',),
'rådde': ('råde',),
'rådede': ('råde',),
'rådende': ('råde',),
'rådet': ('råde',),
'rådete': ('råde',),
'rådelig': ('rådelig',),
'rådelige': ('rådelig',),
'rådeligere': ('rådelig',),
'rådeligst': ('rådelig',),
'rådeligste': ('rådelig',),
'rådførende': ('rådføre',),
'rådført': ('rådføre',),
'rådførte': ('rådføre',),
'rådgivende': ('rådgivende',),
'rådhitne': ('rådhitten',),
'rådhitnere': ('rådhitten',),
'rådhitnest': ('rådhitten',),
'rådhitneste': ('rådhitten',),
'rådhitten': ('rådhitten',),
'rådhittent': ('rådhitten',),
'rådig': ('rådig',),
'rådige': ('rådig',),
'rådigere': ('rådig',),
'rådigst': ('rådig',),
'rådigste': ('rådig',),
'rådlaus': ('rådlaus',),
'rådlause': ('rådlaus',),
'rådlausere': ('rådlaus',),
'rådlausest': ('rådlaus',),
'rådlauseste': ('rådlaus',),
'rådlaust': ('rådlaus',),
'rådlagt': ('rådlegge',),
'rådlagte': ('rådlegge',),
'rådleggende': ('rådlegge',),
'rådløs': ('rådløs',),
'rådløse': ('rådløs',),
'rådløsere': ('rådløs',),
'rådløsest': ('rådløs',),
'rådløseste': ('rådløs',),
'rådløst': ('rådløs',),
'rådsnar': ('rådsnar',),
'rådsnare': ('rådsnar',),
'rådsnarere': ('rådsnar',),
'rådsnarest': ('rådsnar',),
'rådsnareste': ('rådsnar',),
'rådsnart': ('rådsnar',),
'rådspurt': ('rådspørre',),
'rådspurte': ('rådspørre',),
'rådspørrende': ('rådspørre',),
'rådvill': ('rådvill',),
'rådville': ('rådvill',),
'rådvillere': ('rådvill',),
'rådvillest': ('rådvill',),
'rådvilleste': ('rådvill',),
'rådvilt': ('rådvill',),
'råflott': ('råflott',),
'råflotte': ('råflott',),
'råflottere': ('råflott',),
'råflottest': ('råflott',),
'råflotteste': ('råflott',),
'råkald': ('råkald',),
'råkalde': ('råkald',),
'råkaldere': ('råkald',),
'råkaldest': ('råkald',),
'råkaldeste': ('råkald',),
'råkaldt': ('råkald',),
'råka': ('råke',),
'råkede': ('råke',),
'råkende': ('råke',),
'råket': ('råke',),
'råkete': ('råke',),
'råkt': ('råke',),
'råkte': ('råke',),
'råkjørende': ('råkjøre',),
'råkjørt': ('råkjøre',),
'råkjørte': ('råkjøre',),
'råla': ('råle',),
'rålede': ('råle',),
'rålende': ('råle',),
'rålet': ('råle',),
'rålete': ('råle',),
'rålt': ('råle',),
'rålte': ('råle',),
'rålendt': ('rålendt',),
'rålendte': ('rålendt',),
'rålendtere': ('rålendt',),
'rålendtest': ('rålendt',),
'rålendteste': ('rålendt',),
'råmen': ('råmen',),
'råment': ('råmen',),
'råmne': ('råmen',),
'råmnere': ('råmen',),
'råmnest': ('råmen',),
'råmneste': ('råmen',),
'råna': ('råne',),
'rånede': ('råne',),
'rånende': ('råne',),
'rånet': ('råne',),
'rånete': ('råne',),
'rånt': ('råne',),
'rånte': ('råne',),
'råsken': ('råsken',),
'råskent': ('råsken',),
'råskne': ('råsken',),
'råsknere': ('råsken',),
'råsknest': ('råsken',),
'råskneste': ('råsken',),
'råsterk': ('råsterk',),
'råsterke': ('råsterk',),
'råsterkere': ('råsterk',),
'råsterkest': ('råsterk',),
'råsterkeste': ('råsterk',),
'råsterkt': ('råsterk',),
'råtna': ('råtne',),
'råtnede': ('råtne',),
'råtnende': ('råtne',),
'råtnet': ('råtne',),
'råtnete': ('råtne',),
'råtne': ('råtten',),
'råtnere': ('råtten',),
'råtnest': ('råtten',),
'råtneste': ('råtten',),
'råtten': ('råtten',),
'råttent': ('råtten',),
'rød': ('rød',),
'røde': ('rød',),
'rødere': ('rød',),
'rødest': ('rød',),
'rødeste': ('rød',),
'rødt': ('rød',),
'rødd': ('røde',),
'rødde': ('røde',),
'rødende': ('røde',),
'rødglødende': ('rødglødende',),
'rødlig': ('rødlig',),
'rødlige': ('rødlig',),
'rødligere': ('rødlig',),
'rødligst': ('rødlig',),
'rødligste': ('rødlig',),
'rødma': ('rødme',),
'rødmede': ('rødme',),
'rødmende': ('rødme',),
'rødmet': ('rødme',),
'rødmete': ('rødme',),
'rødmussa': ('rødmussa',),
'rødmussede': ('rødmusset',),
'rødmusset': ('rødmusset',),
'rødmussete': ('rødmusset',),
'rødmussetere': ('rødmusset',),
'rødmussetest': ('rødmusset',),
'rødmusseteste': ('rødmusset',),
'rødna': ('rødne',),
'rødnede': ('rødne',),
'rødnende': ('rødne',),
'rødnet': ('rødne',),
'rødnete': ('rødne',),
'rødsprengt': ('rødsprengt',),
'rødsprengte': ('rødsprengt',),
'rødsprengtere': ('rødsprengt',),
'rødsprengtest': ('rødsprengt',),
'rødsprengteste': ('rødsprengt',),
'rødøyd': ('rødøyd',),
'rødøyde': ('rødøyd',),
'rødøydere': ('rødøyd',),
'rødøydest': ('rødøyd',),
'rødøydeste': ('rødøyd',),
'røff': ('røff',),
'røffe': ('røff',),
'røffere': ('røff',),
'røffest': ('røff',),
'røffeste': ('røff',),
'røft': ('røff',),
'røfla': ('røfle',),
'røflede': ('røfle',),
'røflende': ('røfle',),
'røflet': ('røfle',),
'røflete': ('røfle',),
'røklagt': ('røklegge',),
'røklagte': ('røklegge',),
'røkleggende': ('røklegge',),
'røkta': ('røkte',),
'røktede': ('røkte',),
'røktende': ('røkte',),
'røktet': ('røkte',),
'røktete': ('røkte',),
'rølende': ('røle',),
'rølt': ('røle',),
'rølte': ('røle',),
'rølpet': ('rølpet',),
'rølpete': ('rølpet',),
'rølpetere': ('rølpet',),
'rølpetest': ('rølpet',),
'rølpeteste': ('rølpet',),
'rølpete': ('rølpete',),
'røntgenfotograferende': ('røntgenfotografere',),
'røntgenfotografert': ('røntgenfotografere',),
'røntgenfotograferte': ('røntgenfotografere',),
'røpa': ('røpe',),
'røpede': ('røpe',),
'røpende': ('røpe',),
'røpet': ('røpe',),
'røpete': ('røpe',),
'røpt': ('røpe',),
'røpte': ('røpe',),
'rørende': ('røre',),
'rørt': ('røre',),
'rørte': ('røre',),
'rørende': ('rørende',),
'røret': ('røret',),
'rørete': ('røret',),
'røretere': ('røret',),
'røretest': ('røret',),
'røreteste': ('røret',),
'rørete': ('rørete',),
'rørig': ('rørig',),
'rørige': ('rørig',),
'rørigere': ('rørig',),
'rørigst': ('rørig',),
'rørigste': ('rørig',),
'rørlig': ('rørlig',),
'rørlige': ('rørlig',),
'rørligere': ('rørlig',),
'rørligst': ('rørlig',),
'rørligste': ('rørlig',),
'røska': ('røske',),
'røskede': ('røske',),
'røskende': ('røske',),
'røsket': ('røske',),
'røskete': ('røske',),
'røslig': ('røslig',),
'røslige': ('røslig',),
'røsligere': ('røslig',),
'røsligst': ('røslig',),
'røsligste': ('røslig',),
'røsta': ('røste',),
'røstede': ('røste',),
'røstende': ('røste',),
'røstet': ('røste',),
'røstete': ('røste',),
'røva': ('røve',),
'røvd': ('røve',),
'røvde': ('røve',),
'røvede': ('røve',),
'røvende': ('røve',),
'røvet': ('røve',),
'røvete': ('røve',),
'røyka': ('røyke',),
'røykede': ('røyke',),
'røykende': ('røyke',),
'røyket': ('røyke',),
'røykete': ('røyke',),
'røykt': ('røyke',),
'røykte': ('røyke',),
'røyklagt': ('røyklegge',),
'røyklagte': ('røyklegge',),
'røykleggende': ('røyklegge',),
'røyna': ('røyne',),
'røynede': ('røyne',),
'røynende': ('røyne',),
'røynet': ('røyne',),
'røynete': ('røyne',),
'røynt': ('røyne',),
'røynte': ('røyne',),
'røysa': ('røyse',),
'røysede': ('røyse',),
'røysende': ('røyse',),
'røyset': ('røyse',),
'røysete': ('røyse',),
'røyst': ('røyse',),
'røyste': ('røyse',),
'røyset': ('røyset',),
'røysete': ('røyset',),
'røysetere': ('røyset',),
'røysetest': ('røyset',),
'røyseteste': ('røyset',),
'røysete': ('røysete',),
'røyta': ('røyte',),
'røytede': ('røyte',),
'røytende': ('røyte',),
'røytet': ('røyte',),
'røytete': ('røyte',),
'røytt': ('røyte',),
'røytte': ('røyte',),
'sabba': ('sabbe',),
'sabbede': ('sabbe',),
'sabbende': ('sabbe',),
'sabbet': ('sabbe',),
'sabbete': ('sabbe',),
'sabbet': ('sabbet',),
'sabbete': ('sabbet',),
'sabbetere': ('sabbet',),
'sabbetest': ('sabbet',),
'sabbeteste': ('sabbet',),
'sabbete': ('sabbete',),
'sabla': ('sabla',),
'sabla': ('sable',),
'sablede': ('sable',),
'sablende': ('sable',),
'sablet': ('sable',),
'sablete': ('sable',),
'saboterende': ('sabotere',),
'sabotert': ('sabotere',),
'saboterte': ('sabotere',),
'sadistisk': ('sadistisk',),
'sadistiske': ('sadistisk',),
'sadistiskere': ('sadistisk',),
'sadistiskest': ('sadistisk',),
'sadistiskeste': ('sadistisk',),
'sadla': ('sadle',),
'sadlede': ('sadle',),
'sadlende': ('sadle',),
'sadlet': ('sadle',),
'sadlete': ('sadle',),
'sadomasochistisk': ('sadomasochistisk',),
'sadomasochistiske': ('sadomasochistisk',),
'sadomasochistiskere': ('sadomasochistisk',),
'sadomasochistiskest': ('sadomasochistisk',),
'sadomasochistiskeste': ('sadomasochistisk',),
'safa': ('safe',),
'safede': ('safe',),
'safende': ('safe',),
'safet': ('safe',),
'safete': ('safe',),
'safe': ('safe',),
'safirblå': ('safirblå',),
'safirblåe': ('safirblå',),
'safirblåere': ('safirblå',),
'safirblåest': ('safirblå',),
'safirblåeste': ('safirblå',),
'safirblått': ('safirblå',),
'safrangul': ('safrangul',),
'safrangule': ('safrangul',),
'safrangulere': ('safrangul',),
'safrangulest': ('safrangul',),
'safranguleste': ('safrangul',),
'safrangult': ('safrangul',),
'safta': ('safte',),
'saftede': ('safte',),
'saftende': ('safte',),
'saftet': ('safte',),
'saftete': ('safte',),
'saftfull': ('saftfull',),
'saftfulle': ('saftfull',),
'saftfullere': ('saftfull',),
'saftfullest': ('saftfull',),
'saftfulleste': ('saftfull',),
'saftfullt': ('saftfull',),
'saftig': ('saftig',),
'saftige': ('saftig',),
'saftigere': ('saftig',),
'saftigst': ('saftig',),
'saftigste': ('saftig',),
'saftspent': ('saftspent',),
'saftspente': ('saftspent',),
'saftspentere': ('saftspent',),
'saftspentest': ('saftspent',),
'saftspenteste': ('saftspent',),
'saga': ('sage',),
'sagd': ('sage',),
'sagde': ('sage',),
'sagede': ('sage',),
'sagende': ('sage',),
'saget': ('sage',),
'sagete': ('sage',),
'sagnomsust': ('sagnomsust',),
'sagnomsuste': ('sagnomsust',),
'sagnomsustere': ('sagnomsust',),
'sagnomsustest': ('sagnomsust',),
'sagnomsusteste': ('sagnomsust',),
'sagtagga': ('sagtagga',),
'sagtaggede': ('sagtagget',),
'sagtagget': ('sagtagget',),
'sagtaggete': ('sagtagget',),
'sagtaggetere': ('sagtagget',),
'sagtaggetest': ('sagtagget',),
'sagtaggeteste': ('sagtagget',),
'sagtent': ('sagtent',),
'sagtente': ('sagtent',),
'sagtentere': ('sagtent',),
'sagtentest': ('sagtent',),
'sagtenteste': ('sagtent',),
'saka': ('sake',),
'sakede': ('sake',),
'sakende': ('sake',),
'saket': ('sake',),
'sakete': ('sake',),
'saka': ('sake',),
'sakede': ('sake',),
'sakende': ('sake',),
'saket': ('sake',),
'sakete': ('sake',),
'sakesløs': ('sakesløs',),
'sakesløse': ('sakesløs',),
'sakesløsere': ('sakesløs',),
'sakesløsest': ('sakesløs',),
'sakesløseste': ('sakesløs',),
'sakesløst': ('sakesløs',),
'sakfellende': ('sakfelle',),
'sakfelt': ('sakfelle',),
'sakfelte': ('sakfelle',),
'sakka': ('sakke',),
'sakkede': ('sakke',),
'sakkende': ('sakke',),
'sakket': ('sakke',),
'sakkete': ('sakke',),
'sakkyndig': ('sakkyndig',),
'sakkyndige': ('sakkyndig',),
'sakkyndigere': ('sakkyndig',),
'sakkyndigst': ('sakkyndig',),
'sakkyndigste': ('sakkyndig',),
'saklig': ('saklig',),
'saklige': ('saklig',),
'sakligere': ('saklig',),
'sakligst': ('saklig',),
'sakligste': ('saklig',),
'sakna': ('sakne',),
'saknede': ('sakne',),
'saknende': ('sakne',),
'saknet': ('sakne',),
'saknete': ('sakne',),
'sakral': ('sakral',),
'sakrale': ('sakral',),
'sakralere': ('sakral',),
'sakralest': ('sakral',),
'sakraleste': ('sakral',),
'sakralt': ('sakral',),
'sakramental': ('sakramental',),
'sakramentale': ('sakramental',),
'sakramentalere': ('sakramental',),
'sakramentalest': ('sakramental',),
'sakramentaleste': ('sakramental',),
'sakramentalt': ('sakramental',),
'sakrosankt': ('sakrosankt',),
'sakrosankte': ('sakrosankt',),
'sakrosanktere': ('sakrosankt',),
'sakrosanktest': ('sakrosankt',),
'sakrosankteste': ('sakrosankt',),
'saksa': ('sakse',),
'saksede': ('sakse',),
'saksende': ('sakse',),
'sakset': ('sakse',),
'saksete': ('sakse',),
'saksisk': ('saksisk',),
'saksiske': ('saksisk',),
'saksiskere': ('saksisk',),
'saksiskest': ('saksisk',),
'saksiskeste': ('saksisk',),
'saksøkende': ('saksøke',),
'saksøkt': ('saksøke',),
'saksøkte': ('saksøke',),
'sakta': ('sakte',),
'saktede': ('sakte',),
'saktende': ('sakte',),
'saktet': ('sakte',),
'saktete': ('sakte',),
'sakte': ('sakte',),
'saktere': ('sakte',),
'saktest': ('sakte',),
'sakteste': ('sakte',),
'saktmodig': ('saktmodig',),
'saktmodige': ('saktmodig',),
'saktmodigere': ('saktmodig',),
'saktmodigst': ('saktmodig',),
'saktmodigste': ('saktmodig',),
'saktna': ('saktne',),
'saktnede': ('saktne',),
'saktnende': ('saktne',),
'saktnet': ('saktne',),
'saktnete': ('saktne',),
'salderende': ('saldere',),
'saldert': ('saldere',),
'salderte': ('saldere',),
'sala': ('sale',),
'salede': ('sale',),
'salende': ('sale',),
'salet': ('sale',),
'salete': ('sale',),
'salt': ('sale',),
'salte': ('sale',),
'salet': ('salet',),
'salete': ('salet',),
'saletere': ('salet',),
'saletest': ('salet',),
'saleteste': ('salet',),
'salete': ('salete',),
'salgbar': ('salgbar',),
'salgbare': ('salgbar',),
'salgbarere': ('salgbar',),
'salgbarest': ('salgbar',),
'salgbareste': ('salgbar',),
'salgbart': ('salgbar',),
'salig': ('salig',),
'salige': ('salig',),
'saligere': ('salig',),
'saligst': ('salig',),
'saligste': ('salig',),
'saliggjørende': ('saliggjørende',),
'salomonisk': ('salomonisk',),
'salomoniske': ('salomonisk',),
'salomoniskere': ('salomonisk',),
'salomoniskest': ('salomonisk',),
'salomoniskeste': ('salomonisk',),
'salomonsk': ('salomonsk',),
'salomonske': ('salomonsk',),
'salomonskere': ('salomonsk',),
'salomonskest': ('salomonsk',),
'salomonskeste': ('salomonsk',),
'salongfähig': ('salongfähig',),
'salongfähige': ('salongfähig',),
'salongfähigere': ('salongfähig',),
'salongfähigst': ('salongfähig',),
'salongfähigste': ('salongfähig',),
'salongradikal': ('salongradikal',),
'salongradikale': ('salongradikal',),
'salongradikalere': ('salongradikal',),
'salongradikalest': ('salongradikal',),
'salongradikaleste': ('salongradikal',),
'salongradikalt': ('salongradikal',),
'salrygga': ('salrygga',),
'salryggede': ('salrygget',),
'salrygget': ('salrygget',),
'salryggete': ('salrygget',),
'salryggetere': ('salrygget',),
'salryggetest': ('salrygget',),
'salryggeteste': ('salrygget',),
'salt': ('salt',),
'salte': ('salt',),
'saltere': ('salt',),
'saltest': ('salt',),
'salteste': ('salt',),
'salta': ('salte',),
'saltede': ('salte',),
'saltende': ('salte',),
'saltet': ('salte',),
'saltete': ('salte',),
'saltholdig': ('saltholdig',),
'saltholdige': ('saltholdig',),
'saltholdigere': ('saltholdig',),
'saltholdigst': ('saltholdig',),
'saltholdigste': ('saltholdig',),
'saltsprengt': ('saltsprengt',),
'saltsprengte': ('saltsprengt',),
'saltsprengtere': ('saltsprengt',),
'saltsprengtest': ('saltsprengt',),
'saltsprengteste': ('saltsprengt',),
'salutterende': ('saluttere',),
'saluttert': ('saluttere',),
'salutterte': ('saluttere',),
'salvadoransk': ('salvadoransk',),
'salvadoranske': ('salvadoransk',),
'salvadoranskere': ('salvadoransk',),
'salvadoranskest': ('salvadoransk',),
'salvadoranskeste': ('salvadoransk',),
'salva': ('salve',),
'salvede': ('salve',),
'salvende': ('salve',),
'salvet': ('salve',),
'salvete': ('salve',),
'salvelsesfull': ('salvelsesfull',),
'salvelsesfulle': ('salvelsesfull',),
'salvelsesfullere': ('salvelsesfull',),
'salvelsesfullest': ('salvelsesfull',),
'salvelsesfulleste': ('salvelsesfull',),
'salvelsesfullt': ('salvelsesfull',),
'samarbeida': ('samarbeide',),
'samarbeidd': ('samarbeide',),
'samarbeidde': ('samarbeide',),
'samarbeidede': ('samarbeide',),
'samarbeidende': ('samarbeide',),
'samarbeidet': ('samarbeide',),
'samarbeidete': ('samarbeide',),
'samaritansk': ('samaritansk',),
'samaritanske': ('samaritansk',),
'samaritanskere': ('samaritansk',),
'samaritanskest': ('samaritansk',),
'samaritanskeste': ('samaritansk',),
'sambeita': ('sambeite',),
'sambeitede': ('sambeite',),
'sambeitende': ('sambeite',),
'sambeitet': ('sambeite',),
'sambeitete': ('sambeite',),
'sambeitt': ('sambeite',),
'sambeitte': ('sambeite',),
'sambo': ('sambo',),
'samboende': ('samboende',),
'sambu': ('sambu',),
'sambuende': ('sambuende',),
'samd': ('samd',),
'samde': ('samd',),
'samdere': ('samd',),
'samdest': ('samd',),
'samdeste': ('samd',),
'samdrektig': ('samdrektig',),
'samdrektige': ('samdrektig',),
'samdrektigere': ('samdrektig',),
'samdrektigst': ('samdrektig',),
'samdrektigste': ('samdrektig',),
'sameksisterende': ('sameksistere',),
'sameksistert': ('sameksistere',),
'sameksisterte': ('sameksistere',),
'samfengt': ('samfengt',),
'samfull': ('samfull',),
'samfulle': ('samfull',),
'samfullere': ('samfull',),
'samfullest': ('samfull',),
'samfulleste': ('samfull',),
'samfullt': ('samfull',),
'samfunnsbevarende': ('samfunnsbevarende',),
'samfunnsfaglig': ('samfunnsfaglig',),
'samfunnsfaglige': ('samfunnsfaglig',),
'samfunnsfagligere': ('samfunnsfaglig',),
'samfunnsfagligst': ('samfunnsfaglig',),
'samfunnsfagligste': ('samfunnsfaglig',),
'samfunnsgagnlig': ('samfunnsgagnlig',),
'samfunnsgagnlige': ('samfunnsgagnlig',),
'samfunnsgagnligere': ('samfunnsgagnlig',),
'samfunnsgagnligst': ('samfunnsgagnlig',),
'samfunnsgagnligste': ('samfunnsgagnlig',),
'samhørig': ('samhørig',),
'samhørige': ('samhørig',),
'samhørigere': ('samhørig',),
'samhørigst': ('samhørig',),
'samhørigste': ('samhørig',),
'samisk': ('samisk',),
'samiske': ('samisk',),
'samiskere': ('samisk',),
'samiskest': ('samisk',),
'samiskeste': ('samisk',),
'samkjørbar': ('samkjørbar',),
'samkjørbare': ('samkjørbar',),
'samkjørbarere': ('samkjørbar',),
'samkjørbarest': ('samkjørbar',),
'samkjørbareste': ('samkjørbar',),
'samkjørbart': ('samkjørbar',),
'samkjørende': ('samkjøre',),
'samkjørt': ('samkjøre',),
'samkjørte': ('samkjøre',),
'samla': ('samle',),
'samlede': ('samle',),
'samlende': ('samle',),
'samlet': ('samle',),
'samlete': ('samle',),
'sammalt': ('sammalt',),
'sammalte': ('sammalt',),
'sammaltere': ('sammalt',),
'sammaltest': ('sammalt',),
'sammalteste': ('sammalt',),
'sammenbitt': ('sammenbitt',),
'sammenbitte': ('sammenbitt',),
'sammenbittere': ('sammenbitt',),
'sammenbittest': ('sammenbitt',),
'sammenbitteste': ('sammenbitt',),
'sammenfallende': ('sammenfallende',),
'sammenfatta': ('sammenfatte',),
'sammenfattede': ('sammenfatte',),
'sammenfattende': ('sammenfatte',),
'sammenfattet': ('sammenfatte',),
'sammenfattete': ('sammenfatte',),
'sammengrodd': ('sammengrodd',),
'sammengrodde': ('sammengrodd',),
'sammengroddere': ('sammengrodd',),
'sammengroddest': ('sammengrodd',),
'sammengroddeste': ('sammengrodd',),
'sammenhengende': ('sammenhengende',),
'sammenholdende': ('sammenholde',),
'sammenholdt': ('sammenholde',),
'sammenholdte': ('sammenholde',),
'sammenkallende': ('sammenkalle',),
'sammenkalt': ('sammenkalle',),
'sammenkalte': ('sammenkalle',),
'sammenklemt': ('sammenklemt',),
'sammenklemte': ('sammenklemt',),
'sammenklemtere': ('sammenklemt',),
'sammenklemtest': ('sammenklemt',),
'sammenklemteste': ('sammenklemt',),
'sammenknuga': ('sammenknuga',),
'sammenknugede': ('sammenknuget',),
'sammenknuget': ('sammenknuget',),
'sammenknugete': ('sammenknuget',),
'sammenknugetere': ('sammenknuget',),
'sammenknugetest': ('sammenknuget',),
'sammenknugeteste': ('sammenknuget',),
'sammenkrøkt': ('sammenkrøkt',),
'sammenkrøkte': ('sammenkrøkt',),
'sammenkrøktere': ('sammenkrøkt',),
'sammenkrøktest': ('sammenkrøkt',),
'sammenkrøkteste': ('sammenkrøkt',),
'sammenkrøpet': ('sammenkrøpet',),
'sammenkrøpne': ('sammenkrøpet',),
'sammenkrøpnere': ('sammenkrøpet',),
'sammenkrøpnest': ('sammenkrøpet',),
'sammenkrøpneste': ('sammenkrøpet',),
'sammenlagt': ('sammenlagt',),
'sammenlagte': ('sammenlagt',),
'sammenlagtere': ('sammenlagt',),
'sammenlagtest': ('sammenlagt',),
'sammenlagteste': ('sammenlagt',),
'sammenleggbar': ('sammenleggbar',),
'sammenleggbare': ('sammenleggbar',),
'sammenleggbarere': ('sammenleggbar',),
'sammenleggbarest': ('sammenleggbar',),
'sammenleggbareste': ('sammenleggbar',),
'sammenleggbart': ('sammenleggbar',),
'sammenlignbar': ('sammenlignbar',),
'sammenlignbare': ('sammenlignbar',),
'sammenlignbarere': ('sammenlignbar',),
'sammenlignbarest': ('sammenlignbar',),
'sammenlignbareste': ('sammenlignbar',),
'sammenlignbart': ('sammenlignbar',),
'sammenligna': ('sammenligne',),
'sammenlignede': ('sammenligne',),
'sammenlignende': ('sammenligne',),
'sammenlignet': ('sammenligne',),
'sammenlignete': ('sammenligne',),
'sammenliknbar': ('sammenliknbar',),
'sammenliknbare': ('sammenliknbar',),
'sammenliknbarere': ('sammenliknbar',),
'sammenliknbarest': ('sammenliknbar',),
'sammenliknbareste': ('sammenliknbar',),
'sammenliknbart': ('sammenliknbar',),
'sammenlikna': ('sammenlikne',),
'sammenliknede': ('sammenlikne',),
'sammenliknende': ('sammenlikne',),
'sammenliknet': ('sammenlikne',),
'sammenliknete': ('sammenlikne',),
'sammenpakka': ('sammenpakka',),
'sammenpakkede': ('sammenpakket',),
'sammenpakket': ('sammenpakket',),
'sammenpakkete': ('sammenpakket',),
'sammenpakketere': ('sammenpakket',),
'sammenpakketest': ('sammenpakket',),
'sammenpakketeste': ('sammenpakket',),
'sammensatt': ('sammensatt',),
'sammensatte': ('sammensatt',),
'sammensattere': ('sammensatt',),
'sammensattest': ('sammensatt',),
'sammensatteste': ('sammensatt',),
'sammenskrevet': ('sammenskrevet',),
'sammenskrevne': ('sammenskrevet',),
'sammenskrevnere': ('sammenskrevet',),
'sammenskrevnest': ('sammenskrevet',),
'sammenskrevneste': ('sammenskrevet',),
'sammenskrumpa': ('sammenskrumpa',),
'sammenskrumpede': ('sammenskrumpet',),
'sammenskrumpet': ('sammenskrumpet',),
'sammenskrumpete': ('sammenskrumpet',),
'sammenskrumpetere': ('sammenskrumpet',),
'sammenskrumpetest': ('sammenskrumpet',),
'sammenskrumpeteste': ('sammenskrumpet',),
'sammenskutt': ('sammenskutt',),
'sammenskutte': ('sammenskutt',),
'sammenskuttere': ('sammenskutt',),
'sammenskuttest': ('sammenskutt',),
'sammenskutteste': ('sammenskutt',),
'sammenstillende': ('sammenstille',),
'sammenstilt': ('sammenstille',),
'sammenstilte': ('sammenstille',),
'sammensveisa': ('sammensveisa',),
'sammensveisede': ('sammensveiset',),
'sammensveiset': ('sammensveiset',),
'sammensveisete': ('sammensveiset',),
'sammensveisetere': ('sammensveiset',),
'sammensveisetest': ('sammensveiset',),
'sammensveiseteste': ('sammensveiset',),
'sammensveist': ('sammensveist',),
'sammensveiste': ('sammensveist',),
'sammensveistere': ('sammensveist',),
'sammensveistest': ('sammensveist',),
'sammensveisteste': ('sammensveist',),
'sammensverga': ('sammensverge',),
'sammensvergede': ('sammensverge',),
'sammensvergende': ('sammensverge',),
'sammensverget': ('sammensverge',),
'sammensvergete': ('sammensverge',),
'sammensvoren': ('sammensverge',),
'sammensvoret': ('sammensverge',),
'sammensvorne': ('sammensverge',),
'sammensverja': ('sammensverje',),
'sammensverjede': ('sammensverje',),
'sammensverjende': ('sammensverje',),
'sammensverjet': ('sammensverje',),
'sammensverjete': ('sammensverje',),
'sammensvoren': ('sammensverje',),
'sammensvoret': ('sammensverje',),
'sammensvorne': ('sammensverje',),
'sammensvoren': ('sammensvoren',),
'sammensvorent': ('sammensvoren',),
'sammensvorne': ('sammensvoren',),
'sammensvornere': ('sammensvoren',),
'sammensvornest': ('sammensvoren',),
'sammensvorneste': ('sammensvoren',),
'sammentrengt': ('sammentrengt',),
'sammentrengte': ('sammentrengt',),
'sammentrengtere': ('sammentrengt',),
'sammentrengtest': ('sammentrengt',),
'sammentrengteste': ('sammentrengt',),
'sammentømra': ('sammentømra',),
'sammentømrede': ('sammentømret',),
'sammentømret': ('sammentømret',),
'sammentømrete': ('sammentømret',),
'sammentømretere': ('sammentømret',),
'sammentømretest': ('sammentømret',),
'sammentømreteste': ('sammentømret',),
'sammenvokst': ('sammenvokst',),
'sammenvokste': ('sammenvokst',),
'sammenvokstere': ('sammenvokst',),
'sammenvokstest': ('sammenvokst',),
'sammenvoksteste': ('sammenvokst',),
'samnordisk': ('samnordisk',),
'samnordiske': ('samnordisk',),
'samnordiskere': ('samnordisk',),
'samnordiskest': ('samnordisk',),
'samnordiskeste': ('samnordisk',),
'samnorsk': ('samnorsk',),
'samnorske': ('samnorsk',),
'samnorskere': ('samnorsk',),
'samnorskest': ('samnorsk',),
'samnorskeste': ('samnorsk',),
'samoansk': ('samoansk',),
'samoanske': ('samoansk',),
'samoanskere': ('samoansk',),
'samoanskest': ('samoansk',),
'samoanskeste': ('samoansk',),
'samojedisk': ('samojedisk',),
'samojediske': ('samojedisk',),
'samojediskere': ('samojedisk',),
'samojediskest': ('samojedisk',),
'samojediskeste': ('samojedisk',),
'samordna': ('samordne',),
'samordnede': ('samordne',),
'samordnende': ('samordne',),
'samordnet': ('samordne',),
'samordnete': ('samordne',),
'sampla': ('sample',),
'samplede': ('sample',),
'samplende': ('sample',),
'samplet': ('sample',),
'samplete': ('sample',),
'samrådd': ('samrå',),
'samrådde': ('samrå',),
'samrående': ('samrå',),
'sams': ('sams',),
'samsa': ('samse',),
'samsede': ('samse',),
'samsende': ('samse',),
'samset': ('samse',),
'samsete': ('samse',),
'samspelt': ('samspelt',),
'samspelte': ('samspelt',),
'samspeltere': ('samspelt',),
'samspeltest': ('samspelt',),
'samspelteste': ('samspelt',),
'samspilt': ('samspilt',),
'samspilte': ('samspilt',),
'samspiltere': ('samspilt',),
'samspiltest': ('samspilt',),
'samspilteste': ('samspilt',),
'samstava': ('samstave',),
'samstavede': ('samstave',),
'samstavende': ('samstave',),
'samstavet': ('samstave',),
'samstavete': ('samstave',),
'samstemmende': ('samstemme',),
'samstemt': ('samstemme',),
'samstemte': ('samstemme',),
'samstemmig': ('samstemmig',),
'samstemmige': ('samstemmig',),
'samstemmigere': ('samstemmig',),
'samstemmigst': ('samstemmig',),
'samstemmigste': ('samstemmig',),
'samsvarende': ('samsvarende',),
'samtala': ('samtale',),
'samtalende': ('samtale',),
'samtalt': ('samtale',),
'samtalte': ('samtale',),
'samtidig': ('samtidig',),
'samtidige': ('samtidig',),
'samtidigere': ('samtidig',),
'samtidigst': ('samtidig',),
'samtidigste': ('samtidig',),
'samtykka': ('samtykke',),
'samtykkede': ('samtykke',),
'samtykkende': ('samtykke',),
'samtykket': ('samtykke',),
'samtykkete': ('samtykke',),
'samtykt': ('samtykke',),
'samtykte': ('samtykke',),
'samvettsfull': ('samvettsfull',),
'samvettsfulle': ('samvettsfull',),
'samvettsfullere': ('samvettsfull',),
'samvettsfullest': ('samvettsfull',),
'samvettsfulleste': ('samvettsfull',),
'samvettsfullt': ('samvettsfull',),
'samvettslaus': ('samvettslaus',),
'samvettslause': ('samvettslaus',),
'samvettslausere': ('samvettslaus',),
'samvettslausest': ('samvettslaus',),
'samvettslauseste': ('samvettslaus',),
'samvettslaust': ('samvettslaus',),
'samvettsløs': ('samvettsløs',),
'samvettsløse': ('samvettsløs',),
'samvettsløsere': ('samvettsløs',),
'samvettsløsest': ('samvettsløs',),
'samvettsløseste': ('samvettsløs',),
'samvettsløst': ('samvettsløs',),
'samvirka': ('samvirke',),
'samvirkede': ('samvirke',),
'samvirkende': ('samvirke',),
'samvirket': ('samvirke',),
'samvirkete': ('samvirke',),
'samvittighetsfull': ('samvittighetsfull',),
'samvittighetsfulle': ('samvittighetsfull',),
'samvittighetsfullere': ('samvittighetsfull',),
'samvittighetsfullest': ('samvittighetsfull',),
'samvittighetsfulleste': ('samvittighetsfull',),
'samvittighetsfullt': ('samvittighetsfull',),
'samvittighetslaus': ('samvittighetslaus',),
'samvittighetslause': ('samvittighetslaus',),
'samvittighetslausere': ('samvittighetslaus',),
'samvittighetslausest': ('samvittighetslaus',),
'samvittighetslauseste': ('samvittighetslaus',),
'samvittighetslaust': ('samvittighetslaus',),
'samvittighetsløs': ('samvittighetsløs',),
'samvittighetsløse': ('samvittighetsløs',),
'samvittighetsløsere': ('samvittighetsløs',),
'samvittighetsløsest': ('samvittighetsløs',),
'samvittighetsløseste': ('samvittighetsløs',),
'samvittighetsløst': ('samvittighetsløs',),
'sandblåsende': ('sandblåse',),
'sandblåst': ('sandblåse',),
'sandblåste': ('sandblåse',),
'sandet': ('sandet',),
'sandete': ('sandet',),
'sandetere': ('sandet',),
'sandetest': ('sandet',),
'sandeteste': ('sandet',),
'sandete': ('sandete',),
'sandinistisk': ('sandinistisk',),
'sandinistiske': ('sandinistisk',),
'sandinistiskere': ('sandinistisk',),
'sandinistiskest': ('sandinistisk',),
'sandinistiskeste': ('sandinistisk',),
'sanerende': ('sanere',),
'sanert': ('sanere',),
'sanerte': ('sanere',),
'saneringsmoden': ('saneringsmoden',),
'saneringsmodent': ('saneringsmoden',),
'saneringsmodne': ('saneringsmoden',),
'saneringsmodnere': ('saneringsmoden',),
'saneringsmodnest': ('saneringsmoden',),
'saneringsmodneste': ('saneringsmoden',),
'sanforiserende': ('sanforisere',),
'sanforisert': ('sanforisere',),
'sanforiserte': ('sanforisere',),
'sangbar': ('sangbar',),
'sangbare': ('sangbar',),
'sangbarere': ('sangbar',),
'sangbarest': ('sangbar',),
'sangbareste': ('sangbar',),
'sangbart': ('sangbar',),
'sanglig': ('sanglig',),
'sanglige': ('sanglig',),
'sangligere': ('sanglig',),
'sangligst': ('sanglig',),
'sangligste': ('sanglig',),
'sangra': ('sangre',),
'sangrede': ('sangre',),
'sangrende': ('sangre',),
'sangret': ('sangre',),
'sangrete': ('sangre',),
'sangvinsk': ('sangvinsk',),
'sangvinske': ('sangvinsk',),
'sangvinskere': ('sangvinsk',),
'sangvinskest': ('sangvinsk',),
'sangvinskeste': ('sangvinsk',),
'sanitær': ('sanitær',),
'sanitære': ('sanitær',),
'sanitærere': ('sanitær',),
'sanitærest': ('sanitær',),
'sanitæreste': ('sanitær',),
'sanitært': ('sanitær',),
'sanka': ('sanke',),
'sankede': ('sanke',),
'sankende': ('sanke',),
'sanket': ('sanke',),
'sankete': ('sanke',),
'sanksjonerende': ('sanksjonere',),
'sanksjonert': ('sanksjonere',),
'sanksjonerte': ('sanksjonere',),
'sankt': ('sankt',),
'sankta': ('sankta',),
'sanmarinsk': ('sanmarinsk',),
'sanmarinske': ('sanmarinsk',),
'sanmarinskere': ('sanmarinsk',),
'sanmarinskest': ('sanmarinsk',),
'sanmarinskeste': ('sanmarinsk',),
'sann': ('sann',),
'sanne': ('sann',),
'sannere': ('sann',),
'sannest': ('sann',),
'sanneste': ('sann',),
'sant': ('sann',),
'sanndru': ('sanndru',),
'sanndrue': ('sanndru',),
'sanndruere': ('sanndru',),
'sanndruest': ('sanndru',),
'sanndrueste': ('sanndru',),
'sanndrømt': ('sanndrømt',),
'sanndrømte': ('sanndrømt',),
'sanndrømtere': ('sanndrømt',),
'sanndrømtest': ('sanndrømt',),
'sanndrømteste': ('sanndrømt',),
'sanna': ('sanne',),
'sannede': ('sanne',),
'sannende': ('sanne',),
'sannet': ('sanne',),
'sannete': ('sanne',),
'sannferdig': ('sannferdig',),
'sannferdige': ('sannferdig',),
'sannferdigere': ('sannferdig',),
'sannferdigst': ('sannferdig',),
'sannferdigste': ('sannferdig',),
'sannhetskjærlig': ('sannhetskjærlig',),
'sannhetskjærlige': ('sannhetskjærlig',),
'sannhetskjærligere': ('sannhetskjærlig',),
'sannhetskjærligst': ('sannhetskjærlig',),
'sannhetskjærligste': ('sannhetskjærlig',),
'sanningskjær': ('sanningskjær',),
'sanningskjære': ('sanningskjær',),
'sanningskjærere': ('sanningskjær',),
'sanningskjærest': ('sanningskjær',),
'sanningskjæreste': ('sanningskjær',),
'sanningskjært': ('sanningskjær',),
'sannspådd': ('sannspådd',),
'sannspådde': ('sannspådd',),
'sannspåddere': ('sannspådd',),
'sannspåddest': ('sannspådd',),
'sannspåddeste': ('sannspådd',),
'sannsynlig': ('sannsynlig',),
'sannsynlige': ('sannsynlig',),
'sannsynligere': ('sannsynlig',),
'sannsynligst': ('sannsynlig',),
'sannsynligste': ('sannsynlig',),
'sannsynliggjort': ('sannsynliggjøre',),
'sannsynliggjorte': ('sannsynliggjøre',),
'sannsynliggjørende': ('sannsynliggjøre',),
'sansbar': ('sansbar',),
'sansbare': ('sansbar',),
'sansbarere': ('sansbar',),
'sansbarest': ('sansbar',),
'sansbareste': ('sansbar',),
'sansbart': ('sansbar',),
'sansa': ('sanse',),
'sansede': ('sanse',),
'sansende': ('sanse',),
'sanset': ('sanse',),
'sansete': ('sanse',),
'sanselaus': ('sanselaus',),
'sanselause': ('sanselaus',),
'sanselausere': ('sanselaus',),
'sanselausest': ('sanselaus',),
'sanselauseste': ('sanselaus',),
'sanselaust': ('sanselaus',),
'sanselig': ('sanselig',),
'sanselige': ('sanselig',),
'sanseligere': ('sanselig',),
'sanseligst': ('sanselig',),
'sanseligste': ('sanselig',),
'sanseløs': ('sanseløs',),
'sanseløse': ('sanseløs',),
'sanseløsere': ('sanseløs',),
'sanseløsest': ('sanseløs',),
'sanseløseste': ('sanseløs',),
'sanseløst': ('sanseløs',),
'sarasensk': ('sarasensk',),
'sarasenske': ('sarasensk',),
'sarasenskere': ('sarasensk',),
'sarasenskest': ('sarasensk',),
'sarasenskeste': ('sarasensk',),
'sardinsk': ('sardinsk',),
'sardinske': ('sardinsk',),
'sardinskere': ('sardinsk',),
'sardinskest': ('sardinsk',),
'sardinskeste': ('sardinsk',),
'sardonisk': ('sardonisk',),
'sardoniske': ('sardonisk',),
'sardoniskere': ('sardonisk',),
'sardoniskest': ('sardonisk',),
'sardoniskeste': ('sardonisk',),
'sarkastisk': ('sarkastisk',),
'sarkastiske': ('sarkastisk',),
'sarkastiskere': ('sarkastisk',),
'sarkastiskest': ('sarkastisk',),
'sarkastiskeste': ('sarkastisk',),
'sart': ('sart',),
'sarte': ('sart',),
'sartere': ('sart',),
'sartest': ('sart',),
'sarteste': ('sart',),
'satanisk': ('satanisk',),
'sataniske': ('satanisk',),
'sataniskere': ('satanisk',),
'sataniskest': ('satanisk',),
'sataniskeste': ('satanisk',),
'satans': ('satans',),
'satansk': ('satansk',),
'satanske': ('satansk',),
'satanskere': ('satansk',),
'satanskest': ('satansk',),
'satanskeste': ('satansk',),
'satinerende': ('satinere',),
'satinert': ('satinere',),
'satinerte': ('satinere',),
'satiriserende': ('satirisere',),
'satirisert': ('satirisere',),
'satiriserte': ('satirisere',),
'satirisk': ('satirisk',),
'satiriske': ('satirisk',),
'satiriskere': ('satirisk',),
'satiriskest': ('satirisk',),
'satiriskeste': ('satirisk',),
'satisfiserende': ('satisfisere',),
'satisfisert': ('satisfisere',),
'satisfiserte': ('satisfisere',),
'satsa': ('satse',),
'satsede': ('satse',),
'satsende': ('satse',),
'satset': ('satse',),
'satsete': ('satse',),
'satt': ('satt',),
'satte': ('satt',),
'sattere': ('satt',),
'sattest': ('satt',),
'satteste': ('satt',),
'saudiarabisk': ('saudiarabisk',),
'saudiarabiske': ('saudiarabisk',),
'saudiarabiskere': ('saudiarabisk',),
'saudiarabiskest': ('saudiarabisk',),
'saudiarabiskeste': ('saudiarabisk',),
'saudisk': ('saudisk',),
'saudiske': ('saudisk',),
'saudiskere': ('saudisk',),
'saudiskest': ('saudisk',),
'saudiskeste': ('saudisk',),
'saumfarende': ('saumfare',),
'saumfart': ('saumfare',),
'saumfarte': ('saumfare',),
'sausa': ('sause',),
'sausede': ('sause',),
'sausende': ('sause',),
'sauset': ('sause',),
'sausete': ('sause',),
'sauset': ('sauset',),
'sausete': ('sauset',),
'sausetere': ('sauset',),
'sausetest': ('sauset',),
'sauseteste': ('sauset',),
'sausete': ('sausete',),
'savla': ('savle',),
'savlede': ('savle',),
'savlende': ('savle',),
'savlet': ('savle',),
'savlete': ('savle',),
'savna': ('savne',),
'savnede': ('savne',),
'savnende': ('savne',),
'savnet': ('savne',),
'savnete': ('savne',),
'scenevant': ('scenevant',),
'scenevante': ('scenevant',),
'scenevantere': ('scenevant',),
'scenevantest': ('scenevant',),
'scenevanteste': ('scenevant',),
'scenisk': ('scenisk',),
'sceniske': ('scenisk',),
'sceniskere': ('scenisk',),
'sceniskest': ('scenisk',),
'sceniskeste': ('scenisk',),
'schizofren': ('schizofren',),
'schizofrene': ('schizofren',),
'schizofrenere': ('schizofren',),
'schizofrenest': ('schizofren',),
'schizofreneste': ('schizofren',),
'schizofrent': ('schizofren',),
'scientologisk': ('scientologisk',),
'scientologiske': ('scientologisk',),
'scientologiskere': ('scientologisk',),
'scientologiskest': ('scientologisk',),
'scientologiskeste': ('scientologisk',),
'scora': ('score',),
'scorede': ('score',),
'scorende': ('score',),
'scoret': ('score',),
'scorete': ('score',),
'scripta': ('scripte',),
'scriptede': ('scripte',),
'scriptende': ('scripte',),
'scriptet': ('scripte',),
'scriptete': ('scripte',),
'seende': ('se',),
'sett': ('se',),
'sette': ('se',),
'sebrastripet': ('sebrastripet',),
'sebrastripete': ('sebrastripet',),
'sebrastripetere': ('sebrastripet',),
'sebrastripetest': ('sebrastripet',),
'sebrastripeteste': ('sebrastripet',),
'sebrastripete': ('sebrastripete',),
'sec': ('sec',),
'sedat': ('sedat',),
'sedate': ('sedat',),
'sedatere': ('sedat',),
'sedatest': ('sedat',),
'sedateste': ('sedat',),
'sedativ': ('sedativ',),
'sedative': ('sedativ',),
'sedativere': ('sedativ',),
'sedativest': ('sedativ',),
'sedativeste': ('sedativ',),
'sedativt': ('sedativ',),
'sedelig': ('sedelig',),
'sedelige': ('sedelig',),
'sedeligere': ('sedelig',),
'sedeligst': ('sedelig',),
'sedeligste': ('sedelig',),
'sedimenterende': ('sedimentere',),
'sedimentert': ('sedimentere',),
'sedimenterte': ('sedimentere',),
'sedimentær': ('sedimentær',),
'sedimentære': ('sedimentær',),
'sedimentærere': ('sedimentær',),
'sedimentærest': ('sedimentær',),
'sedimentæreste': ('sedimentær',),
'sedimentært': ('sedimentær',),
'sedlaus': ('sedlaus',),
'sedlause': ('sedlaus',),
'sedlausere': ('sedlaus',),
'sedlausest': ('sedlaus',),
'sedlauseste': ('sedlaus',),
'sedlaust': ('sedlaus',),
'sedløs': ('sedløs',),
'sedløse': ('sedløs',),
'sedløsere': ('sedløs',),
'sedløsest': ('sedløs',),
'sedløseste': ('sedløs',),
'sedløst': ('sedløs',),
'sedvanlig': ('sedvanlig',),
'sedvanlige': ('sedvanlig',),
'sedvanligere': ('sedvanlig',),
'sedvanligst': ('sedvanlig',),
'sedvanligste': ('sedvanlig',),
'seeda': ('seede',),
'seedede': ('seede',),
'seedende': ('seede',),
'seedet': ('seede',),
'seedete': ('seede',),
'sefardisk': ('sefardisk',),
'sefardiske': ('sefardisk',),
'sefardiskere': ('sefardisk',),
'sefardiskest': ('sefardisk',),
'sefardiskeste': ('sefardisk',),
'seglbar': ('seglbar',),
'seglbare': ('seglbar',),
'seglbarere': ('seglbar',),
'seglbarest': ('seglbar',),
'seglbareste': ('seglbar',),
'seglbart': ('seglbar',),
'segla': ('segle',),
'seglede': ('segle',),
'seglende': ('segle',),
'seglet': ('segle',),
'seglete': ('segle',),
'segmental': ('segmental',),
'segmentale': ('segmental',),
'segmentalere': ('segmental',),
'segmentalest': ('segmental',),
'segmentaleste': ('segmental',),
'segmentalt': ('segmental',),
'segmenterende': ('segmentere',),
'segmentert': ('segmentere',),
'segmenterte': ('segmentere',),
'segna': ('segne',),
'segnede': ('segne',),
'segnende': ('segne',),
'segnet': ('segne',),
'segnete': ('segne',),
'segneferdig': ('segneferdig',),
'segneferdige': ('segneferdig',),
'segneferdigere': ('segneferdig',),
'segneferdigst': ('segneferdig',),
'segneferdigste': ('segneferdig',),
'segregerende': ('segregere',),
'segregert': ('segregere',),
'segregerte': ('segregere',),
'seida': ('seide',),
'seidede': ('seide',),
'seidende': ('seide',),
'seidet': ('seide',),
'seidete': ('seide',),
'seierrik': ('seierrik',),
'seierrike': ('seierrik',),
'seierrikere': ('seierrik',),
'seierrikest': ('seierrik',),
'seierrikeste': ('seierrik',),
'seierrikt': ('seierrik',),
'seierssikker': ('seierssikker',),
'seierssikkert': ('seierssikker',),
'seierssikre': ('seierssikker',),
'seierssikrere': ('seierssikker',),
'seierssikrest': ('seierssikker',),
'seierssikreste': ('seierssikker',),
'seiersvant': ('seiersvant',),
'seiersvante': ('seiersvant',),
'seiersvantere': ('seiersvant',),
'seiersvantest': ('seiersvant',),
'seiersvanteste': ('seiersvant',),
'seiersæl': ('seiersæl',),
'seiersæle': ('seiersæl',),
'seiersælere': ('seiersæl',),
'seiersælest': ('seiersæl',),
'seiersæleste': ('seiersæl',),
'seiersælt': ('seiersæl',),
'seig': ('seig',),
'seige': ('seig',),
'seigere': ('seig',),
'seigest': ('seig',),
'seigeste': ('seig',),
'seigt': ('seig',),
'seigliva': ('seigliva',),
'seiglivede': ('seiglivet',),
'seiglivet': ('seiglivet',),
'seiglivete': ('seiglivet',),
'seiglivetere': ('seiglivet',),
'seiglivetest': ('seiglivet',),
'seigliveteste': ('seiglivet',),
'seigpinende': ('seigpine',),
'seigpint': ('seigpine',),
'seigpinte': ('seigpine',),
'seilbar': ('seilbar',),
'seilbare': ('seilbar',),
'seilbarere': ('seilbar',),
'seilbarest': ('seilbar',),
'seilbareste': ('seilbar',),
'seilbart': ('seilbar',),
'sein': ('sein',),
'seine': ('sein',),
'seinere': ('sein',),
'seinest': ('sein',),
'seineste': ('sein',),
'seint': ('sein',),
'seinbær': ('seinbær',),
'seinbære': ('seinbær',),
'seinbærere': ('seinbær',),
'seinbærest': ('seinbær',),
'seinbæreste': ('seinbær',),
'seinbært': ('seinbær',),
'seindrektig': ('seindrektig',),
'seindrektige': ('seindrektig',),
'seindrektigere': ('seindrektig',),
'seindrektigst': ('seindrektig',),
'seindrektigste': ('seindrektig',),
'seinferdig': ('seinferdig',),
'seinferdige': ('seinferdig',),
'seinferdigere': ('seinferdig',),
'seinferdigst': ('seinferdig',),
'seinferdigste': ('seinferdig',),
'seinkapitalistisk': ('seinkapitalistisk',),
'seinkapitalistiske': ('seinkapitalistisk',),
'seinkapitalistiskere': ('seinkapitalistisk',),
'seinkapitalistiskest': ('seinkapitalistisk',),
'seinkapitalistiskeste': ('seinkapitalistisk',),
'seinka': ('seinke',),
'seinkede': ('seinke',),
'seinkende': ('seinke',),
'seinket': ('seinke',),
'seinkete': ('seinke',),
'seinka': ('seinke',),
'seinkede': ('seinke',),
'seinkende': ('seinke',),
'seinket': ('seinke',),
'seinkete': ('seinke',),
'seipa': ('seipe',),
'seipede': ('seipe',),
'seipende': ('seipe',),
'seipet': ('seipe',),
'seipete': ('seipe',),
'seira': ('seire',),
'seirede': ('seire',),
'seirende': ('seire',),
'seiret': ('seire',),
'seirete': ('seire',),
'seisa': ('seise',),
'seisede': ('seise',),
'seisende': ('seise',),
'seiset': ('seise',),
'seisete': ('seise',),
'seist': ('seise',),
'seiste': ('seise',),
'seismisk': ('seismisk',),
'seismiske': ('seismisk',),
'seismiskere': ('seismisk',),
'seismiskest': ('seismisk',),
'seismiskeste': ('seismisk',),
'seismografisk': ('seismografisk',),
'seismografiske': ('seismografisk',),
'seismografiskere': ('seismografisk',),
'seismografiskest': ('seismografisk',),
'seismografiskeste': ('seismografisk',),
'seismologisk': ('seismologisk',),
'seismologiske': ('seismologisk',),
'seismologiskere': ('seismologisk',),
'seismologiskest': ('seismologisk',),
'seismologiskeste': ('seismologisk',),
'sekkforma': ('sekkforma',),
'sekkformede': ('sekkformet',),
'sekkformet': ('sekkformet',),
'sekkformete': ('sekkformet',),
'sekkformetere': ('sekkformet',),
'sekkformetest': ('sekkformet',),
'sekkformeteste': ('sekkformet',),
'sekretorisk': ('sekretorisk',),
'sekretoriske': ('sekretorisk',),
'sekretoriskere': ('sekretorisk',),
'sekretoriskest': ('sekretorisk',),
'sekretoriskeste': ('sekretorisk',),
'seksdobbel': ('seksdobbel',),
'seksdobbelt': ('seksdobbel',),
'seksdoble': ('seksdobbel',),
'seksdoblere': ('seksdobbel',),
'seksdoblest': ('seksdobbel',),
'seksdobleste': ('seksdobbel',),
'seksdobla': ('seksdoble',),
'seksdoblede': ('seksdoble',),
'seksdoblende': ('seksdoble',),
'seksdoblet': ('seksdoble',),
'seksdoblete': ('seksdoble',),
'seksjonerende': ('seksjonere',),
'seksjonert': ('seksjonere',),
'seksjonerte': ('seksjonere',),
'sekskanta': ('sekskanta',),
'sekskantede': ('sekskantet',),
'sekskantet': ('sekskantet',),
'sekskantete': ('sekskantet',),
'sekskantetere': ('sekskantet',),
'sekskantetest': ('sekskantet',),
'sekskanteteste': ('sekskantet',),
'seksrada': ('seksrada',),
'seksradede': ('seksradet',),
'seksradet': ('seksradet',),
'seksradete': ('seksradet',),
'seksradetere': ('seksradet',),
'seksradetest': ('seksradet',),
'seksradeteste': ('seksradet',),
'sekstende': ('sekstende',),
'sekstenårig': ('sekstenårig',),
'sekstenårige': ('sekstenårig',),
'sekstenårigere': ('sekstenårig',),
'sekstenårigst': ('sekstenårig',),
'sekstenårigste': ('sekstenårig',),
'sekstenårs': ('sekstenårs',),
'sekstiende': ('sekstiende',),
'sekstiårig': ('sekstiårig',),
'sekstiårige': ('sekstiårig',),
'sekstiårigere': ('sekstiårig',),
'sekstiårigst': ('sekstiårig',),
'sekstiårigste': ('sekstiårig',),
'seksuell': ('seksuell',),
'seksuelle': ('seksuell',),
'seksuellere': ('seksuell',),
'seksuellest': ('seksuell',),
'seksuelleste': ('seksuell',),
'seksuelt': ('seksuell',),
'seksårig': ('seksårig',),
'seksårige': ('seksårig',),
'seksårigere': ('seksårig',),
'seksårigst': ('seksårig',),
'seksårigste': ('seksårig',),
'seksårs': ('seksårs',),
'sekterisk': ('sekterisk',),
'sekteriske': ('sekterisk',),
'sekteriskere': ('sekterisk',),
'sekteriskest': ('sekterisk',),
'sekteriskeste': ('sekterisk',),
'sektoriell': ('sektoriell',),
'sektorielle': ('sektoriell',),
'sektoriellere': ('sektoriell',),
'sektoriellest': ('sektoriell',),
'sektorielleste': ('sektoriell',),
'sektorielt': ('sektoriell',),
'sekulargeistlig': ('sekulargeistlig',),
'sekulargeistlige': ('sekulargeistlig',),
'sekulargeistligere': ('sekulargeistlig',),
'sekulargeistligst': ('sekulargeistlig',),
'sekulargeistligste': ('sekulargeistlig',),
'sekulariserende': ('sekularisere',),
'sekularisert': ('sekularisere',),
'sekulariserte': ('sekularisere',),
'sekulær': ('sekulær',),
'sekulære': ('sekulær',),
'sekulærere': ('sekulær',),
'sekulærest': ('sekulær',),
'sekulæreste': ('sekulær',),
'sekulært': ('sekulær',),
'sekunda': ('sekunda',),
'sekunderende': ('sekundere',),
'sekundert': ('sekundere',),
'sekunderte': ('sekundere',),
'sekundær': ('sekundær',),
'sekundære': ('sekundær',),
'sekundærere': ('sekundær',),
'sekundærest': ('sekundær',),
'sekundæreste': ('sekundær',),
'sekundært': ('sekundær',),
'sekvensiell': ('sekvensiell',),
'sekvensielle': ('sekvensiell',),
'sekvensiellere': ('sekvensiell',),
'sekvensiellest': ('sekvensiell',),
'sekvensielleste': ('sekvensiell',),
'sekvensielt': ('sekvensiell',),
'sela': ('sele',),
'selende': ('sele',),
'selt': ('sele',),
'selte': ('sele',),
'selekterende': ('selektere',),
'selektert': ('selektere',),
'selekterte': ('selektere',),
'selektiv': ('selektiv',),
'selektive': ('selektiv',),
'selektivere': ('selektiv',),
'selektivest': ('selektiv',),
'selektiveste': ('selektiv',),
'selektivt': ('selektiv',),
'selfmade': ('selfmade',),
'selgende': ('selge',),
'solgt': ('selge',),
'solgte': ('selge',),
'selgelig': ('selgelig',),
'selgelige': ('selgelig',),
'selgeligere': ('selgelig',),
'selgeligst': ('selgelig',),
'selgeligste': ('selgelig',),
'selotisk': ('selotisk',),
'selotiske': ('selotisk',),
'selotiskere': ('selotisk',),
'selotiskest': ('selotisk',),
'selotiskeste': ('selotisk',),
'selskapelig': ('selskapelig',),
'selskapelige': ('selskapelig',),
'selskapeligere': ('selskapelig',),
'selskapeligst': ('selskapelig',),
'selskapeligste': ('selskapelig',),
'selskapssjuk': ('selskapssjuk',),
'selskapssjuke': ('selskapssjuk',),
'selskapssjukere': ('selskapssjuk',),
'selskapssjukest': ('selskapssjuk',),
'selskapssjukeste': ('selskapssjuk',),
'selskapssjukt': ('selskapssjuk',),
'selskapssyk': ('selskapssyk',),
'selskapssyke': ('selskapssyk',),
'selskapssykere': ('selskapssyk',),
'selskapssykest': ('selskapssyk',),
'selskapssykeste': ('selskapssyk',),
'selskapssykt': ('selskapssyk',),
'selsom': ('selsom',),
'selsomme': ('selsom',),
'selsommere': ('selsom',),
'selsomst': ('selsom',),
'selsomste': ('selsom',),
'selsomt': ('selsom',),
'selvbedt': ('selvbedt',),
'selvbedte': ('selvbedt',),
'selvbedtere': ('selvbedt',),
'selvbedtest': ('selvbedt',),
'selvbedteste': ('selvbedt',),
'selvbehagelig': ('selvbehagelig',),
'selvbehagelige': ('selvbehagelig',),
'selvbehageligere': ('selvbehagelig',),
'selvbehageligst': ('selvbehagelig',),
'selvbehageligste': ('selvbehagelig',),
'selvbekjennende': ('selvbekjennende',),
'selvberga': ('selvberga',),
'selvbergede': ('selvberget',),
'selvberget': ('selvberget',),
'selvbergete': ('selvberget',),
'selvbergetere': ('selvberget',),
'selvbergetest': ('selvberget',),
'selvbergeteste': ('selvberget',),
'selvbestalta': ('selvbestalta',),
'selvbestaltede': ('selvbestaltet',),
'selvbestaltet': ('selvbestaltet',),
'selvbestaltete': ('selvbestaltet',),
'selvbestaltetere': ('selvbestaltet',),
'selvbestaltetest': ('selvbestaltet',),
'selvbestalteteste': ('selvbestaltet',),
'selvbestemt': ('selvbestemt',),
'selvbestemte': ('selvbestemt',),
'selvbestemtere': ('selvbestemt',),
'selvbestemtest': ('selvbestemt',),
'selvbestemteste': ('selvbestemt',),
'selvbevisst': ('selvbevisst',),
'selvbevisste': ('selvbevisst',),
'selvbevisstere': ('selvbevisst',),
'selvbevisstest': ('selvbevisst',),
'selvbevissteste': ('selvbevisst',),
'selvbiografisk': ('selvbiografisk',),
'selvbiografiske': ('selvbiografisk',),
'selvbiografiskere': ('selvbiografisk',),
'selvbiografiskest': ('selvbiografisk',),
'selvbiografiskeste': ('selvbiografisk',),
'selvbuden': ('selvbuden',),
'selvbudent': ('selvbuden',),
'selvbudne': ('selvbuden',),
'selvbudnere': ('selvbuden',),
'selvbudnest': ('selvbuden',),
'selvbudneste': ('selvbuden',),
'selvbærende': ('selvbærende',),
'selvdaud': ('selvdaud',),
'selvdaude': ('selvdaud',),
'selvdaudere': ('selvdaud',),
'selvdaudest': ('selvdaud',),
'selvdaudeste': ('selvdaud',),
'selvdaudt': ('selvdaud',),
'selvdød': ('selvdød',),
'selvdøde': ('selvdød',),
'selvdødere': ('selvdød',),
'selvdødest': ('selvdød',),
'selvdødeste': ('selvdød',),
'selvdødt': ('selvdød',),
'selveiende': ('selveiende',),
'selververvende': ('selververvende',),
'selvfinansierende': ('selvfinansierende',),
'selvforglemmende': ('selvforglemmende',),
'selvforskyldt': ('selvforskyldt',),
'selvforskyldte': ('selvforskyldt',),
'selvforskyldtere': ('selvforskyldt',),
'selvforskyldtest': ('selvforskyldt',),
'selvforskyldteste': ('selvforskyldt',),
'selvforsynt': ('selvforsynt',),
'selvforsynte': ('selvforsynt',),
'selvforsyntere': ('selvforsynt',),
'selvforsyntest': ('selvforsynt',),
'selvforsynteste': ('selvforsynt',),
'selvfølgelig': ('selvfølgelig',),
'selvfølgelige': ('selvfølgelig',),
'selvfølgeligere': ('selvfølgelig',),
'selvfølgeligst': ('selvfølgelig',),
'selvfølgeligste': ('selvfølgelig',),
'selvgjort': ('selvgjort',),
'selvgjorte': ('selvgjort',),
'selvgjortere': ('selvgjort',),
'selvgjortest': ('selvgjort',),
'selvgjorteste': ('selvgjort',),
'selvbedre': ('selvgod',),
'selvbest': ('selvgod',),
'selvbeste': ('selvgod',),
'selvgod': ('selvgod',),
'selvgode': ('selvgod',),
'selvgodt': ('selvgod',),
'selvgående': ('selvgående',),
'selvhjulpen': ('selvhjulpen',),
'selvhjulpent': ('selvhjulpen',),
'selvhjulpne': ('selvhjulpen',),
'selvhjulpnere': ('selvhjulpen',),
'selvhjulpnest': ('selvhjulpen',),
'selvhjulpneste': ('selvhjulpen',),
'selvinnlysende': ('selvinnlysende',),
'selvironisk': ('selvironisk',),
'selvironiske': ('selvironisk',),
'selvironiskere': ('selvironisk',),
'selvironiskest': ('selvironisk',),
'selvironiskeste': ('selvironisk',),
'selvisk': ('selvisk',),
'selviske': ('selvisk',),
'selviskere': ('selvisk',),
'selviskest': ('selvisk',),
'selviskeste': ('selvisk',),
'selvklar': ('selvklar',),
'selvklare': ('selvklar',),
'selvklarere': ('selvklar',),
'selvklarest': ('selvklar',),
'selvklareste': ('selvklar',),
'selvklart': ('selvklar',),
'selvklok': ('selvklok',),
'selvkloke': ('selvklok',),
'selvklokere': ('selvklok',),
'selvklokest': ('selvklok',),
'selvklokeste': ('selvklok',),
'selvklokt': ('selvklok',),
'selvkostende': ('selvkostende',),
'selvkostende': ('selvkostende',),
'selvkostende': ('selvkostende',),
'selvkritisk': ('selvkritisk',),
'selvkritiske': ('selvkritisk',),
'selvkritiskere': ('selvkritisk',),
'selvkritiskest': ('selvkritisk',),
'selvkritiskeste': ('selvkritisk',),
'selvlaga': ('selvlaga',),
'selvlagd': ('selvlagd',),
'selvlagde': ('selvlagd',),
'selvlagdere': ('selvlagd',),
'selvlagdest': ('selvlagd',),
'selvlagdeste': ('selvlagd',),
'selvlagede': ('selvlaget',),
'selvlaget': ('selvlaget',),
'selvlagete': ('selvlaget',),
'selvlagetere': ('selvlaget',),
'selvlagetest': ('selvlaget',),
'selvlageteste': ('selvlaget',),
'selvlysende': ('selvlysende',),
'selvlært': ('selvlært',),
'selvlærte': ('selvlært',),
'selvlærtere': ('selvlært',),
'selvlærtest': ('selvlært',),
'selvlærteste': ('selvlært',),
'selvmedlidende': ('selvmedlidende',),
'selvmorderisk': ('selvmorderisk',),
'selvmorderiske': ('selvmorderisk',),
'selvmorderiskere': ('selvmorderisk',),
'selvmorderiskest': ('selvmorderisk',),
'selvmorderiskeste': ('selvmorderisk',),
'selvmordersk': ('selvmordersk',),
'selvmorderske': ('selvmordersk',),
'selvmorderskere': ('selvmordersk',),
'selvmorderskest': ('selvmordersk',),
'selvmorderskeste': ('selvmordersk',),
'selvmotsigende': ('selvmotsigende',),
'selvopplevd': ('selvopplevd',),
'selvopplevde': ('selvopplevd',),
'selvopplevdere': ('selvopplevd',),
'selvopplevdest': ('selvopplevd',),
'selvopplevdeste': ('selvopplevd',),
'selvoppofrende': ('selvoppofrende',),
'selvopptatt': ('selvopptatt',),
'selvopptatte': ('selvopptatt',),
'selvopptattere': ('selvopptatt',),
'selvopptattest': ('selvopptatt',),
'selvopptatteste': ('selvopptatt',),
'selvregulerende': ('selvregulerende',),
'selvrensende': ('selvrensende',),
'selvrådig': ('selvrådig',),
'selvrådige': ('selvrådig',),
'selvrådigere': ('selvrådig',),
'selvrådigst': ('selvrådig',),
'selvrådigste': ('selvrådig',),
'selvsagt': ('selvsagt',),
'selvsagte': ('selvsagt',),
'selvsagtere': ('selvsagt',),
'selvsagtest': ('selvsagt',),
'selvsagteste': ('selvsagt',),
'selvsamme': ('selvsamme',),
'selvsikker': ('selvsikker',),
'selvsikkert': ('selvsikker',),
'selvsikre': ('selvsikker',),
'selvsikrere': ('selvsikker',),
'selvsikrest': ('selvsikker',),
'selvsikreste': ('selvsikker',),
'selvskreven': ('selvskreven',),
'selvskrevent': ('selvskreven',),
'selvskrevne': ('selvskreven',),
'selvskrevnere': ('selvskreven',),
'selvskrevnest': ('selvskreven',),
'selvskrevneste': ('selvskreven',),
'selvstendig': ('selvstendig',),
'selvstendige': ('selvstendig',),
'selvstendigere': ('selvstendig',),
'selvstendigst': ('selvstendig',),
'selvstendigste': ('selvstendig',),
'selvstendiggjort': ('selvstendiggjøre',),
'selvstendiggjorte': ('selvstendiggjøre',),
'selvstendiggjørende': ('selvstendiggjøre',),
'selvstyrt': ('selvstyrt',),
'selvstyrte': ('selvstyrt',),
'selvstyrtere': ('selvstyrt',),
'selvstyrtest': ('selvstyrt',),
'selvstyrteste': ('selvstyrt',),
'selvtenkende': ('selvtenkende',),
'selvtilfreds': ('selvtilfreds',),
'selvtilfredse': ('selvtilfreds',),
'selvtilfredsere': ('selvtilfreds',),
'selvtilfredsest': ('selvtilfreds',),
'selvtilfredseste': ('selvtilfreds',),
'selvtrimmende': ('selvtrimmende',),
'selvtrygg': ('selvtrygg',),
'selvtrygge': ('selvtrygg',),
'selvtryggere': ('selvtrygg',),
'selvtryggest': ('selvtrygg',),
'selvtryggeste': ('selvtrygg',),
'selvtrygt': ('selvtrygg',),
'selvutslettende': ('selvutslettende',),
'selvvalgt': ('selvvalgt',),
'selvvalgte': ('selvvalgt',),
'selvvalgtere': ('selvvalgt',),
'selvvalgtest': ('selvvalgt',),
'selvvalgteste': ('selvvalgt',),
'selvødeleggende': ('selvødeleggende',),
'semaforerende': ('semaforere',),
'semaforert': ('semaforere',),
'semaforerte': ('semaforere',),
'semantisk': ('semantisk',),
'semantiske': ('semantisk',),
'semantiskere': ('semantisk',),
'semantiskest': ('semantisk',),
'semantiskeste': ('semantisk',),
'semasiologisk': ('semasiologisk',),
'semasiologiske': ('semasiologisk',),
'semasiologiskere': ('semasiologisk',),
'semasiologiskest': ('semasiologisk',),
'semasiologiskeste': ('semasiologisk',),
'sementerende': ('sementere',),
'sementert': ('sementere',),
'sementerte': ('sementere',),
'seminaristisk': ('seminaristisk',),
'seminaristiske': ('seminaristisk',),
'seminaristiskere': ('seminaristisk',),
'seminaristiskest': ('seminaristisk',),
'seminaristiskeste': ('seminaristisk',),
'seminerende': ('seminere',),
'seminert': ('seminere',),
'seminerte': ('seminere',),
'semipermeabel': ('semipermeabel',),
'semipermeabelt': ('semipermeabel',),
'semipermeable': ('semipermeabel',),
'semipermeablere': ('semipermeabel',),
'semipermeablest': ('semipermeabel',),
'semipermeableste': ('semipermeabel',),
'semisubmersibel': ('semisubmersibel',),
'semisubmersibelt': ('semisubmersibel',),
'semisubmersible': ('semisubmersibel',),
'semisubmersiblere': ('semisubmersibel',),
'semisubmersiblest': ('semisubmersibel',),
'semisubmersibleste': ('semisubmersibel',),
'semittisk': ('semittisk',),
'semittiske': ('semittisk',),
'semittiskere': ('semittisk',),
'semittiskest': ('semittisk',),
'semittiskeste': ('semittisk',),
'semittisk-hamittisk': ('semittisk-hamittisk',),
'semittisk-hamittiske': ('semittisk-hamittisk',),
'semittisk-hamittiskere': ('semittisk-hamittisk',),
'semittisk-hamittiskest': ('semittisk-hamittisk',),
'semittisk-hamittiskeste': ('semittisk-hamittisk',),
'semmer': ('semmer',),
'semmert': ('semmer',),
'semre': ('semmer',),
'semrere': ('semmer',),
'semrest': ('semmer',),
'semreste': ('semmer',),
'semsgarva': ('semsgarve',),
'semsgarvede': ('semsgarve',),
'semsgarvende': ('semsgarve',),
'semsgarvet': ('semsgarve',),
'semsgarvete': ('semsgarve',),
'semska': ('semske',),
'semskede': ('semske',),
'semskende': ('semske',),
'semsket': ('semske',),
'semskete': ('semske',),
'semskgarva': ('semskgarve',),
'semskgarvede': ('semskgarve',),
'semskgarvende': ('semskgarve',),
'semskgarvet': ('semskgarve',),
'semskgarvete': ('semskgarve',),
'sen': ('sen',),
'sene': ('sen',),
'senere': ('sen',),
'senest': ('sen',),
'seneste': ('sen',),
'sent': ('sen',),
'senbær': ('senbær',),
'senbære': ('senbær',),
'senbærere': ('senbær',),
'senbærest': ('senbær',),
'senbæreste': ('senbær',),
'senbært': ('senbær',),
'sendende': ('sende',),
'sendt': ('sende',),
'sendte': ('sende',),
'sendrektig': ('sendrektig',),
'sendrektige': ('sendrektig',),
'sendrektigere': ('sendrektig',),
'sendrektigst': ('sendrektig',),
'sendrektigste': ('sendrektig',),
'senegalesisk': ('senegalesisk',),
'senegalesiske': ('senegalesisk',),
'senegalesiskere': ('senegalesisk',),
'senegalesiskest': ('senegalesisk',),
'senegalesiskeste': ('senegalesisk',),
'senesterk': ('senesterk',),
'senesterke': ('senesterk',),
'senesterkere': ('senesterk',),
'senesterkest': ('senesterk',),
'senesterkeste': ('senesterk',),
'senesterkt': ('senesterk',),
'senet': ('senet',),
'senete': ('senet',),
'senetere': ('senet',),
'senetest': ('senet',),
'seneteste': ('senet',),
'senete': ('senete',),
'senferdig': ('senferdig',),
'senferdige': ('senferdig',),
'senferdigere': ('senferdig',),
'senferdigst': ('senferdig',),
'senferdigste': ('senferdig',),
'sengeliggende': ('sengeliggende',),
'senil': ('senil',),
'senile': ('senil',),
'senilere': ('senil',),
'senilest': ('senil',),
'senileste': ('senil',),
'senilt': ('senil',),
'senildement': ('senildement',),
'senildemente': ('senildement',),
'senildementere': ('senildement',),
'senildementest': ('senildement',),
'senildementeste': ('senildement',),
'senior': ('senior',),
'senkapitalistisk': ('senkapitalistisk',),
'senkapitalistiske': ('senkapitalistisk',),
'senkapitalistiskere': ('senkapitalistisk',),
'senkapitalistiskest': ('senkapitalistisk',),
'senkapitalistiskeste': ('senkapitalistisk',),
'senka': ('senke',),
'senkede': ('senke',),
'senkende': ('senke',),
'senket': ('senke',),
'senkete': ('senke',),
'sennepsgul': ('sennepsgul',),
'sennepsgule': ('sennepsgul',),
'sennepsgulere': ('sennepsgul',),
'sennepsgulest': ('sennepsgul',),
'sennepsguleste': ('sennepsgul',),
'sennepsgult': ('sennepsgul',),
'sensasjonell': ('sensasjonell',),
'sensasjonelle': ('sensasjonell',),
'sensasjonellere': ('sensasjonell',),
'sensasjonellest': ('sensasjonell',),
'sensasjonelleste': ('sensasjonell',),
'sensasjonelt': ('sensasjonell',),
'sensibel': ('sensibel',),
'sensibelt': ('sensibel',),
'sensible': ('sensibel',),
'sensiblere': ('sensibel',),
'sensiblest': ('sensibel',),
'sensibleste': ('sensibel',),
'sensitiv': ('sensitiv',),
'sensitive': ('sensitiv',),
'sensitivere': ('sensitiv',),
'sensitivest': ('sensitiv',),
'sensitiveste': ('sensitiv',),
'sensitivt': ('sensitiv',),
'sensorisk': ('sensorisk',),
'sensoriske': ('sensorisk',),
'sensoriskere': ('sensorisk',),
'sensoriskest': ('sensorisk',),
'sensoriskeste': ('sensorisk',),
'sensualistisk': ('sensualistisk',),
'sensualistiske': ('sensualistisk',),
'sensualistiskere': ('sensualistisk',),
'sensualistiskest': ('sensualistisk',),
'sensualistiskeste': ('sensualistisk',),
'sensuell': ('sensuell',),
'sensuelle': ('sensuell',),
'sensuellere': ('sensuell',),
'sensuellest': ('sensuell',),
'sensuelleste': ('sensuell',),
'sensuelt': ('sensuell',),
'sensurerende': ('sensurere',),
'sensurert': ('sensurere',),
'sensurerte': ('sensurere',),
'sentensiøs': ('sentensiøs',),
'sentensiøse': ('sentensiøs',),
'sentensiøsere': ('sentensiøs',),
'sentensiøsest': ('sentensiøs',),
'sentensiøseste': ('sentensiøs',),
'sentensiøst': ('sentensiøs',),
'sentimental': ('sentimental',),
'sentimentale': ('sentimental',),
'sentimentalere': ('sentimental',),
'sentimentalest': ('sentimental',),
'sentimentaleste': ('sentimental',),
'sentimentalt': ('sentimental',),
'sentimentaliserende': ('sentimentalisere',),
'sentimentalisert': ('sentimentalisere',),
'sentimentaliserte': ('sentimentalisere',),
'sentral': ('sentral',),
'sentrale': ('sentral',),
'sentralere': ('sentral',),
'sentralest': ('sentral',),
'sentraleste': ('sentral',),
'sentralt': ('sentral',),
'sentralafrikansk': ('sentralafrikansk',),
'sentralafrikanske': ('sentralafrikansk',),
'sentralafrikanskere': ('sentralafrikansk',),
'sentralafrikanskest': ('sentralafrikansk',),
'sentralafrikanskeste': ('sentralafrikansk',),
'sentraliserende': ('sentralisere',),
'sentralisert': ('sentralisere',),
'sentraliserte': ('sentralisere',),
'sentralistisk': ('sentralistisk',),
'sentralistiske': ('sentralistisk',),
'sentralistiskere': ('sentralistisk',),
'sentralistiskest': ('sentralistisk',),
'sentralistiskeste': ('sentralistisk',),
'sentrallyrisk': ('sentrallyrisk',),
'sentrallyriske': ('sentrallyrisk',),
'sentrallyriskere': ('sentrallyrisk',),
'sentrallyriskest': ('sentrallyrisk',),
'sentrallyriskeste': ('sentrallyrisk',),
'sentra': ('sentre',),
'sentrede': ('sentre',),
'sentrende': ('sentre',),
'sentret': ('sentre',),
'sentrete': ('sentre',),
'sentrerende': ('sentrere',),
'sentrert': ('sentrere',),
'sentrerte': ('sentrere',),
'sentrifugal': ('sentrifugal',),
'sentrifugale': ('sentrifugal',),
'sentrifugalere': ('sentrifugal',),
'sentrifugalest': ('sentrifugal',),
'sentrifugaleste': ('sentrifugal',),
'sentrifugalt': ('sentrifugal',),
'sentrifugerende': ('sentrifugere',),
'sentrifugert': ('sentrifugere',),
'sentrifugerte': ('sentrifugere',),
'sentripetal': ('sentripetal',),
'sentripetale': ('sentripetal',),
'sentripetalere': ('sentripetal',),
'sentripetalest': ('sentripetal',),
'sentripetaleste': ('sentripetal',),
'sentripetalt': ('sentripetal',),
'sentrisk': ('sentrisk',),
'sentriske': ('sentrisk',),
'sentriskere': ('sentrisk',),
'sentriskest': ('sentrisk',),
'sentriskeste': ('sentrisk',),
'separabel': ('separabel',),
'separabelt': ('separabel',),
'separable': ('separabel',),
'separablere': ('separabel',),
'separablest': ('separabel',),
'separableste': ('separabel',),
'separat': ('separat',),
'separate': ('separat',),
'separatere': ('separat',),
'separatest': ('separat',),
'separateste': ('separat',),
'separatistisk': ('separatistisk',),
'separatistiske': ('separatistisk',),
'separatistiskere': ('separatistisk',),
'separatistiskest': ('separatistisk',),
'separatistiskeste': ('separatistisk',),
'separerende': ('separere',),
'separert': ('separere',),
'separerte': ('separere',),
'septisk': ('septisk',),
'septiske': ('septisk',),
'septiskere': ('septisk',),
'septiskest': ('septisk',),
'septiskeste': ('septisk',),
'serafisk': ('serafisk',),
'serafiske': ('serafisk',),
'serafiskere': ('serafisk',),
'serafiskest': ('serafisk',),
'serafiskeste': ('serafisk',),
'serbisk': ('serbisk',),
'serbiske': ('serbisk',),
'serbiskere': ('serbisk',),
'serbiskest': ('serbisk',),
'serbiskeste': ('serbisk',),
'serbokroatisk': ('serbokroatisk',),
'serbokroatiske': ('serbokroatisk',),
'serbokroatiskere': ('serbokroatisk',),
'serbokroatiskest': ('serbokroatisk',),
'serbokroatiskeste': ('serbokroatisk',),
'seremoniell': ('seremoniell',),
'seremonielle': ('seremoniell',),
'seremoniellere': ('seremoniell',),
'seremoniellest': ('seremoniell',),
'seremonielleste': ('seremoniell',),
'seremonielt': ('seremoniell',),
'seriell': ('seriell',),
'serielle': ('seriell',),
'seriellere': ('seriell',),
'seriellest': ('seriell',),
'serielleste': ('seriell',),
'serielt': ('seriell',),
'seriøs': ('seriøs',),
'seriøse': ('seriøs',),
'seriøsere': ('seriøs',),
'seriøsest': ('seriøs',),
'seriøseste': ('seriøs',),
'seriøst': ('seriøs',),
'serraterende': ('serratere',),
'serratert': ('serratere',),
'serraterte': ('serratere',),
'sertifiserende': ('sertifisere',),
'sertifisert': ('sertifisere',),
'sertifiserte': ('sertifisere',),
'serva': ('serve',),
'servede': ('serve',),
'servende': ('serve',),
'servet': ('serve',),
'servete': ('serve',),
'serverende': ('servere',),
'servert': ('servere',),
'serverte': ('servere',),
'servil': ('servil',),
'servile': ('servil',),
'servilere': ('servil',),
'servilest': ('servil',),
'servileste': ('servil',),
'servilt': ('servil',),
'servituttbelagt': ('servituttbelagt',),
'servituttbelagte': ('servituttbelagt',),
'servituttbelagtere': ('servituttbelagt',),
'servituttbelagtest': ('servituttbelagt',),
'servituttbelagteste': ('servituttbelagt',),
'serøs': ('serøs',),
'serøse': ('serøs',),
'serøsere': ('serøs',),
'serøsest': ('serøs',),
'serøseste': ('serøs',),
'serøst': ('serøs',),
'sesongdebuterende': ('sesongdebutere',),
'sesongdebutert': ('sesongdebutere',),
'sesongdebuterte': ('sesongdebutere',),
'sessa': ('sesse',),
'sessede': ('sesse',),
'sessende': ('sesse',),
'sesset': ('sesse',),
'sessete': ('sesse',),
'setesdalsk': ('setesdalsk',),
'setesdalske': ('setesdalsk',),
'setesdalskere': ('setesdalsk',),
'setesdalskest': ('setesdalsk',),
'setesdalskeste': ('setesdalsk',),
'setra': ('setre',),
'setrede': ('setre',),
'setrende': ('setre',),
'setret': ('setre',),
'setrete': ('setre',),
'satt': ('sette',),
'satte': ('sette',),
'settende': ('sette',),
'setteferdig': ('setteferdig',),
'setteferdige': ('setteferdig',),
'setteferdigere': ('setteferdig',),
'setteferdigst': ('setteferdig',),
'setteferdigste': ('setteferdig',),
'settla': ('settle',),
'settlede': ('settle',),
'settlende': ('settle',),
'settlet': ('settle',),
'settlete': ('settle',),
'severdig': ('severdig',),
'severdige': ('severdig',),
'severdigere': ('severdig',),
'severdigst': ('severdig',),
'severdigste': ('severdig',),
'sevjefull': ('sevjefull',),
'sevjefulle': ('sevjefull',),
'sevjefullere': ('sevjefull',),
'sevjefullest': ('sevjefull',),
'sevjefulleste': ('sevjefull',),
'sevjefullt': ('sevjefull',),
'sevjet': ('sevjet',),
'sevjete': ('sevjet',),
'sevjetere': ('sevjet',),
'sevjetest': ('sevjet',),
'sevjeteste': ('sevjet',),
'sevjete': ('sevjete',),
'sexdebuterende': ('sexdebutere',),
'sexdebutert': ('sexdebutere',),
'sexdebuterte': ('sexdebutere',),
'sexologisk': ('sexologisk',),
'sexologiske': ('sexologisk',),
'sexologiskere': ('sexologisk',),
'sexologiskest': ('sexologisk',),
'sexologiskeste': ('sexologisk',),
'sexy': ('sexy',),
'seychellisk': ('seychellisk',),
'seychelliske': ('seychellisk',),
'seychelliskere': ('seychellisk',),
'seychelliskest': ('seychellisk',),
'seychelliskeste': ('seychellisk',),
'sfærisk': ('sfærisk',),
'sfæriske': ('sfærisk',),
'sfæriskere': ('sfærisk',),
'sfæriskest': ('sfærisk',),
'sfæriskeste': ('sfærisk',),
'shabby': ('shabby',),
'shaka': ('shake',),
'shakede': ('shake',),
'shakende': ('shake',),
'shaket': ('shake',),
'shakete': ('shake',),
'shetlandsk': ('shetlandsk',),
'shetlandske': ('shetlandsk',),
'shetlandskere': ('shetlandsk',),
'shetlandskest': ('shetlandsk',),
'shetlandskeste': ('shetlandsk',),
'shintoistisk': ('shintoistisk',),
'shintoistiske': ('shintoistisk',),
'shintoistiskere': ('shintoistisk',),
'shintoistiskest': ('shintoistisk',),
'shintoistiskeste': ('shintoistisk',),
'shoppa': ('shoppe',),
'shoppede': ('shoppe',),
'shoppende': ('shoppe',),
'shoppet': ('shoppe',),
'shoppete': ('shoppe',),
'showa': ('showe',),
'showede': ('showe',),
'showende': ('showe',),
'showet': ('showe',),
'showete': ('showe',),
'shunta': ('shunte',),
'shuntede': ('shunte',),
'shuntende': ('shunte',),
'shuntet': ('shunte',),
'shuntete': ('shunte',),
'sagt': ('si',),
'sagte': ('si',),
'siende': ('si',),
'siamesisk': ('siamesisk',),
'siamesiske': ('siamesisk',),
'siamesiskere': ('siamesisk',),
'siamesiskest': ('siamesisk',),
'siamesiskeste': ('siamesisk',),
'sibirsk': ('sibirsk',),
'sibirske': ('sibirsk',),
'sibirskere': ('sibirsk',),
'sibirskest': ('sibirsk',),
'sibirskeste': ('sibirsk',),
'sibyllinsk': ('sibyllinsk',),
'sibyllinske': ('sibyllinsk',),
'sibyllinskere': ('sibyllinsk',),
'sibyllinskest': ('sibyllinsk',),
'sibyllinskeste': ('sibyllinsk',),
'siciliansk': ('siciliansk',),
'sicilianske': ('siciliansk',),
'sicilianskere': ('siciliansk',),
'sicilianskest': ('siciliansk',),
'sicilianskeste': ('siciliansk',),
'sid': ('sid',),
'side': ('sid',),
'sidere': ('sid',),
'sidest': ('sid',),
'sideste': ('sid',),
'sidt': ('sid',),
'sideordna': ('sideordne',),
'sideordnede': ('sideordne',),
'sideordnende': ('sideordne',),
'sideordnet': ('sideordne',),
'sideordnete': ('sideordne',),
'siderisk': ('siderisk',),
'sideriske': ('siderisk',),
'sideriskere': ('siderisk',),
'sideriskest': ('siderisk',),
'sideriskeste': ('siderisk',),
'sidestillende': ('sidestille',),
'sidestilt': ('sidestille',),
'sidestilte': ('sidestille',),
'sidlendt': ('sidlendt',),
'sidlendte': ('sidlendt',),
'sidlendtere': ('sidlendt',),
'sidlendtest': ('sidlendt',),
'sidlendteste': ('sidlendt',),
'sidrauva': ('sidrauva',),
'sidrikkende': ('sidrikke',),
'sidrukken': ('sidrikke',),
'sidrukket': ('sidrikke',),
'sidrukne': ('sidrikke',),
'sidrumpa': ('sidrumpa',),
'sidrumpede': ('sidrumpet',),
'sidrumpet': ('sidrumpet',),
'sidrumpete': ('sidrumpet',),
'sidrumpetere': ('sidrumpet',),
'sidrumpetest': ('sidrumpet',),
'sidrumpeteste': ('sidrumpet',),
'sierraleonsk': ('sierraleonsk',),
'sierraleonske': ('sierraleonsk',),
'sierraleonskere': ('sierraleonsk',),
'sierraleonskest': ('sierraleonsk',),
'sierraleonskeste': ('sierraleonsk',),
'sifrerende': ('sifrere',),
'sifrert': ('sifrere',),
'sifrerte': ('sifrere',),
'segen': ('sige',),
'seget': ('sige',),
'segne': ('sige',),
'sigende': ('sige',),
'sigen': ('sigen',),
'sigent': ('sigen',),
'signe': ('sigen',),
'signere': ('sigen',),
'signest': ('sigen',),
'signeste': ('sigen',),
'signalerende': ('signalere',),
'signalert': ('signalere',),
'signalerte': ('signalere',),
'signaliserende': ('signalisere',),
'signalisert': ('signalisere',),
'signaliserte': ('signalisere',),
'signalrød': ('signalrød',),
'signalrøde': ('signalrød',),
'signalrødere': ('signalrød',),
'signalrødest': ('signalrød',),
'signalrødeste': ('signalrød',),
'signalrødt': ('signalrød',),
'signa': ('signe',),
'signede': ('signe',),
'signende': ('signe',),
'signet': ('signe',),
'signete': ('signe',),
'signerende': ('signere',),
'signert': ('signere',),
'signerte': ('signere',),
'signifikant': ('signifikant',),
'signifikante': ('signifikant',),
'signifikantere': ('signifikant',),
'signifikantest': ('signifikant',),
'signifikanteste': ('signifikant',),
'signifikativ': ('signifikativ',),
'signifikative': ('signifikativ',),
'signifikativere': ('signifikativ',),
'signifikativest': ('signifikativ',),
'signifikativeste': ('signifikativ',),
'signifikativt': ('signifikativ',),
'sigøynersk': ('sigøynersk',),
'sigøynerske': ('sigøynersk',),
'sigøynerskere': ('sigøynersk',),
'sigøynerskest': ('sigøynersk',),
'sigøynerskeste': ('sigøynersk',),
'sika': ('sike',),
'sikede': ('sike',),
'sikende': ('sike',),
'siket': ('sike',),
'sikete': ('sike',),
'sikker': ('sikker',),
'sikkert': ('sikker',),
'sikre': ('sikker',),
'sikrere': ('sikker',),
'sikrest': ('sikker',),
'sikreste': ('sikker',),
'sikkerhetsklarerende': ('sikkerhetsklarere',),
'sikkerhetsklarert': ('sikkerhetsklarere',),
'sikkerhetsklarerte': ('sikkerhetsklarere',),
'sikkerhetspolitisk': ('sikkerhetspolitisk',),
'sikkerhetspolitiske': ('sikkerhetspolitisk',),
'sikkerhetspolitiskere': ('sikkerhetspolitisk',),
'sikkerhetspolitiskest': ('sikkerhetspolitisk',),
'sikkerhetspolitiskeste': ('sikkerhetspolitisk',),
'sikkimesisk': ('sikkimesisk',),
'sikkimesiske': ('sikkimesisk',),
'sikkimesiskere': ('sikkimesisk',),
'sikkimesiskest': ('sikkimesisk',),
'sikkimesiskeste': ('sikkimesisk',),
'sikksakka': ('sikksakke',),
'sikksakkede': ('sikksakke',),
'sikksakkende': ('sikksakke',),
'sikksakket': ('sikksakke',),
'sikksakkete': ('sikksakke',),
'sikla': ('sikle',),
'siklede': ('sikle',),
'siklende': ('sikle',),
'siklet': ('sikle',),
'siklete': ('sikle',),
'sikla': ('sikle',),
'siklede': ('sikle',),
'siklende': ('sikle',),
'siklet': ('sikle',),
'siklete': ('sikle',),
'siklen': ('siklen',),
'siklent': ('siklen',),
'siklne': ('siklen',),
'siklnere': ('siklen',),
'siklnest': ('siklen',),
'siklneste': ('siklen',),
'siklet': ('siklet',),
'siklete': ('siklet',),
'sikletere': ('siklet',),
'sikletest': ('siklet',),
'sikleteste': ('siklet',),
'siklete': ('siklete',),
'sikra': ('sikre',),
'sikrede': ('sikre',),
'sikrende': ('sikre',),
'sikret': ('sikre',),
'sikrete': ('sikre',),
'siktbar': ('siktbar',),
'siktbare': ('siktbar',),
'siktbarere': ('siktbar',),
'siktbarest': ('siktbar',),
'siktbareste': ('siktbar',),
'siktbart': ('siktbar',),
'sikta': ('sikte',),
'siktede': ('sikte',),
'siktende': ('sikte',),
'siktet': ('sikte',),
'siktete': ('sikte',),
'sikta': ('sikte',),
'siktede': ('sikte',),
'siktende': ('sikte',),
'siktet': ('sikte',),
'siktete': ('sikte',),
'sikta': ('sikte',),
'siktede': ('sikte',),
'siktende': ('sikte',),
'siktet': ('sikte',),
'siktete': ('sikte',),
'silblødd': ('silblø',),
'silblødde': ('silblø',),
'silbløende': ('silblø',),
'sildig': ('sildig',),
'sildige': ('sildig',),
'sildigere': ('sildig',),
'sildigst': ('sildig',),
'sildigste': ('sildig',),
'sildra': ('sildre',),
'sildrede': ('sildre',),
'sildrende': ('sildre',),
'sildret': ('sildre',),
'sildrete': ('sildre',),
'silende': ('sile',),
'silt': ('sile',),
'silte': ('sile',),
'silkefin': ('silkefin',),
'silkefine': ('silkefin',),
'silkefinere': ('silkefin',),
'silkefinest': ('silkefin',),
'silkefineste': ('silkefin',),
'silkefint': ('silkefin',),
'silkemjuk': ('silkemjuk',),
'silkemjuke': ('silkemjuk',),
'silkemjukere': ('silkemjuk',),
'silkemjukest': ('silkemjuk',),
'silkemjukeste': ('silkemjuk',),
'silkemjukt': ('silkemjuk',),
'silkemyk': ('silkemyk',),
'silkemyke': ('silkemyk',),
'silkemykere': ('silkemyk',),
'silkemykest': ('silkemyk',),
'silkemykeste': ('silkemyk',),
'silkemykt': ('silkemyk',),
'silregna': ('silregne',),
'silregnede': ('silregne',),
'silregnende': ('silregne',),
'silregnet': ('silregne',),
'silregnete': ('silregne',),
'silregnt': ('silregne',),
'silregnte': ('silregne',),
'silrennende': ('silrenne',),
'silrent': ('silrenne',),
'silrente': ('silrenne',),
'silurisk': ('silurisk',),
'siluriske': ('silurisk',),
'siluriskere': ('silurisk',),
'siluriskest': ('silurisk',),
'siluriskeste': ('silurisk',),
'silvåt': ('silvåt',),
'silvåte': ('silvåt',),
'silvåtere': ('silvåt',),
'silvåtest': ('silvåt',),
'silvåteste': ('silvåt',),
'silvått': ('silvåt',),
'simpel': ('simpel',),
'simpelt': ('simpel',),
'simple': ('simpel',),
'simplere': ('simpel',),
'simplest': ('simpel',),
'simpleste': ('simpel',),
'simplifiserende': ('simplifisere',),
'simplifisert': ('simplifisere',),
'simplifiserte': ('simplifisere',),
'simulerende': ('simulere',),
'simulert': ('simulere',),
'simulerte': ('simulere',),
'simultan': ('simultan',),
'simultane': ('simultan',),
'simultanere': ('simultan',),
'simultanest': ('simultan',),
'simultaneste': ('simultan',),
'simultant': ('simultan',),
'sindig': ('sindig',),
'sindige': ('sindig',),
'sindigere': ('sindig',),
'sindigst': ('sindig',),
'sindigste': ('sindig',),
'sindra': ('sindre',),
'sindrede': ('sindre',),
'sindrende': ('sindre',),
'sindret': ('sindre',),
'sindrete': ('sindre',),
'sina': ('sine',),
'sinede': ('sine',),
'sinende': ('sine',),
'sinet': ('sine',),
'sinete': ('sine',),
'singalesisk': ('singalesisk',),
'singalesiske': ('singalesisk',),
'singalesiskere': ('singalesisk',),
'singalesiskest': ('singalesisk',),
'singalesiskeste': ('singalesisk',),
'singaporsk': ('singaporsk',),
'singaporske': ('singaporsk',),
'singaporskere': ('singaporsk',),
'singaporskest': ('singaporsk',),
'singaporskeste': ('singaporsk',),
'singel': ('singel',),
'singelt': ('singel',),
'single': ('singel',),
'singlere': ('singel',),
'singlest': ('singel',),
'singleste': ('singel',),
'singla': ('single',),
'singlede': ('single',),
'singlende': ('single',),
'singlet': ('single',),
'singlete': ('single',),
'singla': ('single',),
'singlede': ('single',),
'singlende': ('single',),
'singlet': ('single',),
'singlete': ('single',),
'single': ('single',),
'singulær': ('singulær',),
'singulære': ('singulær',),
'singulærere': ('singulær',),
'singulærest': ('singulær',),
'singulæreste': ('singulær',),
'singulært': ('singulær',),
'sinka': ('sinke',),
'sinkede': ('sinke',),
'sinkende': ('sinke',),
'sinket': ('sinke',),
'sinkete': ('sinke',),
'sinka': ('sinke',),
'sinkede': ('sinke',),
'sinkende': ('sinke',),
'sinket': ('sinke',),
'sinkete': ('sinke',),
'sinka': ('sinke',),
'sinkede': ('sinke',),
'sinkende': ('sinke',),
'sinket': ('sinke',),
'sinkete': ('sinke',),
'sinna': ('sinna',),
'sinnrik': ('sinnrik',),
'sinnrike': ('sinnrik',),
'sinnrikere': ('sinnrik',),
'sinnrikest': ('sinnrik',),
'sinnrikeste': ('sinnrik',),
'sinnrikt': ('sinnrik',),
'sinnsforvirra': ('sinnsforvirra',),
'sinnsforvirrede': ('sinnsforvirret',),
'sinnsforvirret': ('sinnsforvirret',),
'sinnsforvirrete': ('sinnsforvirret',),
'sinnsforvirretere': ('sinnsforvirret',),
'sinnsforvirretest': ('sinnsforvirret',),
'sinnsforvirreteste': ('sinnsforvirret',),
'sinnssjuk': ('sinnssjuk',),
'sinnssjuke': ('sinnssjuk',),
'sinnssjukere': ('sinnssjuk',),
'sinnssjukest': ('sinnssjuk',),
'sinnssjukeste': ('sinnssjuk',),
'sinnssjukt': ('sinnssjuk',),
'sinnssvak': ('sinnssvak',),
'sinnssvake': ('sinnssvak',),
'sinnssvakere': ('sinnssvak',),
'sinnssvakest': ('sinnssvak',),
'sinnssvakeste': ('sinnssvak',),
'sinnssvakt': ('sinnssvak',),
'sinnssyk': ('sinnssyk',),
'sinnssyke': ('sinnssyk',),
'sinnssykere': ('sinnssyk',),
'sinnssykest': ('sinnssyk',),
'sinnssykeste': ('sinnssyk',),
'sinnssykt': ('sinnssyk',),
'sinoberrød': ('sinoberrød',),
'sinoberrøde': ('sinoberrød',),
'sinoberrødere': ('sinoberrød',),
'sinoberrødest': ('sinoberrød',),
'sinoberrødeste': ('sinoberrød',),
'sinoberrødt': ('sinoberrød',),
'sinologisk': ('sinologisk',),
'sinologiske': ('sinologisk',),
'sinologiskere': ('sinologisk',),
'sinologiskest': ('sinologisk',),
'sinologiskeste': ('sinologisk',),
'sint': ('sint',),
'sinte': ('sint',),
'sintere': ('sint',),
'sintest': ('sint',),
'sinteste': ('sint',),
'sintra': ('sintre',),
'sintrede': ('sintre',),
'sintrende': ('sintre',),
'sintret': ('sintre',),
'sintrete': ('sintre',),
'sionistisk': ('sionistisk',),
'sionistiske': ('sionistisk',),
'sionistiskere': ('sionistisk',),
'sionistiskest': ('sionistisk',),
'sionistiskeste': ('sionistisk',),
'sipa': ('sipe',),
'sipede': ('sipe',),
'sipende': ('sipe',),
'sipet': ('sipe',),
'sipete': ('sipe',),
'sipt': ('sipe',),
'sipte': ('sipe',),
'sipet': ('sipet',),
'sipete': ('sipet',),
'sipetere': ('sipet',),
'sipetest': ('sipet',),
'sipeteste': ('sipet',),
'sipete': ('sipete',),
'sippa': ('sippe',),
'sippede': ('sippe',),
'sippende': ('sippe',),
'sippet': ('sippe',),
'sippete': ('sippe',),
'sipt': ('sippe',),
'sipte': ('sippe',),
'sippet': ('sippet',),
'sippete': ('sippet',),
'sippetere': ('sippet',),
'sippetest': ('sippet',),
'sippeteste': ('sippet',),
'sippete': ('sippete',),
'siregna': ('siregne',),
'siregnede': ('siregne',),
'siregnende': ('siregne',),
'siregnet': ('siregne',),
'siregnete': ('siregne',),
'siregnt': ('siregne',),
'siregnte': ('siregne',),
'sirkelrund': ('sirkelrund',),
'sirkelrunde': ('sirkelrund',),
'sirkelrundere': ('sirkelrund',),
'sirkelrundest': ('sirkelrund',),
'sirkelrundeste': ('sirkelrund',),
'sirkelrundt': ('sirkelrund',),
'sirkla': ('sirkle',),
'sirklede': ('sirkle',),
'sirklende': ('sirkle',),
'sirklet': ('sirkle',),
'sirklete': ('sirkle',),
'sirkulerende': ('sirkulere',),
'sirkulert': ('sirkulere',),
'sirkulerte': ('sirkulere',),
'sirkulær': ('sirkulær',),
'sirkulære': ('sirkulær',),
'sirkulærere': ('sirkulær',),
'sirkulærest': ('sirkulær',),
'sirkulæreste': ('sirkulær',),
'sirkulært': ('sirkulær',),
'sirlig': ('sirlig',),
'sirlige': ('sirlig',),
'sirligere': ('sirlig',),
'sirligst': ('sirlig',),
'sirligste': ('sirlig',),
'siselerende': ('siselere',),
'siselert': ('siselere',),
'siselerte': ('siselere',),
'sisla': ('sisle',),
'sislede': ('sisle',),
'sislende': ('sisle',),
'sislet': ('sisle',),
'sislete': ('sisle',),
'sist': ('sist',),
'siste': ('sist',),
'sistere': ('sist',),
'sistest': ('sist',),
'sisteste': ('sist',),
'sistnevnt': ('sistnevnt',),
'sistnevnte': ('sistnevnt',),
'sistnevntere': ('sistnevnt',),
'sistnevntest': ('sistnevnt',),
'sistnevnteste': ('sistnevnt',),
'siterende': ('sitere',),
'sitert': ('sitere',),
'siterte': ('sitere',),
'sitra': ('sitre',),
'sitrede': ('sitre',),
'sitrende': ('sitre',),
'sitret': ('sitre',),
'sitrete': ('sitre',),
'sitne': ('sitte',),
'sitten': ('sitte',),
'sittende': ('sitte',),
'sittet': ('sitte',),
'sitteriktig': ('sitteriktig',),
'sitteriktige': ('sitteriktig',),
'sitteriktigere': ('sitteriktig',),
'sitteriktigst': ('sitteriktig',),
'sitteriktigste': ('sitteriktig',),
'situasjonsbestemt': ('situasjonsbestemt',),
'situasjonsbestemte': ('situasjonsbestemt',),
'situasjonsbestemtere': ('situasjonsbestemt',),
'situasjonsbestemtest': ('situasjonsbestemt',),
'situasjonsbestemteste': ('situasjonsbestemt',),
'situert': ('situert',),
'situerte': ('situert',),
'situertere': ('situert',),
'situertest': ('situert',),
'situerteste': ('situert',),
'siva': ('sive',),
'sivd': ('sive',),
'sivde': ('sive',),
'sivede': ('sive',),
'sivende': ('sive',),
'sivet': ('sive',),
'sivete': ('sive',),
'sivil': ('sivil',),
'sivile': ('sivil',),
'sivilere': ('sivil',),
'sivilest': ('sivil',),
'sivileste': ('sivil',),
'sivilt': ('sivil',),
'sivilisatorisk': ('sivilisatorisk',),
'sivilisatoriske': ('sivilisatorisk',),
'sivilisatoriskere': ('sivilisatorisk',),
'sivilisatoriskest': ('sivilisatorisk',),
'sivilisatoriskeste': ('sivilisatorisk',),
'siviliserende': ('sivilisere',),
'sivilisert': ('sivilisere',),
'siviliserte': ('sivilisere',),
'sivilkledd': ('sivilkledd',),
'sivilkledde': ('sivilkledd',),
'sivilkleddere': ('sivilkledd',),
'sivilkleddest': ('sivilkledd',),
'sivilkleddeste': ('sivilkledd',),
'sivåt': ('sivåt',),
'sivåte': ('sivåt',),
'sivåtere': ('sivåt',),
'sivåtest': ('sivåt',),
'sivåteste': ('sivåt',),
'sivått': ('sivåt',),
'sjabba': ('sjabbe',),
'sjabbede': ('sjabbe',),
'sjabbende': ('sjabbe',),
'sjabbet': ('sjabbe',),
'sjabbete': ('sjabbe',),
'sjaber': ('sjaber',),
'sjabert': ('sjaber',),
'sjabre': ('sjaber',),
'sjabrere': ('sjaber',),
'sjabrest': ('sjaber',),
'sjabreste': ('sjaber',),
'sjablongmessig': ('sjablongmessig',),
'sjablongmessige': ('sjablongmessig',),
'sjablongmessigere': ('sjablongmessig',),
'sjablongmessigst': ('sjablongmessig',),
'sjablongmessigste': ('sjablongmessig',),
'sjablonmessig': ('sjablonmessig',),
'sjablonmessige': ('sjablonmessig',),
'sjablonmessigere': ('sjablonmessig',),
'sjablonmessigst': ('sjablonmessig',),
'sjablonmessigste': ('sjablonmessig',),
'sjakla': ('sjakle',),
'sjaklede': ('sjakle',),
'sjaklende': ('sjakle',),
'sjaklet': ('sjakle',),
'sjaklete': ('sjakle',),
'sjakra': ('sjakre',),
'sjakrede': ('sjakre',),
'sjakrende': ('sjakre',),
'sjakret': ('sjakre',),
'sjakrete': ('sjakre',),
'sjalta': ('sjalte',),
'sjaltede': ('sjalte',),
'sjaltende': ('sjalte',),
'sjaltet': ('sjalte',),
'sjaltete': ('sjalte',),
'sjalu': ('sjalu',),
'sjalue': ('sjalu',),
'sjaluere': ('sjalu',),
'sjaluest': ('sjalu',),
'sjalueste': ('sjalu',),
'sjamponerende': ('sjamponere',),
'sjamponert': ('sjamponere',),
'sjamponerte': ('sjamponere',),
'sjanghaia': ('sjanghaie',),
'sjanghaiede': ('sjanghaie',),
'sjanghaiende': ('sjanghaie',),
'sjanghaiet': ('sjanghaie',),
'sjanghaiete': ('sjanghaie',),
'sjangla': ('sjangle',),
'sjanglede': ('sjangle',),
'sjanglende': ('sjangle',),
'sjanglet': ('sjangle',),
'sjanglete': ('sjangle',),
'sjanglet': ('sjanglet',),
'sjanglete': ('sjanglet',),
'sjangletere': ('sjanglet',),
'sjangletest': ('sjanglet',),
'sjangleteste': ('sjanglet',),
'sjanglete': ('sjanglete',),
'sjarmant': ('sjarmant',),
'sjarmante': ('sjarmant',),
'sjarmantere': ('sjarmant',),
'sjarmantest': ('sjarmant',),
'sjarmanteste': ('sjarmant',),
'sjarmantiserende': ('sjarmantisere',),
'sjarmantisert': ('sjarmantisere',),
'sjarmantiserte': ('sjarmantisere',),
'sjarmerende': ('sjarmere',),
'sjarmert': ('sjarmere',),
'sjarmerte': ('sjarmere',),
'sjaska': ('sjaske',),
'sjaskede': ('sjaske',),
'sjaskende': ('sjaske',),
'sjasket': ('sjaske',),
'sjaskete': ('sjaske',),
'sjasket': ('sjasket',),
'sjaskete': ('sjasket',),
'sjasketere': ('sjasket',),
'sjasketest': ('sjasket',),
'sjasketeste': ('sjasket',),
'sjaskete': ('sjaskete',),
'sjatterende': ('sjattere',),
'sjattert': ('sjattere',),
'sjatterte': ('sjattere',),
'sjaua': ('sjaue',),
'sjauede': ('sjaue',),
'sjauende': ('sjaue',),
'sjauet': ('sjaue',),
'sjauete': ('sjaue',),
'sjefa': ('sjefe',),
'sjefede': ('sjefe',),
'sjefende': ('sjefe',),
'sjefet': ('sjefe',),
'sjefete': ('sjefe',),
'sjeida': ('sjeide',),
'sjeidede': ('sjeide',),
'sjeidende': ('sjeide',),
'sjeidet': ('sjeide',),
'sjeidete': ('sjeide',),
'sjekka': ('sjekke',),
'sjekkede': ('sjekke',),
'sjekkende': ('sjekke',),
'sjekket': ('sjekke',),
'sjekkete': ('sjekke',),
'sjelden': ('sjelden',),
'sjeldent': ('sjelden',),
'sjeldne': ('sjelden',),
'sjeldnere': ('sjelden',),
'sjeldnest': ('sjelden',),
'sjeldneste': ('sjelden',),
'sjeldsynt': ('sjeldsynt',),
'sjeldsynte': ('sjeldsynt',),
'sjeldsyntere': ('sjeldsynt',),
'sjeldsyntest': ('sjeldsynt',),
'sjeldsynteste': ('sjeldsynt',),
'sjeleglad': ('sjeleglad',),
'sjeleglade': ('sjeleglad',),
'sjelegladere': ('sjeleglad',),
'sjelegladest': ('sjeleglad',),
'sjelegladeste': ('sjeleglad',),
'sjelelega': ('sjelelege',),
'sjelelegede': ('sjelelege',),
'sjelelegende': ('sjelelege',),
'sjeleleget': ('sjelelege',),
'sjelelegete': ('sjelelege',),
'sjelelegt': ('sjelelege',),
'sjelelegte': ('sjelelege',),
'sjelelig': ('sjelelig',),
'sjelelige': ('sjelelig',),
'sjeleligere': ('sjelelig',),
'sjeleligst': ('sjelelig',),
'sjeleligste': ('sjelelig',),
'sjelfull': ('sjelfull',),
'sjelfulle': ('sjelfull',),
'sjelfullere': ('sjelfull',),
'sjelfullest': ('sjelfull',),
'sjelfulleste': ('sjelfull',),
'sjelfullt': ('sjelfull',),
'sjellaus': ('sjellaus',),
'sjellause': ('sjellaus',),
'sjellausere': ('sjellaus',),
'sjellausest': ('sjellaus',),
'sjellauseste': ('sjellaus',),
'sjellaust': ('sjellaus',),
'sjelløs': ('sjelløs',),
'sjelløse': ('sjelløs',),
'sjelløsere': ('sjelløs',),
'sjelløsest': ('sjelløs',),
'sjelløseste': ('sjelløs',),
'sjelløst': ('sjelløs',),
'sjenerende': ('sjenere',),
'sjenert': ('sjenere',),
'sjenerte': ('sjenere',),
'sjenert': ('sjenert',),
'sjenerte': ('sjenert',),
'sjenertere': ('sjenert',),
'sjenertest': ('sjenert',),
'sjenerteste': ('sjenert',),
'sjenerøs': ('sjenerøs',),
'sjenerøse': ('sjenerøs',),
'sjenerøsere': ('sjenerøs',),
'sjenerøsest': ('sjenerøs',),
'sjenerøseste': ('sjenerøs',),
'sjenerøst': ('sjenerøs',),
'sjette': ('sjette',),
'sjever': ('sjever',),
'sjevert': ('sjever',),
'sjevre': ('sjever',),
'sjevrere': ('sjever',),
'sjevrest': ('sjever',),
'sjevreste': ('sjever',),
'sjevra': ('sjevre',),
'sjevrede': ('sjevre',),
'sjevrende': ('sjevre',),
'sjevret': ('sjevre',),
'sjevrete': ('sjevre',),
'sjiittisk': ('sjiittisk',),
'sjiittiske': ('sjiittisk',),
'sjiittiskere': ('sjiittisk',),
'sjiittiskest': ('sjiittisk',),
'sjiittiskeste': ('sjiittisk',),
'sjikanerende': ('sjikanere',),
'sjikanert': ('sjikanere',),
'sjikanerte': ('sjikanere',),
'sjikanøs': ('sjikanøs',),
'sjikanøse': ('sjikanøs',),
'sjikanøsere': ('sjikanøs',),
'sjikanøsest': ('sjikanøs',),
'sjikanøseste': ('sjikanøs',),
'sjikanøst': ('sjikanøs',),
'sjingla': ('sjingle',),
'sjinglede': ('sjingle',),
'sjinglende': ('sjingle',),
'sjinglet': ('sjingle',),
'sjinglete': ('sjingle',),
'sjofel': ('sjofel',),
'sjofelt': ('sjofel',),
'sjofle': ('sjofel',),
'sjoflere': ('sjofel',),
'sjoflest': ('sjofel',),
'sjofleste': ('sjofel',),
'sjofla': ('sjofle',),
'sjoflede': ('sjofle',),
'sjoflende': ('sjofle',),
'sjoflet': ('sjofle',),
'sjoflete': ('sjofle',),
'sjoga': ('sjoge',),
'sjogede': ('sjoge',),
'sjogende': ('sjoge',),
'sjoget': ('sjoge',),
'sjogete': ('sjoge',),
'sjogsa': ('sjogse',),
'sjogsede': ('sjogse',),
'sjogsende': ('sjogse',),
'sjogset': ('sjogse',),
'sjogsete': ('sjogse',),
'sjokka': ('sjokke',),
'sjokkede': ('sjokke',),
'sjokkende': ('sjokke',),
'sjokket': ('sjokke',),
'sjokkete': ('sjokke',),
'sjokkerende': ('sjokkere',),
'sjokkert': ('sjokkere',),
'sjokkerte': ('sjokkere',),
'sjokkskada': ('sjokkskada',),
'sjokkskadd': ('sjokkskadd',),
'sjokkskadde': ('sjokkskadd',),
'sjokkskaddere': ('sjokkskadd',),
'sjokkskaddest': ('sjokkskadd',),
'sjokkskaddeste': ('sjokkskadd',),
'sjokkskadede': ('sjokkskadet',),
'sjokkskadet': ('sjokkskadet',),
'sjokkskadete': ('sjokkskadet',),
'sjokkskadetere': ('sjokkskadet',),
'sjokkskadetest': ('sjokkskadet',),
'sjokkskadeteste': ('sjokkskadet',),
'sjokkåpna': ('sjokkåpne',),
'sjokkåpnede': ('sjokkåpne',),
'sjokkåpnende': ('sjokkåpne',),
'sjokkåpnet': ('sjokkåpne',),
'sjokkåpnete': ('sjokkåpne',),
'sjonglerende': ('sjonglere',),
'sjonglert': ('sjonglere',),
'sjonglerte': ('sjonglere',),
'sjuarma': ('sjuarma',),
'sjuarmede': ('sjuarmet',),
'sjuarmet': ('sjuarmet',),
'sjuarmete': ('sjuarmet',),
'sjuarmetere': ('sjuarmet',),
'sjuarmetest': ('sjuarmet',),
'sjuarmeteste': ('sjuarmet',),
'sjudobbel': ('sjudobbel',),
'sjudobbelt': ('sjudobbel',),
'sjudoble': ('sjudobbel',),
'sjudoblere': ('sjudobbel',),
'sjudoblest': ('sjudobbel',),
'sjudobleste': ('sjudobbel',),
'sjudobbelt': ('sjudobbelt',),
'sjudobbelte': ('sjudobbelt',),
'sjudobbeltere': ('sjudobbelt',),
'sjudobbeltest': ('sjudobbelt',),
'sjudobbelteste': ('sjudobbelt',),
'sjudobla': ('sjudoble',),
'sjudoblede': ('sjudoble',),
'sjudoblende': ('sjudoble',),
'sjudoblet': ('sjudoble',),
'sjudoblete': ('sjudoble',),
'sjuende': ('sjuende',),
'sjuk': ('sjuk',),
'sjuke': ('sjuk',),
'sjukere': ('sjuk',),
'sjukest': ('sjuk',),
'sjukeste': ('sjuk',),
'sjukt': ('sjuk',),
'sjukelig': ('sjukelig',),
'sjukelige': ('sjukelig',),
'sjukeligere': ('sjukelig',),
'sjukeligst': ('sjukelig',),
'sjukeligste': ('sjukelig',),
'sjukemeldende': ('sjukemelde',),
'sjukemeldt': ('sjukemelde',),
'sjukemeldte': ('sjukemelde',),
'sjukemeldt': ('sjukemeldt',),
'sjukemeldte': ('sjukemeldt',),
'sjukemeldtere': ('sjukemeldt',),
'sjukemeldtest': ('sjukemeldt',),
'sjukemeldteste': ('sjukemeldt',),
'sjuklig': ('sjuklig',),
'sjuklige': ('sjuklig',),
'sjukligere': ('sjuklig',),
'sjukligst': ('sjuklig',),
'sjukligste': ('sjuklig',),
'sjukmeldende': ('sjukmelde',),
'sjukmeldt': ('sjukmelde',),
'sjukmeldte': ('sjukmelde',),
'sjukmeldt': ('sjukmeldt',),
'sjukmeldte': ('sjukmeldt',),
'sjukmeldtere': ('sjukmeldt',),
'sjukmeldtest': ('sjukmeldt',),
'sjukmeldteste': ('sjukmeldt',),
'sjukna': ('sjukne',),
'sjuknede': ('sjukne',),
'sjuknende': ('sjukne',),
'sjuknet': ('sjukne',),
'sjuknete': ('sjukne',),
'sjuska': ('sjuske',),
'sjuskede': ('sjuske',),
'sjuskende': ('sjuske',),
'sjusket': ('sjuske',),
'sjuskete': ('sjuske',),
'sjusket': ('sjusket',),
'sjuskete': ('sjusket',),
'sjusketere': ('sjusket',),
'sjusketest': ('sjusket',),
'sjusketeste': ('sjusket',),
'sjuskete': ('sjuskete',),
'sjuårig': ('sjuårig',),
'sjuårige': ('sjuårig',),
'sjuårigere': ('sjuårig',),
'sjuårigst': ('sjuårig',),
'sjuårigste': ('sjuårig',),
'sjuårs': ('sjuårs',),
'sjåvinistisk': ('sjåvinistisk',),
'sjåvinistiske': ('sjåvinistisk',),
'sjåvinistiskere': ('sjåvinistisk',),
'sjåvinistiskest': ('sjåvinistisk',),
'sjåvinistiskeste': ('sjåvinistisk',),
'sjællandsk': ('sjællandsk',),
'sjællandske': ('sjællandsk',),
'sjællandskere': ('sjællandsk',),
'sjællandskest': ('sjællandsk',),
'sjællandskeste': ('sjællandsk',),
'sjødyktig': ('sjødyktig',),
'sjødyktige': ('sjødyktig',),
'sjødyktigere': ('sjødyktig',),
'sjødyktigst': ('sjødyktig',),
'sjødyktigste': ('sjødyktig',),
'sjøfarende': ('sjøfarende',),
'sjøgående': ('sjøgående',),
'sjølbedt': ('sjølbedt',),
'sjølbedte': ('sjølbedt',),
'sjølbedtere': ('sjølbedt',),
'sjølbedtest': ('sjølbedt',),
'sjølbedteste': ('sjølbedt',),
'sjølbehagelig': ('sjølbehagelig',),
'sjølbehagelige': ('sjølbehagelig',),
'sjølbehageligere': ('sjølbehagelig',),
'sjølbehageligst': ('sjølbehagelig',),
'sjølbehageligste': ('sjølbehagelig',),
'sjølbekjennende': ('sjølbekjennende',),
'sjølberga': ('sjølberga',),
'sjølbergede': ('sjølberget',),
'sjølberget': ('sjølberget',),
'sjølbergete': ('sjølberget',),
'sjølbergetere': ('sjølberget',),
'sjølbergetest': ('sjølberget',),
'sjølbergeteste': ('sjølberget',),
'sjølbestalta': ('sjølbestalta',),
'sjølbestaltede': ('sjølbestaltet',),
'sjølbestaltet': ('sjølbestaltet',),
'sjølbestaltete': ('sjølbestaltet',),
'sjølbestaltetere': ('sjølbestaltet',),
'sjølbestaltetest': ('sjølbestaltet',),
'sjølbestalteteste': ('sjølbestaltet',),
'sjølbestemt': ('sjølbestemt',),
'sjølbestemte': ('sjølbestemt',),
'sjølbestemtere': ('sjølbestemt',),
'sjølbestemtest': ('sjølbestemt',),
'sjølbestemteste': ('sjølbestemt',),
'sjølbevisst': ('sjølbevisst',),
'sjølbevisste': ('sjølbevisst',),
'sjølbevisstere': ('sjølbevisst',),
'sjølbevisstest': ('sjølbevisst',),
'sjølbevissteste': ('sjølbevisst',),
'sjølbiografisk': ('sjølbiografisk',),
'sjølbiografiske': ('sjølbiografisk',),
'sjølbiografiskere': ('sjølbiografisk',),
'sjølbiografiskest': ('sjølbiografisk',),
'sjølbiografiskeste': ('sjølbiografisk',),
'sjølbuden': ('sjølbuden',),
'sjølbudent': ('sjølbuden',),
'sjølbudne': ('sjølbuden',),
'sjølbudnere': ('sjølbuden',),
'sjølbudnest': ('sjølbuden',),
'sjølbudneste': ('sjølbuden',),
'sjølbyrg': ('sjølbyrg',),
'sjølbyrge': ('sjølbyrg',),
'sjølbyrgere': ('sjølbyrg',),
'sjølbyrgest': ('sjølbyrg',),
'sjølbyrgeste': ('sjølbyrg',),
'sjølbyrgt': ('sjølbyrg',),
'sjølbærende': ('sjølbærende',),
'sjøldaud': ('sjøldaud',),
'sjøldaude': ('sjøldaud',),
'sjøldaudere': ('sjøldaud',),
'sjøldaudest': ('sjøldaud',),
'sjøldaudeste': ('sjøldaud',),
'sjøldaudt': ('sjøldaud',),
'sjøldød': ('sjøldød',),
'sjøldøde': ('sjøldød',),
'sjøldødere': ('sjøldød',),
'sjøldødest': ('sjøldød',),
'sjøldødeste': ('sjøldød',),
'sjøldødt': ('sjøldød',),
'sjøleiende': ('sjøleiende',),
'sjølervervende': ('sjølervervende',),
'sjølfinansierende': ('sjølfinansierende',),
'sjølforglemmende': ('sjølforglemmende',),
'sjølforskyldt': ('sjølforskyldt',),
'sjølforskyldte': ('sjølforskyldt',),
'sjølforskyldtere': ('sjølforskyldt',),
'sjølforskyldtest': ('sjølforskyldt',),
'sjølforskyldteste': ('sjølforskyldt',),
'sjølforsynt': ('sjølforsynt',),
'sjølforsynte': ('sjølforsynt',),
'sjølforsyntere': ('sjølforsynt',),
'sjølforsyntest': ('sjølforsynt',),
'sjølforsynteste': ('sjølforsynt',),
'sjølgjort': ('sjølgjort',),
'sjølgjorte': ('sjølgjort',),
'sjølgjortere': ('sjølgjort',),
'sjølgjortest': ('sjølgjort',),
'sjølgjorteste': ('sjølgjort',),
'sjølbedre': ('sjølgod',),
'sjølbest': ('sjølgod',),
'sjølbeste': ('sjølgod',),
'sjølgod': ('sjølgod',),
'sjølgode': ('sjølgod',),
'sjølgodt': ('sjølgod',),
'sjølgående': ('sjølgående',),
'sjølhjulpen': ('sjølhjulpen',),
'sjølhjulpent': ('sjølhjulpen',),
'sjølhjulpne': ('sjølhjulpen',),
'sjølhjulpnere': ('sjølhjulpen',),
'sjølhjulpnest': ('sjølhjulpen',),
'sjølhjulpneste': ('sjølhjulpen',),
'sjølinnlysende': ('sjølinnlysende',),
'sjølironisk': ('sjølironisk',),
'sjølironiske': ('sjølironisk',),
'sjølironiskere': ('sjølironisk',),
'sjølironiskest': ('sjølironisk',),
'sjølironiskeste': ('sjølironisk',),
'sjølklar': ('sjølklar',),
'sjølklare': ('sjølklar',),
'sjølklarere': ('sjølklar',),
'sjølklarest': ('sjølklar',),
'sjølklareste': ('sjølklar',),
'sjølklart': ('sjølklar',),
'sjølklok': ('sjølklok',),
'sjølkloke': ('sjølklok',),
'sjølklokere': ('sjølklok',),
'sjølklokest': ('sjølklok',),
'sjølklokeste': ('sjølklok',),
'sjølklokt': ('sjølklok',),
'sjølkostende': ('sjølkostende',),
'sjølkostende': ('sjølkostende',),
'sjølkostende': ('sjølkostende',),
'sjølkritisk': ('sjølkritisk',),
'sjølkritiske': ('sjølkritisk',),
'sjølkritiskere': ('sjølkritisk',),
'sjølkritiskest': ('sjølkritisk',),
'sjølkritiskeste': ('sjølkritisk',),
'sjøllaga': ('sjøllaga',),
'sjøllagd': ('sjøllagd',),
'sjøllagde': ('sjøllagd',),
'sjøllagdere': ('sjøllagd',),
'sjøllagdest': ('sjøllagd',),
'sjøllagdeste': ('sjøllagd',),
'sjøllagede': ('sjøllaget',),
'sjøllaget': ('sjøllaget',),
'sjøllagete': ('sjøllaget',),
'sjøllagetere': ('sjøllaget',),
'sjøllagetest': ('sjøllaget',),
'sjøllageteste': ('sjøllaget',),
'sjøllysende': ('sjøllysende',),
'sjøllært': ('sjøllært',),
'sjøllærte': ('sjøllært',),
'sjøllærtere': ('sjøllært',),
'sjøllærtest': ('sjøllært',),
'sjøllærteste': ('sjøllært',),
'sjølmorderisk': ('sjølmorderisk',),
'sjølmorderiske': ('sjølmorderisk',),
'sjølmorderiskere': ('sjølmorderisk',),
'sjølmorderiskest': ('sjølmorderisk',),
'sjølmorderiskeste': ('sjølmorderisk',),
'sjølmordersk': ('sjølmordersk',),
'sjølmorderske': ('sjølmordersk',),
'sjølmorderskere': ('sjølmordersk',),
'sjølmorderskest': ('sjølmordersk',),
'sjølmorderskeste': ('sjølmordersk',),
'sjølmotsigende': ('sjølmotsigende',),
'sjølopplevd': ('sjølopplevd',),
'sjølopplevde': ('sjølopplevd',),
'sjølopplevdere': ('sjølopplevd',),
'sjølopplevdest': ('sjølopplevd',),
'sjølopplevdeste': ('sjølopplevd',),
'sjøloppofrende': ('sjøloppofrende',),
'sjølopptatt': ('sjølopptatt',),
'sjølopptatte': ('sjølopptatt',),
'sjølopptattere': ('sjølopptatt',),
'sjølopptattest': ('sjølopptatt',),
'sjølopptatteste': ('sjølopptatt',),
'sjølregulerende': ('sjølregulerende',),
'sjølrensende': ('sjølrensende',),
'sjølrådig': ('sjølrådig',),
'sjølrådige': ('sjølrådig',),
'sjølrådigere': ('sjølrådig',),
'sjølrådigst': ('sjølrådig',),
'sjølrådigste': ('sjølrådig',),
'sjølsagt': ('sjølsagt',),
'sjølsagte': ('sjølsagt',),
'sjølsagtere': ('sjølsagt',),
'sjølsagtest': ('sjølsagt',),
'sjølsagteste': ('sjølsagt',),
'sjølsamme': ('sjølsamme',),
'sjølsikker': ('sjølsikker',),
'sjølsikkert': ('sjølsikker',),
'sjølsikre': ('sjølsikker',),
'sjølsikrere': ('sjølsikker',),
'sjølsikrest': ('sjølsikker',),
'sjølsikreste': ('sjølsikker',),
'sjølskreven': ('sjølskreven',),
'sjølskrevent': ('sjølskreven',),
'sjølskrevne': ('sjølskreven',),
'sjølskrevnere': ('sjølskreven',),
'sjølskrevnest': ('sjølskreven',),
'sjølskrevneste': ('sjølskreven',),
'sjølstendig': ('sjølstendig',),
'sjølstendige': ('sjølstendig',),
'sjølstendigere': ('sjølstendig',),
'sjølstendigst': ('sjølstendig',),
'sjølstendigste': ('sjølstendig',),
'sjølstendiggjort': ('sjølstendiggjøre',),
'sjølstendiggjorte': ('sjølstendiggjøre',),
'sjølstendiggjørende': ('sjølstendiggjøre',),
'sjølstyrt': ('sjølstyrt',),
'sjølstyrte': ('sjølstyrt',),
'sjølstyrtere': ('sjølstyrt',),
'sjølstyrtest': ('sjølstyrt',),
'sjølstyrteste': ('sjølstyrt',),
'sjøltenkende': ('sjøltenkende',),
'sjøltilfreds': ('sjøltilfreds',),
'sjøltilfredse': ('sjøltilfreds',),
'sjøltilfredsere': ('sjøltilfreds',),
'sjøltilfredsest': ('sjøltilfreds',),
'sjøltilfredseste': ('sjøltilfreds',),
'sjøltrimmende': ('sjøltrimmende',),
'sjøltrygg': ('sjøltrygg',),
'sjøltrygge': ('sjøltrygg',),
'sjøltryggere': ('sjøltrygg',),
'sjøltryggest': ('sjøltrygg',),
'sjøltryggeste': ('sjøltrygg',),
'sjøltrygt': ('sjøltrygg',),
'sjølutslettende': ('sjølutslettende',),
'sjølvalgt': ('sjølvalgt',),
'sjølvalgte': ('sjølvalgt',),
'sjølvalgtere': ('sjølvalgt',),
'sjølvalgtest': ('sjølvalgt',),
'sjølvalgteste': ('sjølvalgt',),
'sjølødeleggende': ('sjølødeleggende',),
'sjømilitær': ('sjømilitær',),
'sjømilitære': ('sjømilitær',),
'sjømilitærere': ('sjømilitær',),
'sjømilitærest': ('sjømilitær',),
'sjømilitæreste': ('sjømilitær',),
'sjømilitært': ('sjømilitær',),
'sjøredd': ('sjøredd',),
'sjøredde': ('sjøredd',),
'sjøreddere': ('sjøredd',),
'sjøreddest': ('sjøredd',),
'sjøreddeste': ('sjøredd',),
'sjørettslig': ('sjørettslig',),
'sjørettslige': ('sjørettslig',),
'sjørettsligere': ('sjørettslig',),
'sjørettsligst': ('sjørettslig',),
'sjørettsligste': ('sjørettslig',),
'sjøsatt': ('sjøsette',),
'sjøsatte': ('sjøsette',),
'sjøsettende': ('sjøsette',),
'sjøsjuk': ('sjøsjuk',),
'sjøsjuke': ('sjøsjuk',),
'sjøsjukere': ('sjøsjuk',),
'sjøsjukest': ('sjøsjuk',),
'sjøsjukeste': ('sjøsjuk',),
'sjøsjukt': ('sjøsjuk',),
'sjøsterk': ('sjøsterk',),
'sjøsterke': ('sjøsterk',),
'sjøsterkere': ('sjøsterk',),
'sjøsterkest': ('sjøsterk',),
'sjøsterkeste': ('sjøsterk',),
'sjøsterkt': ('sjøsterk',),
'sjøsvak': ('sjøsvak',),
'sjøsvake': ('sjøsvak',),
'sjøsvakere': ('sjøsvak',),
'sjøsvakest': ('sjøsvak',),
'sjøsvakeste': ('sjøsvak',),
'sjøsvakt': ('sjøsvak',),
'sjøsyk': ('sjøsyk',),
'sjøsyke': ('sjøsyk',),
'sjøsykere': ('sjøsyk',),
'sjøsykest': ('sjøsyk',),
'sjøsykeste': ('sjøsyk',),
'sjøsykt': ('sjøsyk',),
'sjøudyktig': ('sjøudyktig',),
'sjøudyktige': ('sjøudyktig',),
'sjøudyktigere': ('sjøudyktig',),
'sjøudyktigst': ('sjøudyktig',),
'sjøudyktigste': ('sjøudyktig',),
'sjøvant': ('sjøvant',),
'sjøvante': ('sjøvant',),
'sjøvantere': ('sjøvant',),
'sjøvantest': ('sjøvant',),
'sjøvanteste': ('sjøvant',),
'sjøveik': ('sjøveik',),
'sjøveike': ('sjøveik',),
'sjøveikere': ('sjøveik',),
'sjøveikest': ('sjøveik',),
'sjøveikeste': ('sjøveik',),
'sjøveikt': ('sjøveik',),
'sjøvek': ('sjøvek',),
'sjøveke': ('sjøvek',),
'sjøvekere': ('sjøvek',),
'sjøvekest': ('sjøvek',),
'sjøvekeste': ('sjøvek',),
'sjøvekt': ('sjøvek',),
'skadd': ('ska',),
'skadde': ('ska',),
'skaende': ('ska',),
'skadd': ('ska',),
'skadde': ('ska',),
'skaende': ('ska',),
'skabbet': ('skabbet',),
'skabbete': ('skabbet',),
'skabbetere': ('skabbet',),
'skabbetest': ('skabbet',),
'skabbeteste': ('skabbet',),
'skabbete': ('skabbete',),
'skabrøs': ('skabrøs',),
'skabrøse': ('skabrøs',),
'skabrøsere': ('skabrøs',),
'skabrøsest': ('skabrøs',),
'skabrøseste': ('skabrøs',),
'skabrøst': ('skabrøs',),
'skada': ('skade',),
'skadd': ('skade',),
'skadde': ('skade',),
'skadede': ('skade',),
'skadende': ('skade',),
'skadet': ('skade',),
'skadete': ('skade',),
'skada': ('skade',),
'skadd': ('skade',),
'skadde': ('skade',),
'skadede': ('skade',),
'skadende': ('skade',),
'skadet': ('skade',),
'skadete': ('skade',),
'skadedaud': ('skadedaud',),
'skadedaude': ('skadedaud',),
'skadedaudere': ('skadedaud',),
'skadedaudest': ('skadedaud',),
'skadedaudeste': ('skadedaud',),
'skadedaudt': ('skadedaud',),
'skadedød': ('skadedød',),
'skadedøde': ('skadedød',),
'skadedødere': ('skadedød',),
'skadedødest': ('skadedød',),
'skadedødeste': ('skadedød',),
'skadedødt': ('skadedød',),
'skadefro': ('skadefro',),
'skadegjørende': ('skadegjørende',),
'skadelidende': ('skadelidende',),
'skadelig': ('skadelig',),
'skadelige': ('skadelig',),
'skadeligere': ('skadelig',),
'skadeligst': ('skadelig',),
'skadeligste': ('skadelig',),
'skadeskutt': ('skadeskyte',),
'skadeskutte': ('skadeskyte',),
'skadeskytende': ('skadeskyte',),
'skadeslaus': ('skadeslaus',),
'skadeslause': ('skadeslaus',),
'skadeslausere': ('skadeslaus',),
'skadeslausest': ('skadeslaus',),
'skadeslauseste': ('skadeslaus',),
'skadeslaust': ('skadeslaus',),
'skadesløs': ('skadesløs',),
'skadesløse': ('skadesløs',),
'skadesløsere': ('skadesløs',),
'skadesløsest': ('skadesløs',),
'skadesløseste': ('skadesløs',),
'skadesløst': ('skadesløs',),
'skaffa': ('skaffe',),
'skaffede': ('skaffe',),
'skaffende': ('skaffe',),
'skaffet': ('skaffe',),
'skaffete': ('skaffe',),
'skaffa': ('skaffe',),
'skaffede': ('skaffe',),
'skaffende': ('skaffe',),
'skaffet': ('skaffe',),
'skaffete': ('skaffe',),
'skafta': ('skafte',),
'skaftede': ('skafte',),
'skaftende': ('skafte',),
'skaftet': ('skafte',),
'skaftete': ('skafte',),
'skaka': ('skake',),
'skakede': ('skake',),
'skakende': ('skake',),
'skaket': ('skake',),
'skakete': ('skake',),
'skakk': ('skakk',),
'skakke': ('skakk',),
'skakkere': ('skakk',),
'skakkest': ('skakk',),
'skakkeste': ('skakk',),
'skakt': ('skakk',),
'skakk-kjørt': ('skakk-kjørt',),
'skakk-kjørte': ('skakk-kjørt',),
'skakk-kjørtere': ('skakk-kjørt',),
'skakk-kjørtest': ('skakk-kjørt',),
'skakk-kjørteste': ('skakk-kjørt',),
'skakka': ('skakke',),
'skakkede': ('skakke',),
'skakkende': ('skakke',),
'skakket': ('skakke',),
'skakkete': ('skakke',),
'skakkjørt': ('skakkjørt',),
'skakkjørte': ('skakkjørt',),
'skakkjørtere': ('skakkjørt',),
'skakkjørtest': ('skakkjørt',),
'skakkjørteste': ('skakkjørt',),
'skalerende': ('skalere',),
'skalert': ('skalere',),
'skalerte': ('skalere',),
'skalka': ('skalke',),
'skalkede': ('skalke',),
'skalkende': ('skalke',),
'skalket': ('skalke',),
'skalkete': ('skalke',),
'skalket': ('skalket',),
'skalkete': ('skalket',),
'skalketere': ('skalket',),
'skalketest': ('skalket',),
'skalketeste': ('skalket',),
'skalkete': ('skalkete',),
'skalla': ('skalla',),
'skalla': ('skalle',),
'skallede': ('skalle',),
'skallende': ('skalle',),
'skallet': ('skalle',),
'skallete': ('skalle',),
'skalla': ('skalle',),
'skallede': ('skalle',),
'skallende': ('skalle',),
'skallet': ('skalle',),
'skallete': ('skalle',),
'skallete': ('skallete',),
'skalltent': ('skalltent',),
'skalltente': ('skalltent',),
'skalltentere': ('skalltent',),
'skalltentest': ('skalltent',),
'skalltenteste': ('skalltent',),
'skalltent': ('skalltent',),
'skalltente': ('skalltent',),
'skalltentere': ('skalltent',),
'skalltentest': ('skalltent',),
'skalltenteste': ('skalltent',),
'skalperende': ('skalpere',),
'skalpert': ('skalpere',),
'skalperte': ('skalpere',),
'skalta': ('skalte',),
'skaltede': ('skalte',),
'skaltende': ('skalte',),
'skaltet': ('skalte',),
'skaltete': ('skalte',),
'skaltent': ('skaltent',),
'skaltente': ('skaltent',),
'skaltentere': ('skaltent',),
'skaltentest': ('skaltent',),
'skaltenteste': ('skaltent',),
'skaltent': ('skaltent',),
'skaltente': ('skaltent',),
'skaltentere': ('skaltent',),
'skaltentest': ('skaltent',),
'skaltenteste': ('skaltent',),
'skamdjerv': ('skamdjerv',),
'skamdjerve': ('skamdjerv',),
'skamdjervere': ('skamdjerv',),
'skamdjervest': ('skamdjerv',),
'skamdjerveste': ('skamdjerv',),
'skamdjervt': ('skamdjerv',),
'skamferende': ('skamfere',),
'skamfert': ('skamfere',),
'skamferte': ('skamfere',),
'skamfrosne': ('skamfryse',),
'skamfrossen': ('skamfryse',),
'skamfrosset': ('skamfryse',),
'skamfryse': ('skamfryse',),
'skamfrysende': ('skamfryse',),
'skamfull': ('skamfull',),
'skamfulle': ('skamfull',),
'skamfullere': ('skamfull',),
'skamfullest': ('skamfull',),
'skamfulleste': ('skamfull',),
'skamfullt': ('skamfull',),
'skamhogd': ('skamhogge',),
'skamhogde': ('skamhogge',),
'skamhoggede': ('skamhogge',),
'skamhoggende': ('skamhogge',),
'skamhogget': ('skamhogge',),
'skamhoggete': ('skamhogge',),
'skamhugd': ('skamhugge',),
'skamhugde': ('skamhugge',),
'skamhugga': ('skamhugge',),
'skamhuggede': ('skamhugge',),
'skamhuggende': ('skamhugge',),
'skamhugget': ('skamhugge',),
'skamhuggete': ('skamhugge',),
'skamkjørende': ('skamkjøre',),
'skamkjørt': ('skamkjøre',),
'skamkjørte': ('skamkjøre',),
'skamklippa': ('skamklippe',),
'skamklippede': ('skamklippe',),
'skamklippende': ('skamklippe',),
'skamklippet': ('skamklippe',),
'skamklippete': ('skamklippe',),
'skamklipt': ('skamklippe',),
'skamklipte': ('skamklippe',),
'skamlaus': ('skamlaus',),
'skamlause': ('skamlaus',),
'skamlausere': ('skamlaus',),
'skamlausest': ('skamlaus',),
'skamlauseste': ('skamlaus',),
'skamlaust': ('skamlaus',),
'skamløs': ('skamløs',),
'skamløse': ('skamløs',),
'skamløsere': ('skamløs',),
'skamløsest': ('skamløs',),
'skamløseste': ('skamløs',),
'skamløst': ('skamløs',),
'skamma': ('skamme',),
'skammede': ('skamme',),
'skammende': ('skamme',),
'skammet': ('skamme',),
'skammete': ('skamme',),
'skammelig': ('skammelig',),
'skammelige': ('skammelig',),
'skammeligere': ('skammelig',),
'skammeligst': ('skammelig',),
'skammeligste': ('skammelig',),
'skamrosende': ('skamrose',),
'skamrost': ('skamrose',),
'skamroste': ('skamrose',),
'skandaliserende': ('skandalisere',),
'skandalisert': ('skandalisere',),
'skandaliserte': ('skandalisere',),
'skandaløs': ('skandaløs',),
'skandaløse': ('skandaløs',),
'skandaløsere': ('skandaløs',),
'skandaløsest': ('skandaløs',),
'skandaløseste': ('skandaløs',),
'skandaløst': ('skandaløs',),
'skanderende': ('skandere',),
'skandert': ('skandere',),
'skanderte': ('skandere',),
'skandinavisk': ('skandinavisk',),
'skandinaviske': ('skandinavisk',),
'skandinaviskere': ('skandinavisk',),
'skandinaviskest': ('skandinavisk',),
'skandinaviskeste': ('skandinavisk',),
'skandinavistisk': ('skandinavistisk',),
'skandinavistiske': ('skandinavistisk',),
'skandinavistiskere': ('skandinavistisk',),
'skandinavistiskest': ('skandinavistisk',),
'skandinavistiskeste': ('skandinavistisk',),
'skanket': ('skanket',),
'skankete': ('skanket',),
'skanketere': ('skanket',),
'skanketest': ('skanket',),
'skanketeste': ('skanket',),
'skankete': ('skankete',),
'skanna': ('skanne',),
'skannede': ('skanne',),
'skannende': ('skanne',),
'skannet': ('skanne',),
'skannete': ('skanne',),
'skanta': ('skante',),
'skantede': ('skante',),
'skantende': ('skante',),
'skantet': ('skante',),
'skantete': ('skante',),
'skapaktig': ('skapaktig',),
'skapaktige': ('skapaktig',),
'skapaktigere': ('skapaktig',),
'skapaktigst': ('skapaktig',),
'skapaktigste': ('skapaktig',),
'skapa': ('skape',),
'skapende': ('skape',),
'skapt': ('skape',),
'skapte': ('skape',),
'skapelig': ('skapelig',),
'skapelige': ('skapelig',),
'skapeligere': ('skapelig',),
'skapeligst': ('skapelig',),
'skapeligste': ('skapelig',),
'skapende': ('skapende',),
'skaplig': ('skaplig',),
'skaplige': ('skaplig',),
'skapligere': ('skaplig',),
'skapligst': ('skaplig',),
'skapligste': ('skaplig',),
'skara': ('skare',),
'skarede': ('skare',),
'skarende': ('skare',),
'skaret': ('skare',),
'skarete': ('skare',),
'skara': ('skare',),
'skarede': ('skare',),
'skarende': ('skare',),
'skaret': ('skare',),
'skarete': ('skare',),
'skara': ('skare',),
'skarede': ('skare',),
'skarende': ('skare',),
'skaret': ('skare',),
'skarete': ('skare',),
'skaret': ('skaret',),
'skarete': ('skaret',),
'skaretere': ('skaret',),
'skaretest': ('skaret',),
'skareteste': ('skaret',),
'skaret': ('skaret',),
'skarete': ('skaret',),
'skaretere': ('skaret',),
'skaretest': ('skaret',),
'skareteste': ('skaret',),
'skarete': ('skarete',),
'skarete': ('skarete',),
'skarifiserende': ('skarifisere',),
'skarifisert': ('skarifisere',),
'skarifiserte': ('skarifisere',),
'skarp': ('skarp',),
'skarpe': ('skarp',),
'skarpere': ('skarp',),
'skarpest': ('skarp',),
'skarpeste': ('skarp',),
'skarpt': ('skarp',),
'skarplada': ('skarplada',),
'skarpladd': ('skarpladd',),
'skarpladde': ('skarpladd',),
'skarpladdere': ('skarpladd',),
'skarpladdest': ('skarpladd',),
'skarpladdeste': ('skarpladd',),
'skarpladede': ('skarpladet',),
'skarpladet': ('skarpladet',),
'skarpladete': ('skarpladet',),
'skarpladetere': ('skarpladet',),
'skarpladetest': ('skarpladet',),
'skarpladeteste': ('skarpladet',),
'skarpsindig': ('skarpsindig',),
'skarpsindige': ('skarpsindig',),
'skarpsindigere': ('skarpsindig',),
'skarpsindigst': ('skarpsindig',),
'skarpsindigste': ('skarpsindig',),
'skarpskodd': ('skarpskodd',),
'skarpskodde': ('skarpskodd',),
'skarpskoddere': ('skarpskodd',),
'skarpskoddest': ('skarpskodd',),
'skarpskoddeste': ('skarpskodd',),
'skarpskåren': ('skarpskåren',),
'skarpskårent': ('skarpskåren',),
'skarpskårne': ('skarpskåren',),
'skarpskårnere': ('skarpskåren',),
'skarpskårnest': ('skarpskåren',),
'skarpskårneste': ('skarpskåren',),
'skarpslipt': ('skarpslipt',),
'skarpslipte': ('skarpslipt',),
'skarpsliptere': ('skarpslipt',),
'skarpsliptest': ('skarpslipt',),
'skarpslipteste': ('skarpslipt',),
'skarpsynt': ('skarpsynt',),
'skarpsynte': ('skarpsynt',),
'skarpsyntere': ('skarpsynt',),
'skarpsyntest': ('skarpsynt',),
'skarpsynteste': ('skarpsynt',),
'skarptent': ('skarptent',),
'skarptente': ('skarptent',),
'skarptentere': ('skarptent',),
'skarptentest': ('skarptent',),
'skarptenteste': ('skarptent',),
'skarptseende': ('skarptseende',),
'skarra': ('skarre',),
'skarrede': ('skarre',),
'skarrende': ('skarre',),
'skarret': ('skarre',),
'skarrete': ('skarre',),
'skarva': ('skarve',),
'skarvede': ('skarve',),
'skarvende': ('skarve',),
'skarvet': ('skarve',),
'skarvete': ('skarve',),
'skarve': ('skarve',),
'skarvelig': ('skarvelig',),
'skarvelige': ('skarvelig',),
'skarveligere': ('skarvelig',),
'skarveligst': ('skarvelig',),
'skarveligste': ('skarvelig',),
'skarvet': ('skarvet',),
'skarvete': ('skarvet',),
'skarvetere': ('skarvet',),
'skarvetest': ('skarvet',),
'skarveteste': ('skarvet',),
'skarvete': ('skarvete',),
'skata': ('skate',),
'skatede': ('skate',),
'skatende': ('skate',),
'skatet': ('skate',),
'skatete': ('skate',),
'skattbar': ('skattbar',),
'skattbare': ('skattbar',),
'skattbarere': ('skattbar',),
'skattbarest': ('skattbar',),
'skattbareste': ('skattbar',),
'skattbart': ('skattbar',),
'skatta': ('skatte',),
'skattede': ('skatte',),
'skattende': ('skatte',),
'skattet': ('skatte',),
'skattete': ('skatte',),
'skattepliktig': ('skattepliktig',),
'skattepliktige': ('skattepliktig',),
'skattepliktigere': ('skattepliktig',),
'skattepliktigst': ('skattepliktig',),
'skattepliktigste': ('skattepliktig',),
'skatterettslig': ('skatterettslig',),
'skatterettslige': ('skatterettslig',),
'skatterettsligere': ('skatterettslig',),
'skatterettsligst': ('skatterettslig',),
'skatterettsligste': ('skatterettslig',),
'skattlagt': ('skattlegge',),
'skattlagte': ('skattlegge',),
'skattleggende': ('skattlegge',),
'skava': ('skave',),
'skavede': ('skave',),
'skavende': ('skave',),
'skavet': ('skave',),
'skavete': ('skave',),
'skavla': ('skavle',),
'skavlede': ('skavle',),
'skavlende': ('skavle',),
'skavlet': ('skavle',),
'skavlete': ('skavle',),
'skavlet': ('skavlet',),
'skavlete': ('skavlet',),
'skavletere': ('skavlet',),
'skavletest': ('skavlet',),
'skavleteste': ('skavlet',),
'skavlete': ('skavlete',),
'skeia': ('skeie',),
'skeid': ('skeie',),
'skeide': ('skeie',),
'skeiede': ('skeie',),
'skeiende': ('skeie',),
'skeiet': ('skeie',),
'skeiete': ('skeie',),
'skeia': ('skeie',),
'skeid': ('skeie',),
'skeide': ('skeie',),
'skeiede': ('skeie',),
'skeiende': ('skeie',),
'skeiet': ('skeie',),
'skeiete': ('skeie',),
'skeinende': ('skeine',),
'skeint': ('skeine',),
'skeinte': ('skeine',),
'skeisa': ('skeise',),
'skeisede': ('skeise',),
'skeisende': ('skeise',),
'skeiset': ('skeise',),
'skeisete': ('skeise',),
'skeist': ('skeise',),
'skeiste': ('skeise',),
'skeiv': ('skeiv',),
'skeive': ('skeiv',),
'skeivere': ('skeiv',),
'skeivest': ('skeiv',),
'skeiveste': ('skeiv',),
'skeivt': ('skeiv',),
'skeiva': ('skeive',),
'skeivede': ('skeive',),
'skeivende': ('skeive',),
'skeivet': ('skeive',),
'skeivete': ('skeive',),
'skeivla': ('skeivle',),
'skeivlede': ('skeivle',),
'skeivlende': ('skeivle',),
'skeivlet': ('skeivle',),
'skeivlete': ('skeivle',),
'skeivøyd': ('skeivøyd',),
'skeivøyde': ('skeivøyd',),
'skeivøydere': ('skeivøyd',),
'skeivøydest': ('skeivøyd',),
'skeivøydeste': ('skeivøyd',),
'skeptisk': ('skeptisk',),
'skeptiske': ('skeptisk',),
'skeptiskere': ('skeptisk',),
'skeptiskest': ('skeptisk',),
'skeptiskeste': ('skeptisk',),
'skifret': ('skifret',),
'skifrete': ('skifret',),
'skifretere': ('skifret',),
'skifretest': ('skifret',),
'skifreteste': ('skifret',),
'skifrete': ('skifrete',),
'skifrig': ('skifrig',),
'skifrige': ('skifrig',),
'skifrigere': ('skifrig',),
'skifrigst': ('skifrig',),
'skifrigste': ('skifrig',),
'skifta': ('skifte',),
'skiftede': ('skifte',),
'skiftende': ('skifte',),
'skiftet': ('skifte',),
'skiftete': ('skifte',),
'skikka': ('skikka',),
'skikka': ('skikke',),
'skikkede': ('skikke',),
'skikkende': ('skikke',),
'skikket': ('skikke',),
'skikkete': ('skikke',),
'skikkelig': ('skikkelig',),
'skikkelige': ('skikkelig',),
'skikkeligere': ('skikkelig',),
'skikkeligst': ('skikkelig',),
'skikkeligste': ('skikkelig',),
'skikkede': ('skikket',),
'skikket': ('skikket',),
'skikkete': ('skikket',),
'skikketere': ('skikket',),
'skikketest': ('skikket',),
'skikketeste': ('skikket',),
'skildra': ('skildre',),
'skildrede': ('skildre',),
'skildrende': ('skildre',),
'skildret': ('skildre',),
'skildrete': ('skildre',),
'skillende': ('skille',),
'skilt': ('skille',),
'skilte': ('skille',),
'skillinga': ('skillinge',),
'skillingede': ('skillinge',),
'skillingende': ('skillinge',),
'skillinget': ('skillinge',),
'skillingete': ('skillinge',),
'skilta': ('skilte',),
'skiltede': ('skilte',),
'skiltende': ('skilte',),
'skiltet': ('skilte',),
'skiltete': ('skilte',),
'skimla': ('skimle',),
'skimlede': ('skimle',),
'skimlende': ('skimle',),
'skimlet': ('skimle',),
'skimlete': ('skimle',),
'skimla': ('skimle',),
'skimlede': ('skimle',),
'skimlende': ('skimle',),
'skimlet': ('skimle',),
'skimlete': ('skimle',),
'skimla': ('skimle',),
'skimlede': ('skimle',),
'skimlende': ('skimle',),
'skimlet': ('skimle',),
'skimlete': ('skimle',),
'skimlet': ('skimlet',),
'skimlete': ('skimlet',),
'skimletere': ('skimlet',),
'skimletest': ('skimlet',),
'skimleteste': ('skimlet',),
'skimlet': ('skimlet',),
'skimlete': ('skimlet',),
'skimletere': ('skimlet',),
'skimletest': ('skimlet',),
'skimleteste': ('skimlet',),
'skimlete': ('skimlete',),
'skimlete': ('skimlete',),
'skimra': ('skimre',),
'skimrede': ('skimre',),
'skimrende': ('skimre',),
'skimret': ('skimre',),
'skimrete': ('skimre',),
'skimta': ('skimte',),
'skimtede': ('skimte',),
'skimtende': ('skimte',),
'skimtet': ('skimte',),
'skimtete': ('skimte',),
'skinger': ('skinger',),
'skingert': ('skinger',),
'skingre': ('skinger',),
'skingrere': ('skinger',),
'skingrest': ('skinger',),
'skingreste': ('skinger',),
'skingra': ('skingre',),
'skingrede': ('skingre',),
'skingrende': ('skingre',),
'skingret': ('skingre',),
'skingrete': ('skingre',),
'skinn- og beinfri': ('skinn- og beinfri',),
'skinn- og beinfrie': ('skinn- og beinfri',),
'skinn- og beinfriere': ('skinn- og beinfri',),
'skinn- og beinfriest': ('skinn- og beinfri',),
'skinn- og beinfrieste': ('skinn- og beinfri',),
'skinn- og beinfritt': ('skinn- og beinfri',),
'skinnbarlig': ('skinnbarlig',),
'skinnbarlige': ('skinnbarlig',),
'skinnbarligere': ('skinnbarlig',),
'skinnbarligst': ('skinnbarlig',),
'skinnbarligste': ('skinnbarlig',),
'skinndaud': ('skinndaud',),
'skinndaude': ('skinndaud',),
'skinndaudere': ('skinndaud',),
'skinndaudest': ('skinndaud',),
'skinndaudeste': ('skinndaud',),
'skinndaudt': ('skinndaud',),
'skinndød': ('skinndød',),
'skinndøde': ('skinndød',),
'skinndødere': ('skinndød',),
'skinndødest': ('skinndød',),
'skinndødeste': ('skinndød',),
'skinndødt': ('skinndød',),
'skinnende': ('skinne',),
'skint': ('skinne',),
'skinte': ('skinne',),
'skinnelaus': ('skinnelaus',),
'skinnelause': ('skinnelaus',),
'skinnelausere': ('skinnelaus',),
'skinnelausest': ('skinnelaus',),
'skinnelauseste': ('skinnelaus',),
'skinnelaust': ('skinnelaus',),
'skinneløs': ('skinneløs',),
'skinneløse': ('skinneløs',),
'skinneløsere': ('skinneløs',),
'skinneløsest': ('skinneløs',),
'skinneløseste': ('skinneløs',),
'skinneløst': ('skinneløs',),
'skinnflat': ('skinnflat',),
'skinnflate': ('skinnflat',),
'skinnflatere': ('skinnflat',),
'skinnflatest': ('skinnflat',),
'skinnflateste': ('skinnflat',),
'skinnflatt': ('skinnflat',),
'skinnhellig': ('skinnhellig',),
'skinnhellige': ('skinnhellig',),
'skinnhelligere': ('skinnhellig',),
'skinnhelligst': ('skinnhellig',),
'skinnhelligste': ('skinnhellig',),
'skinnmager': ('skinnmager',),
'skinnmagert': ('skinnmager',),
'skinnmagre': ('skinnmager',),
'skinnmagrere': ('skinnmager',),
'skinnmagrest': ('skinnmager',),
'skinnmagreste': ('skinnmager',),
'skinnsyk': ('skinnsyk',),
'skinnsyke': ('skinnsyk',),
'skinnsykere': ('skinnsyk',),
'skinnsykest': ('skinnsyk',),
'skinnsykeste': ('skinnsyk',),
'skinnsykt': ('skinnsyk',),
'skipbrudden': ('skipbrudden',),
'skipbruddent': ('skipbrudden',),
'skipbrudne': ('skipbrudden',),
'skipbrudnere': ('skipbrudden',),
'skipbrudnest': ('skipbrudden',),
'skipbrudneste': ('skipbrudden',),
'skipa': ('skipe',),
'skipede': ('skipe',),
'skipende': ('skipe',),
'skipet': ('skipe',),
'skipete': ('skipe',),
'skipa': ('skipe',),
'skipede': ('skipe',),
'skipende': ('skipe',),
'skipet': ('skipe',),
'skipete': ('skipe',),
'skipla': ('skiple',),
'skiplede': ('skiple',),
'skiplende': ('skiple',),
'skiplet': ('skiple',),
'skiplete': ('skiple',),
'skir': ('skir',),
'skire': ('skir',),
'skirere': ('skir',),
'skirest': ('skir',),
'skireste': ('skir',),
'skirt': ('skir',),
'skismatisk': ('skismatisk',),
'skismatiske': ('skismatisk',),
'skismatiskere': ('skismatisk',),
'skismatiskest': ('skismatisk',),
'skismatiskeste': ('skismatisk',),
'skisserende': ('skissere',),
'skissert': ('skissere',),
'skisserte': ('skissere',),
'skitende': ('skite',),
'skitt': ('skite',),
'skitte': ('skite',),
'skitna': ('skitne',),
'skitnede': ('skitne',),
'skitnende': ('skitne',),
'skitnet': ('skitne',),
'skitnete': ('skitne',),
'skitt': ('skitt',),
'skitne': ('skitten',),
'skitnere': ('skitten',),
'skitnest': ('skitten',),
'skitneste': ('skitten',),
'skitten': ('skitten',),
'skittent': ('skitten',),
'skittenferdig': ('skittenferdig',),
'skittenferdige': ('skittenferdig',),
'skittenferdigere': ('skittenferdig',),
'skittenferdigst': ('skittenferdig',),
'skittenferdigste': ('skittenferdig',),
'skittfin': ('skittfin',),
'skittfine': ('skittfin',),
'skittfinere': ('skittfin',),
'skittfinest': ('skittfin',),
'skittfineste': ('skittfin',),
'skittfint': ('skittfin',),
'skittlei': ('skittlei',),
'skittleie': ('skittlei',),
'skittleiere': ('skittlei',),
'skittleiest': ('skittlei',),
'skittleieste': ('skittlei',),
'skittleit': ('skittlei',),
'skittleitt': ('skittlei',),
'skittviktig': ('skittviktig',),
'skittviktige': ('skittviktig',),
'skittviktigere': ('skittviktig',),
'skittviktigst': ('skittviktig',),
'skittviktigste': ('skittviktig',),
'skiva': ('skive',),
'skivede': ('skive',),
'skivende': ('skive',),
'skivet': ('skive',),
'skivete': ('skive',),
'skjedd': ('skje',),
'skjedde': ('skje',),
'skjeende': ('skje',),
'skjebnebestemt': ('skjebnebestemt',),
'skjebnebestemte': ('skjebnebestemt',),
'skjebnebestemtere': ('skjebnebestemt',),
'skjebnebestemtest': ('skjebnebestemt',),
'skjebnebestemteste': ('skjebnebestemt',),
'skjebnesvanger': ('skjebnesvanger',),
'skjebnesvangert': ('skjebnesvanger',),
'skjebnesvangre': ('skjebnesvanger',),
'skjebnesvangrere': ('skjebnesvanger',),
'skjebnesvangrest': ('skjebnesvanger',),
'skjebnesvangreste': ('skjebnesvanger',),
'skjebnetung': ('skjebnetung',),
'skjebnetunge': ('skjebnetung',),
'skjebnetungere': ('skjebnetung',),
'skjebnetungest': ('skjebnetung',),
'skjebnetungeste': ('skjebnetung',),
'skjebnetungt': ('skjebnetung',),
'skjebnetyngre': ('skjebnetung',),
'skjebnetyngst': ('skjebnetung',),
'skjebnetyngste': ('skjebnetung',),
'skjefta': ('skjefte',),
'skjeftede': ('skjefte',),
'skjeftende': ('skjefte',),
'skjeftet': ('skjefte',),
'skjeftete': ('skjefte',),
'skjegget': ('skjegget',),
'skjeggete': ('skjegget',),
'skjeggetere': ('skjegget',),
'skjeggetest': ('skjegget',),
'skjeggeteste': ('skjegget',),
'skjeggete': ('skjeggete',),
'skjelende': ('skjele',),
'skjelt': ('skjele',),
'skjelte': ('skjele',),
'skjeletterende': ('skjelettere',),
'skjelettert': ('skjelettere',),
'skjeletterte': ('skjelettere',),
'skjellende': ('skjelle',),
'skjelt': ('skjelle',),
'skjelte': ('skjelle',),
'skjellende': ('skjelle',),
'skjelt': ('skjelle',),
'skjelte': ('skjelle',),
'skjellet': ('skjellet',),
'skjellete': ('skjellet',),
'skjelletere': ('skjellet',),
'skjelletest': ('skjellet',),
'skjelleteste': ('skjellet',),
'skjellete': ('skjellete',),
'skjellig': ('skjellig',),
'skjellige': ('skjellig',),
'skjelligere': ('skjellig',),
'skjelligst': ('skjellig',),
'skjelligste': ('skjellig',),
'skjellsettende': ('skjellsettende',),
'skjelma': ('skjelme',),
'skjelmede': ('skjelme',),
'skjelmende': ('skjelme',),
'skjelmet': ('skjelme',),
'skjelmete': ('skjelme',),
'skjelmsk': ('skjelmsk',),
'skjelmske': ('skjelmsk',),
'skjelmskere': ('skjelmsk',),
'skjelmskest': ('skjelmsk',),
'skjelmskeste': ('skjelmsk',),
'skjelmskt': ('skjelmsk',),
'skjelna': ('skjelne',),
'skjelnede': ('skjelne',),
'skjelnende': ('skjelne',),
'skjelnet': ('skjelne',),
'skjelnete': ('skjelne',),
'skjelv': ('skjelv',),
'skjelve': ('skjelv',),
'skjelvere': ('skjelv',),
'skjelvest': ('skjelv',),
'skjelveste': ('skjelv',),
'skjelvt': ('skjelv',),
'skjelven': ('skjelve',),
'skjelvende': ('skjelve',),
'skjelvet': ('skjelve',),
'skjelvne': ('skjelve',),
'skjelven': ('skjelven',),
'skjelvent': ('skjelven',),
'skjelvne': ('skjelven',),
'skjelvnere': ('skjelven',),
'skjelvnest': ('skjelven',),
'skjelvneste': ('skjelven',),
'skjelvhendt': ('skjelvhendt',),
'skjelvhendte': ('skjelvhendt',),
'skjelvhendtere': ('skjelvhendt',),
'skjelvhendtest': ('skjelvhendt',),
'skjelvhendteste': ('skjelvhendt',),
'skjeløyd': ('skjeløyd',),
'skjeløyde': ('skjeløyd',),
'skjeløydere': ('skjeløyd',),
'skjeløydest': ('skjeløyd',),
'skjeløydeste': ('skjeløyd',),
'skjematiserende': ('skjematisere',),
'skjematisert': ('skjematisere',),
'skjematiserte': ('skjematisere',),
'skjematisk': ('skjematisk',),
'skjematiske': ('skjematisk',),
'skjematiskere': ('skjematisk',),
'skjematiskest': ('skjematisk',),
'skjematiskeste': ('skjematisk',),
'skjemmede': ('skjemme',),
'skjemmende': ('skjemme',),
'skjemmet': ('skjemme',),
'skjemmete': ('skjemme',),
'skjemt': ('skjemme',),
'skjemte': ('skjemme',),
'skjemta': ('skjemte',),
'skjemtede': ('skjemte',),
'skjemtende': ('skjemte',),
'skjemtet': ('skjemte',),
'skjemtete': ('skjemte',),
'skjemtefull': ('skjemtefull',),
'skjemtefulle': ('skjemtefull',),
'skjemtefullere': ('skjemtefull',),
'skjemtefullest': ('skjemtefull',),
'skjemtefulleste': ('skjemtefull',),
'skjemtefullt': ('skjemtefull',),
'skjemtsom': ('skjemtsom',),
'skjemtsomme': ('skjemtsom',),
'skjemtsommere': ('skjemtsom',),
'skjemtsomst': ('skjemtsom',),
'skjemtsomste': ('skjemtsom',),
'skjemtsomt': ('skjemtsom',),
'skjenda': ('skjende',),
'skjendede': ('skjende',),
'skjendende': ('skjende',),
'skjendet': ('skjende',),
'skjendete': ('skjende',),
'skjendig': ('skjendig',),
'skjendige': ('skjendig',),
'skjendigere': ('skjendig',),
'skjendigst': ('skjendig',),
'skjendigste': ('skjendig',),
'skjena': ('skjene',),
'skjenede': ('skjene',),
'skjenende': ('skjene',),
'skjenet': ('skjene',),
'skjenete': ('skjene',),
'skjent': ('skjene',),
'skjente': ('skjene',),
'skjenka': ('skjenke',),
'skjenkede': ('skjenke',),
'skjenkende': ('skjenke',),
'skjenket': ('skjenke',),
'skjenkete': ('skjenke',),
'skjenkt': ('skjenke',),
'skjenkte': ('skjenke',),
'skjennende': ('skjenne',),
'skjent': ('skjenne',),
'skjente': ('skjenne',),
'skjermblomstra': ('skjermblomstra',),
'skjermblomstret': ('skjermblomstret',),
'skjermblomstrete': ('skjermblomstret',),
'skjermblomstretere': ('skjermblomstret',),
'skjermblomstretest': ('skjermblomstret',),
'skjermblomstreteste': ('skjermblomstret',),
'skjerma': ('skjerme',),
'skjermede': ('skjerme',),
'skjermende': ('skjerme',),
'skjermet': ('skjerme',),
'skjermete': ('skjerme',),
'skjerpa': ('skjerpe',),
'skjerpede': ('skjerpe',),
'skjerpende': ('skjerpe',),
'skjerpet': ('skjerpe',),
'skjerpete': ('skjerpe',),
'skjerpa': ('skjerpe',),
'skjerpede': ('skjerpe',),
'skjerpende': ('skjerpe',),
'skjerpet': ('skjerpe',),
'skjerpete': ('skjerpe',),
'skjerr': ('skjerr',),
'skjerre': ('skjerr',),
'skjerrere': ('skjerr',),
'skjerrest': ('skjerr',),
'skjerreste': ('skjerr',),
'skjert': ('skjerr',),
'skjev': ('skjev',),
'skjeve': ('skjev',),
'skjevere': ('skjev',),
'skjevest': ('skjev',),
'skjeveste': ('skjev',),
'skjevt': ('skjev',),
'skjevøyd': ('skjevøyd',),
'skjevøyde': ('skjevøyd',),
'skjevøydere': ('skjevøyd',),
'skjevøydest': ('skjevøyd',),
'skjevøydeste': ('skjevøyd',),
'skjolda': ('skjolde',),
'skjoldede': ('skjolde',),
'skjoldende': ('skjolde',),
'skjoldet': ('skjolde',),
'skjoldete': ('skjolde',),
'skjoldet': ('skjoldet',),
'skjoldete': ('skjoldet',),
'skjoldetere': ('skjoldet',),
'skjoldetest': ('skjoldet',),
'skjoldeteste': ('skjoldet',),
'skjoldete': ('skjoldete',),
'skjulende': ('skjule',),
'skjult': ('skjule',),
'skjulte': ('skjule',),
'skjær': ('skjær',),
'skjære': ('skjær',),
'skjærere': ('skjær',),
'skjærest': ('skjær',),
'skjæreste': ('skjær',),
'skjært': ('skjær',),
'skjær': ('skjær',),
'skjære': ('skjær',),
'skjærere': ('skjær',),
'skjærest': ('skjær',),
'skjæreste': ('skjær',),
'skjært': ('skjær',),
'skjærende': ('skjære',),
'skåren': ('skjære',),
'skåret': ('skjære',),
'skårne': ('skjære',),
'skjærhuda': ('skjærhuda',),
'skjærhudede': ('skjærhudet',),
'skjærhudet': ('skjærhudet',),
'skjærhudete': ('skjærhudet',),
'skjærhudetere': ('skjærhudet',),
'skjærhudetest': ('skjærhudet',),
'skjærhudeteste': ('skjærhudet',),
'skjærna': ('skjærne',),
'skjærnede': ('skjærne',),
'skjærnende': ('skjærne',),
'skjærnet': ('skjærne',),
'skjærnete': ('skjærne',),
'skjærsatt': ('skjærsatt',),
'skjærsatte': ('skjærsatt',),
'skjærsattere': ('skjærsatt',),
'skjærsattest': ('skjærsatt',),
'skjærsatteste': ('skjærsatt',),
'skjødesløs': ('skjødesløs',),
'skjødesløse': ('skjødesløs',),
'skjødesløsere': ('skjødesløs',),
'skjødesløsest': ('skjødesløs',),
'skjødesløseste': ('skjødesløs',),
'skjødesløst': ('skjødesløs',),
'skjønn': ('skjønn',),
'skjønne': ('skjønn',),
'skjønnere': ('skjønn',),
'skjønnest': ('skjønn',),
'skjønneste': ('skjønn',),
'skjønt': ('skjønn',),
'skjønnende': ('skjønne',),
'skjønt': ('skjønne',),
'skjønte': ('skjønne',),
'skjønnlitterær': ('skjønnlitterær',),
'skjønnlitterære': ('skjønnlitterær',),
'skjønnlitterærere': ('skjønnlitterær',),
'skjønnlitterærest': ('skjønnlitterær',),
'skjønnlitteræreste': ('skjønnlitterær',),
'skjønnlitterært': ('skjønnlitterær',),
'skjønnmalende': ('skjønnmale',),
'skjønnmalt': ('skjønnmale',),
'skjønnmalte': ('skjønnmale',),
'skjønnsligna': ('skjønnsligne',),
'skjønnslignede': ('skjønnsligne',),
'skjønnslignende': ('skjønnsligne',),
'skjønnslignet': ('skjønnsligne',),
'skjønnslignete': ('skjønnsligne',),
'skjønnslikna': ('skjønnslikne',),
'skjønnsliknede': ('skjønnslikne',),
'skjønnsliknende': ('skjønnslikne',),
'skjønnsliknet': ('skjønnslikne',),
'skjønnsliknete': ('skjønnslikne',),
'skjønnsmessig': ('skjønnsmessig',),
'skjønnsmessige': ('skjønnsmessig',),
'skjønnsmessigere': ('skjønnsmessig',),
'skjønnsmessigst': ('skjønnsmessig',),
'skjønnsmessigste': ('skjønnsmessig',),
'skjønnsom': ('skjønnsom',),
'skjønnsomme': ('skjønnsom',),
'skjønnsommere': ('skjønnsom',),
'skjønnsomst': ('skjønnsom',),
'skjønnsomste': ('skjønnsom',),
'skjønnsomt': ('skjønnsom',),
'skjør': ('skjør',),
'skjøre': ('skjør',),
'skjørere': ('skjør',),
'skjørest': ('skjør',),
'skjøreste': ('skjør',),
'skjørt': ('skjør',),
'skjørna': ('skjørne',),
'skjørnede': ('skjørne',),
'skjørnende': ('skjørne',),
'skjørnet': ('skjørne',),
'skjørnete': ('skjørne',),
'skjørna': ('skjørne',),
'skjørnede': ('skjørne',),
'skjørnende': ('skjørne',),
'skjørnet': ('skjørne',),
'skjørnete': ('skjørne',),
'skjørta': ('skjørte',),
'skjørtede': ('skjørte',),
'skjørtende': ('skjørte',),
'skjørtet': ('skjørte',),
'skjørtete': ('skjørte',),
'skjøtende': ('skjøte',),
'skjøtt': ('skjøte',),
'skjøtte': ('skjøte',),
'skjøta': ('skjøte',),
'skjøtede': ('skjøte',),
'skjøtende': ('skjøte',),
'skjøtet': ('skjøte',),
'skjøtete': ('skjøte',),
'skjøtt': ('skjøte',),
'skjøtte': ('skjøte',),
'skjøtta': ('skjøtte',),
'skjøttede': ('skjøtte',),
'skjøttende': ('skjøtte',),
'skjøttet': ('skjøtte',),
'skjøttete': ('skjøtte',),
'sklidd': ('skli',),
'sklidde': ('skli',),
'skliende': ('skli',),
'sklisikker': ('sklisikker',),
'sklisikkert': ('sklisikker',),
'sklisikre': ('sklisikker',),
'sklisikrere': ('sklisikker',),
'sklisikrest': ('sklisikker',),
'sklisikreste': ('sklisikker',),
'skodd': ('sko',),
'skodde': ('sko',),
'skoende': ('sko',),
'skoddet': ('skoddet',),
'skoddete': ('skoddet',),
'skoddetere': ('skoddet',),
'skoddetest': ('skoddet',),
'skoddeteste': ('skoddet',),
'skoddete': ('skoddete',),
'skofta': ('skofte',),
'skoftede': ('skofte',),
'skoftende': ('skofte',),
'skoftet': ('skofte',),
'skoftete': ('skofte',),
'skogkledd': ('skogkledd',),
'skogkledde': ('skogkledd',),
'skogkleddere': ('skogkledd',),
'skogkleddest': ('skogkledd',),
'skogkleddeste': ('skogkledd',),
'skogra': ('skogre',),
'skogrede': ('skogre',),
'skogrende': ('skogre',),
'skogret': ('skogre',),
'skogrete': ('skogre',),
'skogredd': ('skogredd',),
'skogredde': ('skogredd',),
'skogreddere': ('skogredd',),
'skogreddest': ('skogredd',),
'skogreddeste': ('skogredd',),
'skolastisk': ('skolastisk',),
'skolastiske': ('skolastisk',),
'skolastiskere': ('skolastisk',),
'skolastiskest': ('skolastisk',),
'skolastiskeste': ('skolastisk',),
'skolende': ('skole',),
'skolt': ('skole',),
'skolte': ('skole',),
'skoleflink': ('skoleflink',),
'skoleflinke': ('skoleflink',),
'skoleflinkere': ('skoleflink',),
'skoleflinkest': ('skoleflink',),
'skoleflinkeste': ('skoleflink',),
'skoleflinkt': ('skoleflink',),
'skolemoden': ('skolemoden',),
'skolemodent': ('skolemoden',),
'skolemodne': ('skolemoden',),
'skolemodnere': ('skolemoden',),
'skolemodnest': ('skolemoden',),
'skolemodneste': ('skolemoden',),
'skolepliktig': ('skolepliktig',),
'skolepliktige': ('skolepliktig',),
'skolepliktigere': ('skolepliktig',),
'skolepliktigst': ('skolepliktig',),
'skolepliktigste': ('skolepliktig',),
'skolerende': ('skolere',),
'skolert': ('skolere',),
'skolerte': ('skolere',),
'skoletrett': ('skoletrett',),
'skoletrette': ('skoletrett',),
'skoletrettere': ('skoletrett',),
'skoletrettest': ('skoletrett',),
'skoletretteste': ('skoletrett',),
'skoletrøtt': ('skoletrøtt',),
'skoletrøtte': ('skoletrøtt',),
'skoletrøttere': ('skoletrøtt',),
'skoletrøttest': ('skoletrøtt',),
'skoletrøtteste': ('skoletrøtt',),
'skoleveik': ('skoleveik',),
'skoleveike': ('skoleveik',),
'skoleveikere': ('skoleveik',),
'skoleveikest': ('skoleveik',),
'skoleveikeste': ('skoleveik',),
'skoleveikt': ('skoleveik',),
'skolevek': ('skolevek',),
'skoleveke': ('skolevek',),
'skolevekere': ('skolevek',),
'skolevekest': ('skolevek',),
'skolevekeste': ('skolevek',),
'skolevekt': ('skolevek',),
'skolma': ('skolme',),
'skolmede': ('skolme',),
'skolmende': ('skolme',),
'skolmet': ('skolme',),
'skolmete': ('skolme',),
'skorbutisk': ('skorbutisk',),
'skorbutiske': ('skorbutisk',),
'skorbutiskere': ('skorbutisk',),
'skorbutiskest': ('skorbutisk',),
'skorbutiskeste': ('skorbutisk',),
'skorda': ('skorde',),
'skordede': ('skorde',),
'skordende': ('skorde',),
'skordet': ('skorde',),
'skordete': ('skorde',),
'skora': ('skore',),
'skorede': ('skore',),
'skorende': ('skore',),
'skoret': ('skore',),
'skorete': ('skore',),
'skorpa': ('skorpe',),
'skorpede': ('skorpe',),
'skorpende': ('skorpe',),
'skorpet': ('skorpe',),
'skorpete': ('skorpe',),
'skorpet': ('skorpet',),
'skorpete': ('skorpet',),
'skorpetere': ('skorpet',),
'skorpetest': ('skorpet',),
'skorpeteste': ('skorpet',),
'skorpete': ('skorpete',),
'skorta': ('skorte',),
'skortede': ('skorte',),
'skortende': ('skorte',),
'skortet': ('skorte',),
'skortete': ('skorte',),
'skosa': ('skose',),
'skosede': ('skose',),
'skosende': ('skose',),
'skoset': ('skose',),
'skosete': ('skose',),
'skost': ('skose',),
'skoste': ('skose',),
'skotsk': ('skotsk',),
'skotske': ('skotsk',),
'skotskere': ('skotsk',),
'skotskest': ('skotsk',),
'skotskeste': ('skotsk',),
'skotskrutet': ('skotskrutet',),
'skotskrutete': ('skotskrutet',),
'skotskrutetere': ('skotskrutet',),
'skotskrutetest': ('skotskrutet',),
'skotskruteteste': ('skotskrutet',),
'skotskrutete': ('skotskrutete',),
'skotta': ('skotte',),
'skottede': ('skotte',),
'skottende': ('skotte',),
'skottet': ('skotte',),
'skottete': ('skotte',),
'skottklar': ('skottklar',),
'skottklare': ('skottklar',),
'skottklarere': ('skottklar',),
'skottklarest': ('skottklar',),
'skottklareste': ('skottklar',),
'skottklart': ('skottklar',),
'skottredd': ('skottredd',),
'skottredde': ('skottredd',),
'skottreddere': ('skottredd',),
'skottreddest': ('skottredd',),
'skottreddeste': ('skottredd',),
'skottsikker': ('skottsikker',),
'skottsikkert': ('skottsikker',),
'skottsikre': ('skottsikker',),
'skottsikrere': ('skottsikker',),
'skottsikrest': ('skottsikker',),
'skottsikreste': ('skottsikker',),
'skottsterk': ('skottsterk',),
'skottsterke': ('skottsterk',),
'skottsterkere': ('skottsterk',),
'skottsterkest': ('skottsterk',),
'skottsterkeste': ('skottsterk',),
'skottsterkt': ('skottsterk',),
'skova': ('skove',),
'skovede': ('skove',),
'skovende': ('skove',),
'skovet': ('skove',),
'skovete': ('skove',),
'skovet': ('skovet',),
'skovete': ('skovet',),
'skovetere': ('skovet',),
'skovetest': ('skovet',),
'skoveteste': ('skovet',),
'skovete': ('skovete',),
'skovla': ('skovle',),
'skovlede': ('skovle',),
'skovlende': ('skovle',),
'skovlet': ('skovle',),
'skovlete': ('skovle',),
'skrakla': ('skrakle',),
'skraklede': ('skrakle',),
'skraklende': ('skrakle',),
'skraklet': ('skrakle',),
'skraklete': ('skrakle',),
'skrakla': ('skrakle',),
'skraklede': ('skrakle',),
'skraklende': ('skrakle',),
'skraklet': ('skrakle',),
'skraklete': ('skrakle',),
'skraklet': ('skraklet',),
'skraklete': ('skraklet',),
'skrakletere': ('skraklet',),
'skrakletest': ('skraklet',),
'skrakleteste': ('skraklet',),
'skraklete': ('skraklete',),
'skral': ('skral',),
'skrale': ('skral',),
'skralere': ('skral',),
'skralest': ('skral',),
'skraleste': ('skral',),
'skralt': ('skral',),
'skralla': ('skralle',),
'skrallede': ('skralle',),
'skrallende': ('skralle',),
'skrallet': ('skralle',),
'skrallete': ('skralle',),
'skramla': ('skramle',),
'skramlede': ('skramle',),
'skramlende': ('skramle',),
'skramlet': ('skramle',),
'skramlete': ('skramle',),
'skrangla': ('skrangle',),
'skranglede': ('skrangle',),
'skranglende': ('skrangle',),
'skranglet': ('skrangle',),
'skranglete': ('skrangle',),
'skranglet': ('skranglet',),
'skranglete': ('skranglet',),
'skrangletere': ('skranglet',),
'skrangletest': ('skranglet',),
'skrangleteste': ('skranglet',),
'skranglete': ('skranglete',),
'skranta': ('skrante',),
'skrantede': ('skrante',),
'skrantende': ('skrante',),
'skrantet': ('skrante',),
'skrantete': ('skrante',),
'skranten': ('skranten',),
'skrantent': ('skranten',),
'skrantne': ('skranten',),
'skrantnere': ('skranten',),
'skrantnest': ('skranten',),
'skrantneste': ('skranten',),
'skrapa': ('skrape',),
'skrapede': ('skrape',),
'skrapende': ('skrape',),
'skrapet': ('skrape',),
'skrapete': ('skrape',),
'skrapt': ('skrape',),
'skrapte': ('skrape',),
'skrapp': ('skrapp',),
'skrappe': ('skrapp',),
'skrappere': ('skrapp',),
'skrappest': ('skrapp',),
'skrappeste': ('skrapp',),
'skrapt': ('skrapp',),
'skrappa': ('skrappe',),
'skrappede': ('skrappe',),
'skrappende': ('skrappe',),
'skrappet': ('skrappe',),
'skrappete': ('skrappe',),
'skrasla': ('skrasle',),
'skraslede': ('skrasle',),
'skraslende': ('skrasle',),
'skraslet': ('skrasle',),
'skraslete': ('skrasle',),
'skratla': ('skratle',),
'skratlede': ('skratle',),
'skratlende': ('skratle',),
'skratlet': ('skratle',),
'skratlete': ('skratle',),
'skratta': ('skratte',),
'skrattede': ('skratte',),
'skrattende': ('skratte',),
'skrattet': ('skratte',),
'skrattete': ('skratte',),
'skrattledd': ('skrattle',),
'skrattledde': ('skrattle',),
'skrattleende': ('skrattle',),
'skraverende': ('skravere',),
'skravert': ('skravere',),
'skraverte': ('skravere',),
'skravla': ('skravle',),
'skravlede': ('skravle',),
'skravlende': ('skravle',),
'skravlet': ('skravle',),
'skravlete': ('skravle',),
'skravlet': ('skravlet',),
'skravlete': ('skravlet',),
'skravletere': ('skravlet',),
'skravletest': ('skravlet',),
'skravleteste': ('skravlet',),
'skravlete': ('skravlete',),
'skredd': ('skre',),
'skredde': ('skre',),
'skreende': ('skre',),
'skreddererende': ('skredderere',),
'skredderert': ('skredderere',),
'skreddererte': ('skredderere',),
'skreddersydd': ('skreddersy',),
'skreddersydde': ('skreddersy',),
'skreddersyende': ('skreddersy',),
'skrekkblanda': ('skrekkblanda',),
'skrekkblandede': ('skrekkblandet',),
'skrekkblandet': ('skrekkblandet',),
'skrekkblandete': ('skrekkblandet',),
'skrekkblandetere': ('skrekkblandet',),
'skrekkblandetest': ('skrekkblandet',),
'skrekkblandeteste': ('skrekkblandet',),
'skrekkelig': ('skrekkelig',),
'skrekkelige': ('skrekkelig',),
'skrekkeligere': ('skrekkelig',),
'skrekkeligst': ('skrekkelig',),
'skrekkeligste': ('skrekkelig',),
'skrekkslagen': ('skrekkslagen',),
'skrekkslagent': ('skrekkslagen',),
'skrekkslagne': ('skrekkslagen',),
'skrekkslagnere': ('skrekkslagen',),
'skrekkslagnest': ('skrekkslagen',),
'skrekkslagneste': ('skrekkslagen',),
'skrekkslått': ('skrekkslått',),
'skrekkslåtte': ('skrekkslått',),
'skrekkslåttere': ('skrekkslått',),
'skrekkslåttest': ('skrekkslått',),
'skrekkslåtteste': ('skrekkslått',),
'skrellende': ('skrelle',),
'skrelt': ('skrelle',),
'skrelte': ('skrelle',),
'skrella': ('skrelle',),
'skrellede': ('skrelle',),
'skrellende': ('skrelle',),
'skrellet': ('skrelle',),
'skrellete': ('skrelle',),
'skrelt': ('skrelle',),
'skrelte': ('skrelle',),
'skremmende': ('skremme',),
'skremt': ('skremme',),
'skremte': ('skremme',),
'skremmelig': ('skremmelig',),
'skremmelige': ('skremmelig',),
'skremmeligere': ('skremmelig',),
'skremmeligst': ('skremmelig',),
'skremmeligste': ('skremmelig',),
'skrensa': ('skrense',),
'skrensede': ('skrense',),
'skrensende': ('skrense',),
'skrenset': ('skrense',),
'skrensete': ('skrense',),
'skreppa': ('skreppe',),
'skreppede': ('skreppe',),
'skreppende': ('skreppe',),
'skreppet': ('skreppe',),
'skreppete': ('skreppe',),
'skrept': ('skreppe',),
'skrepte': ('skreppe',),
'skreva': ('skreve',),
'skrevd': ('skreve',),
'skrevde': ('skreve',),
'skrevede': ('skreve',),
'skrevende': ('skreve',),
'skrevet': ('skreve',),
'skrevete': ('skreve',),
'skreden': ('skri',),
'skredet': ('skri',),
'skredne': ('skri',),
'skriende': ('skri',),
'skribla': ('skrible',),
'skriblede': ('skrible',),
'skriblende': ('skrible',),
'skriblet': ('skrible',),
'skriblete': ('skrible',),
'skreden': ('skride',),
'skredet': ('skride',),
'skredne': ('skride',),
'skridende': ('skride',),
'skridt': ('skride',),
'skrifta': ('skrifte',),
'skriftede': ('skrifte',),
'skriftende': ('skrifte',),
'skriftet': ('skrifte',),
'skriftete': ('skrifte',),
'skriftfesta': ('skriftfeste',),
'skriftfestede': ('skriftfeste',),
'skriftfestende': ('skriftfeste',),
'skriftfestet': ('skriftfeste',),
'skriftfestete': ('skriftfeste',),
'skriftklok': ('skriftklok',),
'skriftkloke': ('skriftklok',),
'skriftklokere': ('skriftklok',),
'skriftklokest': ('skriftklok',),
'skriftklokeste': ('skriftklok',),
'skriftklokt': ('skriftklok',),
'skriftkyndig': ('skriftkyndig',),
'skriftkyndige': ('skriftkyndig',),
'skriftkyndigere': ('skriftkyndig',),
'skriftkyndigst': ('skriftkyndig',),
'skriftkyndigste': ('skriftkyndig',),
'skriftlig': ('skriftlig',),
'skriftlige': ('skriftlig',),
'skriftligere': ('skriftlig',),
'skriftligst': ('skriftlig',),
'skriftligste': ('skriftlig',),
'skriftlærd': ('skriftlærd',),
'skriftlærde': ('skriftlærd',),
'skriftlærdere': ('skriftlærd',),
'skriftlærdest': ('skriftlærd',),
'skriftlærdeste': ('skriftlærd',),
'skreken': ('skrike',),
'skreket': ('skrike',),
'skrekne': ('skrike',),
'skrikende': ('skrike',),
'skrinlagt': ('skrinlegge',),
'skrinlagte': ('skrinlegge',),
'skrinleggende': ('skrinlegge',),
'skrinn': ('skrinn',),
'skrinne': ('skrinn',),
'skrinnere': ('skrinn',),
'skrinnest': ('skrinn',),
'skrinneste': ('skrinn',),
'skrint': ('skrinn',),
'skripen': ('skripen',),
'skripent': ('skripen',),
'skripne': ('skripen',),
'skripnere': ('skripen',),
'skripnest': ('skripen',),
'skripneste': ('skripen',),
'skripet': ('skripet',),
'skripete': ('skripet',),
'skripetere': ('skripet',),
'skripetest': ('skripet',),
'skripeteste': ('skripet',),
'skripete': ('skripete',),
'skritta': ('skritte',),
'skrittede': ('skritte',),
'skrittende': ('skritte',),
'skrittet': ('skritte',),
'skrittete': ('skritte',),
'skreven': ('skrive',),
'skrevet': ('skrive',),
'skrevne': ('skrive',),
'skrivende': ('skrive',),
'skrivefør': ('skrivefør',),
'skriveføre': ('skrivefør',),
'skriveførere': ('skrivefør',),
'skriveførest': ('skrivefør',),
'skriveføreste': ('skrivefør',),
'skriveført': ('skrivefør',),
'skrofuløs': ('skrofuløs',),
'skrofuløse': ('skrofuløs',),
'skrofuløsere': ('skrofuløs',),
'skrofuløsest': ('skrofuløs',),
'skrofuløseste': ('skrofuløs',),
'skrofuløst': ('skrofuløs',),
'skrota': ('skrote',),
'skrotede': ('skrote',),
'skrotende': ('skrote',),
'skrotet': ('skrote',),
'skrotete': ('skrote',),
'skrudd': ('skru',),
'skrudde': ('skru',),
'skruende': ('skru',),
'skrudd': ('skru',),
'skrudde': ('skru',),
'skruende': ('skru',),
'skrudd': ('skru',),
'skrudde': ('skru',),
'skruende': ('skru',),
'skrubba': ('skrubbe',),
'skrubbede': ('skrubbe',),
'skrubbende': ('skrubbe',),
'skrubbet': ('skrubbe',),
'skrubbete': ('skrubbe',),
'skrubbet': ('skrubbet',),
'skrubbete': ('skrubbet',),
'skrubbetere': ('skrubbet',),
'skrubbetest': ('skrubbet',),
'skrubbeteste': ('skrubbet',),
'skrubbete': ('skrubbete',),
'skrubbsulten': ('skrubbsulten',),
'skrubbsultent': ('skrubbsulten',),
'skrubbsultne': ('skrubbsulten',),
'skrubbsultnere': ('skrubbsulten',),
'skrubbsultnest': ('skrubbsulten',),
'skrubbsultneste': ('skrubbsulten',),
'skrudd': ('skrue',),
'skrudde': ('skrue',),
'skruende': ('skrue',),
'skrudd': ('skrue',),
'skrudde': ('skrue',),
'skruende': ('skrue',),
'skrudd': ('skrue',),
'skrudde': ('skrue',),
'skruende': ('skrue',),
'skrukka': ('skrukke',),
'skrukkede': ('skrukke',),
'skrukkende': ('skrukke',),
'skrukket': ('skrukke',),
'skrukkete': ('skrukke',),
'skrukket': ('skrukket',),
'skrukkete': ('skrukket',),
'skrukketere': ('skrukket',),
'skrukketest': ('skrukket',),
'skrukketeste': ('skrukket',),
'skrukkete': ('skrukkete',),
'skrullet': ('skrullet',),
'skrullete': ('skrullet',),
'skrulletere': ('skrullet',),
'skrulletest': ('skrullet',),
'skrulleteste': ('skrullet',),
'skrullete': ('skrullete',),
'skrumpa': ('skrumpe',),
'skrumpede': ('skrumpe',),
'skrumpende': ('skrumpe',),
'skrumpet': ('skrumpe',),
'skrumpete': ('skrumpe',),
'skrumpen': ('skrumpen',),
'skrumpent': ('skrumpen',),
'skrumpne': ('skrumpen',),
'skrumpnere': ('skrumpen',),
'skrumpnest': ('skrumpen',),
'skrumpneste': ('skrumpen',),
'skrumpet': ('skrumpet',),
'skrumpete': ('skrumpet',),
'skrumpetere': ('skrumpet',),
'skrumpetest': ('skrumpet',),
'skrumpeteste': ('skrumpet',),
'skrumpete': ('skrumpete',),
'skruppellaus': ('skruppellaus',),
'skruppellause': ('skruppellaus',),
'skruppellausere': ('skruppellaus',),
'skruppellausest': ('skruppellaus',),
'skruppellauseste': ('skruppellaus',),
'skruppellaust': ('skruppellaus',),
'skruppelløs': ('skruppelløs',),
'skruppelløse': ('skruppelløs',),
'skruppelløsere': ('skruppelløs',),
'skruppelløsest': ('skruppelløs',),
'skruppelløseste': ('skruppelløs',),
'skruppelløst': ('skruppelløs',),
'skrupuløs': ('skrupuløs',),
'skrupuløse': ('skrupuløs',),
'skrupuløsere': ('skrupuløs',),
'skrupuløsest': ('skrupuløs',),
'skrupuløseste': ('skrupuløs',),
'skrupuløst': ('skrupuløs',),
'skruvd': ('skruve',),
'skruvde': ('skruve',),
'skruvende': ('skruve',),
'skruvd': ('skruve',),
'skruvde': ('skruve',),
'skruvende': ('skruve',),
'skruvd': ('skruve',),
'skruvde': ('skruve',),
'skruvende': ('skruve',),
'skrytende': ('skryte',),
'skrytt': ('skryte',),
'skrytte': ('skryte',),
'skrytet': ('skrytet',),
'skrytete': ('skrytet',),
'skrytetere': ('skrytet',),
'skrytetest': ('skrytet',),
'skryteteste': ('skrytet',),
'skrytete': ('skrytete',),
'skrådd': ('skrå',),
'skrådde': ('skrå',),
'skrående': ('skrå',),
'skrådd': ('skrå',),
'skrådde': ('skrå',),
'skrående': ('skrå',),
'skrå': ('skrå',),
'skråe': ('skrå',),
'skråere': ('skrå',),
'skråest': ('skrå',),
'skråeste': ('skrå',),
'skrått': ('skrå',),
'skrålende': ('skråle',),
'skrålt': ('skråle',),
'skrålte': ('skråle',),
'skråna': ('skråne',),
'skrånede': ('skråne',),
'skrånende': ('skråne',),
'skrånet': ('skråne',),
'skrånete': ('skråne',),
'skrånt': ('skråne',),
'skrånte': ('skråne',),
'skråsatt': ('skråsette',),
'skråsatte': ('skråsette',),
'skråsettende': ('skråsette',),
'skråsikker': ('skråsikker',),
'skråsikkert': ('skråsikker',),
'skråsikre': ('skråsikker',),
'skråsikrere': ('skråsikker',),
'skråsikrest': ('skråsikker',),
'skråsikreste': ('skråsikker',),
'skråstillende': ('skråstille',),
'skråstilt': ('skråstille',),
'skråstilte': ('skråstille',),
'skrødd': ('skrø',),
'skrødde': ('skrø',),
'skrøende': ('skrø',),
'skrøfta': ('skrøfte',),
'skrøftede': ('skrøfte',),
'skrøftende': ('skrøfte',),
'skrøftet': ('skrøfte',),
'skrøftete': ('skrøfte',),
'skrømta': ('skrømte',),
'skrømtede': ('skrømte',),
'skrømtende': ('skrømte',),
'skrømtet': ('skrømte',),
'skrømtete': ('skrømte',),
'skrønende': ('skrøne',),
'skrønt': ('skrøne',),
'skrønte': ('skrøne',),
'skrøpelig': ('skrøpelig',),
'skrøpelige': ('skrøpelig',),
'skrøpeligere': ('skrøpelig',),
'skrøpeligst': ('skrøpelig',),
'skrøpeligste': ('skrøpelig',),
'skubba': ('skubbe',),
'skubbede': ('skubbe',),
'skubbende': ('skubbe',),
'skubbet': ('skubbe',),
'skubbete': ('skubbe',),
'skuddklar': ('skuddklar',),
'skuddklare': ('skuddklar',),
'skuddklarere': ('skuddklar',),
'skuddklarest': ('skuddklar',),
'skuddklareste': ('skuddklar',),
'skuddklart': ('skuddklar',),
'skuddredd': ('skuddredd',),
'skuddredde': ('skuddredd',),
'skuddreddere': ('skuddredd',),
'skuddreddest': ('skuddredd',),
'skuddreddeste': ('skuddredd',),
'skuddsikker': ('skuddsikker',),
'skuddsikkert': ('skuddsikker',),
'skuddsikre': ('skuddsikker',),
'skuddsikrere': ('skuddsikker',),
'skuddsikrest': ('skuddsikker',),
'skuddsikreste': ('skuddsikker',),
'skuddsterk': ('skuddsterk',),
'skuddsterke': ('skuddsterk',),
'skuddsterkere': ('skuddsterk',),
'skuddsterkest': ('skuddsterk',),
'skuddsterkeste': ('skuddsterk',),
'skuddsterkt': ('skuddsterk',),
'skua': ('skue',),
'skuede': ('skue',),
'skuende': ('skue',),
'skuet': ('skue',),
'skuete': ('skue',),
'skuelysten': ('skuelysten',),
'skuelystent': ('skuelysten',),
'skuelystne': ('skuelysten',),
'skuelystnere': ('skuelysten',),
'skuelystnest': ('skuelysten',),
'skuelystneste': ('skuelysten',),
'skuffa': ('skuffe',),
'skuffede': ('skuffe',),
'skuffende': ('skuffe',),
'skuffet': ('skuffe',),
'skuffete': ('skuffe',),
'skuffa': ('skuffe',),
'skuffede': ('skuffe',),
'skuffende': ('skuffe',),
'skuffet': ('skuffe',),
'skuffete': ('skuffe',),
'skufla': ('skufle',),
'skuflede': ('skufle',),
'skuflende': ('skufle',),
'skuflet': ('skufle',),
'skuflete': ('skufle',),
'skulderbred': ('skulderbred',),
'skulderbrede': ('skulderbred',),
'skulderbredere': ('skulderbred',),
'skulderbredest': ('skulderbred',),
'skulderbredeste': ('skulderbred',),
'skulderbredt': ('skulderbred',),
'skulderbrei': ('skulderbrei',),
'skulderbreie': ('skulderbrei',),
'skulderbreiere': ('skulderbrei',),
'skulderbreiest': ('skulderbrei',),
'skulderbreieste': ('skulderbrei',),
'skulderbreit': ('skulderbrei',),
'skulende': ('skule',),
'skult': ('skule',),
'skulte': ('skule',),
'skulka': ('skulke',),
'skulkede': ('skulke',),
'skulkende': ('skulke',),
'skulket': ('skulke',),
'skulkete': ('skulke',),
'skulkesjuk': ('skulkesjuk',),
'skulkesjuke': ('skulkesjuk',),
'skulkesjukere': ('skulkesjuk',),
'skulkesjukest': ('skulkesjuk',),
'skulkesjukeste': ('skulkesjuk',),
'skulkesjukt': ('skulkesjuk',),
'skulkesyk': ('skulkesyk',),
'skulkesyke': ('skulkesyk',),
'skulkesykere': ('skulkesyk',),
'skulkesykest': ('skulkesyk',),
'skulkesykeste': ('skulkesyk',),
'skulkesykt': ('skulkesyk',),
'skullende': ('skulle',),
'skulpterende': ('skulptere',),
'skulptert': ('skulptere',),
'skulpterte': ('skulptere',),
'skulptural': ('skulptural',),
'skulpturale': ('skulptural',),
'skulpturalere': ('skulptural',),
'skulpturalest': ('skulptural',),
'skulpturaleste': ('skulptural',),
'skulpturalt': ('skulptural',),
'skulpturell': ('skulpturell',),
'skulpturelle': ('skulpturell',),
'skulpturellere': ('skulpturell',),
'skulpturellest': ('skulpturell',),
'skulpturelleste': ('skulpturell',),
'skulpturelt': ('skulpturell',),
'skuls': ('skuls',),
'skulsa': ('skulse',),
'skulsede': ('skulse',),
'skulsende': ('skulse',),
'skulset': ('skulse',),
'skulsete': ('skulse',),
'skum': ('skum',),
'skume': ('skum',),
'skumere': ('skum',),
'skumest': ('skum',),
'skumeste': ('skum',),
'skumt': ('skum',),
'skumhvit': ('skumhvit',),
'skumhvite': ('skumhvit',),
'skumhvitere': ('skumhvit',),
'skumhvitest': ('skumhvit',),
'skumhviteste': ('skumhvit',),
'skumhvitt': ('skumhvit',),
'skumkjørende': ('skumkjøre',),
'skumkjørt': ('skumkjøre',),
'skumkjørte': ('skumkjøre',),
'skumkvit': ('skumkvit',),
'skumkvite': ('skumkvit',),
'skumkvitere': ('skumkvit',),
'skumkvitest': ('skumkvit',),
'skumkviteste': ('skumkvit',),
'skumkvitt': ('skumkvit',),
'skumla': ('skumle',),
'skumlede': ('skumle',),
'skumlende': ('skumle',),
'skumlet': ('skumle',),
'skumlete': ('skumle',),
'skumlesende': ('skumlese',),
'skumlest': ('skumlese',),
'skumleste': ('skumlese',),
'skumma': ('skumme',),
'skummede': ('skumme',),
'skummende': ('skumme',),
'skummet': ('skumme',),
'skummete': ('skumme',),
'skumle': ('skummel',),
'skumlere': ('skummel',),
'skumlest': ('skummel',),
'skumleste': ('skummel',),
'skummel': ('skummel',),
'skummelt': ('skummel',),
'skumpa': ('skumpe',),
'skumpede': ('skumpe',),
'skumpende': ('skumpe',),
'skumpet': ('skumpe',),
'skumpete': ('skumpe',),
'skumpiska': ('skumpiske',),
'skumpiskede': ('skumpiske',),
'skumpiskende': ('skumpiske',),
'skumpisket': ('skumpiske',),
'skumpiskete': ('skumpiske',),
'skumpla': ('skumple',),
'skumplede': ('skumple',),
'skumplende': ('skumple',),
'skumplet': ('skumple',),
'skumplete': ('skumple',),
'skumra': ('skumre',),
'skumrede': ('skumre',),
'skumrende': ('skumre',),
'skumret': ('skumre',),
'skumrete': ('skumre',),
'skumsvett': ('skumsvett',),
'skumsvette': ('skumsvett',),
'skumsvettere': ('skumsvett',),
'skumsvettest': ('skumsvett',),
'skumsvetteste': ('skumsvett',),
'skumtygd': ('skumtygge',),
'skumtygde': ('skumtygge',),
'skumtyggede': ('skumtygge',),
'skumtyggende': ('skumtygge',),
'skumtygget': ('skumtygge',),
'skumtyggete': ('skumtygge',),
'skumvåt': ('skumvåt',),
'skumvåte': ('skumvåt',),
'skumvåtere': ('skumvåt',),
'skumvåtest': ('skumvåt',),
'skumvåteste': ('skumvåt',),
'skumvått': ('skumvåt',),
'skura': ('skure',),
'skurede': ('skure',),
'skurende': ('skure',),
'skuret': ('skure',),
'skurete': ('skure',),
'skurt': ('skure',),
'skurte': ('skure',),
'skurkaktig': ('skurkaktig',),
'skurkaktige': ('skurkaktig',),
'skurkaktigere': ('skurkaktig',),
'skurkaktigst': ('skurkaktig',),
'skurkaktigste': ('skurkaktig',),
'skurra': ('skurre',),
'skurrede': ('skurre',),
'skurrende': ('skurre',),
'skurret': ('skurre',),
'skurrete': ('skurre',),
'skurvet': ('skurvet',),
'skurvete': ('skurvet',),
'skurvetere': ('skurvet',),
'skurvetest': ('skurvet',),
'skurveteste': ('skurvet',),
'skurvete': ('skurvete',),
'skusla': ('skusle',),
'skuslede': ('skusle',),
'skuslende': ('skusle',),
'skuslet': ('skusle',),
'skuslete': ('skusle',),
'skutelaus': ('skutelaus',),
'skutelause': ('skutelaus',),
'skutelausere': ('skutelaus',),
'skutelausest': ('skutelaus',),
'skutelauseste': ('skutelaus',),
'skutelaust': ('skutelaus',),
'skuteløs': ('skuteløs',),
'skuteløse': ('skuteløs',),
'skuteløsere': ('skuteløs',),
'skuteløsest': ('skuteløs',),
'skuteløseste': ('skuteløs',),
'skuteløst': ('skuteløs',),
'skutla': ('skutle',),
'skutlede': ('skutle',),
'skutlende': ('skutle',),
'skutlet': ('skutle',),
'skutlete': ('skutle',),
'skutrygga': ('skutrygga',),
'skutryggede': ('skutrygget',),
'skutrygget': ('skutrygget',),
'skutryggete': ('skutrygget',),
'skutryggetere': ('skutrygget',),
'skutryggetest': ('skutrygget',),
'skutryggeteste': ('skutrygget',),
'skutta': ('skutte',),
'skuttede': ('skutte',),
'skuttende': ('skutte',),
'skuttet': ('skutte',),
'skuttete': ('skutte',),
'skuvd': ('skuve',),
'skuvde': ('skuve',),
'skuvende': ('skuve',),
'skuvd': ('skuve',),
'skuvde': ('skuve',),
'skuvende': ('skuve',),
'skvadronerende': ('skvadronere',),
'skvadronert': ('skvadronere',),
'skvadronerte': ('skvadronere',),
'skvaldra': ('skvaldre',),
'skvaldrede': ('skvaldre',),
'skvaldrende': ('skvaldre',),
'skvaldret': ('skvaldre',),
'skvaldrete': ('skvaldre',),
'skvala': ('skvale',),
'skvalede': ('skvale',),
'skvalende': ('skvale',),
'skvalet': ('skvale',),
'skvalete': ('skvale',),
'skvalt': ('skvale',),
'skvalte': ('skvale',),
'skvalpa': ('skvalpe',),
'skvalpede': ('skvalpe',),
'skvalpende': ('skvalpe',),
'skvalpet': ('skvalpe',),
'skvalpete': ('skvalpe',),
'skvatra': ('skvatre',),
'skvatrede': ('skvatre',),
'skvatrende': ('skvatre',),
'skvatret': ('skvatre',),
'skvatrete': ('skvatre',),
'skvetta': ('skvette',),
'skvettede': ('skvette',),
'skvettende': ('skvette',),
'skvettet': ('skvette',),
'skvettete': ('skvette',),
'skvetne': ('skvette',),
'skvetten': ('skvette',),
'skvettende': ('skvette',),
'skvettet': ('skvette',),
'skvetne': ('skvetten',),
'skvetnere': ('skvetten',),
'skvetnest': ('skvetten',),
'skvetneste': ('skvetten',),
'skvetten': ('skvetten',),
'skvettent': ('skvetten',),
'skvipet': ('skvipet',),
'skvipete': ('skvipet',),
'skvipetere': ('skvipet',),
'skvipetest': ('skvipet',),
'skvipeteste': ('skvipet',),
'skvipete': ('skvipete',),
'skvisa': ('skvise',),
'skvisede': ('skvise',),
'skvisende': ('skvise',),
'skviset': ('skvise',),
'skvisete': ('skvise',),
'skvist': ('skvise',),
'skviste': ('skvise',),
'skvulpa': ('skvulpe',),
'skvulpede': ('skvulpe',),
'skvulpende': ('skvulpe',),
'skvulpet': ('skvulpe',),
'skvulpete': ('skvulpe',),
'skvær': ('skvær',),
'skvære': ('skvær',),
'skværere': ('skvær',),
'skværest': ('skvær',),
'skværeste': ('skvær',),
'skvært': ('skvær',),
'skværa': ('skvære',),
'skværede': ('skvære',),
'skværende': ('skvære',),
'skværet': ('skvære',),
'skværete': ('skvære',),
'skvært': ('skvære',),
'skværte': ('skvære',),
'skværrigga': ('skværrigga',),
'skværriggede': ('skværrigget',),
'skværrigget': ('skværrigget',),
'skværriggete': ('skværrigget',),
'skværriggetere': ('skværrigget',),
'skværriggetest': ('skværrigget',),
'skværriggeteste': ('skværrigget',),
'skydd': ('sky',),
'skydde': ('sky',),
'skyende': ('sky',),
'sky': ('sky',),
'skye': ('sky',),
'skyere': ('sky',),
'skyest': ('sky',),
'skyeste': ('sky',),
'skya': ('skya',),
'skya': ('skye',),
'skyede': ('skye',),
'skyende': ('skye',),
'skyet': ('skye',),
'skyete': ('skye',),
'skyete': ('skyete',),
'skyfla': ('skyfle',),
'skyflede': ('skyfle',),
'skyflende': ('skyfle',),
'skyflet': ('skyfle',),
'skyflete': ('skyfle',),
'skygg': ('skygg',),
'skygge': ('skygg',),
'skyggere': ('skygg',),
'skyggest': ('skygg',),
'skyggeste': ('skygg',),
'skygt': ('skygg',),
'skygd': ('skygge',),
'skygde': ('skygge',),
'skygga': ('skygge',),
'skyggede': ('skygge',),
'skyggende': ('skygge',),
'skygget': ('skygge',),
'skyggete': ('skygge',),
'skygd': ('skygge',),
'skygde': ('skygge',),
'skygga': ('skygge',),
'skyggede': ('skygge',),
'skyggende': ('skygge',),
'skygget': ('skygge',),
'skyggete': ('skygge',),
'skyggefull': ('skyggefull',),
'skyggefulle': ('skyggefull',),
'skyggefullere': ('skyggefull',),
'skyggefullest': ('skyggefull',),
'skyggefulleste': ('skyggefull',),
'skyggefullt': ('skyggefull',),
'skyggelagt': ('skyggelegge',),
'skyggelagte': ('skyggelegge',),
'skyggeleggende': ('skyggelegge',),
'skyggeredd': ('skyggeredd',),
'skyggeredde': ('skyggeredd',),
'skyggereddere': ('skyggeredd',),
'skyggereddest': ('skyggeredd',),
'skyggereddeste': ('skyggeredd',),
'skygrå': ('skygrå',),
'skygråe': ('skygrå',),
'skygråere': ('skygrå',),
'skygråest': ('skygrå',),
'skygråeste': ('skygrå',),
'skygrått': ('skygrå',),
'skyhøg': ('skyhøg',),
'skyhøge': ('skyhøg',),
'skyhøgere': ('skyhøg',),
'skyhøgest': ('skyhøg',),
'skyhøgeste': ('skyhøg',),
'skyhøgre': ('skyhøg',),
'skyhøgst': ('skyhøg',),
'skyhøgste': ('skyhøg',),
'skyhøgt': ('skyhøg',),
'skyhøy': ('skyhøy',),
'skyhøye': ('skyhøy',),
'skyhøyere': ('skyhøy',),
'skyhøyest': ('skyhøy',),
'skyhøyeste': ('skyhøy',),
'skyhøyt': ('skyhøy',),
'skyld': ('skyld',),
'skylde': ('skyld',),
'skyldere': ('skyld',),
'skyldest': ('skyld',),
'skyldeste': ('skyld',),
'skyldt': ('skyld',),
'skyldbetynga': ('skyldbetynga',),
'skyldbetyngede': ('skyldbetynget',),
'skyldbetynget': ('skyldbetynget',),
'skyldbetyngete': ('skyldbetynget',),
'skyldbetyngetere': ('skyldbetynget',),
'skyldbetyngetest': ('skyldbetynget',),
'skyldbetyngeteste': ('skyldbetynget',),
'skyldbevisst': ('skyldbevisst',),
'skyldbevisste': ('skyldbevisst',),
'skyldbevisstere': ('skyldbevisst',),
'skyldbevisstest': ('skyldbevisst',),
'skyldbevissteste': ('skyldbevisst',),
'skyldende': ('skylde',),
'skyldt': ('skylde',),
'skyldte': ('skylde',),
'skyldig': ('skyldig',),
'skyldige': ('skyldig',),
'skyldigere': ('skyldig',),
'skyldigst': ('skyldig',),
'skyldigste': ('skyldig',),
'skyldsatt': ('skyldsette',),
'skyldsatte': ('skyldsette',),
'skyldsettende': ('skyldsette',),
'skyldt': ('skyldt',),
'skyldte': ('skyldt',),
'skyldtere': ('skyldt',),
'skyldtest': ('skyldt',),
'skyldteste': ('skyldt',),
'skyldtynga': ('skyldtynga',),
'skyldtyngede': ('skyldtynget',),
'skyldtynget': ('skyldtynget',),
'skyldtyngete': ('skyldtynget',),
'skyldtyngetere': ('skyldtynget',),
'skyldtyngetest': ('skyldtynget',),
'skyldtyngeteste': ('skyldtynget',),
'skylla': ('skylle',),
'skyllede': ('skylle',),
'skyllende': ('skylle',),
'skyllet': ('skylle',),
'skyllete': ('skylle',),
'skylt': ('skylle',),
'skylte': ('skylle',),
'skym': ('skym',),
'skymme': ('skym',),
'skymmere': ('skym',),
'skymmest': ('skym',),
'skymmeste': ('skym',),
'skymt': ('skym',),
'skynda': ('skynde',),
'skyndede': ('skynde',),
'skyndende': ('skynde',),
'skyndet': ('skynde',),
'skyndete': ('skynde',),
'skyndt': ('skynde',),
'skyndte': ('skynde',),
'skyndsom': ('skyndsom',),
'skyndsomme': ('skyndsom',),
'skyndsommere': ('skyndsom',),
'skyndsomst': ('skyndsom',),
'skyndsomste': ('skyndsom',),
'skyndsomt': ('skyndsom',),
'skyssa': ('skysse',),
'skyssede': ('skysse',),
'skyssende': ('skysse',),
'skysset': ('skysse',),
'skyssete': ('skysse',),
'skutt': ('skyte',),
'skutte': ('skyte',),
'skytende': ('skyte',),
'skytung': ('skytung',),
'skytunge': ('skytung',),
'skytungere': ('skytung',),
'skytungest': ('skytung',),
'skytungeste': ('skytung',),
'skytungt': ('skytung',),
'skytyngre': ('skytung',),
'skytyngst': ('skytung',),
'skytyngste': ('skytung',),
'skyvbar': ('skyvbar',),
'skyvbare': ('skyvbar',),
'skyvbarere': ('skyvbar',),
'skyvbarest': ('skyvbar',),
'skyvbareste': ('skyvbar',),
'skyvbart': ('skyvbar',),
'skjøven': ('skyve',),
'skjøvet': ('skyve',),
'skjøvne': ('skyve',),
'skyvd': ('skyve',),
'skyvde': ('skyve',),
'skyvende': ('skyve',),
'skjøven': ('skyve',),
'skjøvet': ('skyve',),
'skjøvne': ('skyve',),
'skyvd': ('skyve',),
'skyvde': ('skyve',),
'skyvende': ('skyve',),
'skåkredd': ('skåkredd',),
'skåkredde': ('skåkredd',),
'skåkreddere': ('skåkredd',),
'skåkreddest': ('skåkredd',),
'skåkreddeste': ('skåkredd',),
'skåksky': ('skåksky',),
'skåkskye': ('skåksky',),
'skåkskyere': ('skåksky',),
'skåkskyest': ('skåksky',),
'skåkskyeste': ('skåksky',),
'skålda': ('skålde',),
'skåldede': ('skålde',),
'skåldende': ('skålde',),
'skåldet': ('skålde',),
'skåldete': ('skålde',),
'skåldheit': ('skåldheit',),
'skåldheite': ('skåldheit',),
'skåldheitere': ('skåldheit',),
'skåldheitest': ('skåldheit',),
'skåldheiteste': ('skåldheit',),
'skåldheitt': ('skåldheit',),
'skåldhett': ('skåldheit',),
'skålende': ('skåle',),
'skålt': ('skåle',),
'skålte': ('skåle',),
'skåna': ('skåne',),
'skånede': ('skåne',),
'skånende': ('skåne',),
'skånet': ('skåne',),
'skånete': ('skåne',),
'skånt': ('skåne',),
'skånte': ('skåne',),
'skånsellaus': ('skånsellaus',),
'skånsellause': ('skånsellaus',),
'skånsellausere': ('skånsellaus',),
'skånsellausest': ('skånsellaus',),
'skånsellauseste': ('skånsellaus',),
'skånsellaust': ('skånsellaus',),
'skånselløs': ('skånselløs',),
'skånselløse': ('skånselløs',),
'skånselløsere': ('skånselløs',),
'skånselløsest': ('skånselløs',),
'skånselløseste': ('skånselløs',),
'skånselløst': ('skånselløs',),
'skånselslaus': ('skånselslaus',),
'skånselslause': ('skånselslaus',),
'skånselslausere': ('skånselslaus',),
'skånselslausest': ('skånselslaus',),
'skånselslauseste': ('skånselslaus',),
'skånselslaust': ('skånselslaus',),
'skånselsløs': ('skånselsløs',),
'skånselsløse': ('skånselsløs',),
'skånselsløsere': ('skånselsløs',),
'skånselsløsest': ('skånselsløs',),
'skånselsløseste': ('skånselsløs',),
'skånselsløst': ('skånselsløs',),
'skånsk': ('skånsk',),
'skånske': ('skånsk',),
'skånskere': ('skånsk',),
'skånskest': ('skånsk',),
'skånskeste': ('skånsk',),
'skånsom': ('skånsom',),
'skånsomme': ('skånsom',),
'skånsommere': ('skånsom',),
'skånsomst': ('skånsom',),
'skånsomste': ('skånsom',),
'skånsomt': ('skånsom',),
'skåra': ('skåre',),
'skårede': ('skåre',),
'skårende': ('skåre',),
'skåret': ('skåre',),
'skårete': ('skåre',),
'skåra': ('skåre',),
'skårede': ('skåre',),
'skårende': ('skåre',),
'skåret': ('skåre',),
'skårete': ('skåre',),
'skåra': ('skåre',),
'skårede': ('skåre',),
'skårende': ('skåre',),
'skåret': ('skåre',),
'skårete': ('skåre',),
'skåren': ('skåren',),
'skåret': ('skåren',),
'skårne': ('skåren',),
'skårnere': ('skåren',),
'skårnest': ('skåren',),
'skårneste': ('skåren',),
'skåret': ('skåret',),
'skårne': ('skåret',),
'skårnere': ('skåret',),
'skårnest': ('skåret',),
'skårneste': ('skåret',),
'skårfast': ('skårfast',),
'skårfaste': ('skårfast',),
'skårfastere': ('skårfast',),
'skårfastest': ('skårfast',),
'skårfasteste': ('skårfast',),
'skårlagt': ('skårlegge',),
'skårlagte': ('skårlegge',),
'skårleggende': ('skårlegge',),
'skåta': ('skåte',),
'skåtede': ('skåte',),
'skåtende': ('skåte',),
'skåtet': ('skåte',),
'skåtete': ('skåte',),
'skøya': ('skøye',),
'skøyede': ('skøye',),
'skøyende': ('skøye',),
'skøyet': ('skøye',),
'skøyete': ('skøye',),
'skøyeraktig': ('skøyeraktig',),
'skøyeraktige': ('skøyeraktig',),
'skøyeraktigere': ('skøyeraktig',),
'skøyeraktigst': ('skøyeraktig',),
'skøyeraktigste': ('skøyeraktig',),
'skøyta': ('skøyte',),
'skøytede': ('skøyte',),
'skøytende': ('skøyte',),
'skøytet': ('skøyte',),
'skøytete': ('skøyte',),
'slabba': ('slabbe',),
'slabbede': ('slabbe',),
'slabbende': ('slabbe',),
'slabbet': ('slabbe',),
'slabbete': ('slabbe',),
'sladda': ('sladde',),
'sladdede': ('sladde',),
'sladdende': ('sladde',),
'sladdet': ('sladde',),
'sladdete': ('sladde',),
'sladda': ('sladde',),
'sladdede': ('sladde',),
'sladdende': ('sladde',),
'sladdet': ('sladde',),
'sladdete': ('sladde',),
'sladra': ('sladre',),
'sladrede': ('sladre',),
'sladrende': ('sladre',),
'sladret': ('sladre',),
'sladrete': ('sladre',),
'slafsa': ('slafse',),
'slafsede': ('slafse',),
'slafsende': ('slafse',),
'slafset': ('slafse',),
'slafsete': ('slafse',),
'slafset': ('slafset',),
'slafsete': ('slafset',),
'slafsetere': ('slafset',),
'slafsetest': ('slafset',),
'slafseteste': ('slafset',),
'slafsete': ('slafsete',),
'slaga': ('slage',),
'slagede': ('slage',),
'slagende': ('slage',),
'slaget': ('slage',),
'slagete': ('slage',),
'slagen': ('slagen',),
'slagent': ('slagen',),
'slagne': ('slagen',),
'slagnere': ('slagen',),
'slagnest': ('slagen',),
'slagneste': ('slagen',),
'slagferdig': ('slagferdig',),
'slagferdige': ('slagferdig',),
'slagferdigere': ('slagferdig',),
'slagferdigst': ('slagferdig',),
'slagferdigste': ('slagferdig',),
'slagga': ('slagge',),
'slaggede': ('slagge',),
'slaggende': ('slagge',),
'slagget': ('slagge',),
'slaggete': ('slagge',),
'slagkraftig': ('slagkraftig',),
'slagkraftige': ('slagkraftig',),
'slagkraftigere': ('slagkraftig',),
'slagkraftigst': ('slagkraftig',),
'slagkraftigste': ('slagkraftig',),
'slagordsprega': ('slagordsprega',),
'slagordspregede': ('slagordspreget',),
'slagordspreget': ('slagordspreget',),
'slagordspregete': ('slagordspreget',),
'slagordspregetere': ('slagordspreget',),
'slagordspregetest': ('slagordspreget',),
'slagordspregeteste': ('slagordspreget',),
'slak': ('slak',),
'slake': ('slak',),
'slakere': ('slak',),
'slakest': ('slak',),
'slakeste': ('slak',),
'slakt': ('slak',),
'slakk': ('slakk',),
'slakke': ('slakk',),
'slakkere': ('slakk',),
'slakkest': ('slakk',),
'slakkeste': ('slakk',),
'slakt': ('slakk',),
'slakka': ('slakke',),
'slakkede': ('slakke',),
'slakkende': ('slakke',),
'slakket': ('slakke',),
'slakkete': ('slakke',),
'slakna': ('slakne',),
'slaknede': ('slakne',),
'slaknende': ('slakne',),
'slaknet': ('slakne',),
'slaknete': ('slakne',),
'slakta': ('slakte',),
'slaktede': ('slakte',),
'slaktende': ('slakte',),
'slaktet': ('slakte',),
'slaktete': ('slakte',),
'slamma': ('slamme',),
'slammede': ('slamme',),
'slammende': ('slamme',),
'slammet': ('slamme',),
'slammete': ('slamme',),
'slammet': ('slammet',),
'slammete': ('slammet',),
'slammetere': ('slammet',),
'slammetest': ('slammet',),
'slammeteste': ('slammet',),
'slammete': ('slammete',),
'slampa': ('slampe',),
'slampede': ('slampe',),
'slampende': ('slampe',),
'slampet': ('slampe',),
'slampete': ('slampe',),
'slampet': ('slampet',),
'slampete': ('slampet',),
'slampetere': ('slampet',),
'slampetest': ('slampet',),
'slampeteste': ('slampet',),
'slampete': ('slampete',),
'slamra': ('slamre',),
'slamrede': ('slamre',),
'slamrende': ('slamre',),
'slamret': ('slamre',),
'slamrete': ('slamre',),
'slamsa': ('slamse',),
'slamsede': ('slamse',),
'slamsende': ('slamse',),
'slamset': ('slamse',),
'slamsete': ('slamse',),
'slamset': ('slamset',),
'slamsete': ('slamset',),
'slamsetere': ('slamset',),
'slamsetest': ('slamset',),
'slamseteste': ('slamset',),
'slamsete': ('slamsete',),
'slanga': ('slange',),
'slangede': ('slange',),
'slangende': ('slange',),
'slanget': ('slange',),
'slangete': ('slange',),
'slangelaus': ('slangelaus',),
'slangelause': ('slangelaus',),
'slangelausere': ('slangelaus',),
'slangelausest': ('slangelaus',),
'slangelauseste': ('slangelaus',),
'slangelaust': ('slangelaus',),
'slangeløs': ('slangeløs',),
'slangeløse': ('slangeløs',),
'slangeløsere': ('slangeløs',),
'slangeløsest': ('slangeløs',),
'slangeløseste': ('slangeløs',),
'slangeløst': ('slangeløs',),
'slank': ('slank',),
'slanke': ('slank',),
'slankere': ('slank',),
'slankest': ('slank',),
'slankeste': ('slank',),
'slankt': ('slank',),
'slanka': ('slanke',),
'slankede': ('slanke',),
'slankende': ('slanke',),
'slanket': ('slanke',),
'slankete': ('slanke',),
'slanten': ('slanten',),
'slantent': ('slanten',),
'slantne': ('slanten',),
'slantnere': ('slanten',),
'slantnest': ('slanten',),
'slantneste': ('slanten',),
'slapna': ('slapne',),
'slapnede': ('slapne',),
'slapnende': ('slapne',),
'slapnet': ('slapne',),
'slapnete': ('slapne',),
'slapp': ('slapp',),
'slappe': ('slapp',),
'slappere': ('slapp',),
'slappest': ('slapp',),
'slappeste': ('slapp',),
'slapt': ('slapp',),
'slappa': ('slappe',),
'slappede': ('slappe',),
'slappende': ('slappe',),
'slappet': ('slappe',),
'slappete': ('slappe',),
'slapset': ('slapset',),
'slapsete': ('slapset',),
'slapsetere': ('slapset',),
'slapsetest': ('slapset',),
'slapseteste': ('slapset',),
'slapsete': ('slapsete',),
'slarka': ('slarke',),
'slarkede': ('slarke',),
'slarkende': ('slarke',),
'slarket': ('slarke',),
'slarkete': ('slarke',),
'slarket': ('slarket',),
'slarkete': ('slarket',),
'slarketere': ('slarket',),
'slarketest': ('slarket',),
'slarketeste': ('slarket',),
'slarkete': ('slarkete',),
'slarva': ('slarve',),
'slarvede': ('slarve',),
'slarvende': ('slarve',),
'slarvet': ('slarve',),
'slarvete': ('slarve',),
'slarvet': ('slarvet',),
'slarvete': ('slarvet',),
'slarvetere': ('slarvet',),
'slarvetest': ('slarvet',),
'slarveteste': ('slarvet',),
'slarvete': ('slarvete',),
'slaska': ('slaske',),
'slaskede': ('slaske',),
'slaskende': ('slaske',),
'slasket': ('slaske',),
'slaskete': ('slaske',),
'slasket': ('slasket',),
'slaskete': ('slasket',),
'slasketere': ('slasket',),
'slasketest': ('slasket',),
'slasketeste': ('slasket',),
'slaskete': ('slaskete',),
'slaura': ('slaure',),
'slaurede': ('slaure',),
'slaurende': ('slaure',),
'slauret': ('slaure',),
'slaurete': ('slaure',),
'slava': ('slave',),
'slavede': ('slave',),
'slavende': ('slave',),
'slavet': ('slave',),
'slavete': ('slave',),
'slavebindende': ('slavebinde',),
'slavebunden': ('slavebinde',),
'slavebundet': ('slavebinde',),
'slavebundne': ('slavebinde',),
'slavisk': ('slavisk',),
'slaviske': ('slavisk',),
'slaviskere': ('slavisk',),
'slaviskest': ('slavisk',),
'slaviskeste': ('slavisk',),
'slavisk': ('slavisk',),
'slaviske': ('slavisk',),
'slaviskere': ('slavisk',),
'slaviskest': ('slavisk',),
'slaviskeste': ('slavisk',),
'slavonsk': ('slavonsk',),
'slavonske': ('slavonsk',),
'slavonskere': ('slavonsk',),
'slavonskest': ('slavonsk',),
'slavonskeste': ('slavonsk',),
'slegga': ('slegge',),
'sleggede': ('slegge',),
'sleggende': ('slegge',),
'slegget': ('slegge',),
'sleggete': ('slegge',),
'sleika': ('sleike',),
'sleikede': ('sleike',),
'sleikende': ('sleike',),
'sleiket': ('sleike',),
'sleikete': ('sleike',),
'sleikt': ('sleike',),
'sleikte': ('sleike',),
'sleiken': ('sleiken',),
'sleikent': ('sleiken',),
'sleikne': ('sleiken',),
'sleiknere': ('sleiken',),
'sleiknest': ('sleiken',),
'sleikneste': ('sleiken',),
'sleiket': ('sleiket',),
'sleikete': ('sleiket',),
'sleiketere': ('sleiket',),
'sleiketest': ('sleiket',),
'sleiketeste': ('sleiket',),
'sleikete': ('sleikete',),
'sleip': ('sleip',),
'sleipe': ('sleip',),
'sleipere': ('sleip',),
'sleipest': ('sleip',),
'sleipeste': ('sleip',),
'sleipt': ('sleip',),
'sleiva': ('sleive',),
'sleivd': ('sleive',),
'sleivde': ('sleive',),
'sleivede': ('sleive',),
'sleivende': ('sleive',),
'sleivet': ('sleive',),
'sleivete': ('sleive',),
'sleivet': ('sleivet',),
'sleivete': ('sleivet',),
'sleivetere': ('sleivet',),
'sleivetest': ('sleivet',),
'sleiveteste': ('sleivet',),
'sleivete': ('sleivete',),
'slekta': ('slekte',),
'slektede': ('slekte',),
'slektende': ('slekte',),
'slektet': ('slekte',),
'slektete': ('slekte',),
'slem': ('slem',),
'slemme': ('slem',),
'slemmere': ('slem',),
'slemmest': ('slem',),
'slemmeste': ('slem',),
'slemt': ('slem',),
'slemma': ('slemme',),
'slemmede': ('slemme',),
'slemmende': ('slemme',),
'slemmet': ('slemme',),
'slemmete': ('slemme',),
'slenget': ('slenget',),
'slengete': ('slenget',),
'slengetere': ('slenget',),
'slengetest': ('slenget',),
'slengeteste': ('slenget',),
'slengete': ('slengete',),
'slentra': ('slentre',),
'slentrede': ('slentre',),
'slentrende': ('slentre',),
'slentret': ('slentre',),
'slentrete': ('slentre',),
'slepende': ('slepe',),
'slept': ('slepe',),
'slepte': ('slepe',),
'slepen': ('slepen',),
'slepent': ('slepen',),
'slepne': ('slepen',),
'slepnere': ('slepen',),
'slepnest': ('slepen',),
'slepneste': ('slepen',),
'sleppet': ('sleppet',),
'sleppete': ('sleppet',),
'sleppetere': ('sleppet',),
'sleppetest': ('sleppet',),
'sleppeteste': ('sleppet',),
'sleppete': ('sleppete',),
'slepphendt': ('slepphendt',),
'slepphendte': ('slepphendt',),
'slepphendtere': ('slepphendt',),
'slepphendtest': ('slepphendt',),
'slepphendteste': ('slepphendt',),
'slesk': ('slesk',),
'sleske': ('slesk',),
'sleskere': ('slesk',),
'sleskest': ('slesk',),
'sleskeste': ('slesk',),
'sleskt': ('slesk',),
'sleska': ('sleske',),
'sleskede': ('sleske',),
'sleskende': ('sleske',),
'slesket': ('sleske',),
'sleskete': ('sleske',),
'slesvigsk': ('slesvigsk',),
'slesvigske': ('slesvigsk',),
'slesvigskere': ('slesvigsk',),
'slesvigskest': ('slesvigsk',),
'slesvigskeste': ('slesvigsk',),
'sletna': ('sletne',),
'sletnede': ('sletne',),
'sletnende': ('sletne',),
'sletnet': ('sletne',),
'sletnete': ('sletne',),
'slett': ('slett',),
'slette': ('slett',),
'slettere': ('slett',),
'slettest': ('slett',),
'sletteste': ('slett',),
'sletta': ('slette',),
'slettede': ('slette',),
'slettende': ('slette',),
'slettet': ('slette',),
'slettete': ('slette',),
'sleva': ('sleve',),
'slevd': ('sleve',),
'slevde': ('sleve',),
'slevede': ('sleve',),
'slevende': ('sleve',),
'slevet': ('sleve',),
'slevete': ('sleve',),
'sli': ('sli',),
'slie': ('sli',),
'sliere': ('sli',),
'sliest': ('sli',),
'slieste': ('sli',),
'slitt': ('sli',),
'slibrig': ('slibrig',),
'slibrige': ('slibrig',),
'slibrigere': ('slibrig',),
'slibrigst': ('slibrig',),
'slibrigste': ('slibrig',),
'slikka': ('slikke',),
'slikkede': ('slikke',),
'slikkende': ('slikke',),
'slikket': ('slikke',),
'slikkete': ('slikke',),
'slima': ('slime',),
'slimede': ('slime',),
'slimende': ('slime',),
'slimet': ('slime',),
'slimete': ('slime',),
'slimet': ('slimet',),
'slimete': ('slimet',),
'slimetere': ('slimet',),
'slimetest': ('slimet',),
'slimeteste': ('slimet',),
'slimete': ('slimete',),
'slindbarka': ('slindbarke',),
'slindbarkede': ('slindbarke',),
'slindbarkende': ('slindbarke',),
'slindbarket': ('slindbarke',),
'slindbarkete': ('slindbarke',),
'slinda': ('slinde',),
'slindede': ('slinde',),
'slindende': ('slinde',),
'slindet': ('slinde',),
'slindete': ('slinde',),
'slindra': ('slindre',),
'slindrede': ('slindre',),
'slindrende': ('slindre',),
'slindret': ('slindre',),
'slindrete': ('slindre',),
'slingra': ('slingre',),
'slingrede': ('slingre',),
'slingrende': ('slingre',),
'slingret': ('slingre',),
'slingrete': ('slingre',),
'slintret': ('slintret',),
'slintrete': ('slintret',),
'slintretere': ('slintret',),
'slintretest': ('slintret',),
'slintreteste': ('slintret',),
'slintrete': ('slintrete',),
'slipende': ('slipe',),
'slipt': ('slipe',),
'slipte': ('slipe',),
'slippende': ('slippe',),
'slupne': ('slippe',),
'sluppen': ('slippe',),
'sluppet': ('slippe',),
'sliska': ('sliske',),
'sliskede': ('sliske',),
'sliskende': ('sliske',),
'slisket': ('sliske',),
'sliskete': ('sliske',),
'slisket': ('slisket',),
'sliskete': ('slisket',),
'slisketere': ('slisket',),
'slisketest': ('slisket',),
'slisketeste': ('slisket',),
'sliskete': ('sliskete',),
'slissa': ('slisse',),
'slissede': ('slisse',),
'slissende': ('slisse',),
'slisset': ('slisse',),
'slissete': ('slisse',),
'slitende': ('slite',),
'slitt': ('slite',),
'slitte': ('slite',),
'sliten': ('sliten',),
'slitent': ('sliten',),
'slitne': ('sliten',),
'slitnere': ('sliten',),
'slitnest': ('sliten',),
'slitneste': ('sliten',),
'slitesterk': ('slitesterk',),
'slitesterke': ('slitesterk',),
'slitesterkere': ('slitesterk',),
'slitesterkest': ('slitesterk',),
'slitesterkeste': ('slitesterk',),
'slitesterkt': ('slitesterk',),
'slitna': ('slitne',),
'slitnede': ('slitne',),
'slitnende': ('slitne',),
'slitnet': ('slitne',),
'slitnete': ('slitne',),
'slitsom': ('slitsom',),
'slitsomme': ('slitsom',),
'slitsommere': ('slitsom',),
'slitsomst': ('slitsom',),
'slitsomste': ('slitsom',),
'slitsomt': ('slitsom',),
'slodda': ('slodde',),
'sloddede': ('slodde',),
'sloddende': ('slodde',),
'sloddet': ('slodde',),
'sloddete': ('slodde',),
'slokka': ('slokke',),
'slokkede': ('slokke',),
'slokkende': ('slokke',),
'slokket': ('slokke',),
'slokkete': ('slokke',),
'slokt': ('slokke',),
'slokte': ('slokke',),
'slokka': ('slokke',),
'slokkede': ('slokke',),
'slokkende': ('slokke',),
'slokket': ('slokke',),
'slokkete': ('slokke',),
'slokt': ('slokke',),
'slokte': ('slokke',),
'slokna': ('slokne',),
'sloknede': ('slokne',),
'sloknende': ('slokne',),
'sloknet': ('slokne',),
'sloknete': ('slokne',),
'slottstappa': ('slottstappa',),
'slottstappede': ('slottstappet',),
'slottstappet': ('slottstappet',),
'slottstappete': ('slottstappet',),
'slottstappetere': ('slottstappet',),
'slottstappetest': ('slottstappet',),
'slottstappeteste': ('slottstappet',),
'slovakisk': ('slovakisk',),
'slovakiske': ('slovakisk',),
'slovakiskere': ('slovakisk',),
'slovakiskest': ('slovakisk',),
'slovakiskeste': ('slovakisk',),
'slovensk': ('slovensk',),
'slovenske': ('slovensk',),
'slovenskere': ('slovensk',),
'slovenskest': ('slovensk',),
'slovenskeste': ('slovensk',),
'slu': ('slu',),
'slue': ('slu',),
'sluere': ('slu',),
'sluest': ('slu',),
'slueste': ('slu',),
'slubba': ('slubbe',),
'slubbede': ('slubbe',),
'slubbende': ('slubbe',),
'slubbet': ('slubbe',),
'slubbete': ('slubbe',),
'slubra': ('slubre',),
'slubrede': ('slubre',),
'slubrende': ('slubre',),
'slubret': ('slubre',),
'slubrete': ('slubre',),
'sludda': ('sludde',),
'sluddede': ('sludde',),
'sluddende': ('sludde',),
'sluddet': ('sludde',),
'sluddete': ('sludde',),
'sludra': ('sludre',),
'sludrede': ('sludre',),
'sludrende': ('sludre',),
'sludret': ('sludre',),
'sludrete': ('sludre',),
'sluffa': ('sluffe',),
'sluffede': ('sluffe',),
'sluffende': ('sluffe',),
'sluffet': ('sluffe',),
'sluffete': ('sluffe',),
'slufsa': ('slufse',),
'slufsede': ('slufse',),
'slufsende': ('slufse',),
'slufset': ('slufse',),
'slufsete': ('slufse',),
'slukende': ('sluke',),
'slukt': ('sluke',),
'slukte': ('sluke',),
'sluken': ('sluken',),
'slukent': ('sluken',),
'slukne': ('sluken',),
'sluknere': ('sluken',),
'sluknest': ('sluken',),
'slukneste': ('sluken',),
'slukka': ('slukke',),
'slukkede': ('slukke',),
'slukkende': ('slukke',),
'slukket': ('slukke',),
'slukkete': ('slukke',),
'slukt': ('slukke',),
'slukte': ('slukke',),
'slukka': ('slukke',),
'slukkede': ('slukke',),
'slukkende': ('slukke',),
'slukket': ('slukke',),
'slukkete': ('slukke',),
'slukt': ('slukke',),
'slukte': ('slukke',),
'slukkøra': ('slukkøra',),
'slukkørede': ('slukkøret',),
'slukkøret': ('slukkøret',),
'slukkørete': ('slukkøret',),
'slukkøretere': ('slukkøret',),
'slukkøretest': ('slukkøret',),
'slukkøreteste': ('slukkøret',),
'slukna': ('slukne',),
'sluknede': ('slukne',),
'sluknende': ('slukne',),
'sluknet': ('slukne',),
'sluknete': ('slukne',),
'slukøra': ('slukøra',),
'slukørede': ('slukøret',),
'slukøret': ('slukøret',),
'slukørete': ('slukøret',),
'slukøretere': ('slukøret',),
'slukøretest': ('slukøret',),
'slukøreteste': ('slukøret',),
'slumpa': ('slumpe',),
'slumpede': ('slumpe',),
'slumpende': ('slumpe',),
'slumpet': ('slumpe',),
'slumpete': ('slumpe',),
'slumpeheldig': ('slumpeheldig',),
'slumpeheldige': ('slumpeheldig',),
'slumpeheldigere': ('slumpeheldig',),
'slumpeheldigst': ('slumpeheldig',),
'slumpeheldigste': ('slumpeheldig',),
'slumra': ('slumre',),
'slumrede': ('slumre',),
'slumrende': ('slumre',),
'slumret': ('slumre',),
'slumrete': ('slumre',),
'slumsa': ('slumse',),
'slumsede': ('slumse',),
'slumsende': ('slumse',),
'slumset': ('slumse',),
'slumsete': ('slumse',),
'slumset': ('slumset',),
'slumsete': ('slumset',),
'slumsetere': ('slumset',),
'slumsetest': ('slumset',),
'slumseteste': ('slumset',),
'slumsete': ('slumsete',),
'slunken': ('slunken',),
'slunkent': ('slunken',),
'slunkne': ('slunken',),
'slunknere': ('slunken',),
'slunknest': ('slunken',),
'slunkneste': ('slunken',),
'sluntra': ('sluntre',),
'sluntrede': ('sluntre',),
'sluntrende': ('sluntre',),
'sluntret': ('sluntre',),
'sluntrete': ('sluntre',),
'slura': ('slure',),
'slurede': ('slure',),
'slurende': ('slure',),
'sluret': ('slure',),
'slurete': ('slure',),
'slurt': ('slure',),
'slurte': ('slure',),
'slurka': ('slurke',),
'slurkede': ('slurke',),
'slurkende': ('slurke',),
'slurket': ('slurke',),
'slurkete': ('slurke',),
'slurpa': ('slurpe',),
'slurpede': ('slurpe',),
'slurpende': ('slurpe',),
'slurpet': ('slurpe',),
'slurpete': ('slurpe',),
'slurva': ('slurve',),
'slurvede': ('slurve',),
'slurvende': ('slurve',),
'slurvet': ('slurve',),
'slurvete': ('slurve',),
'slurvet': ('slurvet',),
'slurvete': ('slurvet',),
'slurvetere': ('slurvet',),
'slurvetest': ('slurvet',),
'slurveteste': ('slurvet',),
'slurvete': ('slurvete',),
'slusa': ('sluse',),
'slusede': ('sluse',),
'slusende': ('sluse',),
'sluset': ('sluse',),
'slusete': ('sluse',),
'sluska': ('sluske',),
'sluskede': ('sluske',),
'sluskende': ('sluske',),
'slusket': ('sluske',),
'sluskete': ('sluske',),
'slusket': ('slusket',),
'sluskete': ('slusket',),
'slusketere': ('slusket',),
'slusketest': ('slusket',),
'slusketeste': ('slusket',),
'sluskete': ('sluskete',),
'slut': ('slut',),
'slute': ('slut',),
'slutere': ('slut',),
'slutest': ('slut',),
'sluteste': ('slut',),
'slutt': ('slut',),
'sluta': ('slute',),
'slutede': ('slute',),
'slutende': ('slute',),
'slutet': ('slute',),
'slutete': ('slute',),
'slutrygga': ('slutrygga',),
'slutryggede': ('slutrygget',),
'slutrygget': ('slutrygget',),
'slutryggete': ('slutrygget',),
'slutryggetere': ('slutrygget',),
'slutryggetest': ('slutrygget',),
'slutryggeteste': ('slutrygget',),
'slutt': ('slutt',),
'slutta': ('slutte',),
'sluttede': ('slutte',),
'sluttende': ('slutte',),
'sluttet': ('slutte',),
'sluttete': ('slutte',),
'sluttførende': ('sluttføre',),
'sluttført': ('sluttføre',),
'sluttførte': ('sluttføre',),
'slyet': ('slyet',),
'slyete': ('slyet',),
'slyetere': ('slyet',),
'slyetest': ('slyet',),
'slyeteste': ('slyet',),
'slyete': ('slyete',),
'slynga': ('slynge',),
'slyngede': ('slynge',),
'slyngende': ('slynge',),
'slynget': ('slynge',),
'slyngete': ('slynge',),
'slyngt': ('slynge',),
'slyngte': ('slynge',),
'slående': ('slå',),
'slått': ('slå',),
'slåtte': ('slå',),
'slåpen': ('slåpen',),
'slåpent': ('slåpen',),
'slåpne': ('slåpen',),
'slåpnere': ('slåpen',),
'slåpnest': ('slåpen',),
'slåpneste': ('slåpen',),
'sløkka': ('sløkke',),
'sløkkede': ('sløkke',),
'sløkkende': ('sløkke',),
'sløkket': ('sløkke',),
'sløkkete': ('sløkke',),
'sløkt': ('sløkke',),
'sløkte': ('sløkke',),
'sløra': ('sløre',),
'slørede': ('sløre',),
'slørende': ('sløre',),
'sløret': ('sløre',),
'slørete': ('sløre',),
'slørt': ('sløre',),
'slørte': ('sløre',),
'sløra': ('sløre',),
'slørede': ('sløre',),
'slørende': ('sløre',),
'sløret': ('sløre',),
'slørete': ('sløre',),
'slørt': ('sløre',),
'slørte': ('sløre',),
'sløret': ('sløret',),
'slørete': ('sløret',),
'sløretere': ('sløret',),
'sløretest': ('sløret',),
'sløreteste': ('sløret',),
'slørete': ('slørete',),
'slørlett': ('slørlett',),
'slørlette': ('slørlett',),
'slørlettere': ('slørlett',),
'slørlettest': ('slørlett',),
'slørletteste': ('slørlett',),
'sløsende': ('sløse',),
'sløst': ('sløse',),
'sløste': ('sløse',),
'sløset': ('sløset',),
'sløsete': ('sløset',),
'sløsetere': ('sløset',),
'sløsetest': ('sløset',),
'sløseteste': ('sløset',),
'sløsete': ('sløsete',),
'sløv': ('sløv',),
'sløve': ('sløv',),
'sløvere': ('sløv',),
'sløvest': ('sløv',),
'sløveste': ('sløv',),
'sløvt': ('sløv',),
'sløva': ('sløve',),
'sløvede': ('sløve',),
'sløvende': ('sløve',),
'sløvet': ('sløve',),
'sløvete': ('sløve',),
'sløvna': ('sløvne',),
'sløvnede': ('sløvne',),
'sløvnende': ('sløvne',),
'sløvnet': ('sløvne',),
'sløvnete': ('sløvne',),
'sløy': ('sløy',),
'sløye': ('sløy',),
'sløyere': ('sløy',),
'sløyest': ('sløy',),
'sløyeste': ('sløy',),
'sløyt': ('sløy',),
'sløytt': ('sløy',),
'sløyda': ('sløyde',),
'sløydede': ('sløyde',),
'sløydende': ('sløyde',),
'sløydet': ('sløyde',),
'sløydete': ('sløyde',),
'sløyfa': ('sløyfe',),
'sløyfede': ('sløyfe',),
'sløyfende': ('sløyfe',),
'sløyfet': ('sløyfe',),
'sløyfete': ('sløyfe',),
'smadra': ('smadre',),
'smadrede': ('smadre',),
'smadrende': ('smadre',),
'smadret': ('smadre',),
'smadrete': ('smadre',),
'smaka': ('smake',),
'smakende': ('smake',),
'smakt': ('smake',),
'smakte': ('smake',),
'smakelig': ('smakelig',),
'smakelige': ('smakelig',),
'smakeligere': ('smakelig',),
'smakeligst': ('smakelig',),
'smakeligste': ('smakelig',),
'smakfull': ('smakfull',),
'smakfulle': ('smakfull',),
'smakfullere': ('smakfull',),
'smakfullest': ('smakfull',),
'smakfulleste': ('smakfull',),
'smakfullt': ('smakfull',),
'smaklaus': ('smaklaus',),
'smaklause': ('smaklaus',),
'smaklausere': ('smaklaus',),
'smaklausest': ('smaklaus',),
'smaklauseste': ('smaklaus',),
'smaklaust': ('smaklaus',),
'smakløs': ('smakløs',),
'smakløse': ('smakløs',),
'smakløsere': ('smakløs',),
'smakløsest': ('smakløs',),
'smakløseste': ('smakløs',),
'smakløst': ('smakløs',),
'smaksatt': ('smaksette',),
'smaksatte': ('smaksette',),
'smaksettende': ('smaksette',),
'smal': ('smal',),
'smale': ('smal',),
'smalere': ('smal',),
'smalest': ('smal',),
'smaleste': ('smal',),
'smalt': ('smal',),
'smala': ('smale',),
'smalede': ('smale',),
'smalende': ('smale',),
'smalet': ('smale',),
'smalete': ('smale',),
'smalna': ('smalne',),
'smalnede': ('smalne',),
'smalnende': ('smalne',),
'smalnet': ('smalne',),
'smalnete': ('smalne',),
'smalspora': ('smalspora',),
'smalsporede': ('smalsporet',),
'smalsporet': ('smalsporet',),
'smalsporete': ('smalsporet',),
'smalsporetere': ('smalsporet',),
'smalsporetest': ('smalsporet',),
'smalsporeteste': ('smalsporet',),
'smaragdgrønn': ('smaragdgrønn',),
'smaragdgrønne': ('smaragdgrønn',),
'smaragdgrønnere': ('smaragdgrønn',),
'smaragdgrønnest': ('smaragdgrønn',),
'smaragdgrønneste': ('smaragdgrønn',),
'smaragdgrønt': ('smaragdgrønn',),
'smart': ('smart',),
'smarte': ('smart',),
'smartere': ('smart',),
'smartest': ('smart',),
'smarteste': ('smart',),
'smasha': ('smashe',),
'smashede': ('smashe',),
'smashende': ('smashe',),
'smashet': ('smashe',),
'smashete': ('smashe',),
'smaska': ('smaske',),
'smaskede': ('smaske',),
'smaskende': ('smaske',),
'smasket': ('smaske',),
'smaskete': ('smaske',),
'smatra': ('smatre',),
'smatrede': ('smatre',),
'smatrende': ('smatre',),
'smatret': ('smatre',),
'smatrete': ('smatre',),
'smatta': ('smatte',),
'smattede': ('smatte',),
'smattende': ('smatte',),
'smattet': ('smatte',),
'smattete': ('smatte',),
'smeda': ('smede',),
'smedede': ('smede',),
'smedende': ('smede',),
'smedet': ('smede',),
'smedete': ('smede',),
'smeikende': ('smeike',),
'smeikt': ('smeike',),
'smeikte': ('smeike',),
'smeiken': ('smeiken',),
'smeikent': ('smeiken',),
'smeikne': ('smeiken',),
'smeiknere': ('smeiken',),
'smeiknest': ('smeiken',),
'smeikneste': ('smeiken',),
'smeisa': ('smeise',),
'smeisede': ('smeise',),
'smeisende': ('smeise',),
'smeiset': ('smeise',),
'smeisete': ('smeise',),
'smeist': ('smeise',),
'smeiste': ('smeise',),
'smekka': ('smekke',),
'smekkede': ('smekke',),
'smekkende': ('smekke',),
'smekket': ('smekke',),
'smekkete': ('smekke',),
'smekker': ('smekker',),
'smekkert': ('smekker',),
'smekre': ('smekker',),
'smekrere': ('smekker',),
'smekrest': ('smekker',),
'smekreste': ('smekker',),
'smekkfull': ('smekkfull',),
'smekkfulle': ('smekkfull',),
'smekkfullere': ('smekkfull',),
'smekkfullest': ('smekkfull',),
'smekkfulleste': ('smekkfull',),
'smekkfullt': ('smekkfull',),
'smekta': ('smekte',),
'smektede': ('smekte',),
'smektende': ('smekte',),
'smektet': ('smekte',),
'smektete': ('smekte',),
'smektende': ('smektende',),
'smellfeit': ('smellfeit',),
'smellfeite': ('smellfeit',),
'smellfeitere': ('smellfeit',),
'smellfeitest': ('smellfeit',),
'smellfeiteste': ('smellfeit',),
'smellfeitt': ('smellfeit',),
'smellfett': ('smellfeit',),
'smellfet': ('smellfet',),
'smellfete': ('smellfet',),
'smellfetere': ('smellfet',),
'smellfetest': ('smellfet',),
'smellfeteste': ('smellfet',),
'smellfett': ('smellfet',),
'smellfin': ('smellfin',),
'smellfine': ('smellfin',),
'smellfinere': ('smellfin',),
'smellfinest': ('smellfin',),
'smellfineste': ('smellfin',),
'smellfint': ('smellfin',),
'smellkald': ('smellkald',),
'smellkalde': ('smellkald',),
'smellkaldere': ('smellkald',),
'smellkaldest': ('smellkald',),
'smellkaldeste': ('smellkald',),
'smellkaldt': ('smellkald',),
'smellvakker': ('smellvakker',),
'smellvakkert': ('smellvakker',),
'smellvakre': ('smellvakker',),
'smellvakrere': ('smellvakker',),
'smellvakrest': ('smellvakker',),
'smellvakreste': ('smellvakker',),
'smeltbar': ('smeltbar',),
'smeltbare': ('smeltbar',),
'smeltbarere': ('smeltbar',),
'smeltbarest': ('smeltbar',),
'smeltbareste': ('smeltbar',),
'smeltbart': ('smeltbar',),
'smelta': ('smelte',),
'smeltede': ('smelte',),
'smeltende': ('smelte',),
'smeltet': ('smelte',),
'smeltete': ('smelte',),
'smeltelig': ('smeltelig',),
'smeltelige': ('smeltelig',),
'smelteligere': ('smeltelig',),
'smelteligst': ('smeltelig',),
'smelteligste': ('smeltelig',),
'smergla': ('smergle',),
'smerglede': ('smergle',),
'smerglende': ('smergle',),
'smerglet': ('smergle',),
'smerglete': ('smergle',),
'smerta': ('smerte',),
'smertede': ('smerte',),
'smertende': ('smerte',),
'smertet': ('smerte',),
'smertete': ('smerte',),
'smertefull': ('smertefull',),
'smertefulle': ('smertefull',),
'smertefullere': ('smertefull',),
'smertefullest': ('smertefull',),
'smertefulleste': ('smertefull',),
'smertefullt': ('smertefull',),
'smertelig': ('smertelig',),
'smertelige': ('smertelig',),
'smerteligere': ('smertelig',),
'smerteligst': ('smertelig',),
'smerteligste': ('smertelig',),
'smertestillende': ('smertestillende',),
'smetta': ('smette',),
'smettede': ('smette',),
'smettende': ('smette',),
'smettet': ('smette',),
'smettete': ('smette',),
'smetne': ('smette',),
'smetten': ('smette',),
'smettende': ('smette',),
'smettet': ('smette',),
'smidd': ('smi',),
'smidde': ('smi',),
'smiende': ('smi',),
'smidig': ('smidig',),
'smidige': ('smidig',),
'smidigere': ('smidig',),
'smidigst': ('smidig',),
'smidigste': ('smidig',),
'smigra': ('smigre',),
'smigrede': ('smigre',),
'smigrende': ('smigre',),
'smigret': ('smigre',),
'smigrete': ('smigre',),
'smikka': ('smikke',),
'smikkede': ('smikke',),
'smikkende': ('smikke',),
'smikket': ('smikke',),
'smikkete': ('smikke',),
'smikkfull': ('smikkfull',),
'smikkfulle': ('smikkfull',),
'smikkfullere': ('smikkfull',),
'smikkfullest': ('smikkfull',),
'smikkfulleste': ('smikkfull',),
'smikkfullt': ('smikkfull',),
'smilende': ('smile',),
'smilt': ('smile',),
'smilte': ('smile',),
'sminka': ('sminke',),
'sminkede': ('sminke',),
'sminkende': ('sminke',),
'sminket': ('sminke',),
'sminkete': ('sminke',),
'smiska': ('smiske',),
'smiskede': ('smiske',),
'smiskende': ('smiske',),
'smisket': ('smiske',),
'smiskete': ('smiske',),
'smisket': ('smisket',),
'smiskete': ('smisket',),
'smisketere': ('smisket',),
'smisketest': ('smisket',),
'smisketeste': ('smisket',),
'smiskete': ('smiskete',),
'smitta': ('smitte',),
'smittede': ('smitte',),
'smittende': ('smitte',),
'smittet': ('smitte',),
'smittete': ('smitte',),
'smittefarlig': ('smittefarlig',),
'smittefarlige': ('smittefarlig',),
'smittefarligere': ('smittefarlig',),
'smittefarligst': ('smittefarlig',),
'smittefarligste': ('smittefarlig',),
'smittsom': ('smittsom',),
'smittsomme': ('smittsom',),
'smittsommere': ('smittsom',),
'smittsomst': ('smittsom',),
'smittsomste': ('smittsom',),
'smittsomt': ('smittsom',),
'smugdrikkende': ('smugdrikke',),
'smugdrukken': ('smugdrikke',),
'smugdrukket': ('smugdrikke',),
'smugdrukne': ('smugdrikke',),
'smugla': ('smugle',),
'smuglede': ('smugle',),
'smuglende': ('smugle',),
'smuglet': ('smugle',),
'smuglete': ('smugle',),
'smukk': ('smukk',),
'smukke': ('smukk',),
'smukkere': ('smukk',),
'smukkest': ('smukk',),
'smukkeste': ('smukk',),
'smukt': ('smukk',),
'smul': ('smul',),
'smule': ('smul',),
'smulere': ('smul',),
'smulest': ('smul',),
'smuleste': ('smul',),
'smult': ('smul',),
'smuldra': ('smuldre',),
'smuldrede': ('smuldre',),
'smuldrende': ('smuldre',),
'smuldret': ('smuldre',),
'smuldrete': ('smuldre',),
'smula': ('smule',),
'smulede': ('smule',),
'smulende': ('smule',),
'smulet': ('smule',),
'smulete': ('smule',),
'smult': ('smule',),
'smulte': ('smule',),
'smulet': ('smulet',),
'smulete': ('smulet',),
'smuletere': ('smulet',),
'smuletest': ('smulet',),
'smuleteste': ('smulet',),
'smulete': ('smulete',),
'smulna': ('smulne',),
'smulnede': ('smulne',),
'smulnende': ('smulne',),
'smulnet': ('smulne',),
'smulnete': ('smulne',),
'smusket': ('smusket',),
'smuskete': ('smusket',),
'smusketere': ('smusket',),
'smusketest': ('smusket',),
'smusketeste': ('smusket',),
'smuskete': ('smuskete',),
'smussa': ('smusse',),
'smussede': ('smusse',),
'smussende': ('smusse',),
'smusset': ('smusse',),
'smussete': ('smusse',),
'smussig': ('smussig',),
'smussige': ('smussig',),
'smussigere': ('smussig',),
'smussigst': ('smussig',),
'smussigste': ('smussig',),
'smutta': ('smutte',),
'smuttede': ('smutte',),
'smuttende': ('smutte',),
'smuttet': ('smutte',),
'smuttete': ('smutte',),
'smygende': ('smyge',),
'smøgen': ('smyge',),
'smøget': ('smyge',),
'smøgne': ('smyge',),
'smykka': ('smykke',),
'smykkede': ('smykke',),
'smykkende': ('smykke',),
'smykket': ('smykke',),
'smykkete': ('smykke',),
'småbakket': ('småbakket',),
'småbakkete': ('småbakket',),
'småbakketere': ('småbakket',),
'småbakketest': ('småbakket',),
'småbakketeste': ('småbakket',),
'småborgerlig': ('småborgerlig',),
'småborgerlige': ('småborgerlig',),
'småborgerligere': ('småborgerlig',),
'småborgerligst': ('småborgerlig',),
'småborgerligste': ('småborgerlig',),
'småfallen': ('småfallen',),
'småfallent': ('småfallen',),
'småfalne': ('småfallen',),
'småfalnere': ('småfallen',),
'småfalnest': ('småfallen',),
'småfalneste': ('småfallen',),
'småkupert': ('småkupert',),
'småkuperte': ('småkupert',),
'småkupertere': ('småkupert',),
'småkupertest': ('småkupert',),
'småkuperteste': ('småkupert',),
'smålig': ('smålig',),
'smålige': ('smålig',),
'småligere': ('smålig',),
'småligst': ('smålig',),
'småligste': ('smålig',),
'smålåten': ('smålåten',),
'smålåtent': ('smålåten',),
'smålåtne': ('smålåten',),
'smålåtnere': ('smålåten',),
'smålåtnest': ('smålåten',),
'smålåtneste': ('smålåten',),
'småløpende': ('småløpe',),
'småløpet': ('småløpe',),
'småløpt': ('småløpe',),
'småløpte': ('småløpe',),
'smånøgd': ('smånøgd',),
'smånøgde': ('smånøgd',),
'smånøgdere': ('smånøgd',),
'smånøgdest': ('smånøgd',),
'smånøgdeste': ('smånøgd',),
'smånøyd': ('smånøyd',),
'smånøyde': ('smånøyd',),
'smånøydere': ('smånøyd',),
'smånøydest': ('smånøyd',),
'smånøydeste': ('smånøyd',),
'småpen': ('småpen',),
'småpene': ('småpen',),
'småpenere': ('småpen',),
'småpenest': ('småpen',),
'småpeneste': ('småpen',),
'småpent': ('småpen',),
'småprata': ('småprate',),
'småpratede': ('småprate',),
'småpratende': ('småprate',),
'småpratet': ('småprate',),
'småpratete': ('småprate',),
'småpussig': ('småpussig',),
'småpussige': ('småpussig',),
'småpussigere': ('småpussig',),
'småpussigst': ('småpussig',),
'småpussigste': ('småpussig',),
'smårar': ('smårar',),
'smårare': ('smårar',),
'smårarere': ('smårar',),
'smårarest': ('smårar',),
'smårareste': ('smårar',),
'smårart': ('smårar',),
'småskåren': ('småskåren',),
'småskårent': ('småskåren',),
'småskårne': ('småskåren',),
'småskårnere': ('småskåren',),
'småskårnest': ('småskåren',),
'småskårneste': ('småskåren',),
'småvokst': ('småvokst',),
'småvokste': ('småvokst',),
'småvokstere': ('småvokst',),
'småvokstest': ('småvokst',),
'småvoksteste': ('småvokst',),
'småøyd': ('småøyd',),
'småøyde': ('småøyd',),
'småøydere': ('småøyd',),
'småøydest': ('småøyd',),
'småøydeste': ('småøyd',),
'smørblid': ('smørblid',),
'smørblide': ('smørblid',),
'smørblidere': ('smørblid',),
'smørblidest': ('smørblid',),
'smørblideste': ('smørblid',),
'smørblidt': ('smørblid',),
'smurt': ('smøre',),
'smurte': ('smøre',),
'smørende': ('smøre',),
'smøret': ('smøret',),
'smørete': ('smøret',),
'smøretere': ('smøret',),
'smøretest': ('smøret',),
'smøreteste': ('smøret',),
'smørete': ('smørete',),
'smørevillig': ('smørevillig',),
'smørevillige': ('smørevillig',),
'smørevilligere': ('smørevillig',),
'smørevilligst': ('smørevillig',),
'smørevilligste': ('smørevillig',),
'smøyd': ('smøye',),
'smøyde': ('smøye',),
'smøyende': ('smøye',),
'snadra': ('snadre',),
'snadrede': ('snadre',),
'snadrende': ('snadre',),
'snadret': ('snadre',),
'snadrete': ('snadre',),
'snafsa': ('snafse',),
'snafsede': ('snafse',),
'snafsende': ('snafse',),
'snafset': ('snafse',),
'snafsete': ('snafse',),
'snak': ('snak',),
'snake': ('snak',),
'snakere': ('snak',),
'snakest': ('snak',),
'snakeste': ('snak',),
'snakt': ('snak',),
'snaka': ('snake',),
'snakede': ('snake',),
'snakende': ('snake',),
'snaket': ('snake',),
'snakete': ('snake',),
'snakt': ('snake',),
'snakte': ('snake',),
'snakka': ('snakke',),
'snakkede': ('snakke',),
'snakkende': ('snakke',),
'snakket': ('snakke',),
'snakkete': ('snakke',),
'snakkesalig': ('snakkesalig',),
'snakkesalige': ('snakkesalig',),
'snakkesaligere': ('snakkesalig',),
'snakkesaligst': ('snakkesalig',),
'snakkesaligste': ('snakkesalig',),
'snakketrengt': ('snakketrengt',),
'snakketrengte': ('snakketrengt',),
'snakketrengtere': ('snakketrengt',),
'snakketrengtest': ('snakketrengt',),
'snakketrengteste': ('snakketrengt',),
'snapp': ('snapp',),
'snappe': ('snapp',),
'snappere': ('snapp',),
'snappest': ('snapp',),
'snappeste': ('snapp',),
'snapt': ('snapp',),
'snappa': ('snappe',),
'snappede': ('snappe',),
'snappende': ('snappe',),
'snappet': ('snappe',),
'snappete': ('snappe',),
'snapsa': ('snapse',),
'snapsede': ('snapse',),
'snapsende': ('snapse',),
'snapset': ('snapse',),
'snapsete': ('snapse',),
'snar': ('snar',),
'snare': ('snar',),
'snarere': ('snar',),
'snarest': ('snar',),
'snareste': ('snar',),
'snart': ('snar',),
'snara': ('snare',),
'snarede': ('snare',),
'snarende': ('snare',),
'snaret': ('snare',),
'snarete': ('snare',),
'snarlig': ('snarlig',),
'snarlige': ('snarlig',),
'snarligere': ('snarlig',),
'snarligst': ('snarlig',),
'snarligste': ('snarlig',),
'snarlik': ('snarlik',),
'snarlike': ('snarlik',),
'snarlikere': ('snarlik',),
'snarlikest': ('snarlik',),
'snarlikeste': ('snarlik',),
'snarlikt': ('snarlik',),
'snarp': ('snarp',),
'snarpe': ('snarp',),
'snarpere': ('snarp',),
'snarpest': ('snarp',),
'snarpeste': ('snarp',),
'snarpt': ('snarp',),
'snarrådig': ('snarrådig',),
'snarrådige': ('snarrådig',),
'snarrådigere': ('snarrådig',),
'snarrådigst': ('snarrådig',),
'snarrådigste': ('snarrådig',),
'snarsinna': ('snarsinna',),
'snarsint': ('snarsint',),
'snarsinte': ('snarsint',),
'snarsintere': ('snarsint',),
'snarsintest': ('snarsint',),
'snarsinteste': ('snarsint',),
'snartenkt': ('snartenkt',),
'snartenkte': ('snartenkt',),
'snartenktere': ('snartenkt',),
'snartenktest': ('snartenkt',),
'snartenkteste': ('snartenkt',),
'snaska': ('snaske',),
'snaskede': ('snaske',),
'snaskende': ('snaske',),
'snasket': ('snaske',),
'snaskete': ('snaske',),
'snau': ('snau',),
'snaue': ('snau',),
'snauere': ('snau',),
'snauest': ('snau',),
'snaueste': ('snau',),
'snaut': ('snau',),
'snautt': ('snau',),
'snaublåsende': ('snaublåse',),
'snaublåst': ('snaublåse',),
'snaublåste': ('snaublåse',),
'snaua': ('snaue',),
'snauede': ('snaue',),
'snauende': ('snaue',),
'snauet': ('snaue',),
'snauete': ('snaue',),
'snaugnagd': ('snaugnage',),
'snaugnagde': ('snaugnage',),
'snaugnagede': ('snaugnage',),
'snaugnagende': ('snaugnage',),
'snaugnaget': ('snaugnage',),
'snaugnagete': ('snaugnage',),
'snauklippa': ('snauklippe',),
'snauklippede': ('snauklippe',),
'snauklippende': ('snauklippe',),
'snauklippet': ('snauklippe',),
'snauklippete': ('snauklippe',),
'snauklipt': ('snauklippe',),
'snauklipte': ('snauklippe',),
'snauslitende': ('snauslite',),
'snauslitt': ('snauslite',),
'snauslitte': ('snauslite',),
'snavla': ('snavle',),
'snavlede': ('snavle',),
'snavlende': ('snavle',),
'snavlet': ('snavle',),
'snavlete': ('snavle',),
'snedden': ('snedden',),
'sneddent': ('snedden',),
'snedne': ('snedden',),
'snednere': ('snedden',),
'snednest': ('snedden',),
'snedneste': ('snedden',),
'snedig': ('snedig',),
'snedige': ('snedig',),
'snedigere': ('snedig',),
'snedigst': ('snedig',),
'snedigste': ('snedig',),
'snegla': ('snegle',),
'sneglede': ('snegle',),
'sneglende': ('snegle',),
'sneglet': ('snegle',),
'sneglete': ('snegle',),
'sneia': ('sneie',),
'sneid': ('sneie',),
'sneidd': ('sneie',),
'sneidde': ('sneie',),
'sneide': ('sneie',),
'sneiede': ('sneie',),
'sneiende': ('sneie',),
'sneiet': ('sneie',),
'sneiete': ('sneie',),
'sneisa': ('sneise',),
'sneisede': ('sneise',),
'sneisende': ('sneise',),
'sneiset': ('sneise',),
'sneisete': ('sneise',),
'sneist': ('sneise',),
'sneiste': ('sneise',),
'sneka': ('sneke',),
'snekede': ('sneke',),
'snekende': ('sneke',),
'sneket': ('sneke',),
'snekete': ('sneke',),
'snekkererende': ('snekkerere',),
'snekkerert': ('snekkerere',),
'snekkererte': ('snekkerere',),
'snekra': ('snekre',),
'snekrede': ('snekre',),
'snekrende': ('snekre',),
'snekret': ('snekre',),
'snekrete': ('snekre',),
'snella': ('snelle',),
'snellede': ('snelle',),
'snellende': ('snelle',),
'snellet': ('snelle',),
'snellete': ('snelle',),
'snerka': ('snerke',),
'snerkede': ('snerke',),
'snerkende': ('snerke',),
'snerket': ('snerke',),
'snerkete': ('snerke',),
'snerpa': ('snerpe',),
'snerpede': ('snerpe',),
'snerpende': ('snerpe',),
'snerpet': ('snerpe',),
'snerpete': ('snerpe',),
'snerpa': ('snerpe',),
'snerpede': ('snerpe',),
'snerpende': ('snerpe',),
'snerpet': ('snerpe',),
'snerpete': ('snerpe',),
'snerpen': ('snerpen',),
'snerpent': ('snerpen',),
'snerpne': ('snerpen',),
'snerpnere': ('snerpen',),
'snerpnest': ('snerpen',),
'snerpneste': ('snerpen',),
'snerpet': ('snerpet',),
'snerpete': ('snerpet',),
'snerpetere': ('snerpet',),
'snerpetest': ('snerpet',),
'snerpeteste': ('snerpet',),
'snerpete': ('snerpete',),
'snerra': ('snerre',),
'snerrede': ('snerre',),
'snerrende': ('snerre',),
'snerret': ('snerre',),
'snerrete': ('snerre',),
'snerta': ('snerte',),
'snertede': ('snerte',),
'snertende': ('snerte',),
'snertet': ('snerte',),
'snertete': ('snerte',),
'snerten': ('snerten',),
'snertent': ('snerten',),
'snertne': ('snerten',),
'snertnere': ('snerten',),
'snertnest': ('snerten',),
'snertneste': ('snerten',),
'snever': ('snever',),
'snevert': ('snever',),
'snevre': ('snever',),
'snevrere': ('snever',),
'snevrest': ('snever',),
'snevreste': ('snever',),
'sneversinna': ('sneversinna',),
'sneversinnet': ('sneversinnet',),
'sneversinnete': ('sneversinnet',),
'sneversinnetere': ('sneversinnet',),
'sneversinnetest': ('sneversinnet',),
'sneversinneteste': ('sneversinnet',),
'sneversynt': ('sneversynt',),
'sneversynte': ('sneversynt',),
'sneversyntere': ('sneversynt',),
'sneversyntest': ('sneversynt',),
'sneversynteste': ('sneversynt',),
'snevra': ('snevre',),
'snevrede': ('snevre',),
'snevrende': ('snevre',),
'snevret': ('snevre',),
'snevrete': ('snevre',),
'sniffa': ('sniffe',),
'sniffede': ('sniffe',),
'sniffende': ('sniffe',),
'sniffet': ('sniffe',),
'sniffete': ('sniffe',),
'sniken': ('sniken',),
'snikent': ('sniken',),
'snikne': ('sniken',),
'sniknere': ('sniken',),
'sniknest': ('sniken',),
'snikneste': ('sniken',),
'sniket': ('sniket',),
'snikete': ('sniket',),
'sniketere': ('sniket',),
'sniketest': ('sniket',),
'sniketeste': ('sniket',),
'snikete': ('snikete',),
'snikmyrda': ('snikmyrde',),
'snikmyrdede': ('snikmyrde',),
'snikmyrdende': ('snikmyrde',),
'snikmyrdet': ('snikmyrde',),
'snikmyrdete': ('snikmyrde',),
'snill': ('snill',),
'snille': ('snill',),
'snillere': ('snill',),
'snillest': ('snill',),
'snilleste': ('snill',),
'snilt': ('snill',),
'snirkla': ('snirkle',),
'snirklede': ('snirkle',),
'snirklende': ('snirkle',),
'snirklet': ('snirkle',),
'snirklete': ('snirkle',),
'snirklet': ('snirklet',),
'snirklete': ('snirklet',),
'snirkletere': ('snirklet',),
'snirkletest': ('snirklet',),
'snirkleteste': ('snirklet',),
'snirklete': ('snirklete',),
'snitta': ('snitte',),
'snittede': ('snitte',),
'snittende': ('snitte',),
'snittet': ('snitte',),
'snittete': ('snitte',),
'snodd': ('sno',),
'snodde': ('sno',),
'snoende': ('sno',),
'snodd': ('sno',),
'snodde': ('sno',),
'snoende': ('sno',),
'snobba': ('snobbe',),
'snobbede': ('snobbe',),
'snobbende': ('snobbe',),
'snobbet': ('snobbe',),
'snobbete': ('snobbe',),
'snobbet': ('snobbet',),
'snobbete': ('snobbet',),
'snobbetere': ('snobbet',),
'snobbetest': ('snobbet',),
'snobbeteste': ('snobbet',),
'snobbete': ('snobbete',),
'snodig': ('snodig',),
'snodige': ('snodig',),
'snodigere': ('snodig',),
'snodigst': ('snodig',),
'snodigste': ('snodig',),
'snoka': ('snoke',),
'snokede': ('snoke',),
'snokende': ('snoke',),
'snoket': ('snoke',),
'snokete': ('snoke',),
'snokt': ('snoke',),
'snokte': ('snoke',),
'snopa': ('snope',),
'snopede': ('snope',),
'snopende': ('snope',),
'snopet': ('snope',),
'snopete': ('snope',),
'snopt': ('snope',),
'snopte': ('snope',),
'snorbein': ('snorbein',),
'snorbeine': ('snorbein',),
'snorbeinere': ('snorbein',),
'snorbeinest': ('snorbein',),
'snorbeineste': ('snorbein',),
'snorbeint': ('snorbein',),
'snorben': ('snorben',),
'snorbene': ('snorben',),
'snorbenere': ('snorben',),
'snorbenest': ('snorben',),
'snorbeneste': ('snorben',),
'snorbent': ('snorben',),
'snorka': ('snorke',),
'snorkede': ('snorke',),
'snorkende': ('snorke',),
'snorket': ('snorke',),
'snorkete': ('snorke',),
'snorksoven': ('snorksove',),
'snorksovende': ('snorksove',),
'snorksovet': ('snorksove',),
'snorksovne': ('snorksove',),
'snorrett': ('snorrett',),
'snorrette': ('snorrett',),
'snorrettere': ('snorrett',),
'snorrettest': ('snorrett',),
'snorretteste': ('snorrett',),
'snudd': ('snu',),
'snudde': ('snu',),
'snuende': ('snu',),
'snubba': ('snubbe',),
'snubbede': ('snubbe',),
'snubbende': ('snubbe',),
'snubbet': ('snubbe',),
'snubbete': ('snubbe',),
'snubbet': ('snubbet',),
'snubbete': ('snubbet',),
'snubbetere': ('snubbet',),
'snubbetest': ('snubbet',),
'snubbeteste': ('snubbet',),
'snubbete': ('snubbete',),
'snubla': ('snuble',),
'snublede': ('snuble',),
'snublende': ('snuble',),
'snublet': ('snuble',),
'snublete': ('snuble',),
'snufsa': ('snufse',),
'snufsede': ('snufse',),
'snufsende': ('snufse',),
'snufset': ('snufse',),
'snufsete': ('snufse',),
'snufset': ('snufset',),
'snufsete': ('snufset',),
'snufsetere': ('snufset',),
'snufsetest': ('snufset',),
'snufseteste': ('snufset',),
'snufsete': ('snufsete',),
'snultra': ('snultre',),
'snultrede': ('snultre',),
'snultrende': ('snultre',),
'snultret': ('snultre',),
'snultrete': ('snultre',),
'snuppa': ('snuppe',),
'snuppede': ('snuppe',),
'snuppende': ('snuppe',),
'snuppet': ('snuppe',),
'snuppete': ('snuppe',),
'snuppelig': ('snuppelig',),
'snuppelige': ('snuppelig',),
'snuppeligere': ('snuppelig',),
'snuppeligst': ('snuppelig',),
'snuppeligste': ('snuppelig',),
'snuppet': ('snuppet',),
'snuppete': ('snuppet',),
'snuppetere': ('snuppet',),
'snuppetest': ('snuppet',),
'snuppeteste': ('snuppet',),
'snuppete': ('snuppete',),
'snurpa': ('snurpe',),
'snurpede': ('snurpe',),
'snurpende': ('snurpe',),
'snurpet': ('snurpe',),
'snurpete': ('snurpe',),
'snurpet': ('snurpet',),
'snurpete': ('snurpet',),
'snurpetere': ('snurpet',),
'snurpetest': ('snurpet',),
'snurpeteste': ('snurpet',),
'snurpete': ('snurpete',),
'snurra': ('snurre',),
'snurrede': ('snurre',),
'snurrende': ('snurre',),
'snurret': ('snurre',),
'snurrete': ('snurre',),
'snurrig': ('snurrig',),
'snurrige': ('snurrig',),
'snurrigere': ('snurrig',),
'snurrigst': ('snurrig',),
'snurrigste': ('snurrig',),
'snurt': ('snurt',),
'snurten': ('snurten',),
'snurtent': ('snurten',),
'snurtne': ('snurten',),
'snurtnere': ('snurten',),
'snurtnest': ('snurten',),
'snurtneste': ('snurten',),
'snusende': ('snuse',),
'snust': ('snuse',),
'snuste': ('snuse',),
'snusfornuftig': ('snusfornuftig',),
'snusfornuftige': ('snusfornuftig',),
'snusfornuftigere': ('snusfornuftig',),
'snusfornuftigst': ('snusfornuftig',),
'snusfornuftigste': ('snusfornuftig',),
'snuska': ('snuske',),
'snuskede': ('snuske',),
'snuskende': ('snuske',),
'snusket': ('snuske',),
'snuskete': ('snuske',),
'snusket': ('snusket',),
'snuskete': ('snusket',),
'snusketere': ('snusket',),
'snusketest': ('snusket',),
'snusketeste': ('snusket',),
'snuskete': ('snuskete',),
'snusmalende': ('snusmale',),
'snusmalt': ('snusmale',),
'snusmalte': ('snusmale',),
'snylta': ('snylte',),
'snyltede': ('snylte',),
'snyltende': ('snylte',),
'snyltet': ('snylte',),
'snyltete': ('snylte',),
'snytende': ('snyte',),
'snytt': ('snyte',),
'snytte': ('snyte',),
'snytt': ('snytt',),
'snytte': ('snytt',),
'snyttere': ('snytt',),
'snyttest': ('snytt',),
'snytteste': ('snytt',),
'snål': ('snål',),
'snåle': ('snål',),
'snålere': ('snål',),
'snålest': ('snål',),
'snåleste': ('snål',),
'snålt': ('snål',),
'snålende': ('snåle',),
'snålt': ('snåle',),
'snålte': ('snåle',),
'snåp': ('snåp',),
'snåpe': ('snåp',),
'snåpere': ('snåp',),
'snåpest': ('snåp',),
'snåpeste': ('snåp',),
'snåpt': ('snåp',),
'snåva': ('snåve',),
'snåvede': ('snåve',),
'snåvende': ('snåve',),
'snåvet': ('snåve',),
'snåvete': ('snåve',),
'snødd': ('snø',),
'snødde': ('snø',),
'snøende': ('snø',),
'snøblind': ('snøblind',),
'snøblinde': ('snøblind',),
'snøblindere': ('snøblind',),
'snøblindest': ('snøblind',),
'snøblindeste': ('snøblind',),
'snøblindt': ('snøblind',),
'snødekka': ('snødekka',),
'snødekkede': ('snødekket',),
'snødekket': ('snødekket',),
'snødekkete': ('snødekket',),
'snødekketere': ('snødekket',),
'snødekketest': ('snødekket',),
'snødekketeste': ('snødekket',),
'snødekt': ('snødekt',),
'snødekte': ('snødekt',),
'snødektere': ('snødekt',),
'snødektest': ('snødekt',),
'snødekteste': ('snødekt',),
'snøfla': ('snøfle',),
'snøflede': ('snøfle',),
'snøflende': ('snøfle',),
'snøflet': ('snøfle',),
'snøflete': ('snøfle',),
'snøflet': ('snøflet',),
'snøflete': ('snøflet',),
'snøfletere': ('snøflet',),
'snøfletest': ('snøflet',),
'snøfleteste': ('snøflet',),
'snøflete': ('snøflete',),
'snøfta': ('snøfte',),
'snøftede': ('snøfte',),
'snøftende': ('snøfte',),
'snøftet': ('snøfte',),
'snøftete': ('snøfte',),
'snøgg': ('snøgg',),
'snøgge': ('snøgg',),
'snøggere': ('snøgg',),
'snøggest': ('snøgg',),
'snøggeste': ('snøgg',),
'snøgt': ('snøgg',),
'snøgga': ('snøgge',),
'snøggede': ('snøgge',),
'snøggende': ('snøgge',),
'snøgget': ('snøgge',),
'snøggete': ('snøgge',),
'snøgglik': ('snøgglik',),
'snøgglike': ('snøgglik',),
'snøgglikere': ('snøgglik',),
'snøgglikest': ('snøgglik',),
'snøgglikeste': ('snøgglik',),
'snøgglikt': ('snøgglik',),
'snøggtenkt': ('snøggtenkt',),
'snøggtenkte': ('snøggtenkt',),
'snøggtenktere': ('snøggtenkt',),
'snøggtenktest': ('snøggtenkt',),
'snøggtenkteste': ('snøggtenkt',),
'snørende': ('snøre',),
'snørt': ('snøre',),
'snørte': ('snøre',),
'snørekjørende': ('snørekjøre',),
'snørekjørt': ('snørekjøre',),
'snørekjørte': ('snørekjøre',),
'snørret': ('snørret',),
'snørrete': ('snørret',),
'snørretere': ('snørret',),
'snørretest': ('snørret',),
'snørreteste': ('snørret',),
'snørrete': ('snørrete',),
'snørrhoven': ('snørrhoven',),
'snørrhovent': ('snørrhoven',),
'snørrhovne': ('snørrhoven',),
'snørrhovnere': ('snørrhoven',),
'snørrhovnest': ('snørrhoven',),
'snørrhovneste': ('snørrhoven',),
'snørrviktig': ('snørrviktig',),
'snørrviktige': ('snørrviktig',),
'snørrviktigere': ('snørrviktig',),
'snørrviktigst': ('snørrviktig',),
'snørrviktigste': ('snørrviktig',),
'snøsende': ('snøse',),
'snøst': ('snøse',),
'snøste': ('snøse',),
'snøvla': ('snøvle',),
'snøvlede': ('snøvle',),
'snøvlende': ('snøvle',),
'snøvlet': ('snøvle',),
'snøvlete': ('snøvle',),
'snøvlet': ('snøvlet',),
'snøvlete': ('snøvlet',),
'snøvletere': ('snøvlet',),
'snøvletest': ('snøvlet',),
'snøvleteste': ('snøvlet',),
'snøvlete': ('snøvlete',),
'snøyd': ('snøye',),
'snøydd': ('snøye',),
'snøydde': ('snøye',),
'snøyde': ('snøye',),
'snøyende': ('snøye',),
'sober': ('sober',),
'sobert': ('sober',),
'sobre': ('sober',),
'sobrere': ('sober',),
'sobrest': ('sober',),
'sobreste': ('sober',),
'sodomittisk': ('sodomittisk',),
'sodomittiske': ('sodomittisk',),
'sodomittiskere': ('sodomittisk',),
'sodomittiskest': ('sodomittisk',),
'sodomittiskeste': ('sodomittisk',),
'sofistikert': ('sofistikert',),
'sofistikerte': ('sofistikert',),
'sofistikertere': ('sofistikert',),
'sofistikertest': ('sofistikert',),
'sofistikerteste': ('sofistikert',),
'sofistisk': ('sofistisk',),
'sofistiske': ('sofistisk',),
'sofistiskere': ('sofistisk',),
'sofistiskest': ('sofistisk',),
'sofistiskeste': ('sofistisk',),
'soft': ('soft',),
'softe': ('soft',),
'softere': ('soft',),
'softest': ('soft',),
'softeste': ('soft',),
'sogna': ('sogne',),
'sognede': ('sogne',),
'sognende': ('sogne',),
'sognet': ('sogne',),
'sognete': ('sogne',),
'soignert': ('soignert',),
'soignerte': ('soignert',),
'soignertere': ('soignert',),
'soignertest': ('soignert',),
'soignerteste': ('soignert',),
'sokka': ('sokke',),
'sokkede': ('sokke',),
'sokkende': ('sokke',),
'sokket': ('sokke',),
'sokkete': ('sokke',),
'sokna': ('sokne',),
'soknede': ('sokne',),
'soknende': ('sokne',),
'soknet': ('sokne',),
'soknete': ('sokne',),
'sokna': ('sokne',),
'soknede': ('sokne',),
'soknende': ('sokne',),
'soknet': ('sokne',),
'soknete': ('sokne',),
'sokratisk': ('sokratisk',),
'sokratiske': ('sokratisk',),
'sokratiskere': ('sokratisk',),
'sokratiskest': ('sokratisk',),
'sokratiskeste': ('sokratisk',),
'solar': ('solar',),
'solare': ('solar',),
'solarere': ('solar',),
'solarest': ('solar',),
'solareste': ('solar',),
'solart': ('solar',),
'solbrent': ('solbrent',),
'solbrente': ('solbrent',),
'solbrentere': ('solbrent',),
'solbrentest': ('solbrent',),
'solbrenteste': ('solbrent',),
'sola': ('sole',),
'solede': ('sole',),
'solende': ('sole',),
'solet': ('sole',),
'solete': ('sole',),
'solt': ('sole',),
'solte': ('sole',),
'soleklar': ('soleklar',),
'soleklare': ('soleklar',),
'soleklarere': ('soleklar',),
'soleklarest': ('soleklar',),
'soleklareste': ('soleklar',),
'soleklart': ('soleklar',),
'solid': ('solid',),
'solide': ('solid',),
'solidere': ('solid',),
'solidest': ('solid',),
'solideste': ('solid',),
'solidariserende': ('solidarisere',),
'solidarisert': ('solidarisere',),
'solidariserte': ('solidarisere',),
'solidarisk': ('solidarisk',),
'solidariske': ('solidarisk',),
'solidariskere': ('solidarisk',),
'solidariskest': ('solidarisk',),
'solidariskeste': ('solidarisk',),
'solipsistisk': ('solipsistisk',),
'solipsistiske': ('solipsistisk',),
'solipsistiskere': ('solipsistisk',),
'solipsistiskest': ('solipsistisk',),
'solipsistiskeste': ('solipsistisk',),
'solistisk': ('solistisk',),
'solistiske': ('solistisk',),
'solistiskere': ('solistisk',),
'solistiskest': ('solistisk',),
'solistiskeste': ('solistisk',),
'solitær': ('solitær',),
'solitære': ('solitær',),
'solitærere': ('solitær',),
'solitærest': ('solitær',),
'solitæreste': ('solitær',),
'solitært': ('solitær',),
'sollisiterende': ('sollisitere',),
'sollisitert': ('sollisitere',),
'sollisiterte': ('sollisitere',),
'solmiserende': ('solmisere',),
'solmisert': ('solmisere',),
'solmiserte': ('solmisere',),
'solmoden': ('solmoden',),
'solmodent': ('solmoden',),
'solmodne': ('solmoden',),
'solmodnere': ('solmoden',),
'solmodnest': ('solmoden',),
'solmodneste': ('solmoden',),
'solrik': ('solrik',),
'solrike': ('solrik',),
'solrikere': ('solrik',),
'solrikest': ('solrik',),
'solrikeste': ('solrik',),
'solrikt': ('solrik',),
'solsvidd': ('solsvidd',),
'solsvidde': ('solsvidd',),
'solsviddere': ('solsvidd',),
'solsviddest': ('solsvidd',),
'solsviddeste': ('solsvidd',),
'solvendt': ('solvendt',),
'solvendte': ('solvendt',),
'solvendtere': ('solvendt',),
'solvendtest': ('solvendt',),
'solvendteste': ('solvendt',),
'solvent': ('solvent',),
'solvente': ('solvent',),
'solventere': ('solvent',),
'solventest': ('solvent',),
'solventeste': ('solvent',),
'somalisk': ('somalisk',),
'somaliske': ('somalisk',),
'somaliskere': ('somalisk',),
'somaliskest': ('somalisk',),
'somaliskeste': ('somalisk',),
'somatisk': ('somatisk',),
'somatiske': ('somatisk',),
'somatiskere': ('somatisk',),
'somatiskest': ('somatisk',),
'somatiskeste': ('somatisk',),
'somla': ('somle',),
'somlede': ('somle',),
'somlende': ('somle',),
'somlet': ('somle',),
'somlete': ('somle',),
'somlet': ('somlet',),
'somlete': ('somlet',),
'somletere': ('somlet',),
'somletest': ('somlet',),
'somleteste': ('somlet',),
'somlete': ('somlete',),
'sommerlig': ('sommerlig',),
'sommerlige': ('sommerlig',),
'sommerligere': ('sommerlig',),
'sommerligst': ('sommerlig',),
'sommerligste': ('sommerlig',),
'somnambul': ('somnambul',),
'somnambule': ('somnambul',),
'somnambulere': ('somnambul',),
'somnambulest': ('somnambul',),
'somnambuleste': ('somnambul',),
'somnambult': ('somnambul',),
'somnambulistisk': ('somnambulistisk',),
'somnambulistiske': ('somnambulistisk',),
'somnambulistiskere': ('somnambulistisk',),
'somnambulistiskest': ('somnambulistisk',),
'somnambulistiskeste': ('somnambulistisk',),
'sonantisk': ('sonantisk',),
'sonantiske': ('sonantisk',),
'sonantiskere': ('sonantisk',),
'sonantiskest': ('sonantisk',),
'sonantiskeste': ('sonantisk',),
'sonar': ('sonar',),
'sonare': ('sonar',),
'sonarere': ('sonar',),
'sonarest': ('sonar',),
'sonareste': ('sonar',),
'sonart': ('sonar',),
'sonderende': ('sondere',),
'sondert': ('sondere',),
'sonderte': ('sondere',),
'sondra': ('sondre',),
'sondrede': ('sondre',),
'sondrende': ('sondre',),
'sondret': ('sondre',),
'sondrete': ('sondre',),
'sona': ('sone',),
'sonede': ('sone',),
'sonende': ('sone',),
'sonet': ('sone',),
'sonete': ('sone',),
'sont': ('sone',),
'sonte': ('sone',),
'sonisk': ('sonisk',),
'soniske': ('sonisk',),
'soniskere': ('sonisk',),
'soniskest': ('sonisk',),
'soniskeste': ('sonisk',),
'sonor': ('sonor',),
'sonore': ('sonor',),
'sonorere': ('sonor',),
'sonorest': ('sonor',),
'sonoreste': ('sonor',),
'sonort': ('sonor',),
'sopende': ('sope',),
'sopt': ('sope',),
'sopte': ('sope',),
'soppa': ('soppe',),
'soppede': ('soppe',),
'soppende': ('soppe',),
'soppet': ('soppe',),
'soppete': ('soppe',),
'sopne': ('soppen',),
'sopnere': ('soppen',),
'sopnest': ('soppen',),
'sopneste': ('soppen',),
'soppen': ('soppen',),
'soppent': ('soppen',),
'sordinerende': ('sordinere',),
'sordinert': ('sordinere',),
'sordinerte': ('sordinere',),
'sorgfri': ('sorgfri',),
'sorgfrie': ('sorgfri',),
'sorgfriere': ('sorgfri',),
'sorgfriest': ('sorgfri',),
'sorgfrieste': ('sorgfri',),
'sorgfritt': ('sorgfri',),
'sorgfull': ('sorgfull',),
'sorgfulle': ('sorgfull',),
'sorgfullere': ('sorgfull',),
'sorgfullest': ('sorgfull',),
'sorgfulleste': ('sorgfull',),
'sorgfullt': ('sorgfull',),
'sorglaus': ('sorglaus',),
'sorglause': ('sorglaus',),
'sorglausere': ('sorglaus',),
'sorglausest': ('sorglaus',),
'sorglauseste': ('sorglaus',),
'sorglaust': ('sorglaus',),
'sorgløs': ('sorgløs',),
'sorgløse': ('sorgløs',),
'sorgløsere': ('sorgløs',),
'sorgløsest': ('sorgløs',),
'sorgløseste': ('sorgløs',),
'sorgløst': ('sorgløs',),
'sorgmild': ('sorgmild',),
'sorgmilde': ('sorgmild',),
'sorgmildere': ('sorgmild',),
'sorgmildest': ('sorgmild',),
'sorgmildeste': ('sorgmild',),
'sorgmildt': ('sorgmild',),
'sorgtung': ('sorgtung',),
'sorgtunge': ('sorgtung',),
'sorgtungere': ('sorgtung',),
'sorgtungest': ('sorgtung',),
'sorgtungeste': ('sorgtung',),
'sorgtungt': ('sorgtung',),
'sorgtyngre': ('sorgtung',),
'sorgtyngst': ('sorgtung',),
'sorgtyngste': ('sorgtung',),
'sort': ('sort',),
'sorte': ('sort',),
'sortere': ('sort',),
'sortest': ('sort',),
'sorteste': ('sort',),
'sorterende': ('sortere',),
'sortert': ('sortere',),
'sorterte': ('sortere',),
'sosa': ('sose',),
'sosede': ('sose',),
'sosende': ('sose',),
'soset': ('sose',),
'sosete': ('sose',),
'sost': ('sose',),
'soste': ('sose',),
'sosial': ('sosial',),
'sosiale': ('sosial',),
'sosialere': ('sosial',),
'sosialest': ('sosial',),
'sosialeste': ('sosial',),
'sosialt': ('sosial',),
'sosialdemokratisk': ('sosialdemokratisk',),
'sosialdemokratiske': ('sosialdemokratisk',),
'sosialdemokratiskere': ('sosialdemokratisk',),
'sosialdemokratiskest': ('sosialdemokratisk',),
'sosialdemokratiskeste': ('sosialdemokratisk',),
'sosialiserende': ('sosialisere',),
'sosialisert': ('sosialisere',),
'sosialiserte': ('sosialisere',),
'sosialistisk': ('sosialistisk',),
'sosialistiske': ('sosialistisk',),
'sosialistiskere': ('sosialistisk',),
'sosialistiskest': ('sosialistisk',),
'sosialistiskeste': ('sosialistisk',),
'sosialliberal': ('sosialliberal',),
'sosialliberale': ('sosialliberal',),
'sosialliberalere': ('sosialliberal',),
'sosialliberalest': ('sosialliberal',),
'sosialliberaleste': ('sosialliberal',),
'sosialliberalt': ('sosialliberal',),
'sosialøkonomisk': ('sosialøkonomisk',),
'sosialøkonomiske': ('sosialøkonomisk',),
'sosialøkonomiskere': ('sosialøkonomisk',),
'sosialøkonomiskest': ('sosialøkonomisk',),
'sosialøkonomiskeste': ('sosialøkonomisk',),
'sosiokulturell': ('sosiokulturell',),
'sosiokulturelle': ('sosiokulturell',),
'sosiokulturellere': ('sosiokulturell',),
'sosiokulturellest': ('sosiokulturell',),
'sosiokulturelleste': ('sosiokulturell',),
'sosiokulturelt': ('sosiokulturell',),
'sosiologisk': ('sosiologisk',),
'sosiologiske': ('sosiologisk',),
'sosiologiskere': ('sosiologisk',),
'sosiologiskest': ('sosiologisk',),
'sosiologiskeste': ('sosiologisk',),
'sosiopolitisk': ('sosiopolitisk',),
'sosiopolitiske': ('sosiopolitisk',),
'sosiopolitiskere': ('sosiopolitisk',),
'sosiopolitiskest': ('sosiopolitisk',),
'sosiopolitiskeste': ('sosiopolitisk',),
'sosioøkonomisk': ('sosioøkonomisk',),
'sosioøkonomiske': ('sosioøkonomisk',),
'sosioøkonomiskere': ('sosioøkonomisk',),
'sosioøkonomiskest': ('sosioøkonomisk',),
'sosioøkonomiskeste': ('sosioøkonomisk',),
'sota': ('sote',),
'sotede': ('sote',),
'sotende': ('sote',),
'sotet': ('sote',),
'sotete': ('sote',),
'sotet': ('sotet',),
'sotete': ('sotet',),
'sotetere': ('sotet',),
'sotetest': ('sotet',),
'soteteste': ('sotet',),
'sotete': ('sotete',),
'soven': ('sove',),
'sovende': ('sove',),
'sovet': ('sove',),
'sovne': ('sove',),
'sovjetisk': ('sovjetisk',),
'sovjetiske': ('sovjetisk',),
'sovjetiskere': ('sovjetisk',),
'sovjetiskest': ('sovjetisk',),
'sovjetiskeste': ('sovjetisk',),
'sovjetrussisk': ('sovjetrussisk',),
'sovjetrussiske': ('sovjetrussisk',),
'sovjetrussiskere': ('sovjetrussisk',),
'sovjetrussiskest': ('sovjetrussisk',),
'sovjetrussiskeste': ('sovjetrussisk',),
'sovna': ('sovne',),
'sovnede': ('sovne',),
'sovnende': ('sovne',),
'sovnet': ('sovne',),
'sovnete': ('sovne',),
'spadd': ('spa',),
'spadde': ('spa',),
'spaende': ('spa',),
'spak': ('spak',),
'spake': ('spak',),
'spakere': ('spak',),
'spakest': ('spak',),
'spakeste': ('spak',),
'spakt': ('spak',),
'spaklynt': ('spaklynt',),
'spaklynte': ('spaklynt',),
'spaklyntere': ('spaklynt',),
'spaklyntest': ('spaklynt',),
'spaklynteste': ('spaklynt',),
'spakna': ('spakne',),
'spaknede': ('spakne',),
'spaknende': ('spakne',),
'spaknet': ('spakne',),
'spaknete': ('spakne',),
'spalta': ('spalte',),
'spaltede': ('spalte',),
'spaltende': ('spalte',),
'spaltet': ('spalte',),
'spaltete': ('spalte',),
'spandabel': ('spandabel',),
'spandabelt': ('spandabel',),
'spandable': ('spandabel',),
'spandablere': ('spandabel',),
'spandablest': ('spandabel',),
'spandableste': ('spandabel',),
'spanderende': ('spandere',),
'spandert': ('spandere',),
'spanderte': ('spandere',),
'spana': ('spane',),
'spanede': ('spane',),
'spanende': ('spane',),
'spanet': ('spane',),
'spanete': ('spane',),
'spant': ('spane',),
'spante': ('spane',),
'spanka': ('spanke',),
'spankede': ('spanke',),
'spankende': ('spanke',),
'spanket': ('spanke',),
'spankete': ('spanke',),
'spankulerende': ('spankulere',),
'spankulert': ('spankulere',),
'spankulerte': ('spankulere',),
'spansk': ('spansk',),
'spanske': ('spansk',),
'spanskere': ('spansk',),
'spanskest': ('spansk',),
'spanskeste': ('spansk',),
'spanska': ('spanske',),
'spanskede': ('spanske',),
'spanskende': ('spanske',),
'spansket': ('spanske',),
'spanskete': ('spanske',),
'spanta': ('spante',),
'spantede': ('spante',),
'spantende': ('spante',),
'spantet': ('spante',),
'spantete': ('spante',),
'spara': ('spare',),
'sparende': ('spare',),
'spart': ('spare',),
'sparte': ('spare',),
'sparka': ('sparke',),
'sparkede': ('sparke',),
'sparkende': ('sparke',),
'sparket': ('sparke',),
'sparkete': ('sparke',),
'sparkla': ('sparkle',),
'sparklede': ('sparkle',),
'sparklende': ('sparkle',),
'sparklet': ('sparkle',),
'sparklete': ('sparkle',),
'sparra': ('sparre',),
'sparrede': ('sparre',),
'sparrende': ('sparre',),
'sparret': ('sparre',),
'sparrete': ('sparre',),
'sparsom': ('sparsom',),
'sparsomme': ('sparsom',),
'sparsommere': ('sparsom',),
'sparsomst': ('sparsom',),
'sparsomste': ('sparsom',),
'sparsomt': ('sparsom',),
'sparsomsommelig': ('sparsomsommelig',),
'sparsomsommelige': ('sparsomsommelig',),
'sparsomsommeligere': ('sparsomsommelig',),
'sparsomsommeligst': ('sparsomsommelig',),
'sparsomsommeligste': ('sparsomsommelig',),
'spartansk': ('spartansk',),
'spartanske': ('spartansk',),
'spartanskere': ('spartansk',),
'spartanskest': ('spartansk',),
'spartanskeste': ('spartansk',),
'spasa': ('spase',),
'spasede': ('spase',),
'spasende': ('spase',),
'spaset': ('spase',),
'spasete': ('spase',),
'spast': ('spase',),
'spaste': ('spase',),
'spaserende': ('spasere',),
'spasert': ('spasere',),
'spaserte': ('spasere',),
'spasmodisk': ('spasmodisk',),
'spasmodiske': ('spasmodisk',),
'spasmodiskere': ('spasmodisk',),
'spasmodiskest': ('spasmodisk',),
'spasmodiskeste': ('spasmodisk',),
'spastisk': ('spastisk',),
'spastiske': ('spastisk',),
'spastiskere': ('spastisk',),
'spastiskest': ('spastisk',),
'spastiskeste': ('spastisk',),
'spatial': ('spatial',),
'spatiale': ('spatial',),
'spatialere': ('spatial',),
'spatialest': ('spatial',),
'spatialeste': ('spatial',),
'spatialt': ('spatial',),
'spedd': ('spe',),
'spedde': ('spe',),
'speende': ('spe',),
'sped': ('sped',),
'spede': ('sped',),
'spedere': ('sped',),
'spedest': ('sped',),
'spedeste': ('sped',),
'spedt': ('sped',),
'spedalsk': ('spedalsk',),
'spedalske': ('spedalsk',),
'spedalskere': ('spedalsk',),
'spedalskest': ('spedalsk',),
'spedalskeste': ('spedalsk',),
'speeda': ('speede',),
'speedede': ('speede',),
'speedende': ('speede',),
'speedet': ('speede',),
'speedete': ('speede',),
'speida': ('speide',),
'speidede': ('speide',),
'speidende': ('speide',),
'speidet': ('speide',),
'speidete': ('speide',),
'speilblank': ('speilblank',),
'speilblanke': ('speilblank',),
'speilblankere': ('speilblank',),
'speilblankest': ('speilblank',),
'speilblankeste': ('speilblank',),
'speilblankt': ('speilblank',),
'speila': ('speile',),
'speilede': ('speile',),
'speilende': ('speile',),
'speilet': ('speile',),
'speilete': ('speile',),
'speilt': ('speile',),
'speilte': ('speile',),
'speilglatt': ('speilglatt',),
'speilglatte': ('speilglatt',),
'speilglattere': ('speilglatt',),
'speilglattest': ('speilglatt',),
'speilglatteste': ('speilglatt',),
'speilvendende': ('speilvende',),
'speilvendt': ('speilvende',),
'speilvendte': ('speilvende',),
'speka': ('speke',),
'spekede': ('speke',),
'spekende': ('speke',),
'speket': ('speke',),
'spekete': ('speke',),
'spekt': ('speke',),
'spekte': ('speke',),
'speken': ('speken',),
'spekent': ('speken',),
'spekne': ('speken',),
'speknere': ('speken',),
'speknest': ('speken',),
'spekneste': ('speken',),
'spekka': ('spekke',),
'spekkede': ('spekke',),
'spekkende': ('spekke',),
'spekket': ('spekke',),
'spekkete': ('spekke',),
'spekkmålende': ('spekkmåle',),
'spekkmålt': ('spekkmåle',),
'spekkmålte': ('spekkmåle',),
'spekna': ('spekne',),
'speknede': ('spekne',),
'speknende': ('spekne',),
'speknet': ('spekne',),
'speknete': ('spekne',),
'speksa': ('spekse',),
'speksede': ('spekse',),
'speksende': ('spekse',),
'spekset': ('spekse',),
'speksete': ('spekse',),
'spektral': ('spektral',),
'spektrale': ('spektral',),
'spektralere': ('spektral',),
'spektralest': ('spektral',),
'spektraleste': ('spektral',),
'spektralt': ('spektral',),
'spektrografisk': ('spektrografisk',),
'spektrografiske': ('spektrografisk',),
'spektrografiskere': ('spektrografisk',),
'spektrografiskest': ('spektrografisk',),
'spektrografiskeste': ('spektrografisk',),
'spektroskopisk': ('spektroskopisk',),
'spektroskopiske': ('spektroskopisk',),
'spektroskopiskere': ('spektroskopisk',),
'spektroskopiskest': ('spektroskopisk',),
'spektroskopiskeste': ('spektroskopisk',),
'spekulativ': ('spekulativ',),
'spekulative': ('spekulativ',),
'spekulativere': ('spekulativ',),
'spekulativest': ('spekulativ',),
'spekulativeste': ('spekulativ',),
'spekulativt': ('spekulativ',),
'spekulerende': ('spekulere',),
'spekulert': ('spekulere',),
'spekulerte': ('spekulere',),
'spellende': ('spelle',),
'spelt': ('spelle',),
'spelte': ('spelle',),
'spenevarm': ('spenevarm',),
'spenevarme': ('spenevarm',),
'spenevarmere': ('spenevarm',),
'spenevarmest': ('spenevarm',),
'spenevarmeste': ('spenevarm',),
'spenevarmt': ('spenevarm',),
'spennende': ('spenne',),
'spent': ('spenne',),
'spente': ('spenne',),
'spennende': ('spenne',),
'spent': ('spenne',),
'spente': ('spenne',),
'spennende': ('spennende',),
'spenstig': ('spenstig',),
'spenstige': ('spenstig',),
'spenstigere': ('spenstig',),
'spenstigst': ('spenstig',),
'spenstigste': ('spenstig',),
'spent': ('spent',),
'spente': ('spent',),
'spentere': ('spent',),
'spentest': ('spent',),
'spenteste': ('spent',),
'sperra': ('sperre',),
'sperrede': ('sperre',),
'sperrende': ('sperre',),
'sperret': ('sperre',),
'sperrete': ('sperre',),
'spesial': ('spesial',),
'spesialiserende': ('spesialisere',),
'spesialisert': ('spesialisere',),
'spesialiserte': ('spesialisere',),
'spesialpreventiv': ('spesialpreventiv',),
'spesialpreventive': ('spesialpreventiv',),
'spesialpreventivere': ('spesialpreventiv',),
'spesialpreventivest': ('spesialpreventiv',),
'spesialpreventiveste': ('spesialpreventiv',),
'spesialpreventivt': ('spesialpreventiv',),
'spesiell': ('spesiell',),
'spesielle': ('spesiell',),
'spesiellere': ('spesiell',),
'spesiellest': ('spesiell',),
'spesielleste': ('spesiell',),
'spesielt': ('spesiell',),
'spesifikk': ('spesifikk',),
'spesifikke': ('spesifikk',),
'spesifikkere': ('spesifikk',),
'spesifikkest': ('spesifikk',),
'spesifikkeste': ('spesifikk',),
'spesifikt': ('spesifikk',),
'spesifiserende': ('spesifisere',),
'spesifisert': ('spesifisere',),
'spesifiserte': ('spesifisere',),
'spettet': ('spettet',),
'spettete': ('spettet',),
'spettetere': ('spettet',),
'spettetest': ('spettet',),
'spetteteste': ('spettet',),
'spettete': ('spettete',),
'spidda': ('spidde',),
'spiddede': ('spidde',),
'spiddende': ('spidde',),
'spiddet': ('spidde',),
'spiddete': ('spidde',),
'spikka': ('spikke',),
'spikkede': ('spikke',),
'spikkende': ('spikke',),
'spikket': ('spikke',),
'spikkete': ('spikke',),
'spikra': ('spikre',),
'spikrede': ('spikre',),
'spikrende': ('spikre',),
'spikret': ('spikre',),
'spikrete': ('spikre',),
'spildra': ('spildre',),
'spildrede': ('spildre',),
'spildrende': ('spildre',),
'spildret': ('spildre',),
'spildrete': ('spildre',),
'spilende': ('spile',),
'spilt': ('spile',),
'spilte': ('spile',),
'spillende': ('spille',),
'spilt': ('spille',),
'spilte': ('spille',),
'spillende': ('spille',),
'spilt': ('spille',),
'spilte': ('spille',),
'spinal': ('spinal',),
'spinale': ('spinal',),
'spinalere': ('spinal',),
'spinalest': ('spinal',),
'spinaleste': ('spinal',),
'spinalt': ('spinal',),
'spinka': ('spinke',),
'spinkede': ('spinke',),
'spinkende': ('spinke',),
'spinket': ('spinke',),
'spinkete': ('spinke',),
'spinkel': ('spinkel',),
'spinkelt': ('spinkel',),
'spinkle': ('spinkel',),
'spinklere': ('spinkel',),
'spinklest': ('spinkel',),
'spinkleste': ('spinkel',),
'spinnende': ('spinne',),
'spunne': ('spinne',),
'spunnen': ('spinne',),
'spunnet': ('spinne',),
'spionerende': ('spionere',),
'spionert': ('spionere',),
'spionerte': ('spionere',),
'spiraliserende': ('spiralisere',),
'spiralisert': ('spiralisere',),
'spiraliserte': ('spiralisere',),
'spirantisk': ('spirantisk',),
'spirantiske': ('spirantisk',),
'spirantiskere': ('spirantisk',),
'spirantiskest': ('spirantisk',),
'spirantiskeste': ('spirantisk',),
'spira': ('spire',),
'spirede': ('spire',),
'spirende': ('spire',),
'spiret': ('spire',),
'spirete': ('spire',),
'spirt': ('spire',),
'spirte': ('spire',),
'spiritistisk': ('spiritistisk',),
'spiritistiske': ('spiritistisk',),
'spiritistiskere': ('spiritistisk',),
'spiritistiskest': ('spiritistisk',),
'spiritistiskeste': ('spiritistisk',),
'spiritualistisk': ('spiritualistisk',),
'spiritualistiske': ('spiritualistisk',),
'spiritualistiskere': ('spiritualistisk',),
'spiritualistiskest': ('spiritualistisk',),
'spiritualistiskeste': ('spiritualistisk',),
'spirituell': ('spirituell',),
'spirituelle': ('spirituell',),
'spirituellere': ('spirituell',),
'spirituellest': ('spirituell',),
'spirituelleste': ('spirituell',),
'spirituelt': ('spirituell',),
'spirituøs': ('spirituøs',),
'spirituøse': ('spirituøs',),
'spirituøsere': ('spirituøs',),
'spirituøsest': ('spirituøs',),
'spirituøseste': ('spirituøs',),
'spirituøst': ('spirituøs',),
'spisende': ('spise',),
'spist': ('spise',),
'spiste': ('spise',),
'spiselig': ('spiselig',),
'spiselige': ('spiselig',),
'spiseligere': ('spiselig',),
'spiseligst': ('spiselig',),
'spiseligste': ('spiselig',),
'spisk': ('spisk',),
'spiske': ('spisk',),
'spiskere': ('spisk',),
'spiskest': ('spisk',),
'spiskeste': ('spisk',),
'spiskt': ('spisk',),
'spiss': ('spiss',),
'spisse': ('spiss',),
'spissere': ('spiss',),
'spissest': ('spiss',),
'spisseste': ('spiss',),
'spisst': ('spiss',),
'spissborgerlig': ('spissborgerlig',),
'spissborgerlige': ('spissborgerlig',),
'spissborgerligere': ('spissborgerlig',),
'spissborgerligst': ('spissborgerlig',),
'spissborgerligste': ('spissborgerlig',),
'spissa': ('spisse',),
'spissede': ('spisse',),
'spissende': ('spisse',),
'spisset': ('spisse',),
'spissete': ('spisse',),
'spissfindig': ('spissfindig',),
'spissfindige': ('spissfindig',),
'spissfindigere': ('spissfindig',),
'spissfindigst': ('spissfindig',),
'spissfindigste': ('spissfindig',),
'spissformulerende': ('spissformulere',),
'spissformulert': ('spissformulere',),
'spissformulerte': ('spissformulere',),
'spissvinkla': ('spissvinkla',),
'spissvinklede': ('spissvinklet',),
'spissvinklet': ('spissvinklet',),
'spissvinklete': ('spissvinklet',),
'spissvinkletere': ('spissvinklet',),
'spissvinkletest': ('spissvinklet',),
'spissvinkleteste': ('spissvinklet',),
'spjelka': ('spjelke',),
'spjelkede': ('spjelke',),
'spjelkende': ('spjelke',),
'spjelket': ('spjelke',),
'spjelkete': ('spjelke',),
'spjerten': ('spjerten',),
'spjertent': ('spjerten',),
'spjertne': ('spjerten',),
'spjertnere': ('spjerten',),
'spjertnest': ('spjerten',),
'spjertneste': ('spjerten',),
'spjetta': ('spjette',),
'spjettede': ('spjette',),
'spjettende': ('spjette',),
'spjettet': ('spjette',),
'spjettete': ('spjette',),
'spjåka': ('spjåke',),
'spjåkede': ('spjåke',),
'spjåkende': ('spjåke',),
'spjåket': ('spjåke',),
'spjåkete': ('spjåke',),
'spjåkt': ('spjåke',),
'spjåkte': ('spjåke',),
'spjåket': ('spjåket',),
'spjåkete': ('spjåket',),
'spjåketere': ('spjåket',),
'spjåketest': ('spjåket',),
'spjåketeste': ('spjåket',),
'spjåkete': ('spjåkete',),
'spjælet': ('spjælet',),
'spjælete': ('spjælet',),
'spjæletere': ('spjælet',),
'spjæletest': ('spjælet',),
'spjæleteste': ('spjælet',),
'spjæletete': ('spjæletete',),
'spjæra': ('spjære',),
'spjærede': ('spjære',),
'spjærende': ('spjære',),
'spjæret': ('spjære',),
'spjærete': ('spjære',),
'spjært': ('spjære',),
'spjærte': ('spjære',),
'spleisa': ('spleise',),
'spleisede': ('spleise',),
'spleisende': ('spleise',),
'spleiset': ('spleise',),
'spleisete': ('spleise',),
'spleist': ('spleise',),
'spleiste': ('spleise',),
'splendid': ('splendid',),
'splidaktig': ('splidaktig',),
'splidaktige': ('splidaktig',),
'splidaktigere': ('splidaktig',),
'splidaktigst': ('splidaktig',),
'splidaktigste': ('splidaktig',),
'splintra': ('splintre',),
'splintrede': ('splintre',),
'splintrende': ('splintre',),
'splintret': ('splintre',),
'splintrete': ('splintre',),
'splintsikker': ('splintsikker',),
'splintsikkert': ('splintsikker',),
'splintsikre': ('splintsikker',),
'splintsikrere': ('splintsikker',),
'splintsikrest': ('splintsikker',),
'splintsikreste': ('splintsikker',),
'splitta': ('splitte',),
'splittede': ('splitte',),
'splittende': ('splitte',),
'splittet': ('splitte',),
'splittete': ('splitte',),
'spola': ('spole',),
'spolede': ('spole',),
'spolende': ('spole',),
'spolet': ('spole',),
'spolete': ('spole',),
'spolt': ('spole',),
'spolte': ('spole',),
'spolerende': ('spolere',),
'spolert': ('spolere',),
'spolerte': ('spolere',),
'spondeisk': ('spondeisk',),
'spondeiske': ('spondeisk',),
'spondeiskere': ('spondeisk',),
'spondeiskest': ('spondeisk',),
'spondeiskeste': ('spondeisk',),
'sponsa': ('sponse',),
'sponsede': ('sponse',),
'sponsende': ('sponse',),
'sponset': ('sponse',),
'sponsete': ('sponse',),
'spontan': ('spontan',),
'spontane': ('spontan',),
'spontanere': ('spontan',),
'spontanest': ('spontan',),
'spontaneste': ('spontan',),
'spontant': ('spontan',),
'sporadisk': ('sporadisk',),
'sporadiske': ('sporadisk',),
'sporadiskere': ('sporadisk',),
'sporadiskest': ('sporadisk',),
'sporadiskeste': ('sporadisk',),
'spora': ('spore',),
'sporede': ('spore',),
'sporende': ('spore',),
'sporet': ('spore',),
'sporete': ('spore',),
'sport': ('spore',),
'sporte': ('spore',),
'spora': ('spore',),
'sporede': ('spore',),
'sporende': ('spore',),
'sporet': ('spore',),
'sporete': ('spore',),
'sport': ('spore',),
'sporte': ('spore',),
'sporet': ('sporet',),
'sporete': ('sporet',),
'sporetere': ('sporet',),
'sporetest': ('sporet',),
'sporeteste': ('sporet',),
'sporete': ('sporete',),
'sporlaus': ('sporlaus',),
'sporlause': ('sporlaus',),
'sporlausere': ('sporlaus',),
'sporlausest': ('sporlaus',),
'sporlauseste': ('sporlaus',),
'sporlaust': ('sporlaus',),
'sporløs': ('sporløs',),
'sporløse': ('sporløs',),
'sporløsere': ('sporløs',),
'sporløsest': ('sporløs',),
'sporløseste': ('sporløs',),
'sporløst': ('sporløs',),
'sporta': ('sporte',),
'sportede': ('sporte',),
'sportende': ('sporte',),
'sportet': ('sporte',),
'sportete': ('sporte',),
'sportsgal': ('sportsgal',),
'sportsgale': ('sportsgal',),
'sportsgalere': ('sportsgal',),
'sportsgalest': ('sportsgal',),
'sportsgaleste': ('sportsgal',),
'sportsgalt': ('sportsgal',),
'sportslig': ('sportslig',),
'sportslige': ('sportslig',),
'sportsligere': ('sportslig',),
'sportsligst': ('sportslig',),
'sportsligste': ('sportslig',),
'sporty': ('sporty',),
'spotsk': ('spotsk',),
'spotske': ('spotsk',),
'spotskere': ('spotsk',),
'spotskest': ('spotsk',),
'spotskeste': ('spotsk',),
'spotta': ('spotte',),
'spottede': ('spotte',),
'spottende': ('spotte',),
'spottet': ('spotte',),
'spottete': ('spotte',),
'sprada': ('sprade',),
'spradede': ('sprade',),
'spradende': ('sprade',),
'spradet': ('sprade',),
'spradete': ('sprade',),
'spraglet': ('spraglet',),
'spraglete': ('spraglet',),
'spragletere': ('spraglet',),
'spragletest': ('spraglet',),
'spragleteste': ('spraglet',),
'spraglete': ('spraglete',),
'spraka': ('sprake',),
'sprakede': ('sprake',),
'sprakende': ('sprake',),
'spraket': ('sprake',),
'sprakete': ('sprake',),
'sprakt': ('sprake',),
'sprakte': ('sprake',),
'spraya': ('spraye',),
'sprayede': ('spraye',),
'sprayende': ('spraye',),
'sprayet': ('spraye',),
'sprayete': ('spraye',),
'spredd': ('sprede',),
'spredde': ('sprede',),
'spredende': ('sprede',),
'spredt': ('sprede',),
'spredte': ('sprede',),
'spredd': ('sprede',),
'spredde': ('sprede',),
'spredende': ('sprede',),
'spredt': ('sprede',),
'spredte': ('sprede',),
'spredt': ('spredt',),
'spredte': ('spredt',),
'spredtere': ('spredt',),
'spredtest': ('spredt',),
'spredteste': ('spredt',),
'spreid': ('spreie',),
'spreidd': ('spreie',),
'spreidde': ('spreie',),
'spreide': ('spreie',),
'spreiende': ('spreie',),
'spreid': ('spreie',),
'spreidd': ('spreie',),
'spreidde': ('spreie',),
'spreide': ('spreie',),
'spreiende': ('spreie',),
'sprek': ('sprek',),
'spreke': ('sprek',),
'sprekere': ('sprek',),
'sprekest': ('sprek',),
'sprekeste': ('sprek',),
'sprekt': ('sprek',),
'sprekkende': ('sprekke',),
'sprukken': ('sprekke',),
'sprukket': ('sprekke',),
'sprukne': ('sprekke',),
'sprekkeferdig': ('sprekkeferdig',),
'sprekkeferdige': ('sprekkeferdig',),
'sprekkeferdigere': ('sprekkeferdig',),
'sprekkeferdigst': ('sprekkeferdig',),
'sprekkeferdigste': ('sprekkeferdig',),
'sprekket': ('sprekket',),
'sprekkete': ('sprekket',),
'sprekketere': ('sprekket',),
'sprekketest': ('sprekket',),
'sprekketeste': ('sprekket',),
'sprekkete': ('sprekkete',),
'sprella': ('sprelle',),
'sprellede': ('sprelle',),
'sprellende': ('sprelle',),
'sprellet': ('sprelle',),
'sprellete': ('sprelle',),
'sprelt': ('sprelle',),
'sprelte': ('sprelle',),
'sprelsk': ('sprelsk',),
'sprelske': ('sprelsk',),
'sprelskere': ('sprelsk',),
'sprelskest': ('sprelsk',),
'sprelskeste': ('sprelsk',),
'sprelskt': ('sprelsk',),
'sprengende': ('sprenge',),
'sprengt': ('sprenge',),
'sprengte': ('sprenge',),
'sprengfull': ('sprengfull',),
'sprengfulle': ('sprengfull',),
'sprengfullere': ('sprengfull',),
'sprengfullest': ('sprengfull',),
'sprengfulleste': ('sprengfull',),
'sprengfullt': ('sprengfull',),
'sprengkald': ('sprengkald',),
'sprengkalde': ('sprengkald',),
'sprengkaldere': ('sprengkald',),
'sprengkaldest': ('sprengkald',),
'sprengkaldeste': ('sprengkald',),
'sprengkaldt': ('sprengkald',),
'sprengkjørende': ('sprengkjøre',),
'sprengkjørt': ('sprengkjøre',),
'sprengkjørte': ('sprengkjøre',),
'sprenglesende': ('sprenglese',),
'sprenglest': ('sprenglese',),
'sprengleste': ('sprenglese',),
'sprenglærd': ('sprenglærd',),
'sprenglærde': ('sprenglærd',),
'sprenglærdere': ('sprenglærd',),
'sprenglærdest': ('sprenglærd',),
'sprenglærdeste': ('sprenglærd',),
'sprengrød': ('sprengrød',),
'sprengrøde': ('sprengrød',),
'sprengrødere': ('sprengrød',),
'sprengrødest': ('sprengrød',),
'sprengrødeste': ('sprengrød',),
'sprengrødt': ('sprengrød',),
'spretta': ('sprette',),
'sprettede': ('sprette',),
'sprettende': ('sprette',),
'sprettet': ('sprette',),
'sprettete': ('sprette',),
'spretne': ('sprette',),
'spretten': ('sprette',),
'sprettende': ('sprette',),
'sprettet': ('sprette',),
'spretne': ('spretten',),
'spretnere': ('spretten',),
'spretnest': ('spretten',),
'spretneste': ('spretten',),
'spretten': ('spretten',),
'sprettent': ('spretten',),
'spridd': ('spri',),
'spridde': ('spri',),
'spriende': ('spri',),
'sprika': ('sprike',),
'sprikede': ('sprike',),
'sprikende': ('sprike',),
'spriket': ('sprike',),
'sprikete': ('sprike',),
'sprikt': ('sprike',),
'sprikte': ('sprike',),
'springende': ('springe',),
'sprungen': ('springe',),
'sprunget': ('springe',),
'sprungne': ('springe',),
'springsk': ('springsk',),
'springske': ('springsk',),
'springskere': ('springsk',),
'springskest': ('springsk',),
'springskeste': ('springsk',),
'sprinta': ('sprinte',),
'sprintede': ('sprinte',),
'sprintende': ('sprinte',),
'sprintet': ('sprinte',),
'sprintete': ('sprinte',),
'sprita': ('sprite',),
'spritede': ('sprite',),
'spritende': ('sprite',),
'spritet': ('sprite',),
'spritete': ('sprite',),
'sprudla': ('sprudle',),
'sprudlede': ('sprudle',),
'sprudlende': ('sprudle',),
'sprudlet': ('sprudle',),
'sprudlete': ('sprudle',),
'sprukken': ('sprukken',),
'sprukkent': ('sprukken',),
'sprukne': ('sprukken',),
'spruknere': ('sprukken',),
'spruknest': ('sprukken',),
'sprukneste': ('sprukken',),
'spruta': ('sprute',),
'sprutede': ('sprute',),
'sprutende': ('sprute',),
'sprutet': ('sprute',),
'sprutete': ('sprute',),
'sprutregna': ('sprutregne',),
'sprutregnede': ('sprutregne',),
'sprutregnende': ('sprutregne',),
'sprutregnet': ('sprutregne',),
'sprutregnete': ('sprutregne',),
'sprutregnt': ('sprutregne',),
'sprutregnte': ('sprutregne',),
'sprutrød': ('sprutrød',),
'sprutrøde': ('sprutrød',),
'sprutrødere': ('sprutrød',),
'sprutrødest': ('sprutrød',),
'sprutrødeste': ('sprutrød',),
'sprutrødt': ('sprutrød',),
'språkgeografisk': ('språkgeografisk',),
'språkgeografiske': ('språkgeografisk',),
'språkgeografiskere': ('språkgeografisk',),
'språkgeografiskest': ('språkgeografisk',),
'språkgeografiskeste': ('språkgeografisk',),
'språklaus': ('språklaus',),
'språklause': ('språklaus',),
'språklausere': ('språklaus',),
'språklausest': ('språklaus',),
'språklauseste': ('språklaus',),
'språklaust': ('språklaus',),
'språklig': ('språklig',),
'språklige': ('språklig',),
'språkligere': ('språklig',),
'språkligst': ('språklig',),
'språkligste': ('språklig',),
'språkløs': ('språkløs',),
'språkløse': ('språkløs',),
'språkløsere': ('språkløs',),
'språkløsest': ('språkløs',),
'språkløseste': ('språkløs',),
'språkløst': ('språkløs',),
'språkmektig': ('språkmektig',),
'språkmektige': ('språkmektig',),
'språkmektigere': ('språkmektig',),
'språkmektigst': ('språkmektig',),
'språkmektigste': ('språkmektig',),
'sprø': ('sprø',),
'sprøe': ('sprø',),
'sprøere': ('sprø',),
'sprøest': ('sprø',),
'sprøeste': ('sprø',),
'sprøtt': ('sprø',),
'sprøsteikende': ('sprøsteike',),
'sprøsteikt': ('sprøsteike',),
'sprøsteikte': ('sprøsteike',),
'sprøyta': ('sprøyte',),
'sprøytede': ('sprøyte',),
'sprøytende': ('sprøyte',),
'sprøytet': ('sprøyte',),
'sprøytete': ('sprøyte',),
'sprøytelakkerende': ('sprøytelakkere',),
'sprøytelakkert': ('sprøytelakkere',),
'sprøytelakkerte': ('sprøytelakkere',),
'spunsa': ('spunse',),
'spunsede': ('spunse',),
'spunsende': ('spunse',),
'spunset': ('spunse',),
'spunsete': ('spunse',),
'spurtbeseira': ('spurtbeseire',),
'spurtbeseirede': ('spurtbeseire',),
'spurtbeseirende': ('spurtbeseire',),
'spurtbeseiret': ('spurtbeseire',),
'spurtbeseirete': ('spurtbeseire',),
'spurta': ('spurte',),
'spurtede': ('spurte',),
'spurtende': ('spurte',),
'spurtet': ('spurte',),
'spurtete': ('spurte',),
'spurtsterk': ('spurtsterk',),
'spurtsterke': ('spurtsterk',),
'spurtsterkere': ('spurtsterk',),
'spurtsterkest': ('spurtsterk',),
'spurtsterkeste': ('spurtsterk',),
'spurtsterkt': ('spurtsterk',),
'spydd': ('spy',),
'spydde': ('spy',),
'spyende': ('spy',),
'spydig': ('spydig',),
'spydige': ('spydig',),
'spydigere': ('spydig',),
'spydigst': ('spydig',),
'spydigste': ('spydig',),
'spylende': ('spyle',),
'spylt': ('spyle',),
'spylte': ('spyle',),
'spytta': ('spytte',),
'spyttede': ('spytte',),
'spyttende': ('spytte',),
'spyttet': ('spytte',),
'spyttete': ('spytte',),
'spådd': ('spå',),
'spådde': ('spå',),
'spående': ('spå',),
'spøkende': ('spøke',),
'spøkt': ('spøke',),
'spøkte': ('spøke',),
'spøkefull': ('spøkefull',),
'spøkefulle': ('spøkefull',),
'spøkefullere': ('spøkefull',),
'spøkefullest': ('spøkefull',),
'spøkefulleste': ('spøkefull',),
'spøkefullt': ('spøkefull',),
'spøkelig': ('spøkelig',),
'spøkelige': ('spøkelig',),
'spøkeligere': ('spøkelig',),
'spøkeligst': ('spøkelig',),
'spøkeligste': ('spøkelig',),
'spurt': ('spørre',),
'spurte': ('spørre',),
'spørrende': ('spørre',),
'spøtende': ('spøte',),
'spøtt': ('spøte',),
'spøtte': ('spøte',),
'srilankisk': ('srilankisk',),
'srilankiske': ('srilankisk',),
'srilankiskere': ('srilankisk',),
'srilankiskest': ('srilankisk',),
'srilankiskeste': ('srilankisk',),
'sta': ('sta',),
'stae': ('sta',),
'staere': ('sta',),
'staest': ('sta',),
'staeste': ('sta',),
'stabba': ('stabbe',),
'stabbede': ('stabbe',),
'stabbende': ('stabbe',),
'stabbet': ('stabbe',),
'stabbete': ('stabbe',),
'stabil': ('stabil',),
'stabile': ('stabil',),
'stabilere': ('stabil',),
'stabilest': ('stabil',),
'stabileste': ('stabil',),
'stabilt': ('stabil',),
'stabiliserende': ('stabilisere',),
'stabilisert': ('stabilisere',),
'stabiliserte': ('stabilisere',),
'stabla': ('stable',),
'stablede': ('stable',),
'stablende': ('stable',),
'stablet': ('stable',),
'stablete': ('stable',),
'stadfesta': ('stadfeste',),
'stadfestede': ('stadfeste',),
'stadfestende': ('stadfeste',),
'stadfestet': ('stadfeste',),
'stadfestete': ('stadfeste',),
'stadig': ('stadig',),
'stadige': ('stadig',),
'stadigere': ('stadig',),
'stadigst': ('stadig',),
'stadigste': ('stadig',),
'stadslega': ('stadslege',),
'stadslegede': ('stadslege',),
'stadslegende': ('stadslege',),
'stadsleget': ('stadslege',),
'stadslegete': ('stadslege',),
'stadslegt': ('stadslege',),
'stadslegte': ('stadslege',),
'stafferende': ('staffere',),
'staffert': ('staffere',),
'stafferte': ('staffere',),
'staga': ('stage',),
'stagede': ('stage',),
'stagende': ('stage',),
'staget': ('stage',),
'stagete': ('stage',),
'stagga': ('stagge',),
'staggede': ('stagge',),
'staggende': ('stagge',),
'stagget': ('stagge',),
'staggete': ('stagge',),
'stagnerende': ('stagnere',),
'stagnert': ('stagnere',),
'stagnerte': ('stagnere',),
'stagvendende': ('stagvende',),
'stagvendt': ('stagvende',),
'stagvendte': ('stagvende',),
'staka': ('stake',),
'stakede': ('stake',),
'stakende': ('stake',),
'staket': ('stake',),
'stakete': ('stake',),
'stakkars': ('stakkars',),
'stakkarslig': ('stakkarslig',),
'stakkarslige': ('stakkarslig',),
'stakkarsligere': ('stakkarslig',),
'stakkarsligst': ('stakkarslig',),
'stakkarsligste': ('stakkarslig',),
'stakka': ('stakke',),
'stakkede': ('stakke',),
'stakkende': ('stakke',),
'stakket': ('stakke',),
'stakkete': ('stakke',),
'stakket': ('stakket',),
'stakkånda': ('stakkånda',),
'stakkåndede': ('stakkåndet',),
'stakkåndet': ('stakkåndet',),
'stakkåndete': ('stakkåndet',),
'stakkåndetere': ('stakkåndet',),
'stakkåndetest': ('stakkåndet',),
'stakkåndeteste': ('stakkåndet',),
'stalinistisk': ('stalinistisk',),
'stalinistiske': ('stalinistisk',),
'stalinistiskere': ('stalinistisk',),
'stalinistiskest': ('stalinistisk',),
'stalinistiskeste': ('stalinistisk',),
'stalla': ('stalle',),
'stallede': ('stalle',),
'stallende': ('stalle',),
'stallet': ('stalle',),
'stallete': ('stalle',),
'stam': ('stam',),
'stamme': ('stam',),
'stammere': ('stam',),
'stammest': ('stam',),
'stammeste': ('stam',),
'stamt': ('stam',),
'stambokførende': ('stambokføre',),
'stambokført': ('stambokføre',),
'stambokførte': ('stambokføre',),
'stamma': ('stamme',),
'stammede': ('stamme',),
'stammende': ('stamme',),
'stammet': ('stamme',),
'stammete': ('stamme',),
'stamma': ('stamme',),
'stammede': ('stamme',),
'stammende': ('stamme',),
'stammet': ('stamme',),
'stammete': ('stamme',),
'stampa': ('stampe',),
'stampede': ('stampe',),
'stampende': ('stampe',),
'stampet': ('stampe',),
'stampete': ('stampe',),
'stampa': ('stampe',),
'stampede': ('stampe',),
'stampende': ('stampe',),
'stampet': ('stampe',),
'stampete': ('stampe',),
'standard': ('standard',),
'standardiserende': ('standardisere',),
'standardisert': ('standardisere',),
'standardiserte': ('standardisere',),
'standhaftig': ('standhaftig',),
'standhaftige': ('standhaftig',),
'standhaftigere': ('standhaftig',),
'standhaftigst': ('standhaftig',),
'standhaftigste': ('standhaftig',),
'standsmessig': ('standsmessig',),
'standsmessige': ('standsmessig',),
'standsmessigere': ('standsmessig',),
'standsmessigst': ('standsmessig',),
'standsmessigste': ('standsmessig',),
'stana': ('stane',),
'stanede': ('stane',),
'stanende': ('stane',),
'stanet': ('stane',),
'stanete': ('stane',),
'stant': ('stane',),
'stante': ('stane',),
'stanga': ('stange',),
'stangede': ('stange',),
'stangende': ('stange',),
'stanget': ('stange',),
'stangete': ('stange',),
'stanka': ('stanke',),
'stankede': ('stanke',),
'stankende': ('stanke',),
'stanket': ('stanke',),
'stankete': ('stanke',),
'stanka': ('stanke',),
'stankede': ('stanke',),
'stankende': ('stanke',),
'stanket': ('stanke',),
'stankete': ('stanke',),
'stansa': ('stanse',),
'stansede': ('stanse',),
'stansende': ('stanse',),
'stanset': ('stanse',),
'stansete': ('stanse',),
'stansa': ('stanse',),
'stansede': ('stanse',),
'stansende': ('stanse',),
'stanset': ('stanse',),
'stansete': ('stanse',),
'stapla': ('staple',),
'staplede': ('staple',),
'staplende': ('staple',),
'staplet': ('staple',),
'staplete': ('staple',),
'stappa': ('stappe',),
'stappede': ('stappe',),
'stappende': ('stappe',),
'stappet': ('stappe',),
'stappete': ('stappe',),
'stappfull': ('stappfull',),
'stappfulle': ('stappfull',),
'stappfullere': ('stappfull',),
'stappfullest': ('stappfull',),
'stappfulleste': ('stappfull',),
'stappfullt': ('stappfull',),
'stappmett': ('stappmett',),
'stappmette': ('stappmett',),
'stappmettere': ('stappmett',),
'stappmettest': ('stappmett',),
'stappmetteste': ('stappmett',),
'stappmørk': ('stappmørk',),
'stappmørke': ('stappmørk',),
'stappmørkere': ('stappmørk',),
'stappmørkest': ('stappmørk',),
'stappmørkeste': ('stappmørk',),
'stappmørkt': ('stappmørk',),
'starta': ('starte',),
'startede': ('starte',),
'startende': ('starte',),
'startet': ('starte',),
'startete': ('starte',),
'stasa': ('stase',),
'stasede': ('stase',),
'stasende': ('stase',),
'staset': ('stase',),
'stasete': ('stase',),
'stast': ('stase',),
'staste': ('stase',),
'staselig': ('staselig',),
'staselige': ('staselig',),
'staseligere': ('staselig',),
'staseligst': ('staselig',),
'staseligste': ('staselig',),
'stasjonerende': ('stasjonere',),
'stasjonert': ('stasjonere',),
'stasjonerte': ('stasjonere',),
'stasjonær': ('stasjonær',),
'stasjonære': ('stasjonær',),
'stasjonærere': ('stasjonær',),
'stasjonærest': ('stasjonær',),
'stasjonæreste': ('stasjonær',),
'stasjonært': ('stasjonær',),
'statarisk': ('statarisk',),
'statariske': ('statarisk',),
'statariskere': ('statarisk',),
'statariskest': ('statarisk',),
'statariskeste': ('statarisk',),
'statelig': ('statelig',),
'statelige': ('statelig',),
'stateligere': ('statelig',),
'stateligst': ('statelig',),
'stateligste': ('statelig',),
'statisk': ('statisk',),
'statiske': ('statisk',),
'statiskere': ('statisk',),
'statiskest': ('statisk',),
'statiskeste': ('statisk',),
'statistisk': ('statistisk',),
'statistiske': ('statistisk',),
'statistiskere': ('statistisk',),
'statistiskest': ('statistisk',),
'statistiskeste': ('statistisk',),
'statlig': ('statlig',),
'statlige': ('statlig',),
'statligere': ('statlig',),
'statligst': ('statlig',),
'statligste': ('statlig',),
'statsautorisert': ('statsautorisert',),
'statsautoriserte': ('statsautorisert',),
'statsautorisertere': ('statsautorisert',),
'statsautorisertest': ('statsautorisert',),
'statsautoriserteste': ('statsautorisert',),
'statsdrevet': ('statsdrevet',),
'statsdrevne': ('statsdrevet',),
'statsdrevnere': ('statsdrevet',),
'statsdrevnest': ('statsdrevet',),
'statsdrevneste': ('statsdrevet',),
'statslaus': ('statslaus',),
'statslause': ('statslaus',),
'statslausere': ('statslaus',),
'statslausest': ('statslaus',),
'statslauseste': ('statslaus',),
'statslaust': ('statslaus',),
'statsløs': ('statsløs',),
'statsløse': ('statsløs',),
'statsløsere': ('statsløs',),
'statsløsest': ('statsløs',),
'statsløseste': ('statsløs',),
'statsløst': ('statsløs',),
'statuerende': ('statuere',),
'statuert': ('statuere',),
'statuerte': ('statuere',),
'staupet': ('staupet',),
'staupete': ('staupet',),
'staupetere': ('staupet',),
'staupetest': ('staupet',),
'staupeteste': ('staupet',),
'staupete': ('staupete',),
'staura': ('staure',),
'staurede': ('staure',),
'staurende': ('staure',),
'stauret': ('staure',),
'staurete': ('staure',),
'stauret': ('stauret',),
'staurete': ('staurete',),
'staurfull': ('staurfull',),
'staurfulle': ('staurfull',),
'staurfullere': ('staurfull',),
'staurfullest': ('staurfull',),
'staurfulleste': ('staurfull',),
'staurfullt': ('staurfull',),
'staut': ('staut',),
'staute': ('staut',),
'stautere': ('staut',),
'stautest': ('staut',),
'stauteste': ('staut',),
'stava': ('stave',),
'stavede': ('stave',),
'stavende': ('stave',),
'stavet': ('stave',),
'stavete': ('stave',),
'stavelsesdannende': ('stavelsesdannende',),
'stavingsdannende': ('stavingsdannende',),
'stavra': ('stavre',),
'stavrede': ('stavre',),
'stavrende': ('stavre',),
'stavret': ('stavre',),
'stavrete': ('stavre',),
'stavstill': ('stavstill',),
'stavstille': ('stavstill',),
'stavstillere': ('stavstill',),
'stavstillest': ('stavstill',),
'stavstilleste': ('stavstill',),
'stavstilt': ('stavstill',),
'stavstille': ('stavstille',),
'stedd': ('ste',),
'stedde': ('ste',),
'steende': ('ste',),
'steady': ('steady',),
'stedbunden': ('stedbunden',),
'stedbundet': ('stedbunden',),
'stedbundne': ('stedbunden',),
'stedbundnere': ('stedbunden',),
'stedbundnest': ('stedbunden',),
'stedbundneste': ('stedbunden',),
'stedbundet': ('stedbundet',),
'stedbundne': ('stedbundet',),
'stedbundnere': ('stedbundet',),
'stedbundnest': ('stedbundet',),
'stedbundneste': ('stedbundet',),
'stedende': ('stede',),
'stedt': ('stede',),
'stedte': ('stede',),
'stedd': ('stede',),
'stedde': ('stede',),
'stedende': ('stede',),
'stedegen': ('stedegen',),
'stedegent': ('stedegen',),
'stedegne': ('stedegen',),
'stedegnere': ('stedegen',),
'stedegnest': ('stedegen',),
'stedegneste': ('stedegen',),
'stedfesta': ('stedfeste',),
'stedfestede': ('stedfeste',),
'stedfestende': ('stedfeste',),
'stedfestet': ('stedfeste',),
'stedfestete': ('stedfeste',),
'stedig': ('stedig',),
'stedige': ('stedig',),
'stedigere': ('stedig',),
'stedigst': ('stedig',),
'stedigste': ('stedig',),
'stedlig': ('stedlig',),
'stedlige': ('stedlig',),
'stedligere': ('stedlig',),
'stedligst': ('stedlig',),
'stedligste': ('stedlig',),
'stega': ('stege',),
'stegede': ('stege',),
'stegende': ('stege',),
'steget': ('stege',),
'stegete': ('stege',),
'steikende': ('steike',),
'steikt': ('steike',),
'steikte': ('steike',),
'steil': ('steil',),
'steile': ('steil',),
'steilere': ('steil',),
'steilest': ('steil',),
'steileste': ('steil',),
'steilt': ('steil',),
'steila': ('steile',),
'steilede': ('steile',),
'steilende': ('steile',),
'steilet': ('steile',),
'steilete': ('steile',),
'steilt': ('steile',),
'steilte': ('steile',),
'stein': ('stein',),
'steine': ('stein',),
'steinere': ('stein',),
'steinest': ('stein',),
'steineste': ('stein',),
'steindaud': ('steindaud',),
'steindaude': ('steindaud',),
'steindaudere': ('steindaud',),
'steindaudest': ('steindaud',),
'steindaudeste': ('steindaud',),
'steindaudt': ('steindaud',),
'steindød': ('steindød',),
'steindøde': ('steindød',),
'steindødere': ('steindød',),
'steindødest': ('steindød',),
'steindødeste': ('steindød',),
'steindødt': ('steindød',),
'steina': ('steine',),
'steinede': ('steine',),
'steinende': ('steine',),
'steinet': ('steine',),
'steinete': ('steine',),
'steinet': ('steinet',),
'steinete': ('steinet',),
'steinetere': ('steinet',),
'steinetest': ('steinet',),
'steineteste': ('steinet',),
'steinete': ('steinete',),
'steingal': ('steingal',),
'steingale': ('steingal',),
'steingalere': ('steingal',),
'steingalest': ('steingal',),
'steingaleste': ('steingal',),
'steingalt': ('steingal',),
'steineldre': ('steingammal',),
'steineldst': ('steingammal',),
'steineldste': ('steingammal',),
'steingamle': ('steingammal',),
'steingammal': ('steingammal',),
'steingammalt': ('steingammal',),
'steineldre': ('steingammel',),
'steineldst': ('steingammel',),
'steineldste': ('steingammel',),
'steingamle': ('steingammel',),
'steingammel': ('steingammel',),
'steingammelt': ('steingammel',),
'steinhard': ('steinhard',),
'steinharde': ('steinhard',),
'steinhardere': ('steinhard',),
'steinhardest': ('steinhard',),
'steinhardeste': ('steinhard',),
'steinhardt': ('steinhard',),
'steinrik': ('steinrik',),
'steinrike': ('steinrik',),
'steinrikere': ('steinrik',),
'steinrikest': ('steinrik',),
'steinrikeste': ('steinrik',),
'steinrikt': ('steinrik',),
'steinsatt': ('steinsette',),
'steinsatte': ('steinsette',),
'steinsettende': ('steinsette',),
'stekende': ('steke',),
'stekt': ('steke',),
'stekte': ('steke',),
'stekka': ('stekke',),
'stekkede': ('stekke',),
'stekkende': ('stekke',),
'stekket': ('stekke',),
'stekkete': ('stekke',),
'stekt': ('stekke',),
'stekte': ('stekke',),
'stelende': ('stele',),
'stålen': ('stele',),
'stålet': ('stele',),
'stålne': ('stele',),
'stelende': ('stele',),
'stålen': ('stele',),
'stålet': ('stele',),
'stålne': ('stele',),
'stellar': ('stellar',),
'stellare': ('stellar',),
'stellarere': ('stellar',),
'stellarest': ('stellar',),
'stellareste': ('stellar',),
'stellart': ('stellar',),
'stellarisk': ('stellarisk',),
'stellariske': ('stellarisk',),
'stellariskere': ('stellarisk',),
'stellariskest': ('stellarisk',),
'stellariskeste': ('stellarisk',),
'stellende': ('stelle',),
'stelt': ('stelle',),
'stelte': ('stelle',),
'stemmende': ('stemme',),
'stemt': ('stemme',),
'stemte': ('stemme',),
'stemma': ('stemme',),
'stemmede': ('stemme',),
'stemmende': ('stemme',),
'stemmet': ('stemme',),
'stemmete': ('stemme',),
'stemt': ('stemme',),
'stemte': ('stemme',),
'stemmeberettiga': ('stemmeberettiga',),
'stemmeberettigede': ('stemmeberettiget',),
'stemmeberettiget': ('stemmeberettiget',),
'stemmeberettigete': ('stemmeberettiget',),
'stemmeberettigetere': ('stemmeberettiget',),
'stemmeberettigetest': ('stemmeberettiget',),
'stemmeberettigeteste': ('stemmeberettiget',),
'stilløs': ('stilløs',),
'stilløse': ('stilløs',),
'stilløsere': ('stilløs',),
'stilløsest': ('stilløs',),
'stilløseste': ('stilløs',),
'stilløst': ('stilløs',),
'stilna': ('stilne',),
'stilnede': ('stilne',),
'stilnende': ('stilne',),
'stilnet': ('stilne',),
'stilnete': ('stilne',),
'stilrein': ('stilrein',),
'stilreine': ('stilrein',),
'stilreinere': ('stilrein',),
'stilreinest': ('stilrein',),
'stilreineste': ('stilrein',),
'stilreint': ('stilrein',),
'stilren': ('stilren',),
'stilrene': ('stilren',),
'stilrenere': ('stilren',),
'stilrenest': ('stilren',),
'stilreneste': ('stilren',),
'stilrent': ('stilren',),
'stilsikker': ('stilsikker',),
'stilsikkert': ('stilsikker',),
'stilsikre': ('stilsikker',),
'stilsikrere': ('stilsikker',),
'stilsikrest': ('stilsikker',),
'stilsikreste': ('stilsikker',),
'stiltra': ('stiltre',),
'stiltrede': ('stiltre',),
'stiltrende': ('stiltre',),
'stiltret': ('stiltre',),
'stiltrete': ('stiltre',),
'stimla': ('stimle',),
'stimlede': ('stimle',),
'stimlende': ('stimle',),
'stimlet': ('stimle',),
'stimlete': ('stimle',),
'stimrensa': ('stimrense',),
'stimrensede': ('stimrense',),
'stimrensende': ('stimrense',),
'stimrenset': ('stimrense',),
'stimrensete': ('stimrense',),
'stimulerende': ('stimulere',),
'stimulert': ('stimulere',),
'stimulerte': ('stimulere',),
'stinga': ('stinge',),
'stingede': ('stinge',),
'stingende': ('stinge',),
'stinget': ('stinge',),
'stingete': ('stinge',),
'stinka': ('stinke',),
'stinkede': ('stinke',),
'stinkende': ('stinke',),
'stinket': ('stinke',),
'stinkete': ('stinke',),
'stinn': ('stinn',),
'stinne': ('stinn',),
'stinnere': ('stinn',),
'stinnest': ('stinn',),
'stinneste': ('stinn',),
'stint': ('stinn',),
'stipla': ('stiple',),
'stiplede': ('stiple',),
'stiplende': ('stiple',),
'stiplet': ('stiple',),
'stiplete': ('stiple',),
'stipulerende': ('stipulere',),
'stipulert': ('stipulere',),
'stipulerte': ('stipulere',),
'stirra': ('stirre',),
'stirrede': ('stirre',),
'stirrende': ('stirre',),
'stirret': ('stirre',),
'stirrete': ('stirre',),
'stiv': ('stiv',),
'stive': ('stiv',),
'stivere': ('stiv',),
'stivest': ('stiv',),
'stiveste': ('stiv',),
'stivt': ('stiv',),
'stivbeint': ('stivbeint',),
'stivbeinte': ('stivbeint',),
'stivbeintere': ('stivbeint',),
'stivbeintest': ('stivbeint',),
'stivbeinteste': ('stivbeint',),
'stivbent': ('stivbent',),
'stivbente': ('stivbent',),
'stivbentere': ('stivbent',),
'stivbentest': ('stivbent',),
'stivbenteste': ('stivbent',),
'stiva': ('stive',),
'stivede': ('stive',),
'stivende': ('stive',),
'stivet': ('stive',),
'stivete': ('stive',),
'stivfrosne': ('stivfrossen',),
'stivfrosnere': ('stivfrossen',),
'stivfrosnest': ('stivfrossen',),
'stivfrosneste': ('stivfrossen',),
'stivfrossen': ('stivfrossen',),
'stivfrosset': ('stivfrossen',),
'stivfrosne': ('stivfrosset',),
'stivfrosnere': ('stivfrosset',),
'stivfrosnest': ('stivfrosset',),
'stivfrosneste': ('stivfrosset',),
'stivfrosset': ('stivfrosset',),
'stivfrosne': ('stivfryse',),
'stivfrossen': ('stivfryse',),
'stivfrosset': ('stivfryse',),
'stivfryse': ('stivfryse',),
'stivfrysende': ('stivfryse',),
'stivnakka': ('stivnakka',),
'stivnakkede': ('stivnakket',),
'stivnakket': ('stivnakket',),
'stivnakkete': ('stivnakket',),
'stivnakketere': ('stivnakket',),
'stivnakketest': ('stivnakket',),
'stivnakketeste': ('stivnakket',),
'stivna': ('stivne',),
'stivnede': ('stivne',),
'stivnende': ('stivne',),
'stivnet': ('stivne',),
'stivnete': ('stivne',),
'stivpiska': ('stivpiske',),
'stivpiskede': ('stivpiske',),
'stivpiskende': ('stivpiske',),
'stivpisket': ('stivpiske',),
'stivpiskete': ('stivpiske',),
'stivsinna': ('stivsinna',),
'stivsinnede': ('stivsinnet',),
'stivsinnet': ('stivsinnet',),
'stivsinnete': ('stivsinnet',),
'stivsinnetere': ('stivsinnet',),
'stivsinnetest': ('stivsinnet',),
'stivsinneteste': ('stivsinnet',),
'stivøyd': ('stivøyd',),
'stivøyde': ('stivøyd',),
'stivøydere': ('stivøyd',),
'stivøydest': ('stivøyd',),
'stivøydeste': ('stivøyd',),
'stjelende': ('stjele',),
'stjålen': ('stjele',),
'stjålet': ('stjele',),
'stjålne': ('stjele',),
'stjerneklar': ('stjerneklar',),
'stjerneklare': ('stjerneklar',),
'stjerneklarere': ('stjerneklar',),
'stjerneklarest': ('stjerneklar',),
'stjerneklareste': ('stjerneklar',),
'stjerneklart': ('stjerneklar',),
'stjålen': ('stjålen',),
'stjålent': ('stjålen',),
'stjålne': ('stjålen',),
'stjålnere': ('stjålen',),
'stjålnest': ('stjålen',),
'stjålneste': ('stjålen',),
'stockholmsk': ('stockholmsk',),
'stockholmske': ('stockholmsk',),
'stockholmskere': ('stockholmsk',),
'stockholmskest': ('stockholmsk',),
'stockholmskeste': ('stockholmsk',),
'stoffa': ('stoffe',),
'stoffede': ('stoffe',),
'stoffende': ('stoffe',),
'stoffet': ('stoffe',),
'stoffete': ('stoffe',),
'stofflig': ('stofflig',),
'stofflige': ('stofflig',),
'stoffligere': ('stofflig',),
'stoffligst': ('stofflig',),
'stoffligste': ('stofflig',),
'stoisk': ('stoisk',),
'stoiske': ('stoisk',),
'stoiskere': ('stoisk',),
'stoiskest': ('stoisk',),
'stoiskeste': ('stoisk',),
'stokastisk': ('stokastisk',),
'stokastiske': ('stokastisk',),
'stokastiskere': ('stokastisk',),
'stokastiskest': ('stokastisk',),
'stokastiskeste': ('stokastisk',),
'stokka': ('stokke',),
'stokkede': ('stokke',),
'stokkende': ('stokke',),
'stokket': ('stokke',),
'stokkete': ('stokke',),
'stolende': ('stole',),
'stolt': ('stole',),
'stolte': ('stole',),
'stolpa': ('stolpe',),
'stolpede': ('stolpe',),
'stolpende': ('stolpe',),
'stolpet': ('stolpe',),
'stolpete': ('stolpe',),
'stolpra': ('stolpre',),
'stolprede': ('stolpre',),
'stolprende': ('stolpre',),
'stolpret': ('stolpre',),
'stolprete': ('stolpre',),
'stolt': ('stolt',),
'stolte': ('stolt',),
'stoltere': ('stolt',),
'stoltest': ('stolt',),
'stolteste': ('stolt',),
'stoltserende': ('stoltsere',),
'stoltsert': ('stoltsere',),
'stoltserte': ('stoltsere',),
'stomla': ('stomle',),
'stomlede': ('stomle',),
'stomlende': ('stomle',),
'stomlet': ('stomle',),
'stomlete': ('stomle',),
'stoppa': ('stoppe',),
'stoppede': ('stoppe',),
'stoppende': ('stoppe',),
'stoppet': ('stoppe',),
'stoppete': ('stoppe',),
'stoppa': ('stoppe',),
'stoppede': ('stoppe',),
'stoppende': ('stoppe',),
'stoppet': ('stoppe',),
'stoppete': ('stoppe',),
'stor': ('stor',),
'store': ('stor',),
'stort': ('stor',),
'større': ('stor',),
'størst': ('stor',),
'største': ('stor',),
'storaktig': ('storaktig',),
'storaktige': ('storaktig',),
'storaktigere': ('storaktig',),
'storaktigst': ('storaktig',),
'storaktigste': ('storaktig',),
'storarta': ('storarta',),
'storartede': ('storartet',),
'storartet': ('storartet',),
'storartete': ('storartet',),
'storartetere': ('storartet',),
'storartetest': ('storartet',),
'storarteteste': ('storartet',),
'storfelt': ('storfelt',),
'storfelte': ('storfelt',),
'storfeltere': ('storfelt',),
'storfeltest': ('storfelt',),
'storfelteste': ('storfelt',),
'storrussisk': ('storrussisk',),
'storrussiske': ('storrussisk',),
'storrussiskere': ('storrussisk',),
'storrussiskest': ('storrussisk',),
'storrussiskeste': ('storrussisk',),
'storsinna': ('storsinna',),
'storsinnede': ('storsinnet',),
'storsinnet': ('storsinnet',),
'storsinnete': ('storsinnet',),
'storsinnetere': ('storsinnet',),
'storsinnetest': ('storsinnet',),
'storsinneteste': ('storsinnet',),
'storskreken': ('storskrike',),
'storskreket': ('storskrike',),
'storskrekne': ('storskrike',),
'storskrikende': ('storskrike',),
'storslagen': ('storslagen',),
'storslagent': ('storslagen',),
'storslagne': ('storslagen',),
'storslagnere': ('storslagen',),
'storslagnest': ('storslagen',),
'storslagneste': ('storslagen',),
'storslått': ('storslått',),
'storslåtte': ('storslått',),
'storslåttere': ('storslått',),
'storslåttest': ('storslått',),
'storslåtteste': ('storslått',),
'storsnuta': ('storsnuta',),
'storsnutede': ('storsnutet',),
'storsnutet': ('storsnutet',),
'storsnutete': ('storsnutet',),
'storsnutetere': ('storsnutet',),
'storsnutetest': ('storsnutet',),
'storsnuteteste': ('storsnutet',),
'storstilt': ('storstilt',),
'storstilte': ('storstilt',),
'storstiltere': ('storstilt',),
'storstiltest': ('storstilt',),
'storstilteste': ('storstilt',),
'stortalende': ('stortalende',),
'storveges': ('storveges',),
'storveies': ('storveies',),
'storvokst': ('storvokst',),
'storvokste': ('storvokst',),
'storvokstere': ('storvokst',),
'storvokstest': ('storvokst',),
'storvoksteste': ('storvokst',),
'storøyd': ('storøyd',),
'storøyde': ('storøyd',),
'storøydere': ('storøyd',),
'storøydest': ('storøyd',),
'storøydeste': ('storøyd',),
'stotra': ('stotre',),
'stotrede': ('stotre',),
'stotrende': ('stotre',),
'stotret': ('stotre',),
'stotrete': ('stotre',),
'strabasiøs': ('strabasiøs',),
'strabasiøse': ('strabasiøs',),
'strabasiøsere': ('strabasiøs',),
'strabasiøsest': ('strabasiøs',),
'strabasiøseste': ('strabasiøs',),
'strabasiøst': ('strabasiøs',),
'straff-fri': ('straff-fri',),
'straff-frie': ('straff-fri',),
'straff-friere': ('straff-fri',),
'straff-friest': ('straff-fri',),
'straff-frieste': ('straff-fri',),
'straff-fritt': ('straff-fri',),
'straffbar': ('straffbar',),
'straffbare': ('straffbar',),
'straffbarere': ('straffbar',),
'straffbarest': ('straffbar',),
'straffbareste': ('straffbar',),
'straffbart': ('straffbar',),
'straffa': ('straffe',),
'straffede': ('straffe',),
'straffende': ('straffe',),
'straffet': ('straffe',),
'straffete': ('straffe',),
'straffedømmende': ('straffedømme',),
'straffedømt': ('straffedømme',),
'straffedømte': ('straffedømme',),
'strafferettslig': ('strafferettslig',),
'strafferettslige': ('strafferettslig',),
'strafferettsligere': ('strafferettslig',),
'strafferettsligst': ('strafferettslig',),
'strafferettsligste': ('strafferettslig',),
'straffri': ('straffri',),
'straffrie': ('straffri',),
'straffriere': ('straffri',),
'straffriest': ('straffri',),
'straffrieste': ('straffri',),
'straffritt': ('straffri',),
'straffskyldig': ('straffskyldig',),
'straffskyldige': ('straffskyldig',),
'straffskyldigere': ('straffskyldig',),
'straffskyldigst': ('straffskyldig',),
'straffskyldigste': ('straffskyldig',),
'strak': ('strak',),
'strake': ('strak',),
'strakere': ('strak',),
'strakest': ('strak',),
'strakeste': ('strak',),
'strakt': ('strak',),
'stram': ('stram',),
'stramme': ('stram',),
'strammere': ('stram',),
'strammest': ('stram',),
'strammeste': ('stram',),
'stramt': ('stram',),
'stramma': ('stramme',),
'strammede': ('stramme',),
'strammende': ('stramme',),
'strammet': ('stramme',),
'strammete': ('stramme',),
'stramtsittende': ('stramtsittende',),
'stranda': ('strande',),
'strandede': ('strande',),
'strandende': ('strande',),
'strandet': ('strande',),
'strandete': ('strande',),
'strangulerende': ('strangulere',),
'strangulert': ('strangulere',),
'strangulerte': ('strangulere',),
'stranta': ('strante',),
'strantede': ('strante',),
'strantende': ('strante',),
'strantet': ('strante',),
'strantete': ('strante',),
'stranten': ('stranten',),
'strantent': ('stranten',),
'strantne': ('stranten',),
'strantnere': ('stranten',),
'strantnest': ('stranten',),
'strantneste': ('stranten',),
'strantet': ('strantet',),
'strantete': ('strantet',),
'strantetere': ('strantet',),
'strantetest': ('strantet',),
'stranteteste': ('strantet',),
'strantete': ('strantete',),
'strategisk': ('strategisk',),
'strategiske': ('strategisk',),
'strategiskere': ('strategisk',),
'strategiskest': ('strategisk',),
'strategiskeste': ('strategisk',),
'stratifiserende': ('stratifisere',),
'stratifisert': ('stratifisere',),
'stratifiserte': ('stratifisere',),
'stratosfærisk': ('stratosfærisk',),
'stratosfæriske': ('stratosfærisk',),
'stratosfæriskere': ('stratosfærisk',),
'stratosfæriskest': ('stratosfærisk',),
'stratosfæriskeste': ('stratosfærisk',),
'streba': ('strebe',),
'strebede': ('strebe',),
'strebende': ('strebe',),
'strebet': ('strebe',),
'strebete': ('strebe',),
'streifa': ('streife',),
'streifede': ('streife',),
'streifende': ('streife',),
'streifet': ('streife',),
'streifete': ('streife',),
'streika': ('streike',),
'streikede': ('streike',),
'streikende': ('streike',),
'streiket': ('streike',),
'streikete': ('streike',),
'streit': ('streit',),
'streite': ('streit',),
'streitere': ('streit',),
'streitest': ('streit',),
'streiteste': ('streit',),
'streita': ('streite',),
'streitede': ('streite',),
'streitende': ('streite',),
'streitet': ('streite',),
'streitete': ('streite',),
'streka': ('streke',),
'strekede': ('streke',),
'strekende': ('streke',),
'streket': ('streke',),
'strekete': ('streke',),
'strenda': ('strende',),
'strendede': ('strende',),
'strendende': ('strende',),
'strendet': ('strende',),
'strendete': ('strende',),
'strenda': ('strende',),
'strendede': ('strende',),
'strendende': ('strende',),
'strendet': ('strende',),
'strendete': ('strende',),
'strena': ('strene',),
'strenede': ('strene',),
'strenende': ('strene',),
'strenet': ('strene',),
'strenete': ('strene',),
'strent': ('strene',),
'strente': ('strene',),
'streng': ('streng',),
'strenge': ('streng',),
'strengere': ('streng',),
'strengest': ('streng',),
'strengeste': ('streng',),
'strengt': ('streng',),
'strenga': ('strenge',),
'strengede': ('strenge',),
'strengende': ('strenge',),
'strenget': ('strenge',),
'strengete': ('strenge',),
'strengla': ('strengle',),
'strenglede': ('strengle',),
'strenglende': ('strengle',),
'strenglet': ('strengle',),
'strenglete': ('strengle',),
'stressa': ('stresse',),
'stressede': ('stresse',),
'stressende': ('stresse',),
'stresset': ('stresse',),
'stressete': ('stresse',),
'streva': ('streve',),
'strevd': ('streve',),
'strevde': ('streve',),
'strevede': ('streve',),
'strevende': ('streve',),
'strevet': ('streve',),
'strevete': ('streve',),
'strevsom': ('strevsom',),
'strevsomme': ('strevsom',),
'strevsommere': ('strevsom',),
'strevsomst': ('strevsom',),
'strevsomste': ('strevsom',),
'strevsomt': ('strevsom',),
'stridd': ('stri',),
'stridde': ('stri',),
'striende': ('stri',),
'stri': ('stri',),
'strie': ('stri',),
'striere': ('stri',),
'striest': ('stri',),
'strieste': ('stri',),
'stritt': ('stri',),
'strid': ('strid',),
'stride': ('strid',),
'stridere': ('strid',),
'stridest': ('strid',),
'strideste': ('strid',),
'stridt': ('strid',),
'stridbar': ('stridbar',),
'stridbare': ('stridbar',),
'stridbarere': ('stridbar',),
'stridbarest': ('stridbar',),
'stridbareste': ('stridbar',),
'stridbart': ('stridbar',),
'stridd': ('stride',),
'stridde': ('stride',),
'stridende': ('stride',),
'stridgråtende': ('stridgråte',),
'stridgrått': ('stridgråte',),
'stridgråtte': ('stridgråte',),
'stridhåra': ('stridhåra',),
'stridhårede': ('stridhåret',),
'stridhåret': ('stridhåret',),
'stridhårete': ('stridhåret',),
'stridhåretere': ('stridhåret',),
'stridhåretest': ('stridhåret',),
'stridhåreteste': ('stridhåret',),
'stridig': ('stridig',),
'stridige': ('stridig',),
'stridigere': ('stridig',),
'stridigst': ('stridig',),
'stridigste': ('stridig',),
'stridlynt': ('stridlynt',),
'stridlynte': ('stridlynt',),
'stridlyntere': ('stridlynt',),
'stridlyntest': ('stridlynt',),
'stridlynteste': ('stridlynt',),
'stridregna': ('stridregne',),
'stridregnede': ('stridregne',),
'stridregnende': ('stridregne',),
'stridregnet': ('stridregne',),
'stridregnete': ('stridregne',),
'stridsdyktig': ('stridsdyktig',),
'stridsdyktige': ('stridsdyktig',),
'stridsdyktigere': ('stridsdyktig',),
'stridsdyktigst': ('stridsdyktig',),
'stridsdyktigste': ('stridsdyktig',),
'stridøyd': ('stridøyd',),
'stridøyde': ('stridøyd',),
'stridøydere': ('stridøyd',),
'stridøydest': ('stridøyd',),
'stridøydeste': ('stridøyd',),
'strigla': ('strigle',),
'striglede': ('strigle',),
'striglende': ('strigle',),
'striglet': ('strigle',),
'striglete': ('strigle',),
'strigråtende': ('strigråte',),
'strigrått': ('strigråte',),
'strigråtte': ('strigråte',),
'strihåra': ('strihåra',),
'strikka': ('strikke',),
'strikkede': ('strikke',),
'strikkende': ('strikke',),
'strikket': ('strikke',),
'strikkete': ('strikke',),
'striks': ('striks',),
'strikse': ('striks',),
'striksere': ('striks',),
'striksest': ('striks',),
'strikseste': ('striks',),
'strikst': ('striks',),
'strikt': ('strikt',),
'strikte': ('strikt',),
'striktere': ('strikt',),
'striktest': ('strikt',),
'strikteste': ('strikt',),
'strikte': ('strikte',),
'strilynt': ('strilynt',),
'strilynte': ('strilynt',),
'strilyntere': ('strilynt',),
'strilyntest': ('strilynt',),
'strilynteste': ('strilynt',),
'strimet': ('strimet',),
'strimete': ('strimet',),
'strimetere': ('strimet',),
'strimetest': ('strimet',),
'strimeteste': ('strimet',),
'strimete': ('strimete',),
'strimla': ('strimle',),
'strimlede': ('strimle',),
'strimlende': ('strimle',),
'strimlet': ('strimle',),
'strimlete': ('strimle',),
'stringent': ('stringent',),
'stringente': ('stringent',),
'stringentere': ('stringent',),
'stringentest': ('stringent',),
'stringenteste': ('stringent',),
'stripa': ('stripe',),
'stripede': ('stripe',),
'stripende': ('stripe',),
'stripet': ('stripe',),
'stripete': ('stripe',),
'stript': ('stripe',),
'stripte': ('stripe',),
'stripet': ('stripet',),
'stripete': ('stripet',),
'stripetere': ('stripet',),
'stripetest': ('stripet',),
'stripeteste': ('stripet',),
'stripete': ('stripete',),
'strippa': ('strippe',),
'strippede': ('strippe',),
'strippende': ('strippe',),
'strippet': ('strippe',),
'strippete': ('strippe',),
'stritta': ('stritte',),
'strittede': ('stritte',),
'strittende': ('stritte',),
'strittet': ('stritte',),
'strittete': ('stritte',),
'striøyd': ('striøyd',),
'striøyde': ('striøyd',),
'striøydere': ('striøyd',),
'striøydest': ('striøyd',),
'striøydeste': ('striøyd',),
'strofisk': ('strofisk',),
'strofiske': ('strofisk',),
'strofiskere': ('strofisk',),
'strofiskest': ('strofisk',),
'strofiskeste': ('strofisk',),
'stroppa': ('stroppe',),
'stroppede': ('stroppe',),
'stroppende': ('stroppe',),
'stroppet': ('stroppe',),
'stroppete': ('stroppe',),
'strukturalistisk': ('strukturalistisk',),
'strukturalistiske': ('strukturalistisk',),
'strukturalistiskere': ('strukturalistisk',),
'strukturalistiskest': ('strukturalistisk',),
'strukturalistiskeste': ('strukturalistisk',),
'strukturell': ('strukturell',),
'strukturelle': ('strukturell',),
'strukturellere': ('strukturell',),
'strukturellest': ('strukturell',),
'strukturelleste': ('strukturell',),
'strukturelt': ('strukturell',),
'strukturerende': ('strukturere',),
'strukturert': ('strukturere',),
'strukturerte': ('strukturere',),
'strunk': ('strunk',),
'strunke': ('strunk',),
'strunkere': ('strunk',),
'strunkest': ('strunk',),
'strunkeste': ('strunk',),
'strunkt': ('strunk',),
'strupende': ('strupe',),
'strupt': ('strupe',),
'strupte': ('strupe',),
'strutta': ('strutte',),
'struttede': ('strutte',),
'struttende': ('strutte',),
'struttet': ('strutte',),
'struttete': ('strutte',),
'strykende': ('stryke',),
'strøken': ('stryke',),
'strøket': ('stryke',),
'strøkne': ('stryke',),
'strykefri': ('strykefri',),
'strykefrie': ('strykefri',),
'strykefriere': ('strykefri',),
'strykefriest': ('strykefri',),
'strykefrieste': ('strykefri',),
'strykefritt': ('strykefri',),
'strypende': ('strype',),
'strypt': ('strype',),
'strypte': ('strype',),
'strålende': ('stråle',),
'strålt': ('stråle',),
'strålte': ('stråle',),
'strødd': ('strø',),
'strødde': ('strø',),
'strøende': ('strø',),
'strøken': ('strøken',),
'strøkent': ('strøken',),
'strøkne': ('strøken',),
'strøknere': ('strøken',),
'strøknest': ('strøken',),
'strøkneste': ('strøken',),
'strømførende': ('strømførende',),
'strømlinja': ('strømlinja',),
'strømlinjeforma': ('strømlinjeforma',),
'strømlinjeformede': ('strømlinjeformet',),
'strømlinjeformet': ('strømlinjeformet',),
'strømlinjeformete': ('strømlinjeformet',),
'strømlinjeformetere': ('strømlinjeformet',),
'strømlinjeformetest': ('strømlinjeformet',),
'strømlinjeformeteste': ('strømlinjeformet',),
'strømlinjede': ('strømlinjet',),
'strømlinjet': ('strømlinjet',),
'strømlinjete': ('strømlinjet',),
'strømlinjetere': ('strømlinjet',),
'strømlinjetest': ('strømlinjet',),
'strømlinjeteste': ('strømlinjet',),
'strømma': ('strømme',),
'strømmede': ('strømme',),
'strømmende': ('strømme',),
'strømmet': ('strømme',),
'strømmete': ('strømme',),
'strømt': ('strømme',),
'strømte': ('strømme',),
'stubbet': ('stubbet',),
'stubbete': ('stubbet',),
'stubbetere': ('stubbet',),
'stubbetest': ('stubbet',),
'stubbeteste': ('stubbet',),
'stubbete': ('stubbete',),
'stubbrumpa': ('stubbrumpa',),
'stubbrumpede': ('stubbrumpet',),
'stubbrumpet': ('stubbrumpet',),
'stubbrumpete': ('stubbrumpet',),
'stubbrumpetere': ('stubbrumpet',),
'stubbrumpetest': ('stubbrumpet',),
'stubbrumpeteste': ('stubbrumpet',),
'studentikos': ('studentikos',),
'studentikose': ('studentikos',),
'studentikosere': ('studentikos',),
'studentikosest': ('studentikos',),
'studentikoseste': ('studentikos',),
'studentikost': ('studentikos',),
'studerende': ('studere',),
'studert': ('studere',),
'studerte': ('studere',),
'stua': ('stue',),
'stuede': ('stue',),
'stuende': ('stue',),
'stuet': ('stue',),
'stuete': ('stue',),
'stua': ('stue',),
'stuede': ('stue',),
'stuende': ('stue',),
'stuet': ('stue',),
'stuete': ('stue',),
'stua': ('stue',),
'stuede': ('stue',),
'stuende': ('stue',),
'stuet': ('stue',),
'stuete': ('stue',),
'stua': ('stue',),
'stuede': ('stue',),
'stuende': ('stue',),
'stuet': ('stue',),
'stuete': ('stue',),
'stua': ('stue',),
'stuede': ('stue',),
'stuende': ('stue',),
'stuet': ('stue',),
'stuete': ('stue',),
'stuerein': ('stuerein',),
'stuereine': ('stuerein',),
'stuereinere': ('stuerein',),
'stuereinest': ('stuerein',),
'stuereineste': ('stuerein',),
'stuereint': ('stuerein',),
'stueren': ('stueren',),
'stuerene': ('stueren',),
'stuerenere': ('stueren',),
'stuerenest': ('stueren',),
'stuereneste': ('stueren',),
'stuerent': ('stueren',),
'stuka': ('stuke',),
'stukede': ('stuke',),
'stukende': ('stuke',),
'stuket': ('stuke',),
'stukete': ('stuke',),
'stukt': ('stuke',),
'stukte': ('stuke',),
'stulla': ('stulle',),
'stullede': ('stulle',),
'stullende': ('stulle',),
'stullet': ('stulle',),
'stullete': ('stulle',),
'stum': ('stum',),
'stumme': ('stum',),
'stummere': ('stum',),
'stummest': ('stum',),
'stummeste': ('stum',),
'stumt': ('stum',),
'stump': ('stump',),
'stumpe': ('stump',),
'stumpere': ('stump',),
'stumpest': ('stump',),
'stumpeste': ('stump',),
'stumpt': ('stump',),
'stumpa': ('stumpe',),
'stumpede': ('stumpe',),
'stumpende': ('stumpe',),
'stumpet': ('stumpe',),
'stumpete': ('stumpe',),
'stumpet': ('stumpet',),
'stumpete': ('stumpet',),
'stumpetere': ('stumpet',),
'stumpetest': ('stumpet',),
'stumpeteste': ('stumpet',),
'stumpete': ('stumpete',),
'stumpvinkla': ('stumpvinkla',),
'stumpvinklede': ('stumpvinklet',),
'stumpvinklet': ('stumpvinklet',),
'stumpvinklete': ('stumpvinklet',),
'stumpvinkletere': ('stumpvinklet',),
'stumpvinkletest': ('stumpvinklet',),
'stumpvinkleteste': ('stumpvinklet',),
'stunda': ('stunde',),
'stundede': ('stunde',),
'stundende': ('stunde',),
'stundet': ('stunde',),
'stundete': ('stunde',),
'stundesløs': ('stundesløs',),
'stundesløse': ('stundesløs',),
'stundesløsere': ('stundesløs',),
'stundesløsest': ('stundesløs',),
'stundesløseste': ('stundesløs',),
'stundesløst': ('stundesløs',),
'stungen': ('stungen',),
'stungent': ('stungen',),
'stungne': ('stungen',),
'stungnere': ('stungen',),
'stungnest': ('stungen',),
'stungneste': ('stungen',),
'stupbratt': ('stupbratt',),
'stupbratte': ('stupbratt',),
'stupbrattere': ('stupbratt',),
'stupbrattest': ('stupbratt',),
'stupbratteste': ('stupbratt',),
'stupende': ('stupe',),
'stupt': ('stupe',),
'stupte': ('stupe',),
'stupid': ('stupid',),
'stupide': ('stupid',),
'stupidere': ('stupid',),
'stupidest': ('stupid',),
'stupideste': ('stupid',),
'stupmørk': ('stupmørk',),
'stupmørke': ('stupmørk',),
'stupmørkere': ('stupmørk',),
'stupmørkest': ('stupmørk',),
'stupmørkeste': ('stupmørk',),
'stupmørkt': ('stupmørk',),
'stuptrett': ('stuptrett',),
'stuptrette': ('stuptrett',),
'stuptrettere': ('stuptrett',),
'stuptrettest': ('stuptrett',),
'stuptretteste': ('stuptrett',),
'stuptrøtt': ('stuptrøtt',),
'stuptrøtte': ('stuptrøtt',),
'stuptrøttere': ('stuptrøtt',),
'stuptrøttest': ('stuptrøtt',),
'stuptrøtteste': ('stuptrøtt',),
'stur': ('stur',),
'sture': ('stur',),
'sturere': ('stur',),
'sturest': ('stur',),
'stureste': ('stur',),
'sturt': ('stur',),
'stura': ('sture',),
'sturede': ('sture',),
'sturende': ('sture',),
'sturet': ('sture',),
'sturete': ('sture',),
'sturt': ('sture',),
'sturte': ('sture',),
'sturen': ('sturen',),
'sturent': ('sturen',),
'sturne': ('sturen',),
'sturnere': ('sturen',),
'sturnest': ('sturen',),
'sturneste': ('sturen',),
'sturta': ('sturte',),
'sturtede': ('sturte',),
'sturtende': ('sturte',),
'sturtet': ('sturte',),
'sturtete': ('sturte',),
'stuss': ('stuss',),
'stusse': ('stuss',),
'stussere': ('stuss',),
'stussest': ('stuss',),
'stusseste': ('stuss',),
'stust': ('stuss',),
'stussa': ('stusse',),
'stussede': ('stusse',),
'stussende': ('stusse',),
'stusset': ('stusse',),
'stussete': ('stusse',),
'stussa': ('stusse',),
'stussede': ('stusse',),
'stussende': ('stusse',),
'stusset': ('stusse',),
'stussete': ('stusse',),
'stusslig': ('stusslig',),
'stusslige': ('stusslig',),
'stussligere': ('stusslig',),
'stussligst': ('stusslig',),
'stussligste': ('stusslig',),
'stutet': ('stutet',),
'stutete': ('stutet',),
'stutetere': ('stutet',),
'stutetest': ('stutet',),
'stuteteste': ('stutet',),
'stutete': ('stutete',),
'stutna': ('stutne',),
'stutnede': ('stutne',),
'stutnende': ('stutne',),
'stutnet': ('stutne',),
'stutnete': ('stutne',),
'stutt': ('stutt',),
'stutte': ('stutt',),
'stuttere': ('stutt',),
'stuttest': ('stutt',),
'stutteste': ('stutt',),
'stutta': ('stutte',),
'stuttede': ('stutte',),
'stuttende': ('stutte',),
'stuttet': ('stutte',),
'stuttete': ('stutte',),
'stuttvokst': ('stuttvokst',),
'stuttvokste': ('stuttvokst',),
'stuttvokstere': ('stuttvokst',),
'stuttvokstest': ('stuttvokst',),
'stuttvoksteste': ('stuttvokst',),
'stuva': ('stuve',),
'stuvede': ('stuve',),
'stuvende': ('stuve',),
'stuvet': ('stuve',),
'stuvete': ('stuve',),
'stuva': ('stuve',),
'stuvede': ('stuve',),
'stuvende': ('stuve',),
'stuvet': ('stuve',),
'stuvete': ('stuve',),
'stuva': ('stuve',),
'stuvede': ('stuve',),
'stuvende': ('stuve',),
'stuvet': ('stuve',),
'stuvete': ('stuve',),
'stuva': ('stuve',),
'stuvede': ('stuve',),
'stuvende': ('stuve',),
'stuvet': ('stuve',),
'stuvete': ('stuve',),
'stygg': ('stygg',),
'stygge': ('stygg',),
'styggere': ('stygg',),
'styggest': ('stygg',),
'styggeste': ('stygg',),
'stygt': ('stygg',),
'stygg-eldre': ('stygg-gammal',),
'stygg-eldst': ('stygg-gammal',),
'stygg-eldste': ('stygg-gammal',),
'stygg-gamle': ('stygg-gammal',),
'stygg-gammal': ('stygg-gammal',),
'stygg-gammalt': ('stygg-gammal',),
'stygg-eldre': ('stygg-gammel',),
'stygg-eldst': ('stygg-gammel',),
'stygg-eldste': ('stygg-gammel',),
'stygg-gamle': ('stygg-gammel',),
'stygg-gammel': ('stygg-gammel',),
'stygg-gammelt': ('stygg-gammel',),
'stygeldre': ('styggammal',),
'stygeldst': ('styggammal',),
'stygeldste': ('styggammal',),
'styggamle': ('styggammal',),
'styggammal': ('styggammal',),
'styggammalt': ('styggammal',),
'stygeldre': ('styggammel',),
'stygeldst': ('styggammel',),
'stygeldste': ('styggammel',),
'styggamle': ('styggammel',),
'styggammel': ('styggammel',),
'styggammelt': ('styggammel',),
'styggbratt': ('styggbratt',),
'styggbratte': ('styggbratt',),
'styggbrattere': ('styggbratt',),
'styggbrattest': ('styggbratt',),
'styggbratteste': ('styggbratt',),
'styggkald': ('styggkald',),
'styggkalde': ('styggkald',),
'styggkaldere': ('styggkald',),
'styggkaldest': ('styggkald',),
'styggkaldeste': ('styggkald',),
'styggkaldt': ('styggkald',),
'styggvakker': ('styggvakker',),
'styggvakkert': ('styggvakker',),
'styggvakre': ('styggvakker',),
'styggvakrere': ('styggvakker',),
'styggvakrest': ('styggvakker',),
'styggvakreste': ('styggvakker',),
'stykka': ('stykke',),
'stykkede': ('stykke',),
'stykkende': ('stykke',),
'stykket': ('stykke',),
'stykkete': ('stykke',),
'stykt': ('stykke',),
'stykte': ('stykke',),
'stylta': ('stylte',),
'styltede': ('stylte',),
'styltende': ('stylte',),
'styltet': ('stylte',),
'styltete': ('stylte',),
'styltra': ('styltre',),
'styltrede': ('styltre',),
'styltrende': ('styltre',),
'styltret': ('styltre',),
'styltrete': ('styltre',),
'styrende': ('styre',),
'styrt': ('styre',),
'styrte': ('styre',),
'styra': ('styre',),
'styrede': ('styre',),
'styrende': ('styre',),
'styret': ('styre',),
'styrete': ('styre',),
'styrt': ('styre',),
'styrte': ('styre',),
'styren': ('styren',),
'styrent': ('styren',),
'styrne': ('styren',),
'styrnere': ('styren',),
'styrnest': ('styren',),
'styrneste': ('styren',),
'styrka': ('styrke',),
'styrkede': ('styrke',),
'styrkende': ('styrke',),
'styrket': ('styrke',),
'styrkete': ('styrke',),
'styrkt': ('styrke',),
'styrkte': ('styrke',),
'styrlaus': ('styrlaus',),
'styrlause': ('styrlaus',),
'styrlausere': ('styrlaus',),
'styrlausest': ('styrlaus',),
'styrlauseste': ('styrlaus',),
'styrlaust': ('styrlaus',),
'styrløs': ('styrløs',),
'styrløse': ('styrløs',),
'styrløsere': ('styrløs',),
'styrløsest': ('styrløs',),
'styrløseste': ('styrløs',),
'styrløst': ('styrløs',),
'styrtblødd': ('styrtblø',),
'styrtblødde': ('styrtblø',),
'styrtbløende': ('styrtblø',),
'styrta': ('styrte',),
'styrtede': ('styrte',),
'styrtende': ('styrte',),
'styrtet': ('styrte',),
'styrtete': ('styrte',),
'styrtregna': ('styrtregne',),
'styrtregnede': ('styrtregne',),
'styrtregnende': ('styrtregne',),
'styrtregnet': ('styrtregne',),
'styrtregnete': ('styrtregne',),
'styrtregnt': ('styrtregne',),
'styrtregnte': ('styrtregne',),
'styrtrik': ('styrtrik',),
'styrtrike': ('styrtrik',),
'styrtrikere': ('styrtrik',),
'styrtrikest': ('styrtrik',),
'styrtrikeste': ('styrtrik',),
'styrtrikt': ('styrtrik',),
'styven': ('styven',),
'styvent': ('styven',),
'styvne': ('styven',),
'styvnere': ('styven',),
'styvnest': ('styven',),
'styvneste': ('styven',),
'stående': ('stå',),
'stått': ('stå',),
'ståtte': ('stå',),
'ståka': ('ståke',),
'ståkede': ('ståke',),
'ståkende': ('ståke',),
'ståket': ('ståke',),
'ståkete': ('ståke',),
'stålblå': ('stålblå',),
'stålblåe': ('stålblå',),
'stålblåere': ('stålblå',),
'stålblåest': ('stålblå',),
'stålblåeste': ('stålblå',),
'stålblått': ('stålblå',),
'stålgrå': ('stålgrå',),
'stålgråe': ('stålgrå',),
'stålgråere': ('stålgrå',),
'stålgråest': ('stålgrå',),
'stålgråeste': ('stålgrå',),
'stålgrått': ('stålgrå',),
'stålsatt': ('stålsette',),
'stålsatte': ('stålsette',),
'stålsettende': ('stålsette',),
'stærblind': ('stærblind',),
'stærblinde': ('stærblind',),
'stærblindere': ('stærblind',),
'stærblindest': ('stærblind',),
'stærblindeste': ('stærblind',),
'stærblindt': ('stærblind',),
'stødd': ('stø',),
'stødde': ('stø',),
'støende': ('stø',),
'stø': ('stø',),
'støe': ('stø',),
'støere': ('stø',),
'støest': ('stø',),
'støeste': ('stø',),
'støtt': ('stø',),
'stødig': ('stødig',),
'stødige': ('stødig',),
'stødigere': ('stødig',),
'stødigst': ('stødig',),
'stødigste': ('stødig',),
'stødd': ('støe',),
'stødde': ('støe',),
'støedd': ('støe',),
'støedde': ('støe',),
'støedende': ('støe',),
'støende': ('støe',),
'støkken': ('støkken',),
'støkkent': ('støkken',),
'støkne': ('støkken',),
'støknere': ('støkken',),
'støknest': ('støkken',),
'støkneste': ('støkken',),
'støl': ('støl',),
'støle': ('støl',),
'stølere': ('støl',),
'stølest': ('støl',),
'støleste': ('støl',),
'stølt': ('støl',),
'støla': ('støle',),
'stølede': ('støle',),
'stølende': ('støle',),
'stølet': ('støle',),
'stølete': ('støle',),
'stølt': ('støle',),
'stølte': ('støle',),
'stølna': ('stølne',),
'stølnede': ('stølne',),
'stølnende': ('stølne',),
'stølnet': ('stølne',),
'stølnete': ('stølne',),
'stønna': ('stønne',),
'stønnede': ('stønne',),
'stønnende': ('stønne',),
'stønnet': ('stønne',),
'stønnete': ('stønne',),
'stønt': ('stønne',),
'stønte': ('stønne',),
'støpende': ('støpe',),
'støpt': ('støpe',),
'støpte': ('støpe',),
'størkna': ('størkne',),
'størknede': ('størkne',),
'størknende': ('størkne',),
'størknet': ('størkne',),
'størknete': ('størkne',),
'størst': ('størst',),
'største': ('størst',),
'støtende': ('støte',),
'støtt': ('støte',),
'støtte': ('støte',),
'støtta': ('støtte',),
'støttede': ('støtte',),
'støttende': ('støtte',),
'støttet': ('støtte',),
'støttete': ('støtte',),
'støva': ('støve',),
'støvede': ('støve',),
'støvende': ('støve',),
'støvet': ('støve',),
'støvete': ('støve',),
'støvet': ('støvet',),
'støvete': ('støvet',),
'støvetere': ('støvet',),
'støvetest': ('støvet',),
'støveteste': ('støvet',),
'støvete': ('støvete',),
'støvsuga': ('støvsuge',),
'støvsugd': ('støvsuge',),
'støvsugde': ('støvsuge',),
'støvsugede': ('støvsuge',),
'støvsugende': ('støvsuge',),
'støvsuget': ('støvsuge',),
'støvsugete': ('støvsuge',),
'støya': ('støye',),
'støyd': ('støye',),
'støyde': ('støye',),
'støyede': ('støye',),
'støyende': ('støye',),
'støyet': ('støye',),
'støyete': ('støye',),
'støypende': ('støype',),
'støypt': ('støype',),
'støypte': ('støype',),
'støytende': ('støyte',),
'støytt': ('støyte',),
'støytte': ('støyte',),
'subalpin': ('subalpin',),
'subalpine': ('subalpin',),
'subalpinere': ('subalpin',),
'subalpinest': ('subalpin',),
'subalpineste': ('subalpin',),
'subalpint': ('subalpin',),
'subarktisk': ('subarktisk',),
'subarktiske': ('subarktisk',),
'subarktiskere': ('subarktisk',),
'subarktiskest': ('subarktisk',),
'subarktiskeste': ('subarktisk',),
'subba': ('subbe',),
'subbede': ('subbe',),
'subbende': ('subbe',),
'subbet': ('subbe',),
'subbete': ('subbe',),
'subbesid': ('subbesid',),
'subbeside': ('subbesid',),
'subbesidere': ('subbesid',),
'subbesidest': ('subbesid',),
'subbesideste': ('subbesid',),
'subbesidt': ('subbesid',),
'subbet': ('subbet',),
'subbete': ('subbet',),
'subbetere': ('subbet',),
'subbetest': ('subbet',),
'subbeteste': ('subbet',),
'subbete': ('subbete',),
'subjektiv': ('subjektiv',),
'subjektive': ('subjektiv',),
'subjektivere': ('subjektiv',),
'subjektivest': ('subjektiv',),
'subjektiveste': ('subjektiv',),
'subjektivt': ('subjektiv',),
'sublim': ('sublim',),
'sublime': ('sublim',),
'sublimere': ('sublim',),
'sublimest': ('sublim',),
'sublimeste': ('sublim',),
'sublimt': ('sublim',),
'sublimerende': ('sublimere',),
'sublimert': ('sublimere',),
'sublimerte': ('sublimere',),
'submarin': ('submarin',),
'submarine': ('submarin',),
'submarinere': ('submarin',),
'submarinest': ('submarin',),
'submarineste': ('submarin',),
'submarint': ('submarin',),
'submersibel': ('submersibel',),
'submersibelt': ('submersibel',),
'submersible': ('submersibel',),
'submersiblere': ('submersibel',),
'submersiblest': ('submersibel',),
'submersibleste': ('submersibel',),
'subordinerende': ('subordinere',),
'subordinert': ('subordinere',),
'subordinerte': ('subordinere',),
'subsidierende': ('subsidiere',),
'subsidiert': ('subsidiere',),
'subsidierte': ('subsidiere',),
'subsidiær': ('subsidiær',),
'subsidiære': ('subsidiær',),
'subsidiærere': ('subsidiær',),
'subsidiærest': ('subsidiær',),
'subsidiæreste': ('subsidiær',),
'subsidiært': ('subsidiær',),
'subsistenslaus': ('subsistenslaus',),
'subsistenslause': ('subsistenslaus',),
'subsistenslausere': ('subsistenslaus',),
'subsistenslausest': ('subsistenslaus',),
'subsistenslauseste': ('subsistenslaus',),
'subsistenslaust': ('subsistenslaus',),
'subsistensløs': ('subsistensløs',),
'subsistensløse': ('subsistensløs',),
'subsistensløsere': ('subsistensløs',),
'subsistensløsest': ('subsistensløs',),
'subsistensløseste': ('subsistensløs',),
'subsistensløst': ('subsistensløs',),
'subskriberende': ('subskribere',),
'subskribert': ('subskribere',),
'subskriberte': ('subskribere',),
'substansiell': ('substansiell',),
'substansielle': ('substansiell',),
'substansiellere': ('substansiell',),
'substansiellest': ('substansiell',),
'substansielleste': ('substansiell',),
'substansielt': ('substansiell',),
'substantiverende': ('substantivere',),
'substantivert': ('substantivere',),
'substantiverte': ('substantivere',),
'substantivisk': ('substantivisk',),
'substantiviske': ('substantivisk',),
'substantiviskere': ('substantivisk',),
'substantiviskest': ('substantivisk',),
'substantiviskeste': ('substantivisk',),
'substituerende': ('substituere',),
'substituert': ('substituere',),
'substituerte': ('substituere',),
'subsumerende': ('subsumere',),
'subsumert': ('subsumere',),
'subsumerte': ('subsumere',),
'subtil': ('subtil',),
'subtile': ('subtil',),
'subtilere': ('subtil',),
'subtilest': ('subtil',),
'subtileste': ('subtil',),
'subtilt': ('subtil',),
'subtraherende': ('subtrahere',),
'subtrahert': ('subtrahere',),
'subtraherte': ('subtrahere',),
'subtropisk': ('subtropisk',),
'subtropiske': ('subtropisk',),
'subtropiskere': ('subtropisk',),
'subtropiskest': ('subtropisk',),
'subtropiskeste': ('subtropisk',),
'subvenerende': ('subvenere',),
'subvenert': ('subvenere',),
'subvenerte': ('subvenere',),
'sudansk': ('sudansk',),
'sudanske': ('sudansk',),
'sudanskere': ('sudansk',),
'sudanskest': ('sudansk',),
'sudanskeste': ('sudansk',),
'suffigerende': ('suffigere',),
'suffigert': ('suffigere',),
'suffigerte': ('suffigere',),
'suffisant': ('suffisant',),
'suffisante': ('suffisant',),
'suffisantere': ('suffisant',),
'suffisantest': ('suffisant',),
'suffisanteste': ('suffisant',),
'sufflerende': ('sufflere',),
'sufflert': ('sufflere',),
'sufflerte': ('sufflere',),
'suga': ('suge',),
'sugd': ('suge',),
'sugde': ('suge',),
'sugede': ('suge',),
'sugende': ('suge',),
'suget': ('suge',),
'sugete': ('suge',),
'sugen': ('sugen',),
'sugent': ('sugen',),
'sugne': ('sugen',),
'sugnere': ('sugen',),
'sugnest': ('sugen',),
'sugneste': ('sugen',),
'suggererende': ('suggerere',),
'suggerert': ('suggerere',),
'suggererte': ('suggerere',),
'suggestibel': ('suggestibel',),
'suggestibelt': ('suggestibel',),
'suggestible': ('suggestibel',),
'suggestiblere': ('suggestibel',),
'suggestiblest': ('suggestibel',),
'suggestibleste': ('suggestibel',),
'suggestiv': ('suggestiv',),
'suggestive': ('suggestiv',),
'suggestivere': ('suggestiv',),
'suggestivest': ('suggestiv',),
'suggestiveste': ('suggestiv',),
'suggestivt': ('suggestiv',),
'sukka': ('sukke',),
'sukkede': ('sukke',),
'sukkende': ('sukke',),
'sukket': ('sukke',),
'sukkete': ('sukke',),
'sukkersøt': ('sukkersøt',),
'sukkersøte': ('sukkersøt',),
'sukkersøtere': ('sukkersøt',),
'sukkersøtest': ('sukkersøt',),
'sukkersøteste': ('sukkersøt',),
'sukkersøtt': ('sukkersøt',),
'sukla': ('sukle',),
'suklede': ('sukle',),
'suklende': ('sukle',),
'suklet': ('sukle',),
'suklete': ('sukle',),
'sukra': ('sukre',),
'sukrede': ('sukre',),
'sukrende': ('sukre',),
'sukret': ('sukre',),
'sukrete': ('sukre',),
'suksederende': ('suksedere',),
'suksedert': ('suksedere',),
'suksederte': ('suksedere',),
'suksessfull': ('suksessfull',),
'suksessfulle': ('suksessfull',),
'suksessfullere': ('suksessfull',),
'suksessfullest': ('suksessfull',),
'suksessfulleste': ('suksessfull',),
'suksessfullt': ('suksessfull',),
'suksessiv': ('suksessiv',),
'suksessive': ('suksessiv',),
'suksessivere': ('suksessiv',),
'suksessivest': ('suksessiv',),
'suksessiveste': ('suksessiv',),
'suksessivt': ('suksessiv',),
'suksessrik': ('suksessrik',),
'suksessrike': ('suksessrik',),
'suksessrikere': ('suksessrik',),
'suksessrikest': ('suksessrik',),
'suksessrikeste': ('suksessrik',),
'suksessrikt': ('suksessrik',),
'sulka': ('sulke',),
'sulkede': ('sulke',),
'sulkende': ('sulke',),
'sulket': ('sulke',),
'sulkete': ('sulke',),
'sulla': ('sulle',),
'sullede': ('sulle',),
'sullende': ('sulle',),
'sullet': ('sulle',),
'sullete': ('sulle',),
'sulla': ('sulle',),
'sullede': ('sulle',),
'sullende': ('sulle',),
'sullet': ('sulle',),
'sullete': ('sulle',),
'sulta': ('sulte',),
'sultede': ('sulte',),
'sultende': ('sulte',),
'sultet': ('sulte',),
'sultete': ('sulte',),
'sulten': ('sulten',),
'sultent': ('sulten',),
'sultne': ('sulten',),
'sultnere': ('sulten',),
'sultnest': ('sulten',),
'sultneste': ('sulten',),
'sultramma': ('sultramma',),
'sultrammede': ('sultrammet',),
'sultrammet': ('sultrammet',),
'sultrammete': ('sultrammet',),
'sultrammetere': ('sultrammet',),
'sultrammetest': ('sultrammet',),
'sultrammeteste': ('sultrammet',),
'sumerisk': ('sumerisk',),
'sumeriske': ('sumerisk',),
'sumeriskere': ('sumerisk',),
'sumeriskest': ('sumerisk',),
'sumeriskeste': ('sumerisk',),
'summarisk': ('summarisk',),
'summariske': ('summarisk',),
'summariskere': ('summarisk',),
'summariskest': ('summarisk',),
'summariskeste': ('summarisk',),
'summa': ('summe',),
'summede': ('summe',),
'summende': ('summe',),
'summet': ('summe',),
'summete': ('summe',),
'summa': ('summe',),
'summede': ('summe',),
'summende': ('summe',),
'summet': ('summe',),
'summete': ('summe',),
'summerende': ('summere',),
'summert': ('summere',),
'summerte': ('summere',),
'sumpet': ('sumpet',),
'sumpete': ('sumpet',),
'sumpetere': ('sumpet',),
'sumpetest': ('sumpet',),
'sumpeteste': ('sumpet',),
'sumpete': ('sumpete',),
'sumpig': ('sumpig',),
'sumpige': ('sumpig',),
'sumpigere': ('sumpig',),
'sumpigst': ('sumpig',),
'sumpigste': ('sumpig',),
'sund': ('sund',),
'sunde': ('sund',),
'sundere': ('sund',),
'sundest': ('sund',),
'sundeste': ('sund',),
'sundt': ('sund',),
'sundanesisk': ('sundanesisk',),
'sundanesiske': ('sundanesisk',),
'sundanesiskere': ('sundanesisk',),
'sundanesiskest': ('sundanesisk',),
'sundanesiskeste': ('sundanesisk',),
'sundlemma': ('sundlemma',),
'sundlemmede': ('sundlemmet',),
'sundlemmet': ('sundlemmet',),
'sundlemmete': ('sundlemmet',),
'sundlemmetere': ('sundlemmet',),
'sundlemmetest': ('sundlemmet',),
'sundlemmeteste': ('sundlemmet',),
'sunn': ('sunn',),
'sunne': ('sunn',),
'sunnere': ('sunn',),
'sunnest': ('sunn',),
'sunneste': ('sunn',),
'sunt': ('sunn',),
'sunnfjordsk': ('sunnfjordsk',),
'sunnfjordske': ('sunnfjordsk',),
'sunnfjordskere': ('sunnfjordsk',),
'sunnfjordskest': ('sunnfjordsk',),
'sunnfjordskeste': ('sunnfjordsk',),
'sunnittisk': ('sunnittisk',),
'sunnittiske': ('sunnittisk',),
'sunnittiskere': ('sunnittisk',),
'sunnittiskest': ('sunnittisk',),
'sunnittiskeste': ('sunnittisk',),
'sunnmørsk': ('sunnmørsk',),
'sunnmørske': ('sunnmørsk',),
'sunnmørskere': ('sunnmørsk',),
'sunnmørskest': ('sunnmørsk',),
'sunnmørskeste': ('sunnmørsk',),
'supende': ('supe',),
'supt': ('supe',),
'supte': ('supe',),
'super': ('super',),
'supert': ('super',),
'supre': ('super',),
'suprere': ('super',),
'suprest': ('super',),
'supreste': ('super',),
'superb': ('superb',),
'superbe': ('superb',),
'superbere': ('superb',),
'superbest': ('superb',),
'superbeste': ('superb',),
'superbt': ('superb',),
'superende': ('supere',),
'supert': ('supere',),
'superte': ('supere',),
'superlativisk': ('superlativisk',),
'superlativiske': ('superlativisk',),
'superlativiskere': ('superlativisk',),
'superlativiskest': ('superlativisk',),
'superlativiskeste': ('superlativisk',),
'supersonisk': ('supersonisk',),
'supersoniske': ('supersonisk',),
'supersoniskere': ('supersonisk',),
'supersoniskest': ('supersonisk',),
'supersoniskeste': ('supersonisk',),
'supinerende': ('supinere',),
'supinert': ('supinere',),
'supinerte': ('supinere',),
'supplementær': ('supplementær',),
'supplementære': ('supplementær',),
'supplementærere': ('supplementær',),
'supplementærest': ('supplementær',),
'supplementæreste': ('supplementær',),
'supplementært': ('supplementær',),
'supplerende': ('supplere',),
'supplert': ('supplere',),
'supplerte': ('supplere',),
'supplikkerende': ('supplikkere',),
'supplikkert': ('supplikkere',),
'supplikkerte': ('supplikkere',),
'supponerende': ('supponere',),
'supponert': ('supponere',),
'supponerte': ('supponere',),
'supprimerende': ('supprimere',),
'supprimert': ('supprimere',),
'supprimerte': ('supprimere',),
'supradental': ('supradental',),
'supradentale': ('supradental',),
'supradentalere': ('supradental',),
'supradentalest': ('supradental',),
'supradentaleste': ('supradental',),
'supradentalt': ('supradental',),
'sur': ('sur',),
'sure': ('sur',),
'surere': ('sur',),
'surest': ('sur',),
'sureste': ('sur',),
'surt': ('sur',),
'surfa': ('surfe',),
'surfede': ('surfe',),
'surfende': ('surfe',),
'surfet': ('surfe',),
'surfete': ('surfe',),
'surinamsk': ('surinamsk',),
'surinamske': ('surinamsk',),
'surinamskere': ('surinamsk',),
'surinamskest': ('surinamsk',),
'surinamskeste': ('surinamsk',),
'surkla': ('surkle',),
'surklede': ('surkle',),
'surklende': ('surkle',),
'surklet': ('surkle',),
'surklete': ('surkle',),
'surklet': ('surklet',),
'surklete': ('surklet',),
'surkletere': ('surklet',),
'surkletest': ('surklet',),
'surkleteste': ('surklet',),
'surklete': ('surklete',),
'surla': ('surle',),
'surlede': ('surle',),
'surlende': ('surle',),
'surlet': ('surle',),
'surlete': ('surle',),
'surmaga': ('surmaga',),
'surmagede': ('surmaget',),
'surmaget': ('surmaget',),
'surmagete': ('surmaget',),
'surmagetere': ('surmaget',),
'surmagetest': ('surmaget',),
'surmageteste': ('surmaget',),
'surmava': ('surmava',),
'surmavede': ('surmavet',),
'surmavet': ('surmavet',),
'surmavete': ('surmavet',),
'surmavetere': ('surmavet',),
'surmavetest': ('surmavet',),
'surmaveteste': ('surmavet',),
'surmulende': ('surmule',),
'surmult': ('surmule',),
'surmulte': ('surmule',),
'surna': ('surne',),
'surnede': ('surne',),
'surnende': ('surne',),
'surnet': ('surne',),
'surnete': ('surne',),
'surra': ('surre',),
'surrede': ('surre',),
'surrende': ('surre',),
'surret': ('surre',),
'surrete': ('surre',),
'surra': ('surre',),
'surrede': ('surre',),
'surrende': ('surre',),
'surret': ('surre',),
'surrete': ('surre',),
'surrealistisk': ('surrealistisk',),
'surrealistiske': ('surrealistisk',),
'surrealistiskere': ('surrealistisk',),
'surrealistiskest': ('surrealistisk',),
'surrealistiskeste': ('surrealistisk',),
'surret': ('surret',),
'surrete': ('surret',),
'surretere': ('surret',),
'surretest': ('surret',),
'surreteste': ('surret',),
'surrete': ('surrete',),
'sursøt': ('sursøt',),
'sursøte': ('sursøt',),
'sursøtere': ('sursøt',),
'sursøtest': ('sursøt',),
'sursøteste': ('sursøt',),
'sursøtt': ('sursøt',),
'surøyd': ('surøyd',),
'surøyde': ('surøyd',),
'surøydere': ('surøyd',),
'surøydest': ('surøyd',),
'surøydeste': ('surøyd',),
'susende': ('suse',),
'sust': ('suse',),
'suste': ('suse',),
'suset': ('suset',),
'susete': ('suset',),
'susetere': ('suset',),
'susetest': ('suset',),
'suseteste': ('suset',),
'susete': ('susete',),
'susla': ('susle',),
'suslede': ('susle',),
'suslende': ('susle',),
'suslet': ('susle',),
'suslete': ('susle',),
'suspekt': ('suspekt',),
'suspekte': ('suspekt',),
'suspektere': ('suspekt',),
'suspektest': ('suspekt',),
'suspekteste': ('suspekt',),
'suspenderende': ('suspendere',),
'suspendert': ('suspendere',),
'suspenderte': ('suspendere',),
'suspensiv': ('suspensiv',),
'suspensive': ('suspensiv',),
'suspensivere': ('suspensiv',),
'suspensivest': ('suspensiv',),
'suspensiveste': ('suspensiv',),
'suspensivt': ('suspensiv',),
'sussa': ('susse',),
'sussede': ('susse',),
'sussende': ('susse',),
'susset': ('susse',),
'sussete': ('susse',),
'sutenerende': ('sutenere',),
'sutenert': ('sutenere',),
'sutenerte': ('sutenere',),
'sutra': ('sutre',),
'sutrede': ('sutre',),
'sutrende': ('sutre',),
'sutret': ('sutre',),
'sutrete': ('sutre',),
'sutret': ('sutret',),
'sutrete': ('sutret',),
'sutretere': ('sutret',),
'sutretest': ('sutret',),
'sutreteste': ('sutret',),
'sutrete': ('sutrete',),
'sutta': ('sutte',),
'suttede': ('sutte',),
'suttende': ('sutte',),
'suttet': ('sutte',),
'suttete': ('sutte',),
'suveren': ('suveren',),
'suverene': ('suveren',),
'suverenere': ('suveren',),
'suverenest': ('suveren',),
'suvereneste': ('suveren',),
'suverent': ('suveren',),
'svabra': ('svabre',),
'svabrede': ('svabre',),
'svabrende': ('svabre',),
'svabret': ('svabre',),
'svabrete': ('svabre',),
'svaga': ('svage',),
'svagede': ('svage',),
'svagende': ('svage',),
'svaget': ('svage',),
'svagete': ('svage',),
'svai': ('svai',),
'svaie': ('svai',),
'svaiere': ('svai',),
'svaiest': ('svai',),
'svaieste': ('svai',),
'svait': ('svai',),
'svaitt': ('svai',),
'svaia': ('svaie',),
'svaiede': ('svaie',),
'svaiende': ('svaie',),
'svaiet': ('svaie',),
'svaiete': ('svaie',),
'svairygga': ('svairygga',),
'svairyggede': ('svairygget',),
'svairygget': ('svairygget',),
'svairyggete': ('svairygget',),
'svairyggetere': ('svairygget',),
'svairyggetest': ('svairygget',),
'svairyggeteste': ('svairygget',),
'svak': ('svak',),
'svake': ('svak',),
'svakere': ('svak',),
'svakest': ('svak',),
'svakeste': ('svak',),
'svakt': ('svak',),
'svakelig': ('svakelig',),
'svakelige': ('svakelig',),
'svakeligere': ('svakelig',),
'svakeligst': ('svakelig',),
'svakeligste': ('svakelig',),
'svakhelsa': ('svakhelsa',),
'svakhelsede': ('svakhelset',),
'svakhelset': ('svakhelset',),
'svakhelsete': ('svakhelset',),
'svakhelsetere': ('svakhelset',),
'svakhelsetest': ('svakhelset',),
'svakhelseteste': ('svakhelset',),
'svaksynt': ('svaksynt',),
'svaksynte': ('svaksynt',),
'svaksyntere': ('svaksynt',),
'svaksyntest': ('svaksynt',),
'svaksynteste': ('svaksynt',),
'sval': ('sval',),
'svale': ('sval',),
'svalere': ('sval',),
'svalest': ('sval',),
'svaleste': ('sval',),
'svalt': ('sval',),
'svala': ('svale',),
'svalede': ('svale',),
'svalende': ('svale',),
'svalet': ('svale',),
'svalete': ('svale',),
'svalt': ('svale',),
'svalte': ('svale',),
'svalna': ('svalne',),
'svalnede': ('svalne',),
'svalnende': ('svalne',),
'svalnet': ('svalne',),
'svalnete': ('svalne',),
'svampa': ('svampe',),
'svampede': ('svampe',),
'svampende': ('svampe',),
'svampet': ('svampe',),
'svampete': ('svampe',),
'svampet': ('svampet',),
'svampete': ('svampet',),
'svampetere': ('svampet',),
'svampetest': ('svampet',),
'svampeteste': ('svampet',),
'svampete': ('svampete',),
'svanger': ('svanger',),
'svangert': ('svanger',),
'svangre': ('svanger',),
'svangrere': ('svanger',),
'svangrest': ('svanger',),
'svangreste': ('svanger',),
'svansa': ('svanse',),
'svansede': ('svanse',),
'svansende': ('svanse',),
'svanset': ('svanse',),
'svansete': ('svanse',),
'svara': ('svare',),
'svarende': ('svare',),
'svart': ('svare',),
'svarte': ('svare',),
'svare': ('svare',),
'svart': ('svart',),
'svarte': ('svart',),
'svartere': ('svart',),
'svartest': ('svart',),
'svarteste': ('svart',),
'svartelista': ('svarteliste',),
'svartelistede': ('svarteliste',),
'svartelistende': ('svarteliste',),
'svartelistet': ('svarteliste',),
'svartelistete': ('svarteliste',),
'svarthvit': ('svarthvit',),
'svarthvite': ('svarthvit',),
'svarthvitere': ('svarthvit',),
'svarthvitest': ('svarthvit',),
'svarthviteste': ('svarthvit',),
'svarthvitt': ('svarthvit',),
'svarthåra': ('svarthåra',),
'svarthårede': ('svarthåret',),
'svarthåret': ('svarthåret',),
'svarthårete': ('svarthåret',),
'svarthåretere': ('svarthåret',),
'svarthåretest': ('svarthåret',),
'svarthåreteste': ('svarthåret',),
'svartkvit': ('svartkvit',),
'svartkvite': ('svartkvit',),
'svartkvitere': ('svartkvit',),
'svartkvitest': ('svartkvit',),
'svartkviteste': ('svartkvit',),
'svartkvitt': ('svartkvit',),
'svartmalende': ('svartmale',),
'svartmalt': ('svartmale',),
'svartmalte': ('svartmale',),
'svartna': ('svartne',),
'svartnede': ('svartne',),
'svartnende': ('svartne',),
'svartnet': ('svartne',),
'svartnete': ('svartne',),
'svartsjuk': ('svartsjuk',),
'svartsjuke': ('svartsjuk',),
'svartsjukere': ('svartsjuk',),
'svartsjukest': ('svartsjuk',),
'svartsjukeste': ('svartsjuk',),
'svartsjukt': ('svartsjuk',),
'svartsmuska': ('svartsmuska',),
'svartsmuskede': ('svartsmusket',),
'svartsmusket': ('svartsmusket',),
'svartsmuskete': ('svartsmusket',),
'svartsmusketere': ('svartsmusket',),
'svartsmusketest': ('svartsmusket',),
'svartsmusketeste': ('svartsmusket',),
'svartstill': ('svartstill',),
'svartstille': ('svartstill',),
'svartstillere': ('svartstill',),
'svartstillest': ('svartstill',),
'svartstilleste': ('svartstill',),
'svartstilt': ('svartstill',),
'svartstille': ('svartstille',),
'svartsynt': ('svartsynt',),
'svartsynte': ('svartsynt',),
'svartsyntere': ('svartsynt',),
'svartsyntest': ('svartsynt',),
'svartsynteste': ('svartsynt',),
'svarva': ('svarve',),
'svarvede': ('svarve',),
'svarvende': ('svarve',),
'svarvet': ('svarve',),
'svarvete': ('svarve',),
'sveipa': ('sveipe',),
'sveipede': ('sveipe',),
'sveipende': ('sveipe',),
'sveipet': ('sveipe',),
'sveipete': ('sveipe',),
'sveipt': ('sveipe',),
'sveipte': ('sveipe',),
'sveisen': ('sveisen',),
'sveisent': ('sveisen',),
'sveisne': ('sveisen',),
'sveisnere': ('sveisen',),
'sveisnest': ('sveisen',),
'sveisneste': ('sveisen',),
'sveitsisk': ('sveitsisk',),
'sveitsiske': ('sveitsisk',),
'sveitsiskere': ('sveitsisk',),
'sveitsiskest': ('sveitsisk',),
'sveitsiskeste': ('sveitsisk',),
'sveiva': ('sveive',),
'sveivd': ('sveive',),
'sveivde': ('sveive',),
'sveivede': ('sveive',),
'sveivende': ('sveive',),
'sveivet': ('sveive',),
'sveivete': ('sveive',),
'svekka': ('svekke',),
'svekkede': ('svekke',),
'svekkende': ('svekke',),
'svekket': ('svekke',),
'svekkete': ('svekke',),
'svekt': ('svekke',),
'svekte': ('svekke',),
'svelga': ('svelge',),
'svelgede': ('svelge',),
'svelgende': ('svelge',),
'svelget': ('svelge',),
'svelgete': ('svelge',),
'svelgd': ('svelgje',),
'svelgde': ('svelgje',),
'svelgende': ('svelgje',),
'svelgja': ('svelgje',),
'svelgjede': ('svelgje',),
'svelgjende': ('svelgje',),
'svelgjet': ('svelgje',),
'svelgjete': ('svelgje',),
'svella': ('svelle',),
'svellede': ('svelle',),
'svellende': ('svelle',),
'svellet': ('svelle',),
'svellete': ('svelle',),
'svelt': ('svelle',),
'svelte': ('svelle',),
'svelta': ('svelte',),
'sveltede': ('svelte',),
'sveltende': ('svelte',),
'sveltet': ('svelte',),
'sveltete': ('svelte',),
'svelten': ('svelte',),
'sveltende': ('svelte',),
'sveltet': ('svelte',),
'sveltne': ('svelte',),
'svensk': ('svensk',),
'svenske': ('svensk',),
'svenskere': ('svensk',),
'svenskest': ('svensk',),
'svenskeste': ('svensk',),
'sverga': ('sverge',),
'svergede': ('sverge',),
'svergende': ('sverge',),
'sverget': ('sverge',),
'svergete': ('sverge',),
'svoren': ('sverge',),
'svoret': ('sverge',),
'svorne': ('sverge',),
'sverja': ('sverje',),
'sverjede': ('sverje',),
'sverjende': ('sverje',),
'sverjet': ('sverje',),
'sverjete': ('sverje',),
'svoren': ('sverje',),
'svoret': ('sverje',),
'svorne': ('sverje',),
'sverma': ('sverme',),
'svermede': ('sverme',),
'svermende': ('sverme',),
'svermet': ('sverme',),
'svermete': ('sverme',),
'svermerisk': ('svermerisk',),
'svermeriske': ('svermerisk',),
'svermeriskere': ('svermerisk',),
'svermeriskest': ('svermerisk',),
'svermeriskeste': ('svermerisk',),
'sverta': ('sverte',),
'svertede': ('sverte',),
'svertende': ('sverte',),
'svertet': ('sverte',),
'svertete': ('sverte',),
'svett': ('svett',),
'svette': ('svett',),
'svettere': ('svett',),
'svettest': ('svett',),
'svetteste': ('svett',),
'svetta': ('svette',),
'svettede': ('svette',),
'svettende': ('svette',),
'svettet': ('svette',),
'svettete': ('svette',),
'sveva': ('sveve',),
'svevd': ('sveve',),
'svevde': ('sveve',),
'svevede': ('sveve',),
'svevende': ('sveve',),
'svevet': ('sveve',),
'svevete': ('sveve',),
'svevende': ('svevende',),
'sveken': ('svike',),
'sveket': ('svike',),
'svekne': ('svike',),
'svikende': ('svike',),
'svikefull': ('svikefull',),
'svikefulle': ('svikefull',),
'svikefullere': ('svikefull',),
'svikefullest': ('svikefull',),
'svikefulleste': ('svikefull',),
'svikefullt': ('svikefull',),
'svikfull': ('svikfull',),
'svikfulle': ('svikfull',),
'svikfullere': ('svikfull',),
'svikfullest': ('svikfull',),
'svikfulleste': ('svikfull',),
'svikfullt': ('svikfull',),
'svikta': ('svikte',),
'sviktede': ('svikte',),
'sviktende': ('svikte',),
'sviktet': ('svikte',),
'sviktete': ('svikte',),
'svima': ('svime',),
'svimede': ('svime',),
'svimende': ('svime',),
'svimet': ('svime',),
'svimete': ('svime',),
'svimt': ('svime',),
'svimte': ('svime',),
'svimerka': ('svimerke',),
'svimerkede': ('svimerke',),
'svimerkende': ('svimerke',),
'svimerket': ('svimerke',),
'svimerkete': ('svimerke',),
'svimeslående': ('svimeslå',),
'svimeslått': ('svimeslå',),
'svimeslåtte': ('svimeslå',),
'svimet': ('svimet',),
'svimete': ('svimet',),
'svimetere': ('svimet',),
'svimetest': ('svimet',),
'svimeteste': ('svimet',),
'svimete': ('svimete',),
'svimla': ('svimle',),
'svimlede': ('svimle',),
'svimlende': ('svimle',),
'svimlet': ('svimle',),
'svimlete': ('svimle',),
'svimlende': ('svimlende',),
'svimle': ('svimmel',),
'svimlere': ('svimmel',),
'svimlest': ('svimmel',),
'svimleste': ('svimmel',),
'svimmel': ('svimmel',),
'svimmelt': ('svimmel',),
'svimra': ('svimre',),
'svimrede': ('svimre',),
'svimrende': ('svimre',),
'svimret': ('svimre',),
'svimrete': ('svimre',),
'svimren': ('svimren',),
'svimrene': ('svimren',),
'svimrenere': ('svimren',),
'svimrenest': ('svimren',),
'svimreneste': ('svimren',),
'svimrent': ('svimren',),
'svimrne': ('svimren',),
'svimrnere': ('svimren',),
'svimrnest': ('svimren',),
'svimrneste': ('svimren',),
'svindla': ('svindle',),
'svindlede': ('svindle',),
'svindlende': ('svindle',),
'svindlet': ('svindle',),
'svindlete': ('svindle',),
'svina': ('svine',),
'svinede': ('svine',),
'svinende': ('svine',),
'svinet': ('svine',),
'svinete': ('svine',),
'svint': ('svine',),
'svinte': ('svine',),
'svinebindende': ('svinebinde',),
'svinebunden': ('svinebinde',),
'svinebundet': ('svinebinde',),
'svinebundne': ('svinebinde',),
'svinedyr': ('svinedyr',),
'svinedyre': ('svinedyr',),
'svinedyrere': ('svinedyr',),
'svinedyrest': ('svinedyr',),
'svinedyreste': ('svinedyr',),
'svinedyrt': ('svinedyr',),
'svineheldig': ('svineheldig',),
'svineheldige': ('svineheldig',),
'svineheldigere': ('svineheldig',),
'svineheldigst': ('svineheldig',),
'svineheldigste': ('svineheldig',),
'svinekald': ('svinekald',),
'svinekalde': ('svinekald',),
'svinekaldere': ('svinekald',),
'svinekaldest': ('svinekald',),
'svinekaldeste': ('svinekald',),
'svinekaldt': ('svinekald',),
'svingbar': ('svingbar',),
'svingbare': ('svingbar',),
'svingbarere': ('svingbar',),
'svingbarest': ('svingbar',),
'svingbareste': ('svingbar',),
'svingbart': ('svingbar',),
'svinga': ('svinge',),
'svingede': ('svinge',),
'svingende': ('svinge',),
'svinget': ('svinge',),
'svingete': ('svinge',),
'svingt': ('svinge',),
'svingte': ('svinge',),
'svingen': ('svinge',),
'svingende': ('svinge',),
'svinget': ('svinge',),
'svingne': ('svinge',),
'svingt': ('svinge',),
'svingte': ('svinge',),
'svungen': ('svinge',),
'svunget': ('svinge',),
'svungne': ('svinge',),
'svinget': ('svinget',),
'svingete': ('svinget',),
'svingetere': ('svinget',),
'svingetest': ('svinget',),
'svingeteste': ('svinget',),
'svingete': ('svingete',),
'svinnende': ('svinne',),
'svunne': ('svinne',),
'svunnen': ('svinne',),
'svunnet': ('svinne',),
'svinsa': ('svinse',),
'svinsede': ('svinse',),
'svinsende': ('svinse',),
'svinset': ('svinse',),
'svinsete': ('svinse',),
'svinset': ('svinset',),
'svinsete': ('svinset',),
'svinsetere': ('svinset',),
'svinsetest': ('svinset',),
'svinseteste': ('svinset',),
'svinsete': ('svinsete',),
'svinsk': ('svinsk',),
'svinske': ('svinsk',),
'svinskere': ('svinsk',),
'svinskest': ('svinsk',),
'svinskeste': ('svinsk',),
'svint': ('svint',),
'svintere': ('svint',),
'svintest': ('svint',),
'svinta': ('svinte',),
'svintede': ('svinte',),
'svintende': ('svinte',),
'svintet': ('svinte',),
'svintete': ('svinte',),
'svippa': ('svippe',),
'svippede': ('svippe',),
'svippende': ('svippe',),
'svippet': ('svippe',),
'svippete': ('svippe',),
'svira': ('svire',),
'svirede': ('svire',),
'svirende': ('svire',),
'sviret': ('svire',),
'svirete': ('svire',),
'svirt': ('svire',),
'svirte': ('svire',),
'svirra': ('svirre',),
'svirrede': ('svirre',),
'svirrende': ('svirre',),
'svirret': ('svirre',),
'svirrete': ('svirre',),
'sviva': ('svive',),
'svivd': ('svive',),
'svivde': ('svive',),
'svivede': ('svive',),
'svivende': ('svive',),
'svivet': ('svive',),
'svivete': ('svive',),
'svivørdende': ('svivørde',),
'svivørdt': ('svivørde',),
'svivørdte': ('svivørde',),
'svivørdslig': ('svivørdslig',),
'svivørdslige': ('svivørdslig',),
'svivørdsligere': ('svivørdslig',),
'svivørdsligst': ('svivørdslig',),
'svivørdsligste': ('svivørdslig',),
'svivørende': ('svivøre',),
'svivørt': ('svivøre',),
'svivørte': ('svivøre',),
'svivørslig': ('svivørslig',),
'svivørslige': ('svivørslig',),
'svivørsligere': ('svivørslig',),
'svivørsligst': ('svivørslig',),
'svivørsligste': ('svivørslig',),
'svolka': ('svolke',),
'svolkede': ('svolke',),
'svolkende': ('svolke',),
'svolket': ('svolke',),
'svolkete': ('svolke',),
'svoren': ('svoren',),
'svorent': ('svoren',),
'svorne': ('svoren',),
'svornere': ('svoren',),
'svornest': ('svoren',),
'svorneste': ('svoren',),
'svovla': ('svovle',),
'svovlede': ('svovle',),
'svovlende': ('svovle',),
'svovlet': ('svovle',),
'svovlete': ('svovle',),
'svullen': ('svullen',),
'svullent': ('svullen',),
'svulne': ('svullen',),
'svulnere': ('svullen',),
'svulnest': ('svullen',),
'svulneste': ('svullen',),
'svullet': ('svullet',),
'svullete': ('svullet',),
'svulletere': ('svullet',),
'svulletest': ('svullet',),
'svulleteste': ('svullet',),
'svullete': ('svullete',),
'svulma': ('svulme',),
'svulmede': ('svulme',),
'svulmende': ('svulme',),
'svulmet': ('svulme',),
'svulmete': ('svulme',),
'svulna': ('svulne',),
'svulnede': ('svulne',),
'svulnende': ('svulne',),
'svulnet': ('svulne',),
'svulnete': ('svulne',),
'svulstig': ('svulstig',),
'svulstige': ('svulstig',),
'svulstigere': ('svulstig',),
'svulstigst': ('svulstig',),
'svulstigste': ('svulstig',),
'svuppa': ('svuppe',),
'svuppede': ('svuppe',),
'svuppende': ('svuppe',),
'svuppet': ('svuppe',),
'svuppete': ('svuppe',),
'svær': ('svær',),
'svære': ('svær',),
'sværere': ('svær',),
'sværest': ('svær',),
'sværeste': ('svær',),
'svært': ('svær',),
'svævd': ('svæve',),
'svævde': ('svæve',),
'svævende': ('svæve',),
'svømmende': ('svømme',),
'svømt': ('svømme',),
'svømte': ('svømme',),
'svømmedyktig': ('svømmedyktig',),
'svømmedyktige': ('svømmedyktig',),
'svømmedyktigere': ('svømmedyktig',),
'svømmedyktigst': ('svømmedyktig',),
'svømmedyktigste': ('svømmedyktig',),
'svøpende': ('svøpe',),
'svøpt': ('svøpe',),
'svøpte': ('svøpe',),
'swazilandsk': ('swazilandsk',),
'swazilandske': ('swazilandsk',),
'swazilandskere': ('swazilandsk',),
'swazilandskest': ('swazilandsk',),
'swazilandskeste': ('swazilandsk',),
'sydd': ('sy',),
'sydde': ('sy',),
'syende': ('sy',),
'sybarittisk': ('sybarittisk',),
'sybarittiske': ('sybarittisk',),
'sybarittiskere': ('sybarittisk',),
'sybarittiskest': ('sybarittisk',),
'sybarittiskeste': ('sybarittisk',),
'syda': ('syde',),
'sydede': ('syde',),
'sydende': ('syde',),
'sydet': ('syde',),
'sydete': ('syde',),
'sydeuropeisk': ('sydeuropeisk',),
'sydeuropeiske': ('sydeuropeisk',),
'sydeuropeiskere': ('sydeuropeisk',),
'sydeuropeiskest': ('sydeuropeisk',),
'sydeuropeiskeste': ('sydeuropeisk',),
'sydgående': ('sydgående',),
'sydlandsk': ('sydlandsk',),
'sydlandske': ('sydlandsk',),
'sydlandskere': ('sydlandsk',),
'sydlandskest': ('sydlandsk',),
'sydlandskeste': ('sydlandsk',),
'sydlig': ('sydlig',),
'sydlige': ('sydlig',),
'sydligere': ('sydlig',),
'sydligst': ('sydlig',),
'sydligste': ('sydlig',),
'sydsamisk': ('sydsamisk',),
'sydsamiske': ('sydsamisk',),
'sydsamiskere': ('sydsamisk',),
'sydsamiskest': ('sydsamisk',),
'sydsamiskeste': ('sydsamisk',),
'sydvendt': ('sydvendt',),
'sydvendte': ('sydvendt',),
'sydvendtere': ('sydvendt',),
'sydvendtest': ('sydvendt',),
'sydvendteste': ('sydvendt',),
'sydvestlig': ('sydvestlig',),
'sydvestlige': ('sydvestlig',),
'sydvestligere': ('sydvestlig',),
'sydvestligst': ('sydvestlig',),
'sydvestligste': ('sydvestlig',),
'sydøstlig': ('sydøstlig',),
'sydøstlige': ('sydøstlig',),
'sydøstligere': ('sydøstlig',),
'sydøstligst': ('sydøstlig',),
'sydøstligste': ('sydøstlig',),
'syfilitisk': ('syfilitisk',),
'syfilitiske': ('syfilitisk',),
'syfilitiskere': ('syfilitisk',),
'syfilitiskest': ('syfilitisk',),
'syfilitiskeste': ('syfilitisk',),
'syk': ('syk',),
'syke': ('syk',),
'sykere': ('syk',),
'sykest': ('syk',),
'sykeste': ('syk',),
'sykt': ('syk',),
'sykelig': ('sykelig',),
'sykelige': ('sykelig',),
'sykeligere': ('sykelig',),
'sykeligst': ('sykelig',),
'sykeligste': ('sykelig',),
'sykemeldende': ('sykemelde',),
'sykemeldt': ('sykemelde',),
'sykemeldte': ('sykemelde',),
'sykemeldt': ('sykemeldt',),
'sykemeldte': ('sykemeldt',),
'sykemeldtere': ('sykemeldt',),
'sykemeldtest': ('sykemeldt',),
'sykemeldteste': ('sykemeldt',),
'sykla': ('sykle',),
'syklede': ('sykle',),
'syklende': ('sykle',),
'syklet': ('sykle',),
'syklete': ('sykle',),
'syklig': ('syklig',),
'syklige': ('syklig',),
'sykligere': ('syklig',),
'sykligst': ('syklig',),
'sykligste': ('syklig',),
'syklisk': ('syklisk',),
'sykliske': ('syklisk',),
'sykliskere': ('syklisk',),
'sykliskest': ('syklisk',),
'sykliskeste': ('syklisk',),
'sykmeldende': ('sykmelde',),
'sykmeldt': ('sykmelde',),
'sykmeldte': ('sykmelde',),
'sykmeldt': ('sykmeldt',),
'sykmeldte': ('sykmeldt',),
'sykmeldtere': ('sykmeldt',),
'sykmeldtest': ('sykmeldt',),
'sykmeldteste': ('sykmeldt',),
'sykna': ('sykne',),
'syknede': ('sykne',),
'syknende': ('sykne',),
'syknet': ('sykne',),
'syknete': ('sykne',),
'sylhvass': ('sylhvass',),
'sylhvasse': ('sylhvass',),
'sylhvassere': ('sylhvass',),
'sylhvassest': ('sylhvass',),
'sylhvasseste': ('sylhvass',),
'sylhvast': ('sylhvass',),
'sylindrisk': ('sylindrisk',),
'sylindriske': ('sylindrisk',),
'sylindriskere': ('sylindrisk',),
'sylindriskest': ('sylindrisk',),
'sylindriskeste': ('sylindrisk',),
'sylkvass': ('sylkvass',),
'sylkvasse': ('sylkvass',),
'sylkvassere': ('sylkvass',),
'sylkvassest': ('sylkvass',),
'sylkvasseste': ('sylkvass',),
'sylkvast': ('sylkvass',),
'syllabisk': ('syllabisk',),
'syllabiske': ('syllabisk',),
'syllabiskere': ('syllabisk',),
'syllabiskest': ('syllabisk',),
'syllabiskeste': ('syllabisk',),
'syllogistisk': ('syllogistisk',),
'syllogistiske': ('syllogistisk',),
'syllogistiskere': ('syllogistisk',),
'syllogistiskest': ('syllogistisk',),
'syllogistiskeste': ('syllogistisk',),
'sylspiss': ('sylspiss',),
'sylspisse': ('sylspiss',),
'sylspissere': ('sylspiss',),
'sylspissest': ('sylspiss',),
'sylspisseste': ('sylspiss',),
'sylspist': ('sylspiss',),
'sylta': ('sylta',),
'sylta': ('sylte',),
'syltede': ('sylte',),
'syltende': ('sylte',),
'syltet': ('sylte',),
'syltete': ('sylte',),
'syltede': ('syltet',),
'syltet': ('syltet',),
'syltete': ('syltet',),
'syltetere': ('syltet',),
'syltetest': ('syltet',),
'sylteteste': ('syltet',),
'syltynn': ('syltynn',),
'syltynne': ('syltynn',),
'syltynnere': ('syltynn',),
'syltynnest': ('syltynn',),
'syltynneste': ('syltynn',),
'syltynt': ('syltynn',),
'symbiotisk': ('symbiotisk',),
'symbiotiske': ('symbiotisk',),
'symbiotiskere': ('symbiotisk',),
'symbiotiskest': ('symbiotisk',),
'symbiotiskeste': ('symbiotisk',),
'symboliserende': ('symbolisere',),
'symbolisert': ('symbolisere',),
'symboliserte': ('symbolisere',),
'symbolistisk': ('symbolistisk',),
'symbolistiske': ('symbolistisk',),
'symbolistiskere': ('symbolistisk',),
'symbolistiskest': ('symbolistisk',),
'symbolistiskeste': ('symbolistisk',),
'symbolsk': ('symbolsk',),
'symbolske': ('symbolsk',),
'symbolskere': ('symbolsk',),
'symbolskest': ('symbolsk',),
'symbolskeste': ('symbolsk',),
'symfonisk': ('symfonisk',),
'symfoniske': ('symfonisk',),
'symfoniskere': ('symfonisk',),
'symfoniskest': ('symfonisk',),
'symfoniskeste': ('symfonisk',),
'symmetrisk': ('symmetrisk',),
'symmetriske': ('symmetrisk',),
'symmetriskere': ('symmetrisk',),
'symmetriskest': ('symmetrisk',),
'symmetriskeste': ('symmetrisk',),
'sympatiserende': ('sympatisere',),
'sympatisert': ('sympatisere',),
'sympatiserte': ('sympatisere',),
'sympatisk': ('sympatisk',),
'sympatiske': ('sympatisk',),
'sympatiskere': ('sympatisk',),
'sympatiskest': ('sympatisk',),
'sympatiskeste': ('sympatisk',),
'sympatistreika': ('sympatistreike',),
'sympatistreikede': ('sympatistreike',),
'sympatistreikende': ('sympatistreike',),
'sympatistreiket': ('sympatistreike',),
'sympatistreikete': ('sympatistreike',),
'symptomatisk': ('symptomatisk',),
'symptomatiske': ('symptomatisk',),
'symptomatiskere': ('symptomatisk',),
'symptomatiskest': ('symptomatisk',),
'symptomatiskeste': ('symptomatisk',),
'synbar': ('synbar',),
'synbare': ('synbar',),
'synbarere': ('synbar',),
'synbarest': ('synbar',),
'synbareste': ('synbar',),
'synbart': ('synbar',),
'synda': ('synde',),
'syndede': ('synde',),
'syndende': ('synde',),
'syndet': ('synde',),
'syndete': ('synde',),
'syndefull': ('syndefull',),
'syndefulle': ('syndefull',),
'syndefullere': ('syndefull',),
'syndefullest': ('syndefull',),
'syndefulleste': ('syndefull',),
'syndefullt': ('syndefull',),
'syndelig': ('syndelig',),
'syndelige': ('syndelig',),
'syndeligere': ('syndelig',),
'syndeligst': ('syndelig',),
'syndeligste': ('syndelig',),
'syndetisk': ('syndetisk',),
'syndetiske': ('syndetisk',),
'syndetiskere': ('syndetisk',),
'syndetiskest': ('syndetisk',),
'syndetiskeste': ('syndetisk',),
'syndig': ('syndig',),
'syndige': ('syndig',),
'syndigere': ('syndig',),
'syndigst': ('syndig',),
'syndigste': ('syndig',),
'syndikalistisk': ('syndikalistisk',),
'syndikalistiske': ('syndikalistisk',),
'syndikalistiskere': ('syndikalistisk',),
'syndikalistiskest': ('syndikalistisk',),
'syndikalistiskeste': ('syndikalistisk',),
'synende': ('syne',),
'synt': ('syne',),
'synte': ('syne',),
'synergisk': ('synergisk',),
'synergiske': ('synergisk',),
'synergiskere': ('synergisk',),
'synergiskest': ('synergisk',),
'synergiskeste': ('synergisk',),
'synergistisk': ('synergistisk',),
'synergistiske': ('synergistisk',),
'synergistiskere': ('synergistisk',),
'synergistiskest': ('synergistisk',),
'synergistiskeste': ('synergistisk',),
'synestetisk': ('synestetisk',),
'synestetiske': ('synestetisk',),
'synestetiskere': ('synestetisk',),
'synestetiskest': ('synestetisk',),
'synestetiskeste': ('synestetisk',),
'synfarende': ('synfare',),
'synfart': ('synfare',),
'synfarte': ('synfare',),
'sungen': ('synge',),
'sunget': ('synge',),
'sungne': ('synge',),
'syngende': ('synge',),
'sunken': ('synke',),
'sunket': ('synke',),
'sunkne': ('synke',),
'synkende': ('synke',),
'synkeferdig': ('synkeferdig',),
'synkeferdige': ('synkeferdig',),
'synkeferdigere': ('synkeferdig',),
'synkeferdigst': ('synkeferdig',),
'synkeferdigste': ('synkeferdig',),
'synkoperende': ('synkopere',),
'synkopert': ('synkopere',),
'synkoperte': ('synkopere',),
'synkretistisk': ('synkretistisk',),
'synkretistiske': ('synkretistisk',),
'synkretistiskere': ('synkretistisk',),
'synkretistiskest': ('synkretistisk',),
'synkretistiskeste': ('synkretistisk',),
'synkron': ('synkron',),
'synkrone': ('synkron',),
'synkronere': ('synkron',),
'synkronest': ('synkron',),
'synkroneste': ('synkron',),
'synkront': ('synkron',),
'synkroniserende': ('synkronisere',),
'synkronisert': ('synkronisere',),
'synkroniserte': ('synkronisere',),
'synkronisk': ('synkronisk',),
'synkroniske': ('synkronisk',),
'synkroniskere': ('synkronisk',),
'synkroniskest': ('synkronisk',),
'synkroniskeste': ('synkronisk',),
'synkronistisk': ('synkronistisk',),
'synkronistiske': ('synkronistisk',),
'synkronistiskere': ('synkronistisk',),
'synkronistiskest': ('synkronistisk',),
'synkronistiskeste': ('synkronistisk',),
'synkverva': ('synkverve',),
'synkvervd': ('synkverve',),
'synkvervde': ('synkverve',),
'synkvervede': ('synkverve',),
'synkvervende': ('synkverve',),
'synkvervet': ('synkverve',),
'synkvervete': ('synkverve',),
'synlig': ('synlig',),
'synlige': ('synlig',),
'synligere': ('synlig',),
'synligst': ('synlig',),
'synligste': ('synlig',),
'synliggjort': ('synliggjøre',),
'synliggjorte': ('synliggjøre',),
'synliggjørende': ('synliggjøre',),
'synodal': ('synodal',),
'synodale': ('synodal',),
'synodalere': ('synodal',),
'synodalest': ('synodal',),
'synodaleste': ('synodal',),
'synodalt': ('synodal',),
'synonym': ('synonym',),
'synonyme': ('synonym',),
'synonymere': ('synonym',),
'synonymest': ('synonym',),
'synonymeste': ('synonym',),
'synonymt': ('synonym',),
'synoptisk': ('synoptisk',),
'synoptiske': ('synoptisk',),
'synoptiskere': ('synoptisk',),
'synoptiskest': ('synoptisk',),
'synoptiskeste': ('synoptisk',),
'synsa': ('synse',),
'synsede': ('synse',),
'synsende': ('synse',),
'synset': ('synse',),
'synsete': ('synse',),
'synsk': ('synsk',),
'synske': ('synsk',),
'synskere': ('synsk',),
'synskest': ('synsk',),
'synskeste': ('synsk',),
'synskt': ('synsk',),
'syntagmatisk': ('syntagmatisk',),
'syntagmatiske': ('syntagmatisk',),
'syntagmatiskere': ('syntagmatisk',),
'syntagmatiskest': ('syntagmatisk',),
'syntagmatiskeste': ('syntagmatisk',),
'syntaktisk': ('syntaktisk',),
'syntaktiske': ('syntaktisk',),
'syntaktiskere': ('syntaktisk',),
'syntaktiskest': ('syntaktisk',),
'syntaktiskeste': ('syntaktisk',),
'syntetiserende': ('syntetisere',),
'syntetisert': ('syntetisere',),
'syntetiserte': ('syntetisere',),
'syntetisk': ('syntetisk',),
'syntetiske': ('syntetisk',),
'syntetiskere': ('syntetisk',),
'syntetiskest': ('syntetisk',),
'syntetiskeste': ('syntetisk',),
'syra': ('syre',),
'syrede': ('syre',),
'syrende': ('syre',),
'syret': ('syre',),
'syrete': ('syre',),
'syrt': ('syre',),
'syrte': ('syre',),
'syrebestandig': ('syrebestandig',),
'syrebestandige': ('syrebestandig',),
'syrebestandigere': ('syrebestandig',),
'syrebestandigst': ('syrebestandig',),
'syrebestandigste': ('syrebestandig',),
'syrefast': ('syrefast',),
'syrefaste': ('syrefast',),
'syrefastere': ('syrefast',),
'syrefastest': ('syrefast',),
'syrefasteste': ('syrefast',),
'syrisk': ('syrisk',),
'syriske': ('syrisk',),
'syriskere': ('syrisk',),
'syriskest': ('syrisk',),
'syriskeste': ('syrisk',),
'syrlig': ('syrlig',),
'syrlige': ('syrlig',),
'syrligere': ('syrlig',),
'syrligst': ('syrlig',),
'syrligste': ('syrlig',),
'syrna': ('syrne',),
'syrnede': ('syrne',),
'syrnende': ('syrne',),
'syrnet': ('syrne',),
'syrnete': ('syrne',),
'sysla': ('sysle',),
'syslede': ('sysle',),
'syslende': ('sysle',),
'syslet': ('sysle',),
'syslete': ('sysle',),
'sysselsatt': ('sysselsatt',),
'sysselsatte': ('sysselsatt',),
'sysselsattere': ('sysselsatt',),
'sysselsattest': ('sysselsatt',),
'sysselsatteste': ('sysselsatt',),
'sysselsatt': ('sysselsette',),
'sysselsatte': ('sysselsette',),
'sysselsettende': ('sysselsette',),
'systematiserende': ('systematisere',),
'systematisert': ('systematisere',),
'systematiserte': ('systematisere',),
'systematisk': ('systematisk',),
'systematiske': ('systematisk',),
'systematiskere': ('systematisk',),
'systematiskest': ('systematisk',),
'systematiskeste': ('systematisk',),
'systemisk': ('systemisk',),
'systemiske': ('systemisk',),
'systemiskere': ('systemisk',),
'systemiskest': ('systemisk',),
'systemiskeste': ('systemisk',),
'syta': ('syte',),
'sytede': ('syte',),
'sytende': ('syte',),
'sytet': ('syte',),
'sytete': ('syte',),
'sytt': ('syte',),
'sytte': ('syte',),
'sytet': ('sytet',),
'sytete': ('sytet',),
'sytetere': ('sytet',),
'sytetest': ('sytet',),
'syteteste': ('sytet',),
'sytete': ('sytete',),
'syttende': ('syttende',),
'syttenårig': ('syttenårig',),
'syttenårige': ('syttenårig',),
'syttenårigere': ('syttenårig',),
'syttenårigst': ('syttenårig',),
'syttenårigste': ('syttenårig',),
'syttenårs': ('syttenårs',),
'syttiårig': ('syttiårig',),
'syttiårige': ('syttiårig',),
'syttiårigere': ('syttiårig',),
'syttiårigst': ('syttiårig',),
'syttiårigste': ('syttiårig',),
'sådd': ('så',),
'sådde': ('så',),
'sående': ('så',),
'såkalt': ('såkalt',),
'såkalte': ('såkalt',),
'såkaltere': ('såkalt',),
'såkaltest': ('såkalt',),
'såkalteste': ('såkalt',),
'sålda': ('sålde',),
'såldede': ('sålde',),
'såldende': ('sålde',),
'såldet': ('sålde',),
'såldete': ('sålde',),
'såla': ('såle',),
'sålede': ('såle',),
'sålende': ('såle',),
'sålet': ('såle',),
'sålete': ('såle',),
'sålt': ('såle',),
'sålte': ('såle',),
'sålydende': ('sålydende',),
'såpa': ('såpe',),
'såpede': ('såpe',),
'såpende': ('såpe',),
'såpet': ('såpe',),
'såpete': ('såpe',),
'såpt': ('såpe',),
'såpte': ('såpe',),
'såpeglatt': ('såpeglatt',),
'såpeglatte': ('såpeglatt',),
'såpeglattere': ('såpeglatt',),
'såpeglattest': ('såpeglatt',),
'såpeglatteste': ('såpeglatt',),
'sår': ('sår',),
'såre': ('sår',),
'sårere': ('sår',),
'sårest': ('sår',),
'såreste': ('sår',),
'sårt': ('sår',),
'sårbar': ('sårbar',),
'sårbare': ('sårbar',),
'sårbarere': ('sårbar',),
'sårbarest': ('sårbar',),
'sårbareste': ('sårbar',),
'sårbart': ('sårbar',),
'sårbeint': ('sårbeint',),
'sårbeinte': ('sårbeint',),
'sårbeintere': ('sårbeint',),
'sårbeintest': ('sårbeint',),
'sårbeinteste': ('sårbeint',),
'sårbent': ('sårbent',),
'sårbente': ('sårbent',),
'sårbentere': ('sårbent',),
'sårbentest': ('sårbent',),
'sårbenteste': ('sårbent',),
'såra': ('såre',),
'sårede': ('såre',),
'sårende': ('såre',),
'såret': ('såre',),
'sårete': ('såre',),
'sårfota': ('sårfota',),
'sårfotede': ('sårfotet',),
'sårfotet': ('sårfotet',),
'sårfotete': ('sårfotet',),
'sårfotetere': ('sårfotet',),
'sårfotetest': ('sårfotet',),
'sårfoteteste': ('sårfotet',),
'sårføtt': ('sårføtt',),
'sårføtte': ('sårføtt',),
'sårføttere': ('sårføtt',),
'sårføttest': ('sårføtt',),
'sårføtteste': ('sårføtt',),
'såta': ('såte',),
'såtede': ('såte',),
'såtende': ('såte',),
'såtet': ('såte',),
'såtete': ('såte',),
'sæl': ('sæl',),
'sæle': ('sæl',),
'sælere': ('sæl',),
'sælest': ('sæl',),
'sæleste': ('sæl',),
'sælt': ('sæl',),
'sælda': ('sælde',),
'sældede': ('sælde',),
'sældende': ('sælde',),
'sældet': ('sælde',),
'sældete': ('sælde',),
'sær': ('sær',),
'sære': ('sær',),
'særere': ('sær',),
'særest': ('sær',),
'særeste': ('sær',),
'sært': ('sær',),
'særbo': ('særbo',),
'særbu': ('særbu',),
'særegen': ('særegen',),
'særegent': ('særegen',),
'særegne': ('særegen',),
'særegnere': ('særegen',),
'særegnest': ('særegen',),
'særegneste': ('særegen',),
'særlig': ('særlig',),
'særlige': ('særlig',),
'særligere': ('særlig',),
'særligst': ('særlig',),
'særligste': ('særlig',),
'særmerka': ('særmerke',),
'særmerkede': ('særmerke',),
'særmerkende': ('særmerke',),
'særmerket': ('særmerke',),
'særmerkete': ('særmerke',),
'særmerkt': ('særmerkt',),
'særmerkte': ('særmerkt',),
'særmerktere': ('særmerkt',),
'særmerktest': ('særmerkt',),
'særmerkteste': ('særmerkt',),
'særnorsk': ('særnorsk',),
'særnorske': ('særnorsk',),
'særnorskere': ('særnorsk',),
'særnorskest': ('særnorsk',),
'særnorskeste': ('særnorsk',),
'særprega': ('særprege',),
'særpregede': ('særprege',),
'særpregende': ('særprege',),
'særpreget': ('særprege',),
'særpregete': ('særprege',),
'særskilt': ('særskilt',),
'særskilte': ('særskilt',),
'særskiltere': ('særskilt',),
'særskiltest': ('særskilt',),
'særskilteste': ('særskilt',),
'søkende': ('søke',),
'søkt': ('søke',),
'søkte': ('søke',),
'søkkeferdig': ('søkkeferdig',),
'søkkeferdige': ('søkkeferdig',),
'søkkeferdigere': ('søkkeferdig',),
'søkkeferdigst': ('søkkeferdig',),
'søkkeferdigste': ('søkkeferdig',),
'søkkfull': ('søkkfull',),
'søkkfulle': ('søkkfull',),
'søkkfullere': ('søkkfull',),
'søkkfullest': ('søkkfull',),
'søkkfulleste': ('søkkfull',),
'søkkfullt': ('søkkfull',),
'søkklasta': ('søkklasta',),
'søkklastede': ('søkklastet',),
'søkklastet': ('søkklastet',),
'søkklastete': ('søkklastet',),
'søkklastetere': ('søkklastet',),
'søkklastetest': ('søkklastet',),
'søkklasteteste': ('søkklastet',),
'søkkrik': ('søkkrik',),
'søkkrike': ('søkkrik',),
'søkkrikere': ('søkkrik',),
'søkkrikest': ('søkkrik',),
'søkkrikeste': ('søkkrik',),
'søkkrikt': ('søkkrik',),
'søkkvåt': ('søkkvåt',),
'søkkvåte': ('søkkvåt',),
'søkkvåtere': ('søkkvåt',),
'søkkvåtest': ('søkkvåt',),
'søkkvåteste': ('søkkvåt',),
'søkkvått': ('søkkvåt',),
'søkt': ('søkt',),
'søkte': ('søkt',),
'søktere': ('søkt',),
'søktest': ('søkt',),
'søkteste': ('søkt',),
'sølende': ('søle',),
'sølt': ('søle',),
'sølte': ('søle',),
'sølet': ('sølet',),
'sølete': ('sølet',),
'søletere': ('sølet',),
'søletest': ('sølet',),
'søleteste': ('sølet',),
'sølete': ('sølete',),
'sølvgrå': ('sølvgrå',),
'sølvgråe': ('sølvgrå',),
'sølvgråere': ('sølvgrå',),
'sølvgråest': ('sølvgrå',),
'sølvgråeste': ('sølvgrå',),
'sølvgrått': ('sølvgrå',),
'sølvklar': ('sølvklar',),
'sølvklare': ('sølvklar',),
'sølvklarere': ('sølvklar',),
'sølvklarest': ('sølvklar',),
'sølvklareste': ('sølvklar',),
'sølvklart': ('sølvklar',),
'sølvspent': ('sølvspent',),
'sølvspente': ('sølvspent',),
'sølvspentere': ('sølvspent',),
'sølvspentest': ('sølvspent',),
'sølvspenteste': ('sølvspent',),
'sømma': ('sømme',),
'sømmede': ('sømme',),
'sømmende': ('sømme',),
'sømmet': ('sømme',),
'sømmete': ('sømme',),
'sømma': ('sømme',),
'sømmede': ('sømme',),
'sømmende': ('sømme',),
'sømmet': ('sømme',),
'sømmete': ('sømme',),
'sømt': ('sømme',),
'sømte': ('sømme',),
'sømmelig': ('sømmelig',),
'sømmelige': ('sømmelig',),
'sømmeligere': ('sømmelig',),
'sømmeligst': ('sømmelig',),
'sømmeligste': ('sømmelig',),
'sønderknust': ('sønderknust',),
'sønderknuste': ('sønderknust',),
'sønderknustere': ('sønderknust',),
'sønderknustest': ('sønderknust',),
'sønderknusteste': ('sønderknust',),
'søndre': ('søndre',),
'sønnafjelsk': ('sønnafjelsk',),
'sønnafjelske': ('sønnafjelsk',),
'sønnafjelskere': ('sønnafjelsk',),
'sønnafjelskest': ('sønnafjelsk',),
'sønnafjelskeste': ('sønnafjelsk',),
'sønnenfjelsk': ('sønnenfjelsk',),
'sønnenfjelske': ('sønnenfjelsk',),
'sønnenfjelskere': ('sønnenfjelsk',),
'sønnenfjelskest': ('sønnenfjelsk',),
'sønnenfjelskeste': ('sønnenfjelsk',),
'sønnlig': ('sønnlig',),
'sønnlige': ('sønnlig',),
'sønnligere': ('sønnlig',),
'sønnligst': ('sønnlig',),
'sønnligste': ('sønnlig',),
'søpla': ('søple',),
'søplede': ('søple',),
'søplende': ('søple',),
'søplet': ('søple',),
'søplete': ('søple',),
'sørafrikansk': ('sørafrikansk',),
'sørafrikanske': ('sørafrikansk',),
'sørafrikanskere': ('sørafrikansk',),
'sørafrikanskest': ('sørafrikansk',),
'sørafrikanskeste': ('sørafrikansk',),
'søramerikansk': ('søramerikansk',),
'søramerikanske': ('søramerikansk',),
'søramerikanskere': ('søramerikansk',),
'søramerikanskest': ('søramerikansk',),
'søramerikanskeste': ('søramerikansk',),
'søre': ('søre',),
'søreuropeisk': ('søreuropeisk',),
'søreuropeiske': ('søreuropeisk',),
'søreuropeiskere': ('søreuropeisk',),
'søreuropeiskest': ('søreuropeisk',),
'søreuropeiskeste': ('søreuropeisk',),
'sørga': ('sørge',),
'sørgd': ('sørge',),
'sørgde': ('sørge',),
'sørgede': ('sørge',),
'sørgende': ('sørge',),
'sørget': ('sørge',),
'sørgete': ('sørge',),
'sørgekledd': ('sørgekledd',),
'sørgekledde': ('sørgekledd',),
'sørgekleddere': ('sørgekledd',),
'sørgekleddest': ('sørgekledd',),
'sørgekleddeste': ('sørgekledd',),
'sørgelig': ('sørgelig',),
'sørgelige': ('sørgelig',),
'sørgeligere': ('sørgelig',),
'sørgeligst': ('sørgelig',),
'sørgeligste': ('sørgelig',),
'sørgmodig': ('sørgmodig',),
'sørgmodige': ('sørgmodig',),
'sørgmodigere': ('sørgmodig',),
'sørgmodigst': ('sørgmodig',),
'sørgmodigste': ('sørgmodig',),
'sørgående': ('sørgående',),
'sørkoreansk': ('sørkoreansk',),
'sørkoreanske': ('sørkoreansk',),
'sørkoreanskere': ('sørkoreansk',),
'sørkoreanskest': ('sørkoreansk',),
'sørkoreanskeste': ('sørkoreansk',),
'sørlandsk': ('sørlandsk',),
'sørlandske': ('sørlandsk',),
'sørlandskere': ('sørlandsk',),
'sørlandskest': ('sørlandsk',),
'sørlandskeste': ('sørlandsk',),
'sørlig': ('sørlig',),
'sørlige': ('sørlig',),
'sørligere': ('sørlig',),
'sørligst': ('sørlig',),
'sørligste': ('sørlig',),
'sørpet': ('sørpet',),
'sørpete': ('sørpet',),
'sørpetere': ('sørpet',),
'sørpetest': ('sørpet',),
'sørpeteste': ('sørpet',),
'sørpete': ('sørpete',),
'sørsamisk': ('sørsamisk',),
'sørsamiske': ('sørsamisk',),
'sørsamiskere': ('sørsamisk',),
'sørsamiskest': ('sørsamisk',),
'sørsamiskeste': ('sørsamisk',),
'sørvendt': ('sørvendt',),
'sørvendte': ('sørvendt',),
'sørvendtere': ('sørvendt',),
'sørvendtest': ('sørvendt',),
'sørvendteste': ('sørvendt',),
'sørvestlig': ('sørvestlig',),
'sørvestlige': ('sørvestlig',),
'sørvestligere': ('sørvestlig',),
'sørvestligst': ('sørvestlig',),
'sørvestligste': ('sørvestlig',),
'søryemenittisk': ('søryemenittisk',),
'søryemenittiske': ('søryemenittisk',),
'søryemenittiskere': ('søryemenittisk',),
'søryemenittiskest': ('søryemenittisk',),
'søryemenittiskeste': ('søryemenittisk',),
'sørøstlig': ('sørøstlig',),
'sørøstlige': ('sørøstlig',),
'sørøstligere': ('sørøstlig',),
'sørøstligst': ('sørøstlig',),
'sørøstligste': ('sørøstlig',),
'søsterlig': ('søsterlig',),
'søsterlige': ('søsterlig',),
'søsterligere': ('søsterlig',),
'søsterligst': ('søsterlig',),
'søsterligste': ('søsterlig',),
'søt': ('søt',),
'søte': ('søt',),
'søtere': ('søt',),
'søtest': ('søt',),
'søteste': ('søt',),
'søtt': ('søt',),
'søta': ('søte',),
'søtede': ('søte',),
'søtende': ('søte',),
'søtet': ('søte',),
'søtete': ('søte',),
'søtelig': ('søtelig',),
'søtelige': ('søtelig',),
'søteligere': ('søtelig',),
'søteligst': ('søtelig',),
'søteligste': ('søtelig',),
'søtlaten': ('søtlaten',),
'søtlatent': ('søtlaten',),
'søtlatne': ('søtlaten',),
'søtlatnere': ('søtlaten',),
'søtlatnest': ('søtlaten',),
'søtlatneste': ('søtlaten',),
'søtlig': ('søtlig',),
'søtlige': ('søtlig',),
'søtligere': ('søtlig',),
'søtligst': ('søtlig',),
'søtligste': ('søtlig',),
'søvndrukken': ('søvndrukken',),
'søvndrukkent': ('søvndrukken',),
'søvndrukne': ('søvndrukken',),
'søvndruknere': ('søvndrukken',),
'søvndruknest': ('søvndrukken',),
'søvndrukneste': ('søvndrukken',),
'søvndyssende': ('søvndyssende',),
'søvnig': ('søvnig',),
'søvnige': ('søvnig',),
'søvnigere': ('søvnig',),
'søvnigst': ('søvnig',),
'søvnigste': ('søvnig',),
'søvnlaus': ('søvnlaus',),
'søvnlause': ('søvnlaus',),
'søvnlausere': ('søvnlaus',),
'søvnlausest': ('søvnlaus',),
'søvnlauseste': ('søvnlaus',),
'søvnlaust': ('søvnlaus',),
'søvnløs': ('søvnløs',),
'søvnløse': ('søvnløs',),
'søvnløsere': ('søvnløs',),
'søvnløsest': ('søvnløs',),
'søvnløseste': ('søvnløs',),
'søvnløst': ('søvnløs',),
'takende': ('ta',),
'tatt': ('ta',),
'tatte': ('ta',),
'tabba': ('tabbe',),
'tabbede': ('tabbe',),
'tabbende': ('tabbe',),
'tabbet': ('tabbe',),
'tabbete': ('tabbe',),
'tabellariserende': ('tabellarisere',),
'tabellarisert': ('tabellarisere',),
'tabellariserte': ('tabellarisere',),
'tabellarisk': ('tabellarisk',),
'tabellariske': ('tabellarisk',),
'tabellariskere': ('tabellarisk',),
'tabellariskest': ('tabellarisk',),
'tabellariskeste': ('tabellarisk',),
'tabu': ('tabu',),
'tabulerende': ('tabulere',),
'tabulert': ('tabulere',),
'tabulerte': ('tabulere',),
'tadsjikisk': ('tadsjikisk',),
'tadsjikiske': ('tadsjikisk',),
'tadsjikiskere': ('tadsjikisk',),
'tadsjikiskest': ('tadsjikisk',),
'tadsjikiskeste': ('tadsjikisk',),
'tafatt': ('tafatt',),
'tafatte': ('tafatt',),
'tafattere': ('tafatt',),
'tafattest': ('tafatt',),
'tafatteste': ('tafatt',),
'tafsa': ('tafse',),
'tafsede': ('tafse',),
'tafsende': ('tafse',),
'tafset': ('tafse',),
'tafsete': ('tafse',),
'tafset': ('tafset',),
'tafsete': ('tafset',),
'tafsetere': ('tafset',),
'tafsetest': ('tafset',),
'tafseteste': ('tafset',),
'tafsete': ('tafsete',),
'tagal': ('tagal',),
'tagale': ('tagal',),
'tagalere': ('tagal',),
'tagalest': ('tagal',),
'tagaleste': ('tagal',),
'tagalt': ('tagal',),
'tagga': ('tagge',),
'taggede': ('tagge',),
'taggende': ('tagge',),
'tagget': ('tagge',),
'taggete': ('tagge',),
'tagget': ('tagget',),
'taggete': ('tagget',),
'taggetere': ('tagget',),
'taggetest': ('tagget',),
'taggeteste': ('tagget',),
'taggete': ('taggete',),
'tagna': ('tagne',),
'tagnede': ('tagne',),
'tagnende': ('tagne',),
'tagnet': ('tagne',),
'tagnete': ('tagne',),
'tahitisk': ('tahitisk',),
'tahitiske': ('tahitisk',),
'tahitiskere': ('tahitisk',),
'tahitiskest': ('tahitisk',),
'tahitiskeste': ('tahitisk',),
'taiwansk': ('taiwansk',),
'taiwanske': ('taiwansk',),
'taiwanskere': ('taiwansk',),
'taiwanskest': ('taiwansk',),
'taiwanskeste': ('taiwansk',),
'takka': ('takke',),
'takkede': ('takke',),
'takkende': ('takke',),
'takket': ('takke',),
'takkete': ('takke',),
'takket': ('takket',),
'takkete': ('takket',),
'takketere': ('takket',),
'takketest': ('takket',),
'takketeste': ('takket',),
'takkete': ('takkete',),
'takknemlig': ('takknemlig',),
'takknemlige': ('takknemlig',),
'takknemligere': ('takknemlig',),
'takknemligst': ('takknemlig',),
'takknemligste': ('takknemlig',),
'takksam': ('takksam',),
'takksamme': ('takksam',),
'takksammere': ('takksam',),
'takksamst': ('takksam',),
'takksamste': ('takksam',),
'takksamt': ('takksam',),
'takla': ('takle',),
'taklede': ('takle',),
'taklende': ('takle',),
'taklet': ('takle',),
'taklete': ('takle',),
'taksa': ('takse',),
'taksede': ('takse',),
'taksende': ('takse',),
'takset': ('takse',),
'taksete': ('takse',),
'takserende': ('taksere',),
'taksert': ('taksere',),
'takserte': ('taksere',),
'taksonom': ('taksonom',),
'taksonome': ('taksonom',),
'taksonomere': ('taksonom',),
'taksonomest': ('taksonom',),
'taksonomeste': ('taksonom',),
'taksonomt': ('taksonom',),
'taksonomisk': ('taksonomisk',),
'taksonomiske': ('taksonomisk',),
'taksonomiskere': ('taksonomisk',),
'taksonomiskest': ('taksonomisk',),
'taksonomiskeste': ('taksonomisk',),
'takterende': ('taktere',),
'taktert': ('taktere',),
'takterte': ('taktere',),
'taktfast': ('taktfast',),
'taktfaste': ('taktfast',),
'taktfastere': ('taktfast',),
'taktfastest': ('taktfast',),
'taktfasteste': ('taktfast',),
'taktfull': ('taktfull',),
'taktfulle': ('taktfull',),
'taktfullere': ('taktfull',),
'taktfullest': ('taktfull',),
'taktfulleste': ('taktfull',),
'taktfullt': ('taktfull',),
'taktil': ('taktil',),
'taktile': ('taktil',),
'taktilere': ('taktil',),
'taktilest': ('taktil',),
'taktileste': ('taktil',),
'taktilt': ('taktil',),
'taktisk': ('taktisk',),
'taktiske': ('taktisk',),
'taktiskere': ('taktisk',),
'taktiskest': ('taktisk',),
'taktiskeste': ('taktisk',),
'taktlaus': ('taktlaus',),
'taktlause': ('taktlaus',),
'taktlausere': ('taktlaus',),
'taktlausest': ('taktlaus',),
'taktlauseste': ('taktlaus',),
'taktlaust': ('taktlaus',),
'taktløs': ('taktløs',),
'taktløse': ('taktløs',),
'taktløsere': ('taktløs',),
'taktløsest': ('taktløs',),
'taktløseste': ('taktløs',),
'taktløst': ('taktløs',),
'tala': ('tale',),
'talende': ('tale',),
'talt': ('tale',),
'talte': ('tale',),
'talefør': ('talefør',),
'taleføre': ('talefør',),
'taleførere': ('talefør',),
'taleførest': ('talefør',),
'taleføreste': ('talefør',),
'taleført': ('talefør',),
'talentfull': ('talentfull',),
'talentfulle': ('talentfull',),
'talentfullere': ('talentfull',),
'talentfullest': ('talentfull',),
'talentfulleste': ('talentfull',),
'talentfullt': ('talentfull',),
'talentlaus': ('talentlaus',),
'talentlause': ('talentlaus',),
'talentlausere': ('talentlaus',),
'talentlausest': ('talentlaus',),
'talentlauseste': ('talentlaus',),
'talentlaust': ('talentlaus',),
'talentløs': ('talentløs',),
'talentløse': ('talentløs',),
'talentløsere': ('talentløs',),
'talentløsest': ('talentløs',),
'talentløseste': ('talentløs',),
'talentløst': ('talentløs',),
'taletrengt': ('taletrengt',),
'taletrengte': ('taletrengt',),
'taletrengtere': ('taletrengt',),
'taletrengtest': ('taletrengt',),
'taletrengteste': ('taletrengt',),
'talfesta': ('talfeste',),
'talfestede': ('talfeste',),
'talfestende': ('talfeste',),
'talfestet': ('talfeste',),
'talfestete': ('talfeste',),
'tall-laus': ('tall-laus',),
'tall-lause': ('tall-laus',),
'tall-lausere': ('tall-laus',),
'tall-lausest': ('tall-laus',),
'tall-lauseste': ('tall-laus',),
'tall-laust': ('tall-laus',),
'tall-løs': ('tall-løs',),
'tall-løse': ('tall-løs',),
'tall-løsere': ('tall-løs',),
'tall-løsest': ('tall-løs',),
'tall-løseste': ('tall-løs',),
'tall-løst': ('tall-løs',),
'tallaus': ('tallaus',),
'tallause': ('tallaus',),
'tallausere': ('tallaus',),
'tallausest': ('tallaus',),
'tallauseste': ('tallaus',),
'tallaust': ('tallaus',),
'tallaus': ('tallaus',),
'tallause': ('tallaus',),
'tallausere': ('tallaus',),
'tallausest': ('tallaus',),
'tallauseste': ('tallaus',),
'tallaust': ('tallaus',),
'tallaus': ('tallaus',),
'tallause': ('tallaus',),
'tallausere': ('tallaus',),
'tallausest': ('tallaus',),
'tallauseste': ('tallaus',),
'tallaust': ('tallaus',),
'talla': ('talle',),
'tallede': ('talle',),
'tallende': ('talle',),
'tallet': ('talle',),
'tallete': ('talle',),
'tallfesta': ('tallfeste',),
'tallfestede': ('tallfeste',),
'tallfestende': ('tallfeste',),
'tallfestet': ('tallfeste',),
'tallfestete': ('tallfeste',),
'tallmessig': ('tallmessig',),
'tallmessige': ('tallmessig',),
'tallmessigere': ('tallmessig',),
'tallmessigst': ('tallmessig',),
'tallmessigste': ('tallmessig',),
'tallrik': ('tallrik',),
'tallrike': ('tallrik',),
'tallrikere': ('tallrik',),
'tallrikest': ('tallrik',),
'tallrikeste': ('tallrik',),
'tallrikt': ('tallrik',),
'tallrik': ('tallrik',),
'tallrike': ('tallrik',),
'tallrikere': ('tallrik',),
'tallrikest': ('tallrik',),
'tallrikeste': ('tallrik',),
'tallrikt': ('tallrik',),
'talløs': ('talløs',),
'talløse': ('talløs',),
'talløsere': ('talløs',),
'talløsest': ('talløs',),
'talløseste': ('talløs',),
'talløst': ('talløs',),
'talløs': ('talløs',),
'talløse': ('talløs',),
'talløsere': ('talløs',),
'talløsest': ('talløs',),
'talløseste': ('talløs',),
'talløst': ('talløs',),
'talløs': ('talløs',),
'talløse': ('talløs',),
'talløsere': ('talløs',),
'talløsest': ('talløs',),
'talløseste': ('talløs',),
'talløst': ('talløs',),
'talmessig': ('talmessig',),
'talmessige': ('talmessig',),
'talmessigere': ('talmessig',),
'talmessigst': ('talmessig',),
'talmessigste': ('talmessig',),
'talmudisk': ('talmudisk',),
'talmudiske': ('talmudisk',),
'talmudiskere': ('talmudisk',),
'talmudiskest': ('talmudisk',),
'talmudiskeste': ('talmudisk',),
'talrik': ('talrik',),
'talrike': ('talrik',),
'talrikere': ('talrik',),
'talrikest': ('talrik',),
'talrikeste': ('talrik',),
'talrikt': ('talrik',),
'talrik': ('talrik',),
'talrike': ('talrik',),
'talrikere': ('talrik',),
'talrikest': ('talrik',),
'talrikeste': ('talrik',),
'talrikt': ('talrik',),
'tam': ('tam',),
'tamme': ('tam',),
'tammere': ('tam',),
'tammest': ('tam',),
'tammeste': ('tam',),
'tamt': ('tam',),
'tampa': ('tampe',),
'tampede': ('tampe',),
'tampende': ('tampe',),
'tampet': ('tampe',),
'tampete': ('tampe',),
'tamsa': ('tamse',),
'tamsede': ('tamse',),
'tamsende': ('tamse',),
'tamset': ('tamse',),
'tamsete': ('tamse',),
'tander': ('tander',),
'tandert': ('tander',),
'tandre': ('tander',),
'tandrere': ('tander',),
'tandrest': ('tander',),
'tandreste': ('tander',),
'tana': ('tane',),
'tanede': ('tane',),
'tanende': ('tane',),
'tanet': ('tane',),
'tanete': ('tane',),
'tant': ('tane',),
'tante': ('tane',),
'tangential': ('tangential',),
'tangentiale': ('tangential',),
'tangentialere': ('tangential',),
'tangentialest': ('tangential',),
'tangentialeste': ('tangential',),
'tangentialt': ('tangential',),
'tangentiell': ('tangentiell',),
'tangentielle': ('tangentiell',),
'tangentiellere': ('tangentiell',),
'tangentiellest': ('tangentiell',),
'tangentielleste': ('tangentiell',),
'tangentielt': ('tangentiell',),
'tangerende': ('tangere',),
'tangert': ('tangere',),
'tangerte': ('tangere',),
'tanka': ('tanke',),
'tankede': ('tanke',),
'tankende': ('tanke',),
'tanket': ('tanke',),
'tankete': ('tanke',),
'tankefull': ('tankefull',),
'tankefulle': ('tankefull',),
'tankefullere': ('tankefull',),
'tankefullest': ('tankefull',),
'tankefulleste': ('tankefull',),
'tankefullt': ('tankefull',),
'tankelaus': ('tankelaus',),
'tankelause': ('tankelaus',),
'tankelausere': ('tankelaus',),
'tankelausest': ('tankelaus',),
'tankelauseste': ('tankelaus',),
'tankelaust': ('tankelaus',),
'tankeløs': ('tankeløs',),
'tankeløse': ('tankeløs',),
'tankeløsere': ('tankeløs',),
'tankeløsest': ('tankeløs',),
'tankeløseste': ('tankeløs',),
'tankeløst': ('tankeløs',),
'tankespredt': ('tankespredt',),
'tankespredte': ('tankespredt',),
'tankespredtere': ('tankespredt',),
'tankespredtest': ('tankespredt',),
'tankespredteste': ('tankespredt',),
'tankevekkende': ('tankevekkende',),
'tannet': ('tannet',),
'tannete': ('tannet',),
'tannetere': ('tannet',),
'tannetest': ('tannet',),
'tanneteste': ('tannet',),
'tannete': ('tannete',),
'tannlaus': ('tannlaus',),
'tannlause': ('tannlaus',),
'tannlausere': ('tannlaus',),
'tannlausest': ('tannlaus',),
'tannlauseste': ('tannlaus',),
'tannlaust': ('tannlaus',),
'tannløs': ('tannløs',),
'tannløse': ('tannløs',),
'tannløsere': ('tannløs',),
'tannløsest': ('tannløs',),
'tannløseste': ('tannløs',),
'tannløst': ('tannløs',),
'tantet': ('tantet',),
'tantete': ('tantet',),
'tantetere': ('tantet',),
'tantetest': ('tantet',),
'tanteteste': ('tantet',),
'tantete': ('tantete',),
'tanzaniansk': ('tanzaniansk',),
'tanzanianske': ('tanzaniansk',),
'tanzanianskere': ('tanzaniansk',),
'tanzanianskest': ('tanzaniansk',),
'tanzanianskeste': ('tanzaniansk',),
'tapa': ('tape',),
'tapede': ('tape',),
'tapende': ('tape',),
'tapet': ('tape',),
'tapete': ('tape',),
'tapende': ('tape',),
'tapt': ('tape',),
'tapte': ('tape',),
'tapetserende': ('tapetsere',),
'tapetsert': ('tapetsere',),
'tapetserte': ('tapetsere',),
'tappa': ('tappe',),
'tappede': ('tappe',),
'tappende': ('tappe',),
'tappet': ('tappe',),
'tappete': ('tappe',),
'tapper': ('tapper',),
'tappert': ('tapper',),
'tapre': ('tapper',),
'taprere': ('tapper',),
'taprest': ('tapper',),
'tapreste': ('tapper',),
'tapsbringende': ('tapsbringende',),
'tariff-festa': ('tariff-feste',),
'tariff-festede': ('tariff-feste',),
'tariff-festende': ('tariff-feste',),
'tariff-festet': ('tariff-feste',),
'tariff-festete': ('tariff-feste',),
'tariffesta': ('tariffeste',),
'tariffestede': ('tariffeste',),
'tariffestende': ('tariffeste',),
'tariffestet': ('tariffeste',),
'tariffestete': ('tariffeste',),
'tariffstridig': ('tariffstridig',),
'tariffstridige': ('tariffstridig',),
'tariffstridigere': ('tariffstridig',),
'tariffstridigst': ('tariffstridig',),
'tariffstridigste': ('tariffstridig',),
'tarpeiisk': ('tarpeiisk',),
'tarpeiiske': ('tarpeiisk',),
'tarpeiiskere': ('tarpeiisk',),
'tarpeiiskest': ('tarpeiisk',),
'tarpeiiskeste': ('tarpeiisk',),
'tarvelig': ('tarvelig',),
'tarvelige': ('tarvelig',),
'tarveligere': ('tarvelig',),
'tarveligst': ('tarvelig',),
'tarveligste': ('tarvelig',),
'tasal': ('tasal',),
'tasale': ('tasal',),
'tasalere': ('tasal',),
'tasalest': ('tasal',),
'tasaleste': ('tasal',),
'tasalt': ('tasal',),
'tasla': ('tasle',),
'taslede': ('tasle',),
'taslende': ('tasle',),
'taslet': ('tasle',),
'taslete': ('tasle',),
'tasmansk': ('tasmansk',),
'tasmanske': ('tasmansk',),
'tasmanskere': ('tasmansk',),
'tasmanskest': ('tasmansk',),
'tasmanskeste': ('tasmansk',),
'tassa': ('tasse',),
'tassede': ('tasse',),
'tassende': ('tasse',),
'tasset': ('tasse',),
'tassete': ('tasse',),
'tasta': ('taste',),
'tastede': ('taste',),
'tastende': ('taste',),
'tastet': ('taste',),
'tastete': ('taste',),
'tatarisk': ('tatarisk',),
'tatariske': ('tatarisk',),
'tatariskere': ('tatarisk',),
'tatariskest': ('tatarisk',),
'tatariskeste': ('tatarisk',),
'tatoverende': ('tatovere',),
'tatovert': ('tatovere',),
'tatoverte': ('tatovere',),
'taua': ('taue',),
'tauede': ('taue',),
'tauende': ('taue',),
'tauet': ('taue',),
'tauete': ('taue',),
'taus': ('taus',),
'tause': ('taus',),
'tausere': ('taus',),
'tausest': ('taus',),
'tauseste': ('taus',),
'taust': ('taus',),
'tautologisk': ('tautologisk',),
'tautologiske': ('tautologisk',),
'tautologiskere': ('tautologisk',),
'tautologiskest': ('tautologisk',),
'tautologiskeste': ('tautologisk',),
'tava': ('tave',),
'tavede': ('tave',),
'tavende': ('tave',),
'tavet': ('tave',),
'tavete': ('tave',),
'tchadisk': ('tchadisk',),
'tchadiske': ('tchadisk',),
'tchadiskere': ('tchadisk',),
'tchadiskest': ('tchadisk',),
'tchadiskeste': ('tchadisk',),
'tedd': ('te',),
'tedde': ('te',),
'teende': ('te',),
'teatral': ('teatral',),
'teatrale': ('teatral',),
'teatralere': ('teatral',),
'teatralest': ('teatral',),
'teatraleste': ('teatral',),
'teatralt': ('teatral',),
'teatralsk': ('teatralsk',),
'teatralske': ('teatralsk',),
'teatralskere': ('teatralsk',),
'teatralskest': ('teatralsk',),
'teatralskeste': ('teatralsk',),
'tefta': ('tefte',),
'teftede': ('tefte',),
'teftende': ('tefte',),
'teftet': ('tefte',),
'teftete': ('tefte',),
'teglrød': ('teglrød',),
'teglrøde': ('teglrød',),
'teglrødere': ('teglrød',),
'teglrødest': ('teglrød',),
'teglrødeste': ('teglrød',),
'teglrødt': ('teglrød',),
'tegna': ('tegne',),
'tegnede': ('tegne',),
'tegnende': ('tegne',),
'tegnet': ('tegne',),
'tegnete': ('tegne',),
'teipa': ('teipe',),
'teipede': ('teipe',),
'teipende': ('teipe',),
'teipet': ('teipe',),
'teipete': ('teipe',),
'teistisk': ('teistisk',),
'teistiske': ('teistisk',),
'teistiskere': ('teistisk',),
'teistiskest': ('teistisk',),
'teistiskeste': ('teistisk',),
'teit': ('teit',),
'teite': ('teit',),
'teitere': ('teit',),
'teitest': ('teit',),
'teiteste': ('teit',),
'teita': ('teite',),
'teitede': ('teite',),
'teitende': ('teite',),
'teitet': ('teite',),
'teitete': ('teite',),
'tekka': ('tekke',),
'tekkede': ('tekke',),
'tekkende': ('tekke',),
'tekket': ('tekke',),
'tekkete': ('tekke',),
'tekt': ('tekke',),
'tekte': ('tekke',),
'tekkelig': ('tekkelig',),
'tekkelige': ('tekkelig',),
'tekkeligere': ('tekkelig',),
'tekkeligst': ('tekkelig',),
'tekkeligste': ('tekkelig',),
'teknifiserende': ('teknifisere',),
'teknifisert': ('teknifisere',),
'teknifiserte': ('teknifisere',),
'teknisk': ('teknisk',),
'tekniske': ('teknisk',),
'tekniskere': ('teknisk',),
'tekniskest': ('teknisk',),
'tekniskeste': ('teknisk',),
'teknokratisk': ('teknokratisk',),
'teknokratiske': ('teknokratisk',),
'teknokratiskere': ('teknokratisk',),
'teknokratiskest': ('teknokratisk',),
'teknokratiskeste': ('teknokratisk',),
'teknologisk': ('teknologisk',),
'teknologiske': ('teknologisk',),
'teknologiskere': ('teknologisk',),
'teknologiskest': ('teknologisk',),
'teknologiskeste': ('teknologisk',),
'teksta': ('tekste',),
'tekstede': ('tekste',),
'tekstende': ('tekste',),
'tekstet': ('tekste',),
'tekstete': ('tekste',),
'tekstil': ('tekstil',),
'tekstile': ('tekstil',),
'tekstilere': ('tekstil',),
'tekstilest': ('tekstil',),
'tekstileste': ('tekstil',),
'tekstilt': ('tekstil',),
'tekstlig': ('tekstlig',),
'tekstlige': ('tekstlig',),
'tekstligere': ('tekstlig',),
'tekstligst': ('tekstlig',),
'tekstligste': ('tekstlig',),
'tekstuell': ('tekstuell',),
'tekstuelle': ('tekstuell',),
'tekstuellere': ('tekstuell',),
'tekstuellest': ('tekstuell',),
'tekstuelleste': ('tekstuell',),
'tekstuelt': ('tekstuell',),
'teksturerende': ('teksturere',),
'teksturert': ('teksturere',),
'teksturerte': ('teksturere',),
'tela': ('tele',),
'telede': ('tele',),
'telende': ('tele',),
'telet': ('tele',),
'telete': ('tele',),
'telefonerende': ('telefonere',),
'telefonert': ('telefonere',),
'telefonerte': ('telefonere',),
'telefonisk': ('telefonisk',),
'telefoniske': ('telefonisk',),
'telefoniskere': ('telefonisk',),
'telefoniskest': ('telefonisk',),
'telefoniskeste': ('telefonisk',),
'telegraferende': ('telegrafere',),
'telegrafert': ('telegrafere',),
'telegraferte': ('telegrafere',),
'telegrafisk': ('telegrafisk',),
'telegrafiske': ('telegrafisk',),
'telegrafiskere': ('telegrafisk',),
'telegrafiskest': ('telegrafisk',),
'telegrafiskeste': ('telegrafisk',),
'telekserende': ('teleksere',),
'teleksert': ('teleksere',),
'telekserte': ('teleksere',),
'telemetrerende': ('telemetrere',),
'telemetrert': ('telemetrere',),
'telemetrerte': ('telemetrere',),
'teleologisk': ('teleologisk',),
'teleologiske': ('teleologisk',),
'teleologiskere': ('teleologisk',),
'teleologiskest': ('teleologisk',),
'teleologiskeste': ('teleologisk',),
'telepatisk': ('telepatisk',),
'telepatiske': ('telepatisk',),
'telepatiskere': ('telepatisk',),
'telepatiskest': ('telepatisk',),
'telepatiskeste': ('telepatisk',),
'teleskopisk': ('teleskopisk',),
'teleskopiske': ('teleskopisk',),
'teleskopiskere': ('teleskopisk',),
'teleskopiskest': ('teleskopisk',),
'teleskopiskeste': ('teleskopisk',),
'telet': ('telet',),
'telete': ('telet',),
'teletere': ('telet',),
'teletest': ('telet',),
'teleteste': ('telet',),
'telete': ('telete',),
'telgd': ('telgje',),
'telgde': ('telgje',),
'telgende': ('telgje',),
'telgja': ('telgje',),
'telgjede': ('telgje',),
'telgjende': ('telgje',),
'telgjet': ('telgje',),
'telgjete': ('telgje',),
'tellbar': ('tellbar',),
'tellbare': ('tellbar',),
'tellbarere': ('tellbar',),
'tellbarest': ('tellbar',),
'tellbareste': ('tellbar',),
'tellbart': ('tellbar',),
'talt': ('telle',),
'talte': ('telle',),
'tella': ('telle',),
'tellede': ('telle',),
'tellende': ('telle',),
'tellet': ('telle',),
'tellete': ('telle',),
'telt': ('telle',),
'telte': ('telle',),
'tellelig': ('tellelig',),
'tellelige': ('tellelig',),
'telleligere': ('tellelig',),
'telleligst': ('tellelig',),
'telleligste': ('tellelig',),
'tellurisk': ('tellurisk',),
'telluriske': ('tellurisk',),
'telluriskere': ('tellurisk',),
'telluriskest': ('tellurisk',),
'telluriskeste': ('tellurisk',),
'telna': ('telne',),
'telnede': ('telne',),
'telnende': ('telne',),
'telnet': ('telne',),
'telnete': ('telne',),
'telta': ('telte',),
'teltede': ('telte',),
'teltende': ('telte',),
'teltet': ('telte',),
'teltete': ('telte',),
'tematiserende': ('tematisere',),
'tematisert': ('tematisere',),
'tematiserte': ('tematisere',),
'tematisk': ('tematisk',),
'tematiske': ('tematisk',),
'tematiskere': ('tematisk',),
'tematiskest': ('tematisk',),
'tematiskeste': ('tematisk',),
'temma': ('temme',),
'temmede': ('temme',),
'temmende': ('temme',),
'temmet': ('temme',),
'temmete': ('temme',),
'temt': ('temme',),
'temte': ('temme',),
'temperamentsfull': ('temperamentsfull',),
'temperamentsfulle': ('temperamentsfull',),
'temperamentsfullere': ('temperamentsfull',),
'temperamentsfullest': ('temperamentsfull',),
'temperamentsfulleste': ('temperamentsfull',),
'temperamentsfullt': ('temperamentsfull',),
'tempererende': ('temperere',),
'temperert': ('temperere',),
'tempererte': ('temperere',),
'temporal': ('temporal',),
'temporale': ('temporal',),
'temporalere': ('temporal',),
'temporalest': ('temporal',),
'temporaleste': ('temporal',),
'temporalt': ('temporal',),
'temporær': ('temporær',),
'temporære': ('temporær',),
'temporærere': ('temporær',),
'temporærest': ('temporær',),
'temporæreste': ('temporær',),
'temporært': ('temporær',),
'tendensiøs': ('tendensiøs',),
'tendensiøse': ('tendensiøs',),
'tendensiøsere': ('tendensiøs',),
'tendensiøsest': ('tendensiøs',),
'tendensiøseste': ('tendensiøs',),
'tendensiøst': ('tendensiøs',),
'tenderende': ('tendere',),
'tendert': ('tendere',),
'tenderte': ('tendere',),
'tenkbar': ('tenkbar',),
'tenkbare': ('tenkbar',),
'tenkbarere': ('tenkbar',),
'tenkbarest': ('tenkbar',),
'tenkbareste': ('tenkbar',),
'tenkbart': ('tenkbar',),
'tenkende': ('tenke',),
'tenkt': ('tenke',),
'tenkte': ('tenke',),
'tenkelig': ('tenkelig',),
'tenkelige': ('tenkelig',),
'tenkeligere': ('tenkelig',),
'tenkeligst': ('tenkelig',),
'tenkeligste': ('tenkelig',),
'tenksom': ('tenksom',),
'tenksomme': ('tenksom',),
'tenksommere': ('tenksom',),
'tenksomst': ('tenksom',),
'tenksomste': ('tenksom',),
'tenksomt': ('tenksom',),
'tennende': ('tenne',),
'tent': ('tenne',),
'tente': ('tenne',),
'tennerskjærende': ('tennerskjærende',),
'tentativ': ('tentativ',),
'tentative': ('tentativ',),
'tentativere': ('tentativ',),
'tentativest': ('tentativ',),
'tentativeste': ('tentativ',),
'tentativt': ('tentativ',),
'tenårig': ('tenårig',),
'tenårige': ('tenårig',),
'tenårigere': ('tenårig',),
'tenårigst': ('tenårig',),
'tenårigste': ('tenårig',),
'teokratisk': ('teokratisk',),
'teokratiske': ('teokratisk',),
'teokratiskere': ('teokratisk',),
'teokratiskest': ('teokratisk',),
'teokratiskeste': ('teokratisk',),
'teologisk': ('teologisk',),
'teologiske': ('teologisk',),
'teologiskere': ('teologisk',),
'teologiskest': ('teologisk',),
'teologiskeste': ('teologisk',),
'teoretiserende': ('teoretisere',),
'teoretisert': ('teoretisere',),
'teoretiserte': ('teoretisere',),
'teoretisk': ('teoretisk',),
'teoretiske': ('teoretisk',),
'teoretiskere': ('teoretisk',),
'teoretiskest': ('teoretisk',),
'teoretiskeste': ('teoretisk',),
'teosentrisk': ('teosentrisk',),
'teosentriske': ('teosentrisk',),
'teosentriskere': ('teosentrisk',),
'teosentriskest': ('teosentrisk',),
'teosentriskeste': ('teosentrisk',),
'teosofisk': ('teosofisk',),
'teosofiske': ('teosofisk',),
'teosofiskere': ('teosofisk',),
'teosofiskest': ('teosofisk',),
'teosofiskeste': ('teosofisk',),
'teppende': ('teppe',),
'tept': ('teppe',),
'tepte': ('teppe',),
'teppelagt': ('teppelegge',),
'teppelagte': ('teppelegge',),
'teppeleggende': ('teppelegge',),
'terapeutisk': ('terapeutisk',),
'terapeutiske': ('terapeutisk',),
'terapeutiskere': ('terapeutisk',),
'terapeutiskest': ('terapeutisk',),
'terapeutiskeste': ('terapeutisk',),
'terga': ('terge',),
'tergede': ('terge',),
'tergende': ('terge',),
'terget': ('terge',),
'tergete': ('terge',),
'termal': ('termal',),
'termale': ('termal',),
'termalere': ('termal',),
'termalest': ('termal',),
'termaleste': ('termal',),
'termalt': ('termal',),
'terminal': ('terminal',),
'terminale': ('terminal',),
'terminalere': ('terminal',),
'terminalest': ('terminal',),
'terminaleste': ('terminal',),
'terminalt': ('terminal',),
'terminfesta': ('terminfeste',),
'terminfestede': ('terminfeste',),
'terminfestende': ('terminfeste',),
'terminfestet': ('terminfeste',),
'terminfestete': ('terminfeste',),
'terminologisk': ('terminologisk',),
'terminologiske': ('terminologisk',),
'terminologiskere': ('terminologisk',),
'terminologiskest': ('terminologisk',),
'terminologiskeste': ('terminologisk',),
'termisk': ('termisk',),
'termiske': ('termisk',),
'termiskere': ('termisk',),
'termiskest': ('termisk',),
'termiskeste': ('termisk',),
'termodynamisk': ('termodynamisk',),
'termodynamiske': ('termodynamisk',),
'termodynamiskere': ('termodynamisk',),
'termodynamiskest': ('termodynamisk',),
'termodynamiskeste': ('termodynamisk',),
'termonukleær': ('termonukleær',),
'termonukleære': ('termonukleær',),
'termonukleærere': ('termonukleær',),
'termonukleærest': ('termonukleær',),
'termonukleæreste': ('termonukleær',),
'termonukleært': ('termonukleær',),
'termoplastisk': ('termoplastisk',),
'termoplastiske': ('termoplastisk',),
'termoplastiskere': ('termoplastisk',),
'termoplastiskest': ('termoplastisk',),
'termoplastiskeste': ('termoplastisk',),
'ternet': ('ternet',),
'ternete': ('ternet',),
'ternetere': ('ternet',),
'ternetest': ('ternet',),
'terneteste': ('ternet',),
'ternete': ('ternete',),
'terningforma': ('terningforma',),
'terningformede': ('terningformet',),
'terningformet': ('terningformet',),
'terningformete': ('terningformet',),
'terningformetere': ('terningformet',),
'terningformetest': ('terningformet',),
'terningformeteste': ('terningformet',),
'terpa': ('terpe',),
'terpede': ('terpe',),
'terpende': ('terpe',),
'terpet': ('terpe',),
'terpete': ('terpe',),
'terrakottafarga': ('terrakottafarga',),
'terrakottafargede': ('terrakottafarget',),
'terrakottafarget': ('terrakottafarget',),
'terrakottafargete': ('terrakottafarget',),
'terrakottafargetere': ('terrakottafarget',),
'terrakottafargetest': ('terrakottafarget',),
'terrakottafargeteste': ('terrakottafarget',),
'terrasserende': ('terrassere',),
'terrassert': ('terrassere',),
'terrasserte': ('terrassere',),
'terrenggående': ('terrenggående',),
'terrestrisk': ('terrestrisk',),
'terrestriske': ('terrestrisk',),
'terrestriskere': ('terrestrisk',),
'terrestriskest': ('terrestrisk',),
'terrestriskeste': ('terrestrisk',),
'territorial': ('territorial',),
'territoriale': ('territorial',),
'territorialere': ('territorial',),
'territorialest': ('territorial',),
'territorialeste': ('territorial',),
'territorialt': ('territorial',),
'terroriserende': ('terrorisere',),
'terrorisert': ('terrorisere',),
'terroriserte': ('terrorisere',),
'terroristisk': ('terroristisk',),
'terroristiske': ('terroristisk',),
'terroristiskere': ('terroristisk',),
'terroristiskest': ('terroristisk',),
'terroristiskeste': ('terroristisk',),
'terska': ('terske',),
'terskede': ('terske',),
'terskende': ('terske',),
'tersket': ('terske',),
'terskete': ('terske',),
'tertefin': ('tertefin',),
'tertefine': ('tertefin',),
'tertefinere': ('tertefin',),
'tertefinest': ('tertefin',),
'tertefineste': ('tertefin',),
'tertefint': ('tertefin',),
'terten': ('terten',),
'tertent': ('terten',),
'tertne': ('terten',),
'tertnere': ('terten',),
'tertnest': ('terten',),
'tertneste': ('terten',),
'tertet': ('tertet',),
'tertete': ('tertet',),
'tertetere': ('tertet',),
'tertetest': ('tertet',),
'terteteste': ('tertet',),
'tertete': ('tertete',),
'tertial': ('tertial',),
'tertiale': ('tertial',),
'tertialere': ('tertial',),
'tertialest': ('tertial',),
'tertialeste': ('tertial',),
'tertialt': ('tertial',),
'tertiær': ('tertiær',),
'tertiære': ('tertiær',),
'tertiærere': ('tertiær',),
'tertiærest': ('tertiær',),
'tertiæreste': ('tertiær',),
'tertiært': ('tertiær',),
'tesaurisk': ('tesaurisk',),
'tesauriske': ('tesaurisk',),
'tesauriskere': ('tesaurisk',),
'tesauriskest': ('tesaurisk',),
'tesauriskeste': ('tesaurisk',),
'tess': ('tess',),
'testamentarisk': ('testamentarisk',),
'testamentariske': ('testamentarisk',),
'testamentariskere': ('testamentarisk',),
'testamentariskest': ('testamentarisk',),
'testamentariskeste': ('testamentarisk',),
'testamenterende': ('testamentere',),
'testamentert': ('testamentere',),
'testamenterte': ('testamentere',),
'testa': ('teste',),
'testede': ('teste',),
'testende': ('teste',),
'testet': ('teste',),
'testete': ('teste',),
'tetna': ('tetne',),
'tetnede': ('tetne',),
'tetnende': ('tetne',),
'tetnet': ('tetne',),
'tetnete': ('tetne',),
'tetraedrisk': ('tetraedrisk',),
'tetraedriske': ('tetraedrisk',),
'tetraedriskere': ('tetraedrisk',),
'tetraedriskest': ('tetraedrisk',),
'tetraedriskeste': ('tetraedrisk',),
'tetragonal': ('tetragonal',),
'tetragonale': ('tetragonal',),
'tetragonalere': ('tetragonal',),
'tetragonalest': ('tetragonal',),
'tetragonaleste': ('tetragonal',),
'tetragonalt': ('tetragonal',),
'tett': ('tett',),
'tette': ('tett',),
'tettere': ('tett',),
'tettest': ('tett',),
'tetteste': ('tett',),
'tettbygd': ('tettbygd',),
'tettbygde': ('tettbygd',),
'tettbygdere': ('tettbygd',),
'tettbygdest': ('tettbygd',),
'tettbygdeste': ('tettbygd',),
'tetta': ('tette',),
'tettede': ('tette',),
'tettende': ('tette',),
'tettet': ('tette',),
'tettete': ('tette',),
'tettgrendt': ('tettgrendt',),
'tettgrendte': ('tettgrendt',),
'tettgrendtere': ('tettgrendt',),
'tettgrendtest': ('tettgrendt',),
'tettgrendteste': ('tettgrendt',),
'tettpakka': ('tettpakka',),
'tettpakkede': ('tettpakket',),
'tettpakket': ('tettpakket',),
'tettpakkete': ('tettpakket',),
'tettpakketere': ('tettpakket',),
'tettpakketest': ('tettpakket',),
'tettpakketeste': ('tettpakket',),
'tettsittende': ('tettsittende',),
'tettskreven': ('tettskreven',),
'tettskrevet': ('tettskreven',),
'tettskrevne': ('tettskreven',),
'tettskrevnere': ('tettskreven',),
'tettskrevnest': ('tettskreven',),
'tettskrevneste': ('tettskreven',),
'tettskrevet': ('tettskrevet',),
'tettskrevne': ('tettskrevet',),
'tettskrevnere': ('tettskrevet',),
'tettskrevnest': ('tettskrevet',),
'tettskrevneste': ('tettskrevet',),
'tettvokst': ('tettvokst',),
'tettvokste': ('tettvokst',),
'tettvokstere': ('tettvokst',),
'tettvokstest': ('tettvokst',),
'tettvoksteste': ('tettvokst',),
'teutonisk': ('teutonisk',),
'teutoniske': ('teutonisk',),
'teutoniskere': ('teutonisk',),
'teutoniskest': ('teutonisk',),
'teutoniskeste': ('teutonisk',),
'teutonsk': ('teutonsk',),
'teutonske': ('teutonsk',),
'teutonskere': ('teutonsk',),
'teutonskest': ('teutonsk',),
'teutonskeste': ('teutonsk',),
'teva': ('teve',),
'tevede': ('teve',),
'tevende': ('teve',),
'tevet': ('teve',),
'tevete': ('teve',),
'tevla': ('tevle',),
'tevlede': ('tevle',),
'tevlende': ('tevle',),
'tevlet': ('tevle',),
'tevlete': ('tevle',),
'thailandsk': ('thailandsk',),
'thailandske': ('thailandsk',),
'thailandskere': ('thailandsk',),
'thailandskest': ('thailandsk',),
'thailandskeste': ('thailandsk',),
'thomistisk': ('thomistisk',),
'thomistiske': ('thomistisk',),
'thomistiskere': ('thomistisk',),
'thomistiskest': ('thomistisk',),
'thomistiskeste': ('thomistisk',),
'tibetansk': ('tibetansk',),
'tibetanske': ('tibetansk',),
'tibetanskere': ('tibetansk',),
'tibetanskest': ('tibetansk',),
'tibetanskeste': ('tibetansk',),
'tidfesta': ('tidfeste',),
'tidfestede': ('tidfeste',),
'tidfestende': ('tidfeste',),
'tidfestet': ('tidfeste',),
'tidfestete': ('tidfeste',),
'tidig': ('tidig',),
'tidige': ('tidig',),
'tidigere': ('tidig',),
'tidigst': ('tidig',),
'tidigste': ('tidig',),
'tidkrevende': ('tidkrevende',),
'tidlaus': ('tidlaus',),
'tidlause': ('tidlaus',),
'tidlausere': ('tidlaus',),
'tidlausest': ('tidlaus',),
'tidlauseste': ('tidlaus',),
'tidlaust': ('tidlaus',),
'tidlig': ('tidlig',),
'tidlige': ('tidlig',),
'tidligere': ('tidlig',),
'tidligst': ('tidlig',),
'tidligste': ('tidlig',),
'tidløs': ('tidløs',),
'tidløse': ('tidløs',),
'tidløsere': ('tidløs',),
'tidløsest': ('tidløs',),
'tidløseste': ('tidløs',),
'tidløst': ('tidløs',),
'tidobbel': ('tidobbel',),
'tidobbelt': ('tidobbel',),
'tidoble': ('tidobbel',),
'tidoblere': ('tidobbel',),
'tidoblest': ('tidobbel',),
'tidobleste': ('tidobbel',),
'tidobbelt': ('tidobbelt',),
'tidobbelte': ('tidobbelt',),
'tidobbeltere': ('tidobbelt',),
'tidobbeltest': ('tidobbelt',),
'tidobbelteste': ('tidobbelt',),
'tidobla': ('tidoble',),
'tidoblede': ('tidoble',),
'tidoblende': ('tidoble',),
'tidoblet': ('tidoble',),
'tidoblete': ('tidoble',),
'tids': ('tids',),
'tidsbesparende': ('tidsbesparende',),
'tidsbestemmende': ('tidsbestemme',),
'tidsbestemt': ('tidsbestemme',),
'tidsbestemte': ('tidsbestemme',),
'tidsbundet': ('tidsbundet',),
'tidsbundne': ('tidsbundet',),
'tidsbundnere': ('tidsbundet',),
'tidsbundnest': ('tidsbundet',),
'tidsbundneste': ('tidsbundet',),
'tidsinnstillende': ('tidsinnstille',),
'tidsinnstilt': ('tidsinnstille',),
'tidsinnstilte': ('tidsinnstille',),
'tidskrevende': ('tidskrevende',),
'tidsmessig': ('tidsmessig',),
'tidsmessige': ('tidsmessig',),
'tidsmessigere': ('tidsmessig',),
'tidsmessigst': ('tidsmessig',),
'tidsmessigste': ('tidsmessig',),
'tidssparende': ('tidssparende',),
'tidstypisk': ('tidstypisk',),
'tidstypiske': ('tidstypisk',),
'tidstypiskere': ('tidstypisk',),
'tidstypiskest': ('tidstypisk',),
'tidstypiskeste': ('tidstypisk',),
'tagd': ('tie',),
'tagde': ('tie',),
'tia': ('tie',),
'tidd': ('tie',),
'tidde': ('tie',),
'tiede': ('tie',),
'tiende': ('tie',),
'tiet': ('tie',),
'tiete': ('tie',),
'tien': ('tien',),
'tiene': ('tien',),
'tienere': ('tien',),
'tienest': ('tien',),
'tieneste': ('tien',),
'tient': ('tien',),
'tiende': ('tiende',),
'tifold': ('tifold',),
'tigd': ('tigge',),
'tigde': ('tigge',),
'tigga': ('tigge',),
'tiggede': ('tigge',),
'tiggende': ('tigge',),
'tigget': ('tigge',),
'tiggete': ('tigge',),
'tigret': ('tigret',),
'tigrete': ('tigret',),
'tigretere': ('tigret',),
'tigretest': ('tigret',),
'tigreteste': ('tigret',),
'tigrete': ('tigrete',),
'tikka': ('tikke',),
'tikkede': ('tikke',),
'tikkende': ('tikke',),
'tikket': ('tikke',),
'tikkete': ('tikke',),
'tikka': ('tikke',),
'tikkede': ('tikke',),
'tikkende': ('tikke',),
'tikket': ('tikke',),
'tikkete': ('tikke',),
'tiksotrop': ('tiksotrop',),
'tiksotrope': ('tiksotrop',),
'tiksotropere': ('tiksotrop',),
'tiksotropest': ('tiksotrop',),
'tiksotropeste': ('tiksotrop',),
'tiksotropt': ('tiksotrop',),
'tiksotropisk': ('tiksotropisk',),
'tiksotropiske': ('tiksotropisk',),
'tiksotropiskere': ('tiksotropisk',),
'tiksotropiskest': ('tiksotropisk',),
'tiksotropiskeste': ('tiksotropisk',),
'tilbakebetalende': ('tilbakebetale',),
'tilbakebetalt': ('tilbakebetale',),
'tilbakebetalte': ('tilbakebetale',),
'tilbakeførende': ('tilbakeføre',),
'tilbakeført': ('tilbakeføre',),
'tilbakeførte': ('tilbakeføre',),
'tilbakeholden': ('tilbakeholden',),
'tilbakeholdent': ('tilbakeholden',),
'tilbakeholdne': ('tilbakeholden',),
'tilbakeholdnere': ('tilbakeholden',),
'tilbakeholdnest': ('tilbakeholden',),
'tilbakeholdneste': ('tilbakeholden',),
'tilbakekallende': ('tilbakekalle',),
'tilbakekalt': ('tilbakekalle',),
'tilbakekalte': ('tilbakekalle',),
'tilbakelagt': ('tilbakelegge',),
'tilbakelagte': ('tilbakelegge',),
'tilbakeleggende': ('tilbakelegge',),
'tilbakeliggende': ('tilbakeliggende',),
'tilbakestående': ('tilbakestående',),
'tilbaketrukket': ('tilbaketrukket',),
'tilbaketrukne': ('tilbaketrukket',),
'tilbaketruknere': ('tilbaketrukket',),
'tilbaketruknest': ('tilbaketrukket',),
'tilbaketrukneste': ('tilbaketrukket',),
'tilbakevendende': ('tilbakevendende',),
'tilbakevirkende': ('tilbakevirkende',),
'tilbakevisende': ('tilbakevise',),
'tilbakevist': ('tilbakevise',),
'tilbakeviste': ('tilbakevise',),
'tilbedt': ('tilbe',),
'tilbedte': ('tilbe',),
'tilbeende': ('tilbe',),
'tilberedende': ('tilberede',),
'tilberedt': ('tilberede',),
'tilberedte': ('tilberede',),
'tilbragt': ('tilbringe',),
'tilbragte': ('tilbringe',),
'tilbrakt': ('tilbringe',),
'tilbrakte': ('tilbringe',),
'tilbringende': ('tilbringe',),
'tilbørlig': ('tilbørlig',),
'tilbørlige': ('tilbørlig',),
'tilbørligere': ('tilbørlig',),
'tilbørligst': ('tilbørlig',),
'tilbørligste': ('tilbørlig',),
'tilbøyelig': ('tilbøyelig',),
'tilbøyelige': ('tilbøyelig',),
'tilbøyeligere': ('tilbøyelig',),
'tilbøyeligst': ('tilbøyelig',),
'tilbøyeligste': ('tilbøyelig',),
'tildekka': ('tildekke',),
'tildekkede': ('tildekke',),
'tildekkende': ('tildekke',),
'tildekket': ('tildekke',),
'tildekkete': ('tildekke',),
'tildekt': ('tildekke',),
'tildekte': ('tildekke',),
'tildelende': ('tildele',),
'tildelt': ('tildele',),
'tildelte': ('tildele',),
'tildømmende': ('tildømme',),
'tildømt': ('tildømme',),
'tildømte': ('tildømme',),
'tilegna': ('tilegne',),
'tilegnede': ('tilegne',),
'tilegnende': ('tilegne',),
'tilegnet': ('tilegne',),
'tilegnete': ('tilegne',),
'tilendebragt': ('tilendebringe',),
'tilendebragte': ('tilendebringe',),
'tilendebrakt': ('tilendebringe',),
'tilendebrakte': ('tilendebringe',),
'tilendebringende': ('tilendebringe',),
'tilfallende': ('tilfalle',),
'tilfalt': ('tilfalle',),
'tilfalte': ('tilfalle',),
'tilfeldig': ('tilfeldig',),
'tilfeldige': ('tilfeldig',),
'tilfeldigere': ('tilfeldig',),
'tilfeldigst': ('tilfeldig',),
'tilfeldigste': ('tilfeldig',),
'tilflytende': ('tilflyte',),
'tilflytt': ('tilflyte',),
'tilflytte': ('tilflyte',),
'tilforlatelig': ('tilforlatelig',),
'tilforlatelige': ('tilforlatelig',),
'tilforlateligere': ('tilforlatelig',),
'tilforlateligst': ('tilforlatelig',),
'tilforlateligste': ('tilforlatelig',),
'tilfreds': ('tilfreds',),
'tilfredse': ('tilfreds',),
'tilfredsere': ('tilfreds',),
'tilfredsest': ('tilfreds',),
'tilfredseste': ('tilfreds',),
'tilfredsstillende': ('tilfredsstille',),
'tilfredsstilt': ('tilfredsstille',),
'tilfredsstilte': ('tilfredsstille',),
'tilfrosne': ('tilfryse',),
'tilfrossen': ('tilfryse',),
'tilfrosset': ('tilfryse',),
'tilfryse': ('tilfryse',),
'tilfrysende': ('tilfryse',),
'tilfykende': ('tilfyke',),
'tilføken': ('tilfyke',),
'tilføket': ('tilfyke',),
'tilføkne': ('tilfyke',),
'tilførende': ('tilføre',),
'tilført': ('tilføre',),
'tilførte': ('tilføre',),
'tilføya': ('tilføye',),
'tilføyd': ('tilføye',),
'tilføyde': ('tilføye',),
'tilføyede': ('tilføye',),
'tilføyende': ('tilføye',),
'tilføyet': ('tilføye',),
'tilføyete': ('tilføye',),
'tilgiende': ('tilgi',),
'tilgitt': ('tilgi',),
'tilgitte': ('tilgi',),
'tilgivende': ('tilgi',),
'tilgivelig': ('tilgivelig',),
'tilgivelige': ('tilgivelig',),
'tilgiveligere': ('tilgivelig',),
'tilgiveligst': ('tilgivelig',),
'tilgiveligste': ('tilgivelig',),
'tilgjengelig': ('tilgjengelig',),
'tilgjengelige': ('tilgjengelig',),
'tilgjengeligere': ('tilgjengelig',),
'tilgjengeligst': ('tilgjengelig',),
'tilgjengeligste': ('tilgjengelig',),
'tilgjort': ('tilgjort',),
'tilgjorte': ('tilgjort',),
'tilgjortere': ('tilgjort',),
'tilgjortest': ('tilgjort',),
'tilgjorteste': ('tilgjort',),
'tilgodeseende': ('tilgodese',),
'tilgodesett': ('tilgodese',),
'tilgodesette': ('tilgodese',),
'tilgrensende': ('tilgrensende',),
'tilgrisa': ('tilgrise',),
'tilgrisede': ('tilgrise',),
'tilgrisende': ('tilgrise',),
'tilgriset': ('tilgrise',),
'tilgrisete': ('tilgrise',),
'tilgrist': ('tilgrise',),
'tilgriste': ('tilgrise',),
'tilgrodd': ('tilgro',),
'tilgrodde': ('tilgro',),
'tilgroende': ('tilgro',),
'tilhogd': ('tilhogge',),
'tilhogde': ('tilhogge',),
'tilhoggede': ('tilhogge',),
'tilhoggende': ('tilhogge',),
'tilhogget': ('tilhogge',),
'tilhoggete': ('tilhogge',),
'tilholdende': ('tilholde',),
'tilholdt': ('tilholde',),
'tilholdte': ('tilholde',),
'tilhugd': ('tilhugge',),
'tilhugde': ('tilhugge',),
'tilhugga': ('tilhugge',),
'tilhuggede': ('tilhugge',),
'tilhuggende': ('tilhugge',),
'tilhugget': ('tilhugge',),
'tilhuggete': ('tilhugge',),
'tilhylla': ('tilhylle',),
'tilhyllede': ('tilhylle',),
'tilhyllende': ('tilhylle',),
'tilhyllet': ('tilhylle',),
'tilhyllete': ('tilhylle',),
'tilhørende': ('tilhøre',),
'tilhørt': ('tilhøre',),
'tilhørte': ('tilhøre',),
'tilintetgjort': ('tilintetgjøre',),
'tilintetgjorte': ('tilintetgjøre',),
'tilintetgjørende': ('tilintetgjøre',),
'tiljamna': ('tiljamne',),
'tiljamnede': ('tiljamne',),
'tiljamnende': ('tiljamne',),
'tiljamnet': ('tiljamne',),
'tiljamnete': ('tiljamne',),
'tiljevna': ('tiljevne',),
'tiljevnede': ('tiljevne',),
'tiljevnende': ('tiljevne',),
'tiljevnet': ('tiljevne',),
'tiljevnete': ('tiljevne',),
'tiljubla': ('tiljuble',),
'tiljublede': ('tiljuble',),
'tiljublende': ('tiljuble',),
'tiljublet': ('tiljuble',),
'tiljublete': ('tiljuble',),
'tilkallende': ('tilkalle',),
'tilkalt': ('tilkalle',),
'tilkalte': ('tilkalle',),
'tilkjempa': ('tilkjempe',),
'tilkjempede': ('tilkjempe',),
'tilkjempende': ('tilkjempe',),
'tilkjempet': ('tilkjempe',),
'tilkjempete': ('tilkjempe',),
'tilkjennende': ('tilkjenne',),
'tilkjent': ('tilkjenne',),
'tilkjente': ('tilkjenne',),
'tilkjennegiende': ('tilkjennegi',),
'tilkjennegitt': ('tilkjennegi',),
'tilkjennegitte': ('tilkjennegi',),
'tilkjennegivende': ('tilkjennegi',),
'tilkjørende': ('tilkjøre',),
'tilkjørt': ('tilkjøre',),
'tilkjørte': ('tilkjøre',),
'tilklinende': ('tilkline',),
'tilklint': ('tilkline',),
'tilklinte': ('tilkline',),
'tilknappa': ('tilknappa',),
'tilknappede': ('tilknappet',),
'tilknappet': ('tilknappet',),
'tilknappete': ('tilknappet',),
'tilknappetere': ('tilknappet',),
'tilknappetest': ('tilknappet',),
'tilknappeteste': ('tilknappet',),
'tilknytta': ('tilknytte',),
'tilknyttede': ('tilknytte',),
'tilknyttende': ('tilknytte',),
'tilknyttet': ('tilknytte',),
'tilknyttete': ('tilknytte',),
'tilkobla': ('tilkoble',),
'tilkoblede': ('tilkoble',),
'tilkoblende': ('tilkoble',),
'tilkoblet': ('tilkoble',),
'tilkoblete': ('tilkoble',),
'tilkommen': ('tilkomme',),
'tilkommende': ('tilkomme',),
'tilkommet': ('tilkomme',),
'tilkomne': ('tilkomme',),
'tilkommende': ('tilkommende',),
'tilkopla': ('tilkople',),
'tilkoplede': ('tilkople',),
'tilkoplende': ('tilkople',),
'tilkoplet': ('tilkople',),
'tilkoplete': ('tilkople',),
'tillaga': ('tillage',),
'tillagd': ('tillage',),
'tillagde': ('tillage',),
'tillagede': ('tillage',),
'tillagende': ('tillage',),
'tillaget': ('tillage',),
'tillagete': ('tillage',),
'tillatende': ('tillate',),
'tillatt': ('tillate',),
'tillatte': ('tillate',),
'tillatelig': ('tillatelig',),
'tillatelige': ('tillatelig',),
'tillateligere': ('tillatelig',),
'tillateligst': ('tillatelig',),
'tillateligste': ('tillatelig',),
'tillagt': ('tillegge',),
'tillagte': ('tillegge',),
'tilleggende': ('tillegge',),
'tillempa': ('tillempe',),
'tillempede': ('tillempe',),
'tillempende': ('tillempe',),
'tillempet': ('tillempe',),
'tillempete': ('tillempe',),
'tilliggen': ('tilligge',),
'tilliggende': ('tilligge',),
'tilligget': ('tilligge',),
'tilligne': ('tilligge',),
'tillitsfull': ('tillitsfull',),
'tillitsfulle': ('tillitsfull',),
'tillitsfullere': ('tillitsfull',),
'tillitsfullest': ('tillitsfull',),
'tillitsfulleste': ('tillitsfull',),
'tillitsfullt': ('tillitsfull',),
'tillitsvalgt': ('tillitsvalgt',),
'tillitsvalgte': ('tillitsvalgt',),
'tillitsvalgtere': ('tillitsvalgt',),
'tillitsvalgtest': ('tillitsvalgt',),
'tillitsvalgteste': ('tillitsvalgt',),
'tillitvekkende': ('tillitvekkende',),
'tillokkende': ('tillokkende',),
'tillukka': ('tillukka',),
'tillukkede': ('tillukket',),
'tillukket': ('tillukket',),
'tillukkete': ('tillukket',),
'tillukketere': ('tillukket',),
'tillukketest': ('tillukket',),
'tillukketeste': ('tillukket',),
'tillysende': ('tillyse',),
'tillyst': ('tillyse',),
'tillyste': ('tillyse',),
'tillært': ('tillært',),
'tillærte': ('tillært',),
'tillærtere': ('tillært',),
'tillærtest': ('tillært',),
'tillærteste': ('tillært',),
'tilmålende': ('tilmåle',),
'tilmålt': ('tilmåle',),
'tilmålte': ('tilmåle',),
'tilnærma': ('tilnærme',),
'tilnærmede': ('tilnærme',),
'tilnærmende': ('tilnærme',),
'tilnærmet': ('tilnærme',),
'tilnærmete': ('tilnærme',),
'tiloversblitt': ('tiloversblitt',),
'tiloversblitte': ('tiloversblitt',),
'tiloversblittere': ('tiloversblitt',),
'tiloversblittest': ('tiloversblitt',),
'tiloversblitteste': ('tiloversblitt',),
'tilpassa': ('tilpasse',),
'tilpassede': ('tilpasse',),
'tilpassende': ('tilpasse',),
'tilpasset': ('tilpasse',),
'tilpassete': ('tilpasse',),
'tilplanta': ('tilplante',),
'tilplantede': ('tilplante',),
'tilplantende': ('tilplante',),
'tilplantet': ('tilplante',),
'tilplantete': ('tilplante',),
'tilrana': ('tilrane',),
'tilranede': ('tilrane',),
'tilranende': ('tilrane',),
'tilranet': ('tilrane',),
'tilranete': ('tilrane',),
'tilrant': ('tilrane',),
'tilrante': ('tilrane',),
'tilreda': ('tilrede',),
'tilredede': ('tilrede',),
'tilredende': ('tilrede',),
'tilredet': ('tilrede',),
'tilredete': ('tilrede',),
'tilregnelig': ('tilregnelig',),
'tilregnelige': ('tilregnelig',),
'tilregneligere': ('tilregnelig',),
'tilregneligst': ('tilregnelig',),
'tilregneligste': ('tilregnelig',),
'tilreisende': ('tilreisende',),
'tilreknelig': ('tilreknelig',),
'tilreknelige': ('tilreknelig',),
'tilrekneligere': ('tilreknelig',),
'tilrekneligst': ('tilreknelig',),
'tilrekneligste': ('tilreknelig',),
'tilrettelagt': ('tilrettelegge',),
'tilrettelagte': ('tilrettelegge',),
'tilretteleggende': ('tilrettelegge',),
'tilrettevisende': ('tilrettevise',),
'tilrettevist': ('tilrettevise',),
'tilretteviste': ('tilrettevise',),
'tilreven': ('tilrive',),
'tilrevet': ('tilrive',),
'tilrevne': ('tilrive',),
'tilrivende': ('tilrive',),
'tilrådd': ('tilrå',),
'tilrådde': ('tilrå',),
'tilrående': ('tilrå',),
'tilråda': ('tilråde',),
'tilrådd': ('tilråde',),
'tilrådde': ('tilråde',),
'tilrådede': ('tilråde',),
'tilrådende': ('tilråde',),
'tilrådet': ('tilråde',),
'tilrådete': ('tilråde',),
'tilrådelig': ('tilrådelig',),
'tilrådelige': ('tilrådelig',),
'tilrådeligere': ('tilrådelig',),
'tilrådeligst': ('tilrådelig',),
'tilrådeligste': ('tilrådelig',),
'tilsendende': ('tilsende',),
'tilsendt': ('tilsende',),
'tilsendte': ('tilsende',),
'tilsatt': ('tilsette',),
'tilsatte': ('tilsette',),
'tilsettende': ('tilsette',),
'tilsagt': ('tilsi',),
'tilsagte': ('tilsi',),
'tilsiende': ('tilsi',),
'tilsidesatt': ('tilsidesette',),
'tilsidesatte': ('tilsidesette',),
'tilsidesettende': ('tilsidesette',),
'tilsikta': ('tilsikte',),
'tilsiktede': ('tilsikte',),
'tilsiktende': ('tilsikte',),
'tilsiktet': ('tilsikte',),
'tilsiktete': ('tilsikte',),
'tilskadekommen': ('tilskadekommen',),
'tilskadekommet': ('tilskadekommen',),
'tilskadekomne': ('tilskadekommen',),
'tilskadekomnere': ('tilskadekommen',),
'tilskadekomnest': ('tilskadekommen',),
'tilskadekomneste': ('tilskadekommen',),
'tilskadekommet': ('tilskadekommet',),
'tilskadekommne': ('tilskadekommet',),
'tilskadekommnere': ('tilskadekommet',),
'tilskadekommnest': ('tilskadekommet',),
'tilskadekommneste': ('tilskadekommet',),
'tilskapt': ('tilskapt',),
'tilskapte': ('tilskapt',),
'tilskaptere': ('tilskapt',),
'tilskaptest': ('tilskapt',),
'tilskapteste': ('tilskapt',),
'tilskitna': ('tilskitna',),
'tilskitnede': ('tilskitnet',),
'tilskitnet': ('tilskitnet',),
'tilskitnete': ('tilskitnet',),
'tilskitnetere': ('tilskitnet',),
'tilskitnetest': ('tilskitnet',),
'tilskitneteste': ('tilskitnet',),
'tilskjøta': ('tilskjøte',),
'tilskjøtede': ('tilskjøte',),
'tilskjøtende': ('tilskjøte',),
'tilskjøtet': ('tilskjøte',),
'tilskjøtete': ('tilskjøte',),
'tilskjøtt': ('tilskjøte',),
'tilskjøtte': ('tilskjøte',),
'tilskreven': ('tilskrive',),
'tilskrevet': ('tilskrive',),
'tilskrevne': ('tilskrive',),
'tilskrivende': ('tilskrive',),
'tilskya': ('tilskye',),
'tilskyede': ('tilskye',),
'tilskyende': ('tilskye',),
'tilskyet': ('tilskye',),
'tilskyete': ('tilskye',),
'tilskynda': ('tilskynde',),
'tilskyndede': ('tilskynde',),
'tilskyndende': ('tilskynde',),
'tilskyndet': ('tilskynde',),
'tilskyndete': ('tilskynde',),
'tilskyndt': ('tilskynde',),
'tilskyndte': ('tilskynde',),
'tilslutta': ('tilslutte',),
'tilsluttede': ('tilslutte',),
'tilsluttende': ('tilslutte',),
'tilsluttet': ('tilslutte',),
'tilsluttete': ('tilslutte',),
'tilsløra': ('tilsløre',),
'tilslørede': ('tilsløre',),
'tilslørende': ('tilsløre',),
'tilsløret': ('tilsløre',),
'tilslørete': ('tilsløre',),
'tilslørt': ('tilsløre',),
'tilslørte': ('tilsløre',),
'tilsmussa': ('tilsmusse',),
'tilsmussede': ('tilsmusse',),
'tilsmussende': ('tilsmusse',),
'tilsmusset': ('tilsmusse',),
'tilsmussete': ('tilsmusse',),
'tilsmurt': ('tilsmøre',),
'tilsmurte': ('tilsmøre',),
'tilsmørende': ('tilsmøre',),
'tilsnakka': ('tilsnakke',),
'tilsnakkede': ('tilsnakke',),
'tilsnakkende': ('tilsnakke',),
'tilsnakket': ('tilsnakke',),
'tilsnakkete': ('tilsnakke',),
'tilsneken': ('tilsnike',),
'tilsneket': ('tilsnike',),
'tilsnekne': ('tilsnike',),
'tilsnikende': ('tilsnike',),
'tilspissa': ('tilspisse',),
'tilspissede': ('tilspisse',),
'tilspissende': ('tilspisse',),
'tilspisset': ('tilspisse',),
'tilspissete': ('tilspisse',),
'tilstedende': ('tilstede',),
'tilstedt': ('tilstede',),
'tilstedte': ('tilstede',),
'tilstedeværende': ('tilstedeværende',),
'tilstillende': ('tilstille',),
'tilstilt': ('tilstille',),
'tilstilte': ('tilstille',),
'tilstoppa': ('tilstoppe',),
'tilstoppede': ('tilstoppe',),
'tilstoppende': ('tilstoppe',),
'tilstoppet': ('tilstoppe',),
'tilstoppete': ('tilstoppe',),
'tilstreba': ('tilstrebe',),
'tilstrebede': ('tilstrebe',),
'tilstrebende': ('tilstrebe',),
'tilstrebet': ('tilstrebe',),
'tilstrebete': ('tilstrebe',),
'tilstrekkelig': ('tilstrekkelig',),
'tilstrekkelige': ('tilstrekkelig',),
'tilstrekkeligere': ('tilstrekkelig',),
'tilstrekkeligst': ('tilstrekkelig',),
'tilstrekkeligste': ('tilstrekkelig',),
'tilstundende': ('tilstundende',),
'tilstående': ('tilstå',),
'tilstått': ('tilstå',),
'tilståtte': ('tilstå',),
'tilstøtende': ('tilstøte',),
'tilstøtt': ('tilstøte',),
'tilstøtte': ('tilstøte',),
'tilstøytende': ('tilstøyte',),
'tilstøytt': ('tilstøyte',),
'tilstøytte': ('tilstøyte',),
'tilsvina': ('tilsvine',),
'tilsvinede': ('tilsvine',),
'tilsvinende': ('tilsvine',),
'tilsvinet': ('tilsvine',),
'tilsvinete': ('tilsvine',),
'tilsvint': ('tilsvine',),
'tilsvinte': ('tilsvine',),
'tilsynelatende': ('tilsynelatende',),
'tilsådd': ('tilså',),
'tilsådde': ('tilså',),
'tilsående': ('tilså',),
'tilsølende': ('tilsøle',),
'tilsølt': ('tilsøle',),
'tilsølte': ('tilsøle',),
'tiltakende': ('tilta',),
'tiltatt': ('tilta',),
'tiltatte': ('tilta',),
'tiltagende': ('tiltagende',),
'tiltakende': ('tiltakende',),
'tiltakslaus': ('tiltakslaus',),
'tiltakslause': ('tiltakslaus',),
'tiltakslausere': ('tiltakslaus',),
'tiltakslausest': ('tiltakslaus',),
'tiltakslauseste': ('tiltakslaus',),
'tiltakslaust': ('tiltakslaus',),
'tiltakslysten': ('tiltakslysten',),
'tiltakslystent': ('tiltakslysten',),
'tiltakslystne': ('tiltakslysten',),
'tiltakslystnere': ('tiltakslysten',),
'tiltakslystnest': ('tiltakslysten',),
'tiltakslystneste': ('tiltakslysten',),
'tiltaksløs': ('tiltaksløs',),
'tiltaksløse': ('tiltaksløs',),
'tiltaksløsere': ('tiltaksløs',),
'tiltaksløsest': ('tiltaksløs',),
'tiltaksløseste': ('tiltaksløs',),
'tiltaksløst': ('tiltaksløs',),
'tiltaksom': ('tiltaksom',),
'tiltaksomme': ('tiltaksom',),
'tiltaksommere': ('tiltaksom',),
'tiltaksomst': ('tiltaksom',),
'tiltaksomste': ('tiltaksom',),
'tiltaksomt': ('tiltaksom',),
'tiltala': ('tiltale',),
'tiltalende': ('tiltale',),
'tiltalt': ('tiltale',),
'tiltalte': ('tiltale',),
'tiltenkende': ('tiltenke',),
'tiltenkt': ('tiltenke',),
'tiltenkte': ('tiltenke',),
'tiltredende': ('tiltre',),
'tiltrådt': ('tiltre',),
'tiltrådte': ('tiltre',),
'tiltrekkende': ('tiltrekke',),
'tiltrukken': ('tiltrekke',),
'tiltrukket': ('tiltrekke',),
'tiltrukne': ('tiltrekke',),
'tiltrengt': ('tiltrengt',),
'tiltrengte': ('tiltrengt',),
'tiltrengtere': ('tiltrengt',),
'tiltrengtest': ('tiltrengt',),
'tiltrengteste': ('tiltrengt',),
'tiltrodd': ('tiltro',),
'tiltrodde': ('tiltro',),
'tiltroende': ('tiltro',),
'tiltvingende': ('tiltvinge',),
'tiltvungen': ('tiltvinge',),
'tiltvunget': ('tiltvinge',),
'tiltvungne': ('tiltvinge',),
'tilvant': ('tilvant',),
'tilvante': ('tilvant',),
'tilvantere': ('tilvant',),
'tilvantest': ('tilvant',),
'tilvanteste': ('tilvant',),
'tilvendende': ('tilvende',),
'tilvendt': ('tilvende',),
'tilvendte': ('tilvende',),
'tilvenna': ('tilvenne',),
'tilvennede': ('tilvenne',),
'tilvennende': ('tilvenne',),
'tilvennet': ('tilvenne',),
'tilvennete': ('tilvenne',),
'tilvent': ('tilvenne',),
'tilvente': ('tilvenne',),
'tilvirka': ('tilvirke',),
'tilvirkede': ('tilvirke',),
'tilvirkende': ('tilvirke',),
'tilvirket': ('tilvirke',),
'tilvirkete': ('tilvirke',),
'tilvisende': ('tilvise',),
'tilvist': ('tilvise',),
'tilviste': ('tilvise',),
'tilårskommen': ('tilårskommen',),
'tilårskommet': ('tilårskommen',),
'tilårskomne': ('tilårskommen',),
'tilårskomnere': ('tilårskommen',),
'tilårskomnest': ('tilårskommen',),
'tilårskomneste': ('tilårskommen',),
'tilårskommet': ('tilårskommet',),
'tilårskomne': ('tilårskommet',),
'tilårskomnere': ('tilårskommet',),
'tilårskomnest': ('tilårskommet',),
'tilårskomneste': ('tilårskommet',),
'tima': ('time',),
'timede': ('time',),
'timende': ('time',),
'timet': ('time',),
'timete': ('time',),
'timelang': ('timelang',),
'timelange': ('timelang',),
'timelangt': ('timelang',),
'timelenger': ('timelang',),
'timelengre': ('timelang',),
'timelengst': ('timelang',),
'timelengste': ('timelang',),
'timelig': ('timelig',),
'timelige': ('timelig',),
'timeligere': ('timelig',),
'timeligst': ('timelig',),
'timeligste': ('timelig',),
'timelønna': ('timelønna',),
'timelønnede': ('timelønnet',),
'timelønnet': ('timelønnet',),
'timelønnete': ('timelønnet',),
'timelønnetere': ('timelønnet',),
'timelønnetest': ('timelønnet',),
'timelønneteste': ('timelønnet',),
'timelønt': ('timelønt',),
'timelønte': ('timelønt',),
'timeløntere': ('timelønt',),
'timeløntest': ('timelønt',),
'timelønteste': ('timelønt',),
'timid': ('timid',),
'timide': ('timid',),
'timidere': ('timid',),
'timidest': ('timid',),
'timideste': ('timid',),
'tinda': ('tinde',),
'tindede': ('tinde',),
'tindende': ('tinde',),
'tindet': ('tinde',),
'tindete': ('tinde',),
'tindra': ('tindre',),
'tindrede': ('tindre',),
'tindrende': ('tindre',),
'tindret': ('tindre',),
'tindrete': ('tindre',),
'tina': ('tine',),
'tinede': ('tine',),
'tinende': ('tine',),
'tinet': ('tine',),
'tinete': ('tine',),
'tint': ('tine',),
'tinte': ('tine',),
'tina': ('tine',),
'tinede': ('tine',),
'tinende': ('tine',),
'tinet': ('tine',),
'tinete': ('tine',),
'tint': ('tine',),
'tinte': ('tine',),
'tinga': ('tinge',),
'tingede': ('tinge',),
'tingende': ('tinge',),
'tinget': ('tinge',),
'tingete': ('tinge',),
'tingliggjort': ('tingliggjøre',),
'tingliggjorte': ('tingliggjøre',),
'tingliggjørende': ('tingliggjøre',),
'tinglysende': ('tinglyse',),
'tinglyst': ('tinglyse',),
'tinglyste': ('tinglyse',),
'tinkla': ('tinkle',),
'tinklede': ('tinkle',),
'tinklende': ('tinkle',),
'tinklet': ('tinkle',),
'tinklete': ('tinkle',),
'tipla': ('tiple',),
'tiplede': ('tiple',),
'tiplende': ('tiple',),
'tiplet': ('tiple',),
'tiplete': ('tiple',),
'tipp topp': ('tipp topp',),
'tippbar': ('tippbar',),
'tippbare': ('tippbar',),
'tippbarere': ('tippbar',),
'tippbarest': ('tippbar',),
'tippbareste': ('tippbar',),
'tippbart': ('tippbar',),
'tippa': ('tippe',),
'tippede': ('tippe',),
'tippende': ('tippe',),
'tippet': ('tippe',),
'tippete': ('tippe',),
'tippa': ('tippe',),
'tippede': ('tippe',),
'tippende': ('tippe',),
'tippet': ('tippe',),
'tippete': ('tippe',),
'tippa': ('tippe',),
'tippede': ('tippe',),
'tippende': ('tippe',),
'tippet': ('tippe',),
'tippete': ('tippe',),
'tipsa': ('tipse',),
'tipsede': ('tipse',),
'tipsende': ('tipse',),
'tipset': ('tipse',),
'tipsete': ('tipse',),
'tirra': ('tirre',),
'tirrede': ('tirre',),
'tirrende': ('tirre',),
'tirret': ('tirre',),
'tirrete': ('tirre',),
'tiska': ('tiske',),
'tiskede': ('tiske',),
'tiskende': ('tiske',),
'tisket': ('tiske',),
'tiskete': ('tiske',),
'tisla': ('tisle',),
'tislede': ('tisle',),
'tislende': ('tisle',),
'tislet': ('tisle',),
'tislete': ('tisle',),
'tissa': ('tisse',),
'tissede': ('tisse',),
'tissende': ('tisse',),
'tisset': ('tisse',),
'tissete': ('tisse',),
'tissetrengt': ('tissetrengt',),
'tissetrengte': ('tissetrengt',),
'tissetrengtere': ('tissetrengt',),
'tissetrengtest': ('tissetrengt',),
'tissetrengteste': ('tissetrengt',),
'tistret': ('tistret',),
'tistrete': ('tistret',),
'tistretere': ('tistret',),
'tistretest': ('tistret',),
'tistreteste': ('tistret',),
'tistrete': ('tistrete',),
'titalls': ('titalls',),
'titals': ('titals',),
'titanisk': ('titanisk',),
'titaniske': ('titanisk',),
'titaniskere': ('titanisk',),
'titaniskest': ('titanisk',),
'titaniskeste': ('titanisk',),
'titoistisk': ('titoistisk',),
'titoistiske': ('titoistisk',),
'titoistiskere': ('titoistisk',),
'titoistiskest': ('titoistisk',),
'titoistiskeste': ('titoistisk',),
'titrerende': ('titrere',),
'titrert': ('titrere',),
'titrerte': ('titrere',),
'tiere': ('titt',),
'tiest': ('titt',),
'titt': ('titt',),
'titta': ('titte',),
'tittede': ('titte',),
'tittende': ('titte',),
'tittet': ('titte',),
'tittete': ('titte',),
'titulerende': ('titulere',),
'titulert': ('titulere',),
'titulerte': ('titulere',),
'titulær': ('titulær',),
'titulære': ('titulær',),
'titulærere': ('titulær',),
'titulærest': ('titulær',),
'titulæreste': ('titulær',),
'titulært': ('titulær',),
'tiårig': ('tiårig',),
'tiårige': ('tiårig',),
'tiårigere': ('tiårig',),
'tiårigst': ('tiårig',),
'tiårigste': ('tiårig',),
'tiårs': ('tiårs',),
'tiøres': ('tiøres',),
'tjadra': ('tjadre',),
'tjadrede': ('tjadre',),
'tjadrende': ('tjadre',),
'tjadret': ('tjadre',),
'tjadrete': ('tjadre',),
'tjafsa': ('tjafse',),
'tjafsede': ('tjafse',),
'tjafsende': ('tjafse',),
'tjafset': ('tjafse',),
'tjafsete': ('tjafse',),
'tjafset': ('tjafset',),
'tjafsete': ('tjafset',),
'tjafsetere': ('tjafset',),
'tjafsetest': ('tjafset',),
'tjafseteste': ('tjafset',),
'tjafsete': ('tjafsete',),
'tjatra': ('tjatre',),
'tjatrede': ('tjatre',),
'tjatrende': ('tjatre',),
'tjatret': ('tjatre',),
'tjatrete': ('tjatre',),
'tjatta': ('tjatte',),
'tjattede': ('tjatte',),
'tjattende': ('tjatte',),
'tjattet': ('tjatte',),
'tjattete': ('tjatte',),
'tjelda': ('tjelde',),
'tjeldede': ('tjelde',),
'tjeldende': ('tjelde',),
'tjeldet': ('tjelde',),
'tjeldete': ('tjelde',),
'tjenende': ('tjene',),
'tjent': ('tjene',),
'tjente': ('tjene',),
'tjenende': ('tjenende',),
'tjenestedyktig': ('tjenestedyktig',),
'tjenestedyktige': ('tjenestedyktig',),
'tjenestedyktigere': ('tjenestedyktig',),
'tjenestedyktigst': ('tjenestedyktig',),
'tjenestedyktigste': ('tjenestedyktig',),
'tjenestegjort': ('tjenestegjøre',),
'tjenestegjorte': ('tjenestegjøre',),
'tjenestegjørende': ('tjenestegjøre',),
'tjenestevillig': ('tjenestevillig',),
'tjenestevillige': ('tjenestevillig',),
'tjenestevilligere': ('tjenestevillig',),
'tjenestevilligst': ('tjenestevillig',),
'tjenestevilligste': ('tjenestevillig',),
'tjenesteytende': ('tjenesteytende',),
'tjenlig': ('tjenlig',),
'tjenlige': ('tjenlig',),
'tjenligere': ('tjenlig',),
'tjenligst': ('tjenlig',),
'tjenligste': ('tjenlig',),
'tjenstdyktig': ('tjenstdyktig',),
'tjenstdyktige': ('tjenstdyktig',),
'tjenstdyktigere': ('tjenstdyktig',),
'tjenstdyktigst': ('tjenstdyktig',),
'tjenstdyktigste': ('tjenstdyktig',),
'tjenstgjort': ('tjenstgjøre',),
'tjenstgjorte': ('tjenstgjøre',),
'tjenstgjørende': ('tjenstgjøre',),
'tjenstlig': ('tjenstlig',),
'tjenstlige': ('tjenstlig',),
'tjenstligere': ('tjenstlig',),
'tjenstligst': ('tjenstlig',),
'tjenstligste': ('tjenstlig',),
'tjenstvillig': ('tjenstvillig',),
'tjenstvillige': ('tjenstvillig',),
'tjenstvilligere': ('tjenstvillig',),
'tjenstvilligst': ('tjenstvillig',),
'tjenstvilligste': ('tjenstvillig',),
'tjokkfull': ('tjokkfull',),
'tjokkfulle': ('tjokkfull',),
'tjokkfullere': ('tjokkfull',),
'tjokkfullest': ('tjokkfull',),
'tjokkfulleste': ('tjokkfull',),
'tjokkfullt': ('tjokkfull',),
'tjona': ('tjone',),
'tjonede': ('tjone',),
'tjonende': ('tjone',),
'tjonet': ('tjone',),
'tjonete': ('tjone',),
'tjora': ('tjore',),
'tjorede': ('tjore',),
'tjorende': ('tjore',),
'tjoret': ('tjore',),
'tjorete': ('tjore',),
'tjort': ('tjore',),
'tjorte': ('tjore',),
'tjuende': ('tjuende',),
'tjueårig': ('tjueårig',),
'tjueårige': ('tjueårig',),
'tjueårigere': ('tjueårig',),
'tjueårigst': ('tjueårig',),
'tjueårigste': ('tjueårig',),
'tjukk': ('tjukk',),
'tjukke': ('tjukk',),
'tjukkere': ('tjukk',),
'tjukkest': ('tjukk',),
'tjukkeste': ('tjukk',),
'tjukt': ('tjukk',),
'tjukkfallen': ('tjukkfallen',),
'tjukkfallent': ('tjukkfallen',),
'tjukkfalne': ('tjukkfallen',),
'tjukkfalnere': ('tjukkfallen',),
'tjukkfalnest': ('tjukkfallen',),
'tjukkfalneste': ('tjukkfallen',),
'tjukkhuda': ('tjukkhuda',),
'tjukkhudede': ('tjukkhudet',),
'tjukkhudet': ('tjukkhudet',),
'tjukkhudete': ('tjukkhudet',),
'tjukkhudetere': ('tjukkhudet',),
'tjukkhudetest': ('tjukkhudet',),
'tjukkhudeteste': ('tjukkhudet',),
'tjukkskalla': ('tjukkskalla',),
'tjukkskallede': ('tjukkskallet',),
'tjukkskallet': ('tjukkskallet',),
'tjukkskallete': ('tjukkskallet',),
'tjukkskalletere': ('tjukkskallet',),
'tjukkskalletest': ('tjukkskallet',),
'tjukkskalleteste': ('tjukkskallet',),
'tjukna': ('tjukne',),
'tjuknede': ('tjukne',),
'tjuknende': ('tjukne',),
'tjuknet': ('tjukne',),
'tjuknete': ('tjukne',),
'tjuvaktig': ('tjuvaktig',),
'tjuvaktige': ('tjuvaktig',),
'tjuvaktigere': ('tjuvaktig',),
'tjuvaktigst': ('tjuvaktig',),
'tjuvaktigste': ('tjuvaktig',),
'tjuva': ('tjuve',),
'tjuvd': ('tjuve',),
'tjuvde': ('tjuve',),
'tjuvede': ('tjuve',),
'tjuvende': ('tjuve',),
'tjuvet': ('tjuve',),
'tjuvete': ('tjuve',),
'tjuvlytta': ('tjuvlytte',),
'tjuvlyttede': ('tjuvlytte',),
'tjuvlyttende': ('tjuvlytte',),
'tjuvlyttet': ('tjuvlytte',),
'tjuvlyttete': ('tjuvlytte',),
'tjuvlånende': ('tjuvlåne',),
'tjuvlånt': ('tjuvlåne',),
'tjuvlånte': ('tjuvlåne',),
'tjuvslakta': ('tjuvslakte',),
'tjuvslaktede': ('tjuvslakte',),
'tjuvslaktende': ('tjuvslakte',),
'tjuvslaktet': ('tjuvslakte',),
'tjuvslaktete': ('tjuvslakte',),
'tjuvstarta': ('tjuvstarte',),
'tjuvstartede': ('tjuvstarte',),
'tjuvstartende': ('tjuvstarte',),
'tjuvstartet': ('tjuvstarte',),
'tjuvstartete': ('tjuvstarte',),
'tjuvtitta': ('tjuvtitte',),
'tjuvtittede': ('tjuvtitte',),
'tjuvtittende': ('tjuvtitte',),
'tjuvtittet': ('tjuvtitte',),
'tjuvtittete': ('tjuvtitte',),
'tjuvtitta': ('tjuvtitte',),
'tjuvtittede': ('tjuvtitte',),
'tjuvtittende': ('tjuvtitte',),
'tjuvtittet': ('tjuvtitte',),
'tjuvtittete': ('tjuvtitte',),
'tjuvtrena': ('tjuvtrene',),
'tjuvtrenede': ('tjuvtrene',),
'tjuvtrenende': ('tjuvtrene',),
'tjuvtrenet': ('tjuvtrene',),
'tjuvtrenete': ('tjuvtrene',),
'tjuvtrent': ('tjuvtrene',),
'tjuvtrente': ('tjuvtrene',),
'tjåka': ('tjåke',),
'tjåkede': ('tjåke',),
'tjåkende': ('tjåke',),
'tjåket': ('tjåke',),
'tjåkete': ('tjåke',),
'tjæra': ('tjære',),
'tjærede': ('tjære',),
'tjærende': ('tjære',),
'tjæret': ('tjære',),
'tjærete': ('tjære',),
'tjærebredd': ('tjærebre',),
'tjærebredde': ('tjærebre',),
'tjærebreende': ('tjærebre',),
'toaksla': ('toaksla',),
'toakslede': ('toakslet',),
'toakslet': ('toakslet',),
'toakslete': ('toakslet',),
'toaksletere': ('toakslet',),
'toaksletest': ('toakslet',),
'toaksleteste': ('toakslet',),
'toakts': ('toakts',),
'toarma': ('toarma',),
'toarmede': ('toarmet',),
'toarmet': ('toarmet',),
'toarmete': ('toarmet',),
'toarmetere': ('toarmet',),
'toarmetest': ('toarmet',),
'toarmeteste': ('toarmet',),
'toasted': ('toasted',),
'tobagisk': ('tobagisk',),
'tobagiske': ('tobagisk',),
'tobagiskere': ('tobagisk',),
'tobagiskest': ('tobagisk',),
'tobagiskeste': ('tobagisk',),
'tobasisk': ('tobasisk',),
'tobasiske': ('tobasisk',),
'tobasiskere': ('tobasisk',),
'tobasiskest': ('tobasisk',),
'tobasiskeste': ('tobasisk',),
'todelt': ('todelt',),
'todelte': ('todelt',),
'todeltere': ('todelt',),
'todeltest': ('todelt',),
'todelteste': ('todelt',),
'todimensjonal': ('todimensjonal',),
'todimensjonale': ('todimensjonal',),
'todimensjonalere': ('todimensjonal',),
'todimensjonalest': ('todimensjonal',),
'todimensjonaleste': ('todimensjonal',),
'todimensjonalt': ('todimensjonal',),
'toa': ('toe',),
'toede': ('toe',),
'toende': ('toe',),
'toet': ('toe',),
'toete': ('toe',),
'toegga': ('toegga',),
'toegga': ('toegga',),
'toeggede': ('toegget',),
'toegget': ('toegget',),
'toeggete': ('toegget',),
'toeggetere': ('toegget',),
'toeggetest': ('toegget',),
'toeggeteste': ('toegget',),
'toeggede': ('toegget',),
'toegget': ('toegget',),
'toeggete': ('toegget',),
'toeggetere': ('toegget',),
'toeggetest': ('toegget',),
'toeggeteste': ('toegget',),
'toene': ('toene',),
'toetasjes': ('toetasjes',),
'tofags': ('tofags',),
'tofags': ('tofags',),
'tofelta': ('tofelta',),
'tofeltede': ('tofeltet',),
'tofeltet': ('tofeltet',),
'tofeltete': ('tofeltet',),
'tofeltetere': ('tofeltet',),
'tofeltetest': ('tofeltet',),
'tofelteteste': ('tofeltet',),
'tofelts': ('tofelts',),
'tofota': ('tofota',),
'tofotede': ('tofotet',),
'tofotet': ('tofotet',),
'tofotete': ('tofotet',),
'tofotetere': ('tofotet',),
'tofotetest': ('tofotet',),
'tofoteteste': ('tofotet',),
'toføtt': ('toføtt',),
'toføtte': ('toføtt',),
'toføttere': ('toføtt',),
'toføttest': ('toføtt',),
'toføtteste': ('toføtt',),
'toga': ('toge',),
'togede': ('toge',),
'togende': ('toge',),
'toget': ('toge',),
'togete': ('toge',),
'togolesisk': ('togolesisk',),
'togolesiske': ('togolesisk',),
'togolesiskere': ('togolesisk',),
'togolesiskest': ('togolesisk',),
'togolesiskeste': ('togolesisk',),
'tohendig': ('tohendig',),
'tohendige': ('tohendig',),
'tohendigere': ('tohendig',),
'tohendigst': ('tohendig',),
'tohendigste': ('tohendig',),
'tohjula': ('tohjula',),
'tohjulede': ('tohjulet',),
'tohjulet': ('tohjulet',),
'tohjulete': ('tohjulet',),
'tohjuletere': ('tohjulet',),
'tohjuletest': ('tohjulet',),
'tohjuleteste': ('tohjulet',),
'tohjuls': ('tohjuls',),
'tohjult': ('tohjult',),
'tohjulte': ('tohjult',),
'tohjultere': ('tohjult',),
'tohjultest': ('tohjult',),
'tohjulteste': ('tohjult',),
'tokarisk': ('tokarisk',),
'tokariske': ('tokarisk',),
'tokariskere': ('tokarisk',),
'tokariskest': ('tokarisk',),
'tokariskeste': ('tokarisk',),
'tokrets': ('tokrets',),
'toksikologisk': ('toksikologisk',),
'toksikologiske': ('toksikologisk',),
'toksikologiskere': ('toksikologisk',),
'toksikologiskest': ('toksikologisk',),
'toksikologiskeste': ('toksikologisk',),
'toksikoman': ('toksikoman',),
'toksikomane': ('toksikoman',),
'toksikomanere': ('toksikoman',),
'toksikomanest': ('toksikoman',),
'toksikomaneste': ('toksikoman',),
'toksikomant': ('toksikoman',),
'toksisk': ('toksisk',),
'toksiske': ('toksisk',),
'toksiskere': ('toksisk',),
'toksiskest': ('toksisk',),
'toksiskeste': ('toksisk',),
'tolerabel': ('tolerabel',),
'tolerabelt': ('tolerabel',),
'tolerable': ('tolerabel',),
'tolerablere': ('tolerabel',),
'tolerablest': ('tolerabel',),
'tolerableste': ('tolerabel',),
'tolerant': ('tolerant',),
'tolerante': ('tolerant',),
'tolerantere': ('tolerant',),
'tolerantest': ('tolerant',),
'toleranteste': ('tolerant',),
'tolererende': ('tolerere',),
'tolerert': ('tolerere',),
'tolererte': ('tolerere',),
'tolka': ('tolke',),
'tolkede': ('tolke',),
'tolkende': ('tolke',),
'tolket': ('tolke',),
'tolkete': ('tolke',),
'tollbehandla': ('tollbehandle',),
'tollbehandlede': ('tollbehandle',),
'tollbehandlende': ('tollbehandle',),
'tollbehandlet': ('tollbehandle',),
'tollbehandlete': ('tollbehandle',),
'tollpliktig': ('tollpliktig',),
'tollpliktige': ('tollpliktig',),
'tollpliktigere': ('tollpliktig',),
'tollpliktigst': ('tollpliktig',),
'tollpliktigste': ('tollpliktig',),
'tolvte': ('tolvte',),
'tolvårig': ('tolvårig',),
'tolvårige': ('tolvårig',),
'tolvårigere': ('tolvårig',),
'tolvårigst': ('tolvårig',),
'tolvårigste': ('tolvårig',),
'tolvårs': ('tolvårs',),
'toløpa': ('toløpa',),
'toløpede': ('toløpet',),
'toløpet': ('toløpet',),
'toløpete': ('toløpet',),
'toløpetere': ('toløpet',),
'toløpetest': ('toløpet',),
'toløpeteste': ('toløpet',),
'tom': ('tom',),
'tomme': ('tom',),
'tommere': ('tom',),
'tommest': ('tom',),
'tommeste': ('tom',),
'tomt': ('tom',),
'tomanns': ('tomanns',),
'tomannsbetjent': ('tomannsbetjent',),
'tomannsbetjente': ('tomannsbetjent',),
'tomannsbetjentere': ('tomannsbetjent',),
'tomannsbetjentest': ('tomannsbetjent',),
'tomannsbetjenteste': ('tomannsbetjent',),
'tomasta': ('tomasta',),
'tomastede': ('tomastet',),
'tomastet': ('tomastet',),
'tomastete': ('tomastet',),
'tomastetere': ('tomastet',),
'tomastetest': ('tomastet',),
'tomasteteste': ('tomastet',),
'tomatfarga': ('tomatfarga',),
'tomatfargede': ('tomatfarget',),
'tomatfarget': ('tomatfarget',),
'tomatfargete': ('tomatfarget',),
'tomatfargetere': ('tomatfarget',),
'tomatfargetest': ('tomatfarget',),
'tomatfargeteste': ('tomatfarget',),
'tomatrød': ('tomatrød',),
'tomatrøde': ('tomatrød',),
'tomatrødere': ('tomatrød',),
'tomatrødest': ('tomatrød',),
'tomatrødeste': ('tomatrød',),
'tomatrødt': ('tomatrød',),
'tomhendt': ('tomhendt',),
'tomhendte': ('tomhendt',),
'tomhendtere': ('tomhendt',),
'tomhendtest': ('tomhendt',),
'tomhendteste': ('tomhendt',),
'tomotors': ('tomotors',),
'tomsa': ('tomse',),
'tomsede': ('tomse',),
'tomsende': ('tomse',),
'tomset': ('tomse',),
'tomsete': ('tomse',),
'tomset': ('tomset',),
'tomsete': ('tomset',),
'tomsetere': ('tomset',),
'tomsetest': ('tomset',),
'tomseteste': ('tomset',),
'tomsete': ('tomsete',),
'tonal': ('tonal',),
'tonale': ('tonal',),
'tonalere': ('tonal',),
'tonalest': ('tonal',),
'tonaleste': ('tonal',),
'tonalt': ('tonal',),
'tona': ('tone',),
'tonede': ('tone',),
'tonende': ('tone',),
'tonet': ('tone',),
'tonete': ('tone',),
'tont': ('tone',),
'tonte': ('tone',),
'tona': ('tone',),
'tonede': ('tone',),
'tonende': ('tone',),
'tonet': ('tone',),
'tonete': ('tone',),
'tont': ('tone',),
'tonte': ('tone',),
'toneangivende': ('toneangivende',),
'tongansk': ('tongansk',),
'tonganske': ('tongansk',),
'tonganskere': ('tongansk',),
'tonganskest': ('tongansk',),
'tonganskeste': ('tongansk',),
'tonlaus': ('tonlaus',),
'tonlause': ('tonlaus',),
'tonlausere': ('tonlaus',),
'tonlausest': ('tonlaus',),
'tonlauseste': ('tonlaus',),
'tonlaust': ('tonlaus',),
'tonløs': ('tonløs',),
'tonløse': ('tonløs',),
'tonløsere': ('tonløs',),
'tonløsest': ('tonløs',),
'tonløseste': ('tonløs',),
'tonløst': ('tonløs',),
'topografisk': ('topografisk',),
'topografiske': ('topografisk',),
'topografiskere': ('topografisk',),
'topografiskest': ('topografisk',),
'topografiskeste': ('topografisk',),
'topologisk': ('topologisk',),
'topologiske': ('topologisk',),
'topologiskere': ('topologisk',),
'topologiskest': ('topologisk',),
'topologiskeste': ('topologisk',),
'topp': ('topp',),
'toppa': ('toppe',),
'toppede': ('toppe',),
'toppende': ('toppe',),
'toppet': ('toppe',),
'toppete': ('toppe',),
'topplaus': ('topplaus',),
'topplause': ('topplaus',),
'topplausere': ('topplaus',),
'topplausest': ('topplaus',),
'topplauseste': ('topplaus',),
'topplaust': ('topplaus',),
'toppløs': ('toppløs',),
'toppløse': ('toppløs',),
'toppløsere': ('toppløs',),
'toppløsest': ('toppløs',),
'toppløseste': ('toppløs',),
'toppløst': ('toppløs',),
'topptung': ('topptung',),
'topptunge': ('topptung',),
'topptungere': ('topptung',),
'topptungest': ('topptung',),
'topptungeste': ('topptung',),
'topptungt': ('topptung',),
'topptyngre': ('topptung',),
'topptyngst': ('topptung',),
'topptyngste': ('topptung',),
'topukla': ('topukla',),
'topuklede': ('topuklet',),
'topuklet': ('topuklet',),
'topuklete': ('topuklet',),
'topukletere': ('topuklet',),
'topukletest': ('topuklet',),
'topukleteste': ('topuklet',),
'tordna': ('tordne',),
'tordnede': ('tordne',),
'tordnende': ('tordne',),
'tordnet': ('tordne',),
'tordnete': ('tordne',),
'tornefull': ('tornefull',),
'tornefulle': ('tornefull',),
'tornefullere': ('tornefull',),
'tornefullest': ('tornefull',),
'tornefulleste': ('tornefull',),
'tornefullt': ('tornefull',),
'tornet': ('tornet',),
'tornete': ('tornet',),
'tornetere': ('tornet',),
'tornetest': ('tornet',),
'torneteste': ('tornet',),
'tornete': ('tornete',),
'toroms': ('toroms',),
'torpederende': ('torpedere',),
'torpedert': ('torpedere',),
'torpederte': ('torpedere',),
'torturerende': ('torturere',),
'torturert': ('torturere',),
'torturerte': ('torturere',),
'torva': ('torve',),
'torvede': ('torve',),
'torvende': ('torve',),
'torvet': ('torve',),
'torvete': ('torve',),
'tosidig': ('tosidig',),
'tosidige': ('tosidig',),
'tosidigere': ('tosidig',),
'tosidigst': ('tosidig',),
'tosidigste': ('tosidig',),
'tosifra': ('tosifra',),
'tosifrede': ('tosifret',),
'tosifret': ('tosifret',),
'tosifrete': ('tosifret',),
'tosifretere': ('tosifret',),
'tosifretest': ('tosifret',),
'tosifreteste': ('tosifret',),
'toskansk': ('toskansk',),
'toskanske': ('toskansk',),
'toskanskere': ('toskansk',),
'toskanskest': ('toskansk',),
'toskanskeste': ('toskansk',),
'tosket': ('tosket',),
'toskete': ('tosket',),
'tosketere': ('tosket',),
'tosketest': ('tosket',),
'tosketeste': ('tosket',),
'toskete': ('toskete',),
'tospråklig': ('tospråklig',),
'tospråklige': ('tospråklig',),
'tospråkligere': ('tospråklig',),
'tospråkligst': ('tospråklig',),
'tospråkligste': ('tospråklig',),
'tosset': ('tosset',),
'tossete': ('tosset',),
'tossetere': ('tosset',),
'tossetest': ('tosset',),
'tosseteste': ('tosset',),
'tossete': ('tossete',),
'tostavelses': ('tostavelses',),
'tostavings': ('tostavings',),
'tostemmig': ('tostemmig',),
'tostemmige': ('tostemmig',),
'tostemmigere': ('tostemmig',),
'tostemmigst': ('tostemmig',),
'tostemmigste': ('tostemmig',),
'tostrøken': ('tostrøken',),
'tostrøket': ('tostrøken',),
'tostrøkne': ('tostrøken',),
'tostrøknere': ('tostrøken',),
'tostrøknest': ('tostrøken',),
'tostrøkneste': ('tostrøken',),
'tostrøket': ('tostrøket',),
'tostrøkne': ('tostrøket',),
'tostrøknere': ('tostrøket',),
'tostrøknest': ('tostrøket',),
'tostrøkneste': ('tostrøket',),
'total': ('total',),
'totale': ('total',),
'totalere': ('total',),
'totalest': ('total',),
'totaleste': ('total',),
'totalt': ('total',),
'totalfreda': ('totalfrede',),
'totalfredede': ('totalfrede',),
'totalfredende': ('totalfrede',),
'totalfredet': ('totalfrede',),
'totalfredete': ('totalfrede',),
'totalitær': ('totalitær',),
'totalitære': ('totalitær',),
'totalitærere': ('totalitær',),
'totalitærest': ('totalitær',),
'totalitæreste': ('totalitær',),
'totalitært': ('totalitær',),
'totalskada': ('totalskade',),
'totalskadd': ('totalskade',),
'totalskadde': ('totalskade',),
'totalskadede': ('totalskade',),
'totalskadende': ('totalskade',),
'totalskadet': ('totalskade',),
'totalskadete': ('totalskade',),
'totoms': ('totoms',),
'toucha': ('touche',),
'touchede': ('touche',),
'touchende': ('touche',),
'touchet': ('touche',),
'touchete': ('touche',),
'tova': ('tove',),
'tovede': ('tove',),
'tovende': ('tove',),
'tovet': ('tove',),
'tovete': ('tove',),
'tovegs': ('tovegs',),
'toveis': ('toveis',),
'toverdig': ('toverdig',),
'toverdige': ('toverdig',),
'toverdigere': ('toverdig',),
'toverdigst': ('toverdig',),
'toverdigste': ('toverdig',),
'toårig': ('toårig',),
'toårige': ('toårig',),
'toårigere': ('toårig',),
'toårigst': ('toårig',),
'toårigste': ('toårig',),
'toårlig': ('toårlig',),
'toårlige': ('toårlig',),
'toårligere': ('toårlig',),
'toårligst': ('toårlig',),
'toårligste': ('toårlig',),
'toårs': ('toårs',),
'toøres': ('toøres',),
'trabelerende': ('trabelere',),
'trabelert': ('trabelere',),
'trabelerte': ('trabelere',),
'traca': ('trace',),
'tracede': ('trace',),
'tracende': ('trace',),
'tracet': ('trace',),
'tracete': ('trace',),
'traderende': ('tradere',),
'tradert': ('tradere',),
'traderte': ('tradere',),
'tradisjonalistisk': ('tradisjonalistisk',),
'tradisjonalistiske': ('tradisjonalistisk',),
'tradisjonalistiskere': ('tradisjonalistisk',),
'tradisjonalistiskest': ('tradisjonalistisk',),
'tradisjonalistiskeste': ('tradisjonalistisk',),
'tradisjonell': ('tradisjonell',),
'tradisjonelle': ('tradisjonell',),
'tradisjonellere': ('tradisjonell',),
'tradisjonellest': ('tradisjonell',),
'tradisjonelleste': ('tradisjonell',),
'tradisjonelt': ('tradisjonell',),
'tradisjonsbestemt': ('tradisjonsbestemt',),
'tradisjonsbestemte': ('tradisjonsbestemt',),
'tradisjonsbestemtere': ('tradisjonsbestemt',),
'tradisjonsbestemtest': ('tradisjonsbestemt',),
'tradisjonsbestemteste': ('tradisjonsbestemt',),
'tradisjonsbundet': ('tradisjonsbundet',),
'tradisjonsbundne': ('tradisjonsbundet',),
'tradisjonsbundnere': ('tradisjonsbundet',),
'tradisjonsbundnest': ('tradisjonsbundet',),
'tradisjonsbundneste': ('tradisjonsbundet',),
'tradisjonsrik': ('tradisjonsrik',),
'tradisjonsrike': ('tradisjonsrik',),
'tradisjonsrikere': ('tradisjonsrik',),
'tradisjonsrikest': ('tradisjonsrik',),
'tradisjonsrikeste': ('tradisjonsrik',),
'tradisjonsrikt': ('tradisjonsrik',),
'trafikabel': ('trafikabel',),
'trafikabelt': ('trafikabel',),
'trafikable': ('trafikabel',),
'trafikablere': ('trafikabel',),
'trafikablest': ('trafikabel',),
'trafikableste': ('trafikabel',),
'trafikal': ('trafikal',),
'trafikale': ('trafikal',),
'trafikalere': ('trafikal',),
'trafikalest': ('trafikal',),
'trafikaleste': ('trafikal',),
'trafikalt': ('trafikal',),
'trafikkdrept': ('trafikkdrept',),
'trafikkdrepte': ('trafikkdrept',),
'trafikkdreptere': ('trafikkdrept',),
'trafikkdreptest': ('trafikkdrept',),
'trafikkdrepteste': ('trafikkdrept',),
'trafikkerende': ('trafikkere',),
'trafikkert': ('trafikkere',),
'trafikkerte': ('trafikkere',),
'trafikkfarlig': ('trafikkfarlig',),
'trafikkfarlige': ('trafikkfarlig',),
'trafikkfarligere': ('trafikkfarlig',),
'trafikkfarligst': ('trafikkfarlig',),
'trafikkfarligste': ('trafikkfarlig',),
'tragikomisk': ('tragikomisk',),
'tragikomiske': ('tragikomisk',),
'tragikomiskere': ('tragikomisk',),
'tragikomiskest': ('tragikomisk',),
'tragikomiskeste': ('tragikomisk',),
'tragisk': ('tragisk',),
'tragiske': ('tragisk',),
'tragiskere': ('tragisk',),
'tragiskest': ('tragisk',),
'tragiskeste': ('tragisk',),
'trakasserende': ('trakassere',),
'trakassert': ('trakassere',),
'trakasserte': ('trakassere',),
'trakka': ('trakke',),
'trakkede': ('trakke',),
'trakkende': ('trakke',),
'trakket': ('trakke',),
'trakkete': ('trakke',),
'traktatstridig': ('traktatstridig',),
'traktatstridige': ('traktatstridig',),
'traktatstridigere': ('traktatstridig',),
'traktatstridigst': ('traktatstridig',),
'traktatstridigste': ('traktatstridig',),
'trakta': ('trakte',),
'traktede': ('trakte',),
'traktende': ('trakte',),
'traktet': ('trakte',),
'traktete': ('trakte',),
'trakta': ('trakte',),
'traktede': ('trakte',),
'traktende': ('trakte',),
'traktet': ('trakte',),
'traktete': ('trakte',),
'trakta': ('trakte',),
'traktede': ('trakte',),
'traktende': ('trakte',),
'traktet': ('trakte',),
'traktete': ('trakte',),
'trakterende': ('traktere',),
'traktert': ('traktere',),
'trakterte': ('traktere',),
'trala': ('trale',),
'tralede': ('trale',),
'tralende': ('trale',),
'tralet': ('trale',),
'tralete': ('trale',),
'tralt': ('trale',),
'tralte': ('trale',),
'tralla': ('tralle',),
'trallede': ('tralle',),
'trallende': ('tralle',),
'trallet': ('tralle',),
'trallete': ('tralle',),
'trampa': ('trampe',),
'trampede': ('trampe',),
'trampende': ('trampe',),
'trampet': ('trampe',),
'trampete': ('trampe',),
'trampa': ('trampe',),
'trampede': ('trampe',),
'trampende': ('trampe',),
'trampet': ('trampe',),
'trampete': ('trampe',),
'trang': ('trang',),
'trange': ('trang',),
'trangere': ('trang',),
'trangest': ('trang',),
'trangeste': ('trang',),
'trangt': ('trang',),
'trangbodd': ('trangbodd',),
'trangbodde': ('trangbodd',),
'trangboddere': ('trangbodd',),
'trangboddest': ('trangbodd',),
'trangboddeste': ('trangbodd',),
'trangbrysta': ('trangbrysta',),
'trangbrystede': ('trangbrystet',),
'trangbrystet': ('trangbrystet',),
'trangbrystete': ('trangbrystet',),
'trangbrystetere': ('trangbrystet',),
'trangbrystetest': ('trangbrystet',),
'trangbrysteteste': ('trangbrystet',),
'trangbudd': ('trangbudd',),
'trangbudde': ('trangbudd',),
'trangbuddere': ('trangbudd',),
'trangbuddest': ('trangbudd',),
'trangbuddeste': ('trangbudd',),
'trangpusta': ('trangpusta',),
'trangpustede': ('trangpustet',),
'trangpustet': ('trangpustet',),
'trangpustete': ('trangpustet',),
'trangpustetere': ('trangpustet',),
'trangpustetest': ('trangpustet',),
'trangpusteteste': ('trangpustet',),
'trangsynt': ('trangsynt',),
'trangsynte': ('trangsynt',),
'trangsyntere': ('trangsynt',),
'trangsyntest': ('trangsynt',),
'trangsynteste': ('trangsynt',),
'trangviksk': ('trangviksk',),
'trangvikske': ('trangviksk',),
'trangvikskere': ('trangviksk',),
'trangvikskest': ('trangviksk',),
'trangvikskeste': ('trangviksk',),
'transalpinsk': ('transalpinsk',),
'transalpinske': ('transalpinsk',),
'transalpinskere': ('transalpinsk',),
'transalpinskest': ('transalpinsk',),
'transalpinskeste': ('transalpinsk',),
'transatlantisk': ('transatlantisk',),
'transatlantiske': ('transatlantisk',),
'transatlantiskere': ('transatlantisk',),
'transatlantiskest': ('transatlantisk',),
'transatlantiskeste': ('transatlantisk',),
'transcendent': ('transcendent',),
'transcendente': ('transcendent',),
'transcendentere': ('transcendent',),
'transcendentest': ('transcendent',),
'transcendenteste': ('transcendent',),
'transcendental': ('transcendental',),
'transcendentale': ('transcendental',),
'transcendentalere': ('transcendental',),
'transcendentalest': ('transcendental',),
'transcendentaleste': ('transcendental',),
'transcendentalt': ('transcendental',),
'transcenderende': ('transcendere',),
'transcendert': ('transcendere',),
'transcenderte': ('transcendere',),
'transfererende': ('transferere',),
'transferert': ('transferere',),
'transfererte': ('transferere',),
'transfigurerende': ('transfigurere',),
'transfigurert': ('transfigurere',),
'transfigurerte': ('transfigurere',),
'transformasjonell': ('transformasjonell',),
'transformasjonelle': ('transformasjonell',),
'transformasjonellere': ('transformasjonell',),
'transformasjonellest': ('transformasjonell',),
'transformasjonelleste': ('transformasjonell',),
'transformasjonelt': ('transformasjonell',),
'transformerende': ('transformere',),
'transformert': ('transformere',),
'transformerte': ('transformere',),
'transfunderende': ('transfundere',),
'transfundert': ('transfundere',),
'transfunderte': ('transfundere',),
'transibirsk': ('transibirsk',),
'transibirske': ('transibirsk',),
'transibirskere': ('transibirsk',),
'transibirskest': ('transibirsk',),
'transibirskeste': ('transibirsk',),
'transilvansk': ('transilvansk',),
'transilvanske': ('transilvansk',),
'transilvanskere': ('transilvansk',),
'transilvanskest': ('transilvansk',),
'transilvanskeste': ('transilvansk',),
'transistoriserende': ('transistorisere',),
'transistorisert': ('transistorisere',),
'transistoriserte': ('transistorisere',),
'transitiv': ('transitiv',),
'transitive': ('transitiv',),
'transitivere': ('transitiv',),
'transitivest': ('transitiv',),
'transitiveste': ('transitiv',),
'transitivt': ('transitiv',),
'transitiverende': ('transitivere',),
'transitivert': ('transitivere',),
'transitiverte': ('transitivere',),
'transitorisk': ('transitorisk',),
'transitoriske': ('transitorisk',),
'transitoriskere': ('transitorisk',),
'transitoriskest': ('transitorisk',),
'transitoriskeste': ('transitorisk',),
'transitterende': ('transittere',),
'transittert': ('transittere',),
'transitterte': ('transittere',),
'transjerende': ('transjere',),
'transjert': ('transjere',),
'transjerte': ('transjere',),
'transjordansk': ('transjordansk',),
'transjordanske': ('transjordansk',),
'transjordanskere': ('transjordansk',),
'transjordanskest': ('transjordansk',),
'transjordanskeste': ('transjordansk',),
'transkaukasisk': ('transkaukasisk',),
'transkaukasiske': ('transkaukasisk',),
'transkaukasiskere': ('transkaukasisk',),
'transkaukasiskest': ('transkaukasisk',),
'transkaukasiskeste': ('transkaukasisk',),
'transkontinental': ('transkontinental',),
'transkontinentale': ('transkontinental',),
'transkontinentalere': ('transkontinental',),
'transkontinentalest': ('transkontinental',),
'transkontinentaleste': ('transkontinental',),
'transkontinentalt': ('transkontinental',),
'transkriberende': ('transkribere',),
'transkribert': ('transkribere',),
'transkriberte': ('transkribere',),
'transkriberende': ('transkribere',),
'transkribert': ('transkribere',),
'transkriberte': ('transkribere',),
'translittererende': ('translitterere',),
'translitterert': ('translitterere',),
'translittererte': ('translitterere',),
'transmitterende': ('transmittere',),
'transmittert': ('transmittere',),
'transmitterte': ('transmittere',),
'transparent': ('transparent',),
'transparente': ('transparent',),
'transparentere': ('transparent',),
'transparentest': ('transparent',),
'transparenteste': ('transparent',),
'transpirerende': ('transpirere',),
'transpirert': ('transpirere',),
'transpirerte': ('transpirere',),
'transplanterende': ('transplantere',),
'transplantert': ('transplantere',),
'transplanterte': ('transplantere',),
'transpolar': ('transpolar',),
'transpolare': ('transpolar',),
'transpolarere': ('transpolar',),
'transpolarest': ('transpolar',),
'transpolareste': ('transpolar',),
'transpolart': ('transpolar',),
'transponerende': ('transponere',),
'transponert': ('transponere',),
'transponerte': ('transponere',),
'transportabel': ('transportabel',),
'transportabelt': ('transportabel',),
'transportable': ('transportabel',),
'transportablere': ('transportabel',),
'transportablest': ('transportabel',),
'transportableste': ('transportabel',),
'transporterende': ('transportere',),
'transportert': ('transportere',),
'transporterte': ('transportere',),
'transsibirsk': ('transsibirsk',),
'transsibirske': ('transsibirsk',),
'transsibirskere': ('transsibirsk',),
'transsibirskest': ('transsibirsk',),
'transsibirskeste': ('transsibirsk',),
'transskriberende': ('transskribere',),
'transskribert': ('transskribere',),
'transskriberte': ('transskribere',),
'transskriberende': ('transskribere',),
'transskribert': ('transskribere',),
'transskriberte': ('transskribere',),
'transuran': ('transuran',),
'transurane': ('transuran',),
'transuranere': ('transuran',),
'transuranest': ('transuran',),
'transuraneste': ('transuran',),
'transurant': ('transuran',),
'transversal': ('transversal',),
'transversale': ('transversal',),
'transversalere': ('transversal',),
'transversalest': ('transversal',),
'transversaleste': ('transversal',),
'transversalt': ('transversal',),
'transversell': ('transversell',),
'transverselle': ('transversell',),
'transversellere': ('transversell',),
'transversellest': ('transversell',),
'transverselleste': ('transversell',),
'transverselt': ('transversell',),
'transvestittisk': ('transvestittisk',),
'transvestittiske': ('transvestittisk',),
'transvestittiskere': ('transvestittisk',),
'transvestittiskest': ('transvestittisk',),
'transvestittiskeste': ('transvestittisk',),
'trappa': ('trappe',),
'trappede': ('trappe',),
'trappende': ('trappe',),
'trappet': ('trappe',),
'trappete': ('trappe',),
'trasa': ('trase',),
'trasede': ('trase',),
'trasende': ('trase',),
'traset': ('trase',),
'trasete': ('trase',),
'trasen': ('trasen',),
'trasent': ('trasen',),
'trasne': ('trasen',),
'trasnere': ('trasen',),
'trasnest': ('trasen',),
'trasneste': ('trasen',),
'traserende': ('trasere',),
'trasert': ('trasere',),
'traserte': ('trasere',),
'traset': ('traset',),
'trasete': ('traset',),
'trasetere': ('traset',),
'trasetest': ('traset',),
'traseteste': ('traset',),
'trasete': ('trasete',),
'trasig': ('trasig',),
'trasige': ('trasig',),
'trasigere': ('trasig',),
'trasigst': ('trasig',),
'trasigste': ('trasig',),
'traska': ('traske',),
'traskede': ('traske',),
'traskende': ('traske',),
'trasket': ('traske',),
'traskete': ('traske',),
'trassa': ('trasse',),
'trassede': ('trasse',),
'trassende': ('trasse',),
'trasset': ('trasse',),
'trassete': ('trasse',),
'trasserende': ('trassere',),
'trassert': ('trassere',),
'trasserte': ('trassere',),
'trassig': ('trassig',),
'trassige': ('trassig',),
'trassigere': ('trassig',),
'trassigst': ('trassig',),
'trassigste': ('trassig',),
'traumatisk': ('traumatisk',),
'traumatiske': ('traumatisk',),
'traumatiskere': ('traumatisk',),
'traumatiskest': ('traumatisk',),
'traumatiskeste': ('traumatisk',),
'traurig': ('traurig',),
'traurige': ('traurig',),
'traurigere': ('traurig',),
'traurigst': ('traurig',),
'traurigste': ('traurig',),
'traust': ('traust',),
'trauste': ('traust',),
'traustere': ('traust',),
'traustest': ('traust',),
'trausteste': ('traust',),
'trava': ('trave',),
'travd': ('trave',),
'travde': ('trave',),
'travede': ('trave',),
'travende': ('trave',),
'travet': ('trave',),
'travete': ('trave',),
'travel': ('travel',),
'travelt': ('travel',),
'travle': ('travel',),
'travlere': ('travel',),
'travlest': ('travel',),
'travleste': ('travel',),
'traverserende': ('traversere',),
'traversert': ('traversere',),
'traverserte': ('traversere',),
'travesterende': ('travestere',),
'travestert': ('travestere',),
'travesterte': ('travestere',),
'tredd': ('tre',),
'tredde': ('tre',),
'tredende': ('tre',),
'treende': ('tre',),
'trådt': ('tre',),
'trådte': ('tre',),
'treaktig': ('treaktig',),
'treaktige': ('treaktig',),
'treaktigere': ('treaktig',),
'treaktigst': ('treaktig',),
'treaktigste': ('treaktig',),
'treakts': ('treakts',),
'trearma': ('trearma',),
'trearmede': ('trearmet',),
'trearmet': ('trearmet',),
'trearmete': ('trearmet',),
'trearmetere': ('trearmet',),
'trearmetest': ('trearmet',),
'trearmeteste': ('trearmet',),
'trebeint': ('trebeint',),
'trebeinte': ('trebeint',),
'trebeintere': ('trebeint',),
'trebeintest': ('trebeint',),
'trebeinteste': ('trebeint',),
'trebent': ('trebent',),
'trebente': ('trebent',),
'trebentere': ('trebent',),
'trebentest': ('trebent',),
'trebenteste': ('trebent',),
'treborende': ('treborende',),
'tredagers': ('tredagers',),
'tredelende': ('tredele',),
'tredelt': ('tredele',),
'tredelte': ('tredele',),
'tredimensjonal': ('tredimensjonal',),
'tredimensjonale': ('tredimensjonal',),
'tredimensjonalere': ('tredimensjonal',),
'tredimensjonalest': ('tredimensjonal',),
'tredimensjonaleste': ('tredimensjonal',),
'tredimensjonalt': ('tredimensjonal',),
'tredje': ('tredje',),
'tredjeklasses': ('tredjeklasses',),
'tredjerangs': ('tredjerangs',),
'tredobbel': ('tredobbel',),
'tredobbelt': ('tredobbel',),
'tredoble': ('tredobbel',),
'tredoblere': ('tredobbel',),
'tredoblest': ('tredobbel',),
'tredobleste': ('tredobbel',),
'tredobbelt': ('tredobbelt',),
'tredobbelte': ('tredobbelt',),
'tredobbeltere': ('tredobbelt',),
'tredobbeltest': ('tredobbelt',),
'tredobbelteste': ('tredobbelt',),
'tredobla': ('tredoble',),
'tredoblede': ('tredoble',),
'tredoblende': ('tredoble',),
'tredoblet': ('tredoble',),
'tredoblete': ('tredoble',),
'treen': ('treen',),
'treene': ('treen',),
'treenere': ('treen',),
'treenest': ('treen',),
'treeneste': ('treen',),
'treent': ('treen',),
'trene': ('treen',),
'trenere': ('treen',),
'trenest': ('treen',),
'treneste': ('treen',),
'treenig': ('treenig',),
'treenige': ('treenig',),
'treenigere': ('treenig',),
'treenigst': ('treenig',),
'treenigste': ('treenig',),
'treet': ('treet',),
'treete': ('treet',),
'treetere': ('treet',),
'treetest': ('treet',),
'treeteste': ('treet',),
'treetasjes': ('treetasjes',),
'treete': ('treete',),
'trefags': ('trefags',),
'treffende': ('treffe',),
'truffen': ('treffe',),
'truffet': ('treffe',),
'trufne': ('treffe',),
'treffende': ('treffende',),
'treffsikker': ('treffsikker',),
'treffsikkert': ('treffsikker',),
'treffsikre': ('treffsikker',),
'treffsikrere': ('treffsikker',),
'treffsikrest': ('treffsikker',),
'treffsikreste': ('treffsikker',),
'trefold': ('trefold',),
'trefoldig': ('trefoldig',),
'trefoldige': ('trefoldig',),
'trefoldigere': ('trefoldig',),
'trefoldigst': ('trefoldig',),
'trefoldigste': ('trefoldig',),
'trefri': ('trefri',),
'trefrie': ('trefri',),
'trefriere': ('trefri',),
'trefriest': ('trefri',),
'trefrieste': ('trefri',),
'trefritt': ('trefri',),
'treg': ('treg',),
'trege': ('treg',),
'tregere': ('treg',),
'tregest': ('treg',),
'tregeste': ('treg',),
'tregt': ('treg',),
'trega': ('trege',),
'tregede': ('trege',),
'tregende': ('trege',),
'treget': ('trege',),
'tregete': ('trege',),
'trehendt': ('trehendt',),
'trehendte': ('trehendt',),
'trehendtere': ('trehendt',),
'trehendtest': ('trehendt',),
'trehendteste': ('trehendt',),
'trehjuls': ('trehjuls',),
'trehjult': ('trehjult',),
'trehjulte': ('trehjult',),
'trehjultere': ('trehjult',),
'trehjultest': ('trehjult',),
'trehjulteste': ('trehjult',),
'trehvit': ('trehvit',),
'trehvite': ('trehvit',),
'trehvitere': ('trehvit',),
'trehvitest': ('trehvit',),
'trehviteste': ('trehvit',),
'trehvitt': ('trehvit',),
'trekanta': ('trekanta',),
'trekantede': ('trekantet',),
'trekantet': ('trekantet',),
'trekantete': ('trekantet',),
'trekantetere': ('trekantet',),
'trekantetest': ('trekantet',),
'trekanteteste': ('trekantet',),
'trekkende': ('trekke',),
'trukken': ('trekke',),
'trukket': ('trekke',),
'trukne': ('trekke',),
'trekkfri': ('trekkfri',),
'trekkfrie': ('trekkfri',),
'trekkfriere': ('trekkfri',),
'trekkfriest': ('trekkfri',),
'trekkfrieste': ('trekkfri',),
'trekkfritt': ('trekkfri',),
'trekkfull': ('trekkfull',),
'trekkfulle': ('trekkfull',),
'trekkfullere': ('trekkfull',),
'trekkfullest': ('trekkfull',),
'trekkfulleste': ('trekkfull',),
'trekkfullt': ('trekkfull',),
'trekta': ('trekte',),
'trektede': ('trekte',),
'trektende': ('trekte',),
'trektet': ('trekte',),
'trektete': ('trekte',),
'trekta': ('trekte',),
'trektede': ('trekte',),
'trektende': ('trekte',),
'trektet': ('trekte',),
'trektete': ('trekte',),
'trekvart': ('trekvart',),
'trekvarte': ('trekvart',),
'trekvartere': ('trekvart',),
'trekvartest': ('trekvart',),
'trekvarteste': ('trekvart',),
'trekvartlang': ('trekvartlang',),
'trekvartlange': ('trekvartlang',),
'trekvartlangt': ('trekvartlang',),
'trekvartlenger': ('trekvartlang',),
'trekvartlengre': ('trekvartlang',),
'trekvartlengst': ('trekvartlang',),
'trekvartlengste': ('trekvartlang',),
'trekvit': ('trekvit',),
'trekvite': ('trekvit',),
'trekvitere': ('trekvit',),
'trekvitest': ('trekvit',),
'trekviteste': ('trekvit',),
'trekvitt': ('trekvit',),
'trellbindende': ('trellbinde',),
'trellbunden': ('trellbinde',),
'trellbundet': ('trellbinde',),
'trellbundne': ('trellbinde',),
'trellbundet': ('trellbundet',),
'trellbundne': ('trellbundet',),
'trellbundnere': ('trellbundet',),
'trellbundnest': ('trellbundet',),
'trellbundneste': ('trellbundet',),
'trellbåren': ('trellbåren',),
'trellbårent': ('trellbåren',),
'trellbårne': ('trellbåren',),
'trellbårnere': ('trellbåren',),
'trellbårnest': ('trellbåren',),
'trellbårneste': ('trellbåren',),
'trella': ('trelle',),
'trellede': ('trelle',),
'trellende': ('trelle',),
'trellet': ('trelle',),
'trellete': ('trelle',),
'trellsom': ('trellsom',),
'trellsomme': ('trellsom',),
'trellsommere': ('trellsom',),
'trellsomst': ('trellsom',),
'trellsomste': ('trellsom',),
'trellsomt': ('trellsom',),
'tremasta': ('tremasta',),
'tremastede': ('tremastet',),
'tremastet': ('tremastet',),
'tremastete': ('tremastet',),
'tremastetere': ('tremastet',),
'tremastetest': ('tremastet',),
'tremasteteste': ('tremastet',),
'tremulerende': ('tremulere',),
'tremulert': ('tremulere',),
'tremulerte': ('tremulere',),
'trena': ('trene',),
'trenede': ('trene',),
'trenende': ('trene',),
'trenet': ('trene',),
'trenete': ('trene',),
'trena': ('trene',),
'trenede': ('trene',),
'trenende': ('trene',),
'trenet': ('trene',),
'trenete': ('trene',),
'trent': ('trene',),
'trente': ('trene',),
'trenerende': ('trenere',),
'trenert': ('trenere',),
'trenerte': ('trenere',),
'trengende': ('trenge',),
'trengt': ('trenge',),
'trengte': ('trenge',),
'trengende': ('trengende',),
'trepanerende': ('trepanere',),
'trepanert': ('trepanere',),
'trepanerte': ('trepanere',),
'trepunkts': ('trepunkts',),
'treroms': ('treroms',),
'tresifra': ('tresifra',),
'tresifrede': ('tresifret',),
'tresifret': ('tresifret',),
'tresifrete': ('tresifret',),
'tresifretere': ('tresifret',),
'tresifretest': ('tresifret',),
'tresifreteste': ('tresifret',),
'tresk': ('tresk',),
'treske': ('tresk',),
'treskere': ('tresk',),
'treskest': ('tresk',),
'treskeste': ('tresk',),
'treskt': ('tresk',),
'treska': ('treske',),
'treskede': ('treske',),
'treskende': ('treske',),
'tresket': ('treske',),
'treskete': ('treske',),
'treskt': ('treske',),
'treskte': ('treske',),
'tresnuta': ('tresnuta',),
'tresnutede': ('tresnutet',),
'tresnutet': ('tresnutet',),
'tresnutete': ('tresnutet',),
'tresnutetere': ('tresnutet',),
'tresnutetest': ('tresnutet',),
'tresnuteteste': ('tresnutet',),
'trestemmig': ('trestemmig',),
'trestemmige': ('trestemmig',),
'trestemmigere': ('trestemmig',),
'trestemmigst': ('trestemmig',),
'trestemmigste': ('trestemmig',),
'trestemt': ('trestemt',),
'trestemte': ('trestemt',),
'trestemtere': ('trestemt',),
'trestemtest': ('trestemt',),
'trestemteste': ('trestemt',),
'trestjerners': ('trestjerners',),
'trestrøken': ('trestrøken',),
'trestrøket': ('trestrøken',),
'trestrøkne': ('trestrøken',),
'trestrøknere': ('trestrøken',),
'trestrøknest': ('trestrøken',),
'trestrøkneste': ('trestrøken',),
'trestrøket': ('trestrøket',),
'trestrøkne': ('trestrøket',),
'trestrøknere': ('trestrøket',),
'trestrøknest': ('trestrøket',),
'trestrøkneste': ('trestrøket',),
'tretna': ('tretne',),
'tretnede': ('tretne',),
'tretnende': ('tretne',),
'tretnet': ('tretne',),
'tretnete': ('tretne',),
'tretoms': ('tretoms',),
'trett': ('trett',),
'trette': ('trett',),
'trettere': ('trett',),
'trettest': ('trett',),
'tretteste': ('trett',),
'tretta': ('trette',),
'trettede': ('trette',),
'trettende': ('trette',),
'trettet': ('trette',),
'trettete': ('trette',),
'tretta': ('trette',),
'trettede': ('trette',),
'trettende': ('trette',),
'trettet': ('trette',),
'trettete': ('trette',),
'trettekjær': ('trettekjær',),
'trettekjære': ('trettekjær',),
'trettekjærere': ('trettekjær',),
'trettekjærest': ('trettekjær',),
'trettekjæreste': ('trettekjær',),
'trettekjært': ('trettekjær',),
'trettenårig': ('trettenårig',),
'trettenårige': ('trettenårig',),
'trettenårigere': ('trettenårig',),
'trettenårigst': ('trettenårig',),
'trettenårigste': ('trettenårig',),
'trettenårs': ('trettenårs',),
'trettiende': ('trettiende',),
'trettiårig': ('trettiårig',),
'trettiårige': ('trettiårig',),
'trettiårigere': ('trettiårig',),
'trettiårigst': ('trettiårig',),
'trettiårigste': ('trettiårig',),
'trevegs': ('trevegs',),
'treveis': ('treveis',),
'treven': ('treven',),
'trevent': ('treven',),
'trevne': ('treven',),
'trevnere': ('treven',),
'trevnest': ('treven',),
'trevneste': ('treven',),
'treverdig': ('treverdig',),
'treverdige': ('treverdig',),
'treverdigere': ('treverdig',),
'treverdigst': ('treverdig',),
'treverdigste': ('treverdig',),
'trevla': ('trevle',),
'trevlede': ('trevle',),
'trevlende': ('trevle',),
'trevlet': ('trevle',),
'trevlete': ('trevle',),
'trevlet': ('trevlet',),
'trevlete': ('trevlet',),
'trevletere': ('trevlet',),
'trevletest': ('trevlet',),
'trevleteste': ('trevlet',),
'trevlete': ('trevlete',),
'treværelses': ('treværelses',),
'treårig': ('treårig',),
'treårige': ('treårig',),
'treårigere': ('treårig',),
'treårigst': ('treårig',),
'treårigste': ('treårig',),
'treårs': ('treårs',),
'triangulerende': ('triangulere',),
'triangulert': ('triangulere',),
'triangulerte': ('triangulere',),
'triangulær': ('triangulær',),
'triangulære': ('triangulær',),
'triangulærere': ('triangulær',),
'triangulærest': ('triangulær',),
'triangulæreste': ('triangulær',),
'triangulært': ('triangulær',),
'triasisk': ('triasisk',),
'triasiske': ('triasisk',),
'triasiskere': ('triasisk',),
'triasiskest': ('triasisk',),
'triasiskeste': ('triasisk',),
'tribalistisk': ('tribalistisk',),
'tribalistiske': ('tribalistisk',),
'tribalistiskere': ('tribalistisk',),
'tribalistiskest': ('tribalistisk',),
'tribalistiskeste': ('tribalistisk',),
'trifokal': ('trifokal',),
'trifokale': ('trifokal',),
'trifokalere': ('trifokal',),
'trifokalest': ('trifokal',),
'trifokaleste': ('trifokal',),
'trifokalt': ('trifokal',),
'trigga': ('trigge',),
'triggede': ('trigge',),
'triggende': ('trigge',),
'trigget': ('trigge',),
'triggete': ('trigge',),
'trigonometrisk': ('trigonometrisk',),
'trigonometriske': ('trigonometrisk',),
'trigonometriskere': ('trigonometrisk',),
'trigonometriskest': ('trigonometrisk',),
'trigonometriskeste': ('trigonometrisk',),
'trikinøs': ('trikinøs',),
'trikinøse': ('trikinøs',),
'trikinøsere': ('trikinøs',),
'trikinøsest': ('trikinøs',),
'trikinøseste': ('trikinøs',),
'trikinøst': ('trikinøs',),
'trikka': ('trikke',),
'trikkede': ('trikke',),
'trikkende': ('trikke',),
'trikket': ('trikke',),
'trikkete': ('trikke',),
'triksa': ('trikse',),
'triksede': ('trikse',),
'triksende': ('trikse',),
'trikset': ('trikse',),
'triksete': ('trikse',),
'trilla': ('trille',),
'trillede': ('trille',),
'trillende': ('trille',),
'trillet': ('trille',),
'trillete': ('trille',),
'trilla': ('trille',),
'trillede': ('trille',),
'trillende': ('trille',),
'trillet': ('trille',),
'trillete': ('trille',),
'trillende': ('trillende',),
'trillrund': ('trillrund',),
'trillrunde': ('trillrund',),
'trillrundere': ('trillrund',),
'trillrundest': ('trillrund',),
'trillrundeste': ('trillrund',),
'trillrundt': ('trillrund',),
'trimma': ('trimme',),
'trimmede': ('trimme',),
'trimmende': ('trimme',),
'trimmet': ('trimme',),
'trimmete': ('trimme',),
'trina': ('trine',),
'trinede': ('trine',),
'trinende': ('trine',),
'trinet': ('trine',),
'trinete': ('trine',),
'trint': ('trine',),
'trinte': ('trine',),
'trinidadisk': ('trinidadisk',),
'trinidadiske': ('trinidadisk',),
'trinidadiskere': ('trinidadisk',),
'trinidadiskest': ('trinidadisk',),
'trinidadiskeste': ('trinidadisk',),
'trinn': ('trinn',),
'trinne': ('trinn',),
'trinnere': ('trinn',),
'trinnest': ('trinn',),
'trinneste': ('trinn',),
'trint': ('trinn',),
'trinnlaus': ('trinnlaus',),
'trinnlause': ('trinnlaus',),
'trinnlausere': ('trinnlaus',),
'trinnlausest': ('trinnlaus',),
'trinnlauseste': ('trinnlaus',),
'trinnlaust': ('trinnlaus',),
'trinnløs': ('trinnløs',),
'trinnløse': ('trinnløs',),
'trinnløsere': ('trinnløs',),
'trinnløsest': ('trinnløs',),
'trinnløseste': ('trinnløs',),
'trinnløst': ('trinnløs',),
'trinsa': ('trinse',),
'trinsede': ('trinse',),
'trinsende': ('trinse',),
'trinset': ('trinse',),
'trinsete': ('trinse',),
'trippa': ('trippe',),
'trippede': ('trippe',),
'trippende': ('trippe',),
'trippet': ('trippe',),
'trippete': ('trippe',),
'triple': ('trippel',),
'triplere': ('trippel',),
'triplest': ('trippel',),
'tripleste': ('trippel',),
'trippel': ('trippel',),
'trippelt': ('trippel',),
'trist': ('trist',),
'triste': ('trist',),
'tristere': ('trist',),
'tristest': ('trist',),
'tristeste': ('trist',),
'triumferende': ('triumfere',),
'triumfert': ('triumfere',),
'triumferte': ('triumfere',),
'trivalent': ('trivalent',),
'trivalente': ('trivalent',),
'trivalentere': ('trivalent',),
'trivalentest': ('trivalent',),
'trivalenteste': ('trivalent',),
'treven': ('trive',),
'trevet': ('trive',),
'trevne': ('trive',),
'trivd': ('trive',),
'trivde': ('trive',),
'trivende': ('trive',),
'trivelig': ('trivelig',),
'trivelige': ('trivelig',),
'triveligere': ('trivelig',),
'triveligst': ('trivelig',),
'triveligste': ('trivelig',),
'trivialiserende': ('trivialisere',),
'trivialisert': ('trivialisere',),
'trivialiserte': ('trivialisere',),
'triviell': ('triviell',),
'trivielle': ('triviell',),
'triviellere': ('triviell',),
'triviellest': ('triviell',),
'trivielleste': ('triviell',),
'trivielt': ('triviell',),
'trivla': ('trivle',),
'trivlede': ('trivle',),
'trivlende': ('trivle',),
'trivlet': ('trivle',),
'trivlete': ('trivle',),
'trivselsfremmende': ('trivselsfremmende',),
'trodd': ('tro',),
'trodde': ('tro',),
'troende': ('tro',),
'tro': ('tro',),
'troende': ('troende',),
'troende': ('troende',),
'trofast': ('trofast',),
'trofaste': ('trofast',),
'trofastere': ('trofast',),
'trofastest': ('trofast',),
'trofasteste': ('trofast',),
'trohjerta': ('trohjerta',),
'trohjertede': ('trohjertet',),
'trohjertet': ('trohjertet',),
'trohjertete': ('trohjertet',),
'trohjertetere': ('trohjertet',),
'trohjertetest': ('trohjertet',),
'trohjerteteste': ('trohjertet',),
'trohjertig': ('trohjertig',),
'trohjertige': ('trohjertig',),
'trohjertigere': ('trohjertig',),
'trohjertigst': ('trohjertig',),
'trohjertigste': ('trohjertig',),
'trojansk': ('trojansk',),
'trojanske': ('trojansk',),
'trojanskere': ('trojansk',),
'trojanskest': ('trojansk',),
'trojanskeste': ('trojansk',),
'trokeisk': ('trokeisk',),
'trokeiske': ('trokeisk',),
'trokeiskere': ('trokeisk',),
'trokeiskest': ('trokeisk',),
'trokeiskeste': ('trokeisk',),
'trolaus': ('trolaus',),
'trolause': ('trolaus',),
'trolausere': ('trolaus',),
'trolausest': ('trolaus',),
'trolauseste': ('trolaus',),
'trolaust': ('trolaus',),
'trolig': ('trolig',),
'trolige': ('trolig',),
'troligere': ('trolig',),
'troligst': ('trolig',),
'troligste': ('trolig',),
'trollbindende': ('trollbinde',),
'trollbunden': ('trollbinde',),
'trollbundet': ('trollbinde',),
'trollbundne': ('trollbinde',),
'trolla': ('trolle',),
'trollede': ('trolle',),
'trollende': ('trolle',),
'trollet': ('trolle',),
'trollete': ('trolle',),
'trollet': ('trollet',),
'trollete': ('trollet',),
'trolletere': ('trollet',),
'trolletest': ('trollet',),
'trolleteste': ('trollet',),
'trollete': ('trollete',),
'trollkyndig': ('trollkyndig',),
'trollkyndige': ('trollkyndig',),
'trollkyndigere': ('trollkyndig',),
'trollkyndigst': ('trollkyndig',),
'trollkyndigste': ('trollkyndig',),
'trollslig': ('trollslig',),
'trollslige': ('trollslig',),
'trollsligere': ('trollslig',),
'trollsligst': ('trollslig',),
'trollsligste': ('trollslig',),
'trollstemmende': ('trollstemme',),
'trollstemt': ('trollstemme',),
'trollstemte': ('trollstemme',),
'trollstillende': ('trollstille',),
'trollstilt': ('trollstille',),
'trollstilte': ('trollstille',),
'trolova': ('trolove',),
'trolovede': ('trolove',),
'trolovende': ('trolove',),
'trolovet': ('trolove',),
'trolovete': ('trolove',),
'trolsk': ('trolsk',),
'trolske': ('trolsk',),
'trolskere': ('trolsk',),
'trolskest': ('trolsk',),
'trolskeste': ('trolsk',),
'troløs': ('troløs',),
'troløse': ('troløs',),
'troløsere': ('troløs',),
'troløsest': ('troløs',),
'troløseste': ('troløs',),
'troløst': ('troløs',),
'tromla': ('tromle',),
'tromlede': ('tromle',),
'tromlende': ('tromle',),
'tromlet': ('tromle',),
'tromlete': ('tromle',),
'tromma': ('tromme',),
'trommede': ('tromme',),
'trommende': ('tromme',),
'trommet': ('tromme',),
'trommete': ('tromme',),
'trondheimsk': ('trondheimsk',),
'trondheimske': ('trondheimsk',),
'trondheimskere': ('trondheimsk',),
'trondheimskest': ('trondheimsk',),
'trondheimskeste': ('trondheimsk',),
'trona': ('trone',),
'tronede': ('trone',),
'tronende': ('trone',),
'tronet': ('trone',),
'tronete': ('trone',),
'tropisk': ('tropisk',),
'tropiske': ('tropisk',),
'tropiskere': ('tropisk',),
'tropiskest': ('tropisk',),
'tropiskeste': ('tropisk',),
'troposfærisk': ('troposfærisk',),
'troposfæriske': ('troposfærisk',),
'troposfæriskere': ('troposfærisk',),
'troposfæriskest': ('troposfærisk',),
'troposfæriskeste': ('troposfærisk',),
'troppa': ('troppe',),
'troppede': ('troppe',),
'troppende': ('troppe',),
'troppet': ('troppe',),
'troppete': ('troppe',),
'troskyldig': ('troskyldig',),
'troskyldige': ('troskyldig',),
'troskyldigere': ('troskyldig',),
'troskyldigst': ('troskyldig',),
'troskyldigste': ('troskyldig',),
'trossa': ('trosse',),
'trossede': ('trosse',),
'trossende': ('trosse',),
'trosset': ('trosse',),
'trossete': ('trosse',),
'trossig': ('trossig',),
'trossige': ('trossig',),
'trossigere': ('trossig',),
'trossigst': ('trossig',),
'trossigste': ('trossig',),
'trotskistisk': ('trotskistisk',),
'trotskistiske': ('trotskistisk',),
'trotskistiskere': ('trotskistisk',),
'trotskistiskest': ('trotskistisk',),
'trotskistiskeste': ('trotskistisk',),
'troverdig': ('troverdig',),
'troverdige': ('troverdig',),
'troverdigere': ('troverdig',),
'troverdigst': ('troverdig',),
'troverdigste': ('troverdig',),
'trudd': ('tru',),
'trudde': ('tru',),
'truende': ('tru',),
'tru': ('tru',),
'true': ('tru',),
'truere': ('tru',),
'truest': ('tru',),
'trueste': ('tru',),
'trua': ('true',),
'truede': ('true',),
'truende': ('true',),
'truet': ('true',),
'truete': ('true',),
'trua': ('true',),
'truede': ('true',),
'truende': ('true',),
'truet': ('true',),
'truete': ('true',),
'truen': ('truen',),
'truene': ('truen',),
'truenere': ('truen',),
'truenest': ('truen',),
'trueneste': ('truen',),
'truent': ('truen',),
'trune': ('truen',),
'trunere': ('truen',),
'trunest': ('truen',),
'truneste': ('truen',),
'truende': ('truende',),
'truende': ('truende',),
'truende': ('truende',),
'trufast': ('trufast',),
'trufaste': ('trufast',),
'trufastere': ('trufast',),
'trufastest': ('trufast',),
'trufasteste': ('trufast',),
'truga': ('truge',),
'trugede': ('truge',),
'trugende': ('truge',),
'truget': ('truge',),
'trugete': ('truge',),
'truga': ('truge',),
'trugede': ('truge',),
'trugende': ('truge',),
'truget': ('truge',),
'trugete': ('truge',),
'trugende': ('trugende',),
'trugende': ('trugende',),
'truhjerta': ('truhjerta',),
'truhjertede': ('truhjertet',),
'truhjertet': ('truhjertet',),
'truhjertete': ('truhjertet',),
'truhjertetere': ('truhjertet',),
'truhjertetest': ('truhjertet',),
'truhjerteteste': ('truhjertet',),
'truhjertig': ('truhjertig',),
'truhjertige': ('truhjertig',),
'truhjertigere': ('truhjertig',),
'truhjertigst': ('truhjertig',),
'truhjertigste': ('truhjertig',),
'truistisk': ('truistisk',),
'truistiske': ('truistisk',),
'truistiskere': ('truistisk',),
'truistiskest': ('truistisk',),
'truistiskeste': ('truistisk',),
'trulaus': ('trulaus',),
'trulause': ('trulaus',),
'trulausere': ('trulaus',),
'trulausest': ('trulaus',),
'trulauseste': ('trulaus',),
'trulaust': ('trulaus',),
'trulig': ('trulig',),
'trulige': ('trulig',),
'truligere': ('trulig',),
'truligst': ('trulig',),
'truligste': ('trulig',),
'trulova': ('trulove',),
'trulovede': ('trulove',),
'trulovende': ('trulove',),
'trulovet': ('trulove',),
'trulovete': ('trulove',),
'trulta': ('trulte',),
'trultede': ('trulte',),
'trultende': ('trulte',),
'trultet': ('trulte',),
'trultete': ('trulte',),
'truløs': ('truløs',),
'truløse': ('truløs',),
'truløsere': ('truløs',),
'truløsest': ('truløs',),
'truløseste': ('truløs',),
'truløst': ('truløs',),
'trumfa': ('trumfe',),
'trumfede': ('trumfe',),
'trumfende': ('trumfe',),
'trumfet': ('trumfe',),
'trumfete': ('trumfe',),
'trumpet': ('trumpet',),
'trumpete': ('trumpet',),
'trumpetere': ('trumpet',),
'trumpetest': ('trumpet',),
'trumpeteste': ('trumpet',),
'trumpete': ('trumpete',),
'truskyldig': ('truskyldig',),
'truskyldige': ('truskyldig',),
'truskyldigere': ('truskyldig',),
'truskyldigst': ('truskyldig',),
'truskyldigste': ('truskyldig',),
'truten': ('truten',),
'trutent': ('truten',),
'trutne': ('truten',),
'trutnere': ('truten',),
'trutnest': ('truten',),
'trutneste': ('truten',),
'trutna': ('trutne',),
'trutnede': ('trutne',),
'trutnende': ('trutne',),
'trutnet': ('trutne',),
'trutnete': ('trutne',),
'truverdig': ('truverdig',),
'truverdige': ('truverdig',),
'truverdigere': ('truverdig',),
'truverdigst': ('truverdig',),
'truverdigste': ('truverdig',),
'trygda': ('trygde',),
'trygdede': ('trygde',),
'trygdende': ('trygde',),
'trygdet': ('trygde',),
'trygdete': ('trygde',),
'trygg': ('trygg',),
'trygge': ('trygg',),
'tryggere': ('trygg',),
'tryggest': ('trygg',),
'tryggeste': ('trygg',),
'trygt': ('trygg',),
'trygd': ('trygge',),
'trygde': ('trygge',),
'trygga': ('trygge',),
'tryggede': ('trygge',),
'tryggende': ('trygge',),
'trygget': ('trygge',),
'tryggete': ('trygge',),
'trygla': ('trygle',),
'tryglede': ('trygle',),
'tryglende': ('trygle',),
'tryglet': ('trygle',),
'tryglete': ('trygle',),
'trykka': ('trykke',),
'trykkede': ('trykke',),
'trykkende': ('trykke',),
'trykket': ('trykke',),
'trykkete': ('trykke',),
'trykt': ('trykke',),
'trykte': ('trykke',),
'trykkede': ('trykket',),
'trykket': ('trykket',),
'trykkete': ('trykket',),
'trykketere': ('trykket',),
'trykketest': ('trykket',),
'trykketeste': ('trykket',),
'trykkimpregnerende': ('trykkimpregnere',),
'trykkimpregnert': ('trykkimpregnere',),
'trykkimpregnerte': ('trykkimpregnere',),
'trykklett': ('trykklett',),
'trykklette': ('trykklett',),
'trykklettere': ('trykklett',),
'trykklettest': ('trykklett',),
'trykkletteste': ('trykklett',),
'trykksterk': ('trykksterk',),
'trykksterke': ('trykksterk',),
'trykksterkere': ('trykksterk',),
'trykksterkest': ('trykksterk',),
'trykksterkeste': ('trykksterk',),
'trykksterkt': ('trykksterk',),
'trykksvak': ('trykksvak',),
'trykksvake': ('trykksvak',),
'trykksvakere': ('trykksvak',),
'trykksvakest': ('trykksvak',),
'trykksvakeste': ('trykksvak',),
'trykksvakt': ('trykksvak',),
'trykktung': ('trykktung',),
'trykktunge': ('trykktung',),
'trykktungere': ('trykktung',),
'trykktungest': ('trykktung',),
'trykktungeste': ('trykktung',),
'trykktungt': ('trykktung',),
'trykktyngre': ('trykktung',),
'trykktyngst': ('trykktung',),
'trykktyngste': ('trykktung',),
'trykt': ('trykt',),
'trykte': ('trykt',),
'tryktere': ('trykt',),
'tryktest': ('trykt',),
'trykteste': ('trykt',),
'trylla': ('trylle',),
'tryllede': ('trylle',),
'tryllende': ('trylle',),
'tryllet': ('trylle',),
'tryllete': ('trylle',),
'trylt': ('trylle',),
'trylte': ('trylle',),
'tryllebindende': ('tryllebinde',),
'tryllebunden': ('tryllebinde',),
'tryllebundet': ('tryllebinde',),
'tryllebundne': ('tryllebinde',),
'tryna': ('tryne',),
'trynede': ('tryne',),
'trynende': ('tryne',),
'trynet': ('tryne',),
'trynete': ('tryne',),
'trytende': ('tryte',),
'trytt': ('tryte',),
'trytte': ('tryte',),
'trådd': ('trå',),
'trådde': ('trå',),
'trående': ('trå',),
'trådd': ('trå',),
'trådde': ('trå',),
'trådt': ('trå',),
'trådte': ('trå',),
'trående': ('trå',),
'trå': ('trå',),
'tråe': ('trå',),
'tråere': ('trå',),
'tråest': ('trå',),
'tråeste': ('trå',),
'trått': ('trå',),
'tråda': ('tråde',),
'trådede': ('tråde',),
'trådende': ('tråde',),
'trådet': ('tråde',),
'trådete': ('tråde',),
'trådet': ('trådet',),
'trådete': ('trådet',),
'trådetere': ('trådet',),
'trådetest': ('trådet',),
'trådeteste': ('trådet',),
'trådete': ('trådete',),
'trådlaus': ('trådlaus',),
'trådlause': ('trådlaus',),
'trådlausere': ('trådlaus',),
'trådlausest': ('trådlaus',),
'trådlauseste': ('trådlaus',),
'trådlaust': ('trådlaus',),
'trådløs': ('trådløs',),
'trådløse': ('trådløs',),
'trådløsere': ('trådløs',),
'trådløsest': ('trådløs',),
'trådløseste': ('trådløs',),
'trådløst': ('trådløs',),
'tråkka': ('tråkke',),
'tråkkede': ('tråkke',),
'tråkkende': ('tråkke',),
'tråkket': ('tråkke',),
'tråkkete': ('tråkke',),
'tråkla': ('tråkle',),
'tråklede': ('tråkle',),
'tråklende': ('tråkle',),
'tråklet': ('tråkle',),
'tråklete': ('tråkle',),
'tråla': ('tråle',),
'trålede': ('tråle',),
'trålende': ('tråle',),
'trålet': ('tråle',),
'trålete': ('tråle',),
'trålt': ('tråle',),
'trålte': ('tråle',),
'trålfri': ('trålfri',),
'trålfrie': ('trålfri',),
'trålfriere': ('trålfri',),
'trålfriest': ('trålfri',),
'trålfrieste': ('trålfri',),
'trålfritt': ('trålfri',),
'tråva': ('tråve',),
'tråvd': ('tråve',),
'tråvde': ('tråve',),
'tråvede': ('tråve',),
'tråvende': ('tråve',),
'tråvet': ('tråve',),
'tråvete': ('tråve',),
'trædd': ('træ',),
'trædde': ('træ',),
'træende': ('træ',),
'trælet': ('trælet',),
'trælete': ('trælet',),
'træletere': ('trælet',),
'træletest': ('trælet',),
'træleteste': ('trælet',),
'trælete': ('trælete',),
'trødd': ('trø',),
'trødde': ('trø',),
'trøende': ('trø',),
'trøndersk': ('trøndersk',),
'trønderske': ('trøndersk',),
'trønderskere': ('trøndersk',),
'trønderskest': ('trøndersk',),
'trønderskeste': ('trøndersk',),
'trøndsk': ('trøndsk',),
'trøndske': ('trøndsk',),
'trøndskere': ('trøndsk',),
'trøndskest': ('trøndsk',),
'trøndskeste': ('trøndsk',),
'trøsken': ('trøsken',),
'trøskent': ('trøsken',),
'trøskne': ('trøsken',),
'trøsknere': ('trøsken',),
'trøsknest': ('trøsken',),
'trøskneste': ('trøsken',),
'trøsket': ('trøsket',),
'trøskete': ('trøsket',),
'trøsketere': ('trøsket',),
'trøsketest': ('trøsket',),
'trøsketeste': ('trøsket',),
'trøskete': ('trøskete',),
'trøsta': ('trøste',),
'trøstede': ('trøste',),
'trøstende': ('trøste',),
'trøstet': ('trøste',),
'trøstete': ('trøste',),
'trøstefull': ('trøstefull',),
'trøstefulle': ('trøstefull',),
'trøstefullere': ('trøstefull',),
'trøstefullest': ('trøstefull',),
'trøstefulleste': ('trøstefull',),
'trøstefullt': ('trøstefull',),
'trøsteslaus': ('trøsteslaus',),
'trøsteslause': ('trøsteslaus',),
'trøsteslausere': ('trøsteslaus',),
'trøsteslausest': ('trøsteslaus',),
'trøsteslauseste': ('trøsteslaus',),
'trøsteslaust': ('trøsteslaus',),
'trøstesløs': ('trøstesløs',),
'trøstesløse': ('trøstesløs',),
'trøstesløsere': ('trøstesløs',),
'trøstesløsest': ('trøstesløs',),
'trøstesløseste': ('trøstesløs',),
'trøstesløst': ('trøstesløs',),
'trøstespisende': ('trøstespise',),
'trøstespist': ('trøstespise',),
'trøstespiste': ('trøstespise',),
'trøstig': ('trøstig',),
'trøstige': ('trøstig',),
'trøstigere': ('trøstig',),
'trøstigst': ('trøstig',),
'trøstigste': ('trøstig',),
'trøtna': ('trøtne',),
'trøtnede': ('trøtne',),
'trøtnende': ('trøtne',),
'trøtnet': ('trøtne',),
'trøtnete': ('trøtne',),
'trøtt': ('trøtt',),
'trøtte': ('trøtt',),
'trøttere': ('trøtt',),
'trøttest': ('trøtt',),
'trøtteste': ('trøtt',),
'trøtt': ('trøtt',),
'trøtte': ('trøtt',),
'trøttere': ('trøtt',),
'trøttest': ('trøtt',),
'trøtteste': ('trøtt',),
'trøtta': ('trøtte',),
'trøttede': ('trøtte',),
'trøttende': ('trøtte',),
'trøttet': ('trøtte',),
'trøttete': ('trøtte',),
'trøttende': ('trøttende',),
'tsaristisk': ('tsaristisk',),
'tsaristiske': ('tsaristisk',),
'tsaristiskere': ('tsaristisk',),
'tsaristiskest': ('tsaristisk',),
'tsaristiskeste': ('tsaristisk',),
'tsjekkisk': ('tsjekkisk',),
'tsjekkiske': ('tsjekkisk',),
'tsjekkiskere': ('tsjekkisk',),
'tsjekkiskest': ('tsjekkisk',),
'tsjekkiskeste': ('tsjekkisk',),
'tsjekkoslovakisk': ('tsjekkoslovakisk',),
'tsjekkoslovakiske': ('tsjekkoslovakisk',),
'tsjekkoslovakiskere': ('tsjekkoslovakisk',),
'tsjekkoslovakiskest': ('tsjekkoslovakisk',),
'tsjekkoslovakiskeste': ('tsjekkoslovakisk',),
'tsjuvasjisk': ('tsjuvasjisk',),
'tsjuvasjiske': ('tsjuvasjisk',),
'tsjuvasjiskere': ('tsjuvasjisk',),
'tsjuvasjiskest': ('tsjuvasjisk',),
'tsjuvasjiskeste': ('tsjuvasjisk',),
'tuberkuløs': ('tuberkuløs',),
'tuberkuløse': ('tuberkuløs',),
'tuberkuløsere': ('tuberkuløs',),
'tuberkuløsest': ('tuberkuløs',),
'tuberkuløseste': ('tuberkuløs',),
'tuberkuløst': ('tuberkuløs',),
'tuet': ('tuet',),
'tuete': ('tuet',),
'tuetere': ('tuet',),
'tuetest': ('tuet',),
'tueteste': ('tuet',),
'tuet': ('tuet',),
'tuete': ('tuet',),
'tuetere': ('tuet',),
'tuetest': ('tuet',),
'tueteste': ('tuet',),
'tuete': ('tuete',),
'tuete': ('tuete',),
'tufs': ('tufs',),
'tufse': ('tufs',),
'tufsere': ('tufs',),
'tufsest': ('tufs',),
'tufseste': ('tufs',),
'tufst': ('tufs',),
'tufsa': ('tufse',),
'tufsede': ('tufse',),
'tufsende': ('tufse',),
'tufset': ('tufse',),
'tufsete': ('tufse',),
'tufsen': ('tufsen',),
'tufsent': ('tufsen',),
'tufsne': ('tufsen',),
'tufsnere': ('tufsen',),
'tufsnest': ('tufsen',),
'tufsneste': ('tufsen',),
'tufset': ('tufset',),
'tufsete': ('tufset',),
'tufsetere': ('tufset',),
'tufsetest': ('tufset',),
'tufseteste': ('tufset',),
'tufsete': ('tufsete',),
'tufta': ('tufte',),
'tuftede': ('tufte',),
'tuftende': ('tufte',),
'tuftet': ('tufte',),
'tuftete': ('tufte',),
'tukla': ('tukle',),
'tuklede': ('tukle',),
'tuklende': ('tukle',),
'tuklet': ('tukle',),
'tuklete': ('tukle',),
'tuklet': ('tuklet',),
'tuklete': ('tuklet',),
'tukletere': ('tuklet',),
'tukletest': ('tuklet',),
'tukleteste': ('tuklet',),
'tuklete': ('tuklete',),
'tukta': ('tukte',),
'tuktede': ('tukte',),
'tuktende': ('tukte',),
'tuktet': ('tukte',),
'tuktete': ('tukte',),
'tuktig': ('tuktig',),
'tuktige': ('tuktig',),
'tuktigere': ('tuktig',),
'tuktigst': ('tuktig',),
'tuktigste': ('tuktig',),
'tulla': ('tulle',),
'tullede': ('tulle',),
'tullende': ('tulle',),
'tullet': ('tulle',),
'tullete': ('tulle',),
'tullerusk': ('tullerusk',),
'tulleruske': ('tullerusk',),
'tulleruskere': ('tullerusk',),
'tulleruskest': ('tullerusk',),
'tulleruskeste': ('tullerusk',),
'tullet': ('tullet',),
'tullete': ('tullet',),
'tulletere': ('tullet',),
'tulletest': ('tullet',),
'tulleteste': ('tullet',),
'tullete': ('tullete',),
'tumla': ('tumle',),
'tumlede': ('tumle',),
'tumlende': ('tumle',),
'tumlet': ('tumle',),
'tumlete': ('tumle',),
'tummelumsk': ('tummelumsk',),
'tummelumske': ('tummelumsk',),
'tummelumskere': ('tummelumsk',),
'tummelumskest': ('tummelumsk',),
'tummelumskeste': ('tummelumsk',),
'tumultuarisk': ('tumultuarisk',),
'tumultuariske': ('tumultuarisk',),
'tumultuariskere': ('tumultuarisk',),
'tumultuariskest': ('tumultuarisk',),
'tumultuariskeste': ('tumultuarisk',),
'tuna': ('tune',),
'tunede': ('tune',),
'tunende': ('tune',),
'tunet': ('tune',),
'tunete': ('tune',),
'tung': ('tung',),
'tunge': ('tung',),
'tungere': ('tung',),
'tungest': ('tung',),
'tungeste': ('tung',),
'tungt': ('tung',),
'tyngre': ('tung',),
'tyngst': ('tung',),
'tyngste': ('tung',),
'tungbedt': ('tungbedt',),
'tungbedte': ('tungbedt',),
'tungbedtere': ('tungbedt',),
'tungbedtest': ('tungbedt',),
'tungbedteste': ('tungbedt',),
'tungbedtt': ('tungbedt',),
'tungdrevet': ('tungdrevet',),
'tungdrevne': ('tungdrevet',),
'tungdrevnere': ('tungdrevet',),
'tungdrevnest': ('tungdrevet',),
'tungdrevneste': ('tungdrevet',),
'tungerapp': ('tungerapp',),
'tungerappe': ('tungerapp',),
'tungerappere': ('tungerapp',),
'tungerappest': ('tungerapp',),
'tungerappeste': ('tungerapp',),
'tungerapt': ('tungerapp',),
'tunget': ('tunget',),
'tungete': ('tunget',),
'tungetere': ('tunget',),
'tungetest': ('tunget',),
'tungeteste': ('tunget',),
'tungete': ('tungete',),
'tunghørt': ('tunghørt',),
'tunghørte': ('tunghørt',),
'tunghørtere': ('tunghørt',),
'tunghørtest': ('tunghørt',),
'tunghørteste': ('tunghørt',),
'tunglasta': ('tunglasta',),
'tunglastede': ('tunglastet',),
'tunglastet': ('tunglastet',),
'tunglastete': ('tunglastet',),
'tunglastetere': ('tunglastet',),
'tunglastetest': ('tunglastet',),
'tunglasteteste': ('tunglastet',),
'tunglest': ('tunglest',),
'tungleste': ('tunglest',),
'tunglestere': ('tunglest',),
'tunglestest': ('tunglest',),
'tunglesteste': ('tunglest',),
'tunglynt': ('tunglynt',),
'tunglynte': ('tunglynt',),
'tunglyntere': ('tunglynt',),
'tunglyntest': ('tunglynt',),
'tunglynteste': ('tunglynt',),
'tungnem': ('tungnem',),
'tungnemme': ('tungnem',),
'tungnemmere': ('tungnem',),
'tungnemmest': ('tungnem',),
'tungnemmeste': ('tungnem',),
'tungnemt': ('tungnem',),
'tungpusta': ('tungpusta',),
'tungpusten': ('tungpusten',),
'tungpustent': ('tungpusten',),
'tungpustne': ('tungpusten',),
'tungpustnere': ('tungpusten',),
'tungpustnest': ('tungpusten',),
'tungpustneste': ('tungpusten',),
'tungpustede': ('tungpustet',),
'tungpustet': ('tungpustet',),
'tungpustete': ('tungpustet',),
'tungpustetere': ('tungpustet',),
'tungpustetest': ('tungpustet',),
'tungpusteteste': ('tungpustet',),
'tungrodd': ('tungrodd',),
'tungrodde': ('tungrodd',),
'tungroddere': ('tungrodd',),
'tungroddest': ('tungrodd',),
'tungroddeste': ('tungrodd',),
'tungsindig': ('tungsindig',),
'tungsindige': ('tungsindig',),
'tungsindigere': ('tungsindig',),
'tungsindigst': ('tungsindig',),
'tungsindigste': ('tungsindig',),
'tungsint': ('tungsint',),
'tungsinte': ('tungsint',),
'tungsintere': ('tungsint',),
'tungsintest': ('tungsint',),
'tungsinteste': ('tungsint',),
'tungtflytende': ('tungtflytende',),
'tungtfordøyelig': ('tungtfordøyelig',),
'tungtfordøyelige': ('tungtfordøyelig',),
'tungtfordøyeligere': ('tungtfordøyelig',),
'tungtfordøyeligst': ('tungtfordøyelig',),
'tungtfordøyeligste': ('tungtfordøyelig',),
'tungtveiende': ('tungtveiende',),
'tungusisk': ('tungusisk',),
'tungusiske': ('tungusisk',),
'tungusiskere': ('tungusisk',),
'tungusiskest': ('tungusisk',),
'tungusiskeste': ('tungusisk',),
'tungvinn': ('tungvinn',),
'tungvinne': ('tungvinn',),
'tungvinnere': ('tungvinn',),
'tungvinnest': ('tungvinn',),
'tungvinneste': ('tungvinn',),
'tungvint': ('tungvinn',),
'tungvint': ('tungvint',),
'tungvinte': ('tungvint',),
'tungvintere': ('tungvint',),
'tungvintest': ('tungvint',),
'tungvinteste': ('tungvint',),
'tunisisk': ('tunisisk',),
'tunisiske': ('tunisisk',),
'tunisiskere': ('tunisisk',),
'tunisiskest': ('tunisisk',),
'tunisiskeste': ('tunisisk',),
'tuperende': ('tupere',),
'tupert': ('tupere',),
'tuperte': ('tupere',),
'tuppa': ('tuppe',),
'tuppede': ('tuppe',),
'tuppende': ('tuppe',),
'tuppet': ('tuppe',),
'tuppete': ('tuppe',),
'tuppet': ('tuppet',),
'tuppete': ('tuppet',),
'tuppetere': ('tuppet',),
'tuppetest': ('tuppet',),
'tuppeteste': ('tuppet',),
'tuppete': ('tuppete',),
'turbulent': ('turbulent',),
'turbulente': ('turbulent',),
'turbulentere': ('turbulent',),
'turbulentest': ('turbulent',),
'turbulenteste': ('turbulent',),
'tura': ('ture',),
'turede': ('ture',),
'turende': ('ture',),
'turet': ('ture',),
'turete': ('ture',),
'turt': ('ture',),
'turte': ('ture',),
'turevis': ('turevis',),
'turevise': ('turevis',),
'turevisere': ('turevis',),
'turevisest': ('turevis',),
'tureviseste': ('turevis',),
'turevist': ('turevis',),
'turkis': ('turkis',),
'turkise': ('turkis',),
'turkisere': ('turkis',),
'turkisest': ('turkis',),
'turkiseste': ('turkis',),
'turkist': ('turkis',),
'turkisblå': ('turkisblå',),
'turkisblåe': ('turkisblå',),
'turkisblåere': ('turkisblå',),
'turkisblåest': ('turkisblå',),
'turkisblåeste': ('turkisblå',),
'turkisblått': ('turkisblå',),
'turkmensk': ('turkmensk',),
'turkmenske': ('turkmensk',),
'turkmenskere': ('turkmensk',),
'turkmenskest': ('turkmensk',),
'turkmenskeste': ('turkmensk',),
'turkotatarisk': ('turkotatarisk',),
'turkotatariske': ('turkotatarisk',),
'turkotatariskere': ('turkotatarisk',),
'turkotatariskest': ('turkotatarisk',),
'turkotatariskeste': ('turkotatarisk',),
'turna': ('turne',),
'turnede': ('turne',),
'turnende': ('turne',),
'turnet': ('turne',),
'turnete': ('turne',),
'turnerende': ('turnere',),
'turnert': ('turnere',),
'turnerte': ('turnere',),
'turnerende': ('turnere',),
'turnert': ('turnere',),
'turnerte': ('turnere',),
'turvende': ('turve',),
'turvt': ('turve',),
'turvte': ('turve',),
'turvis': ('turvis',),
'turvise': ('turvis',),
'turvisere': ('turvis',),
'turvisest': ('turvis',),
'turviseste': ('turvis',),
'turvist': ('turvis',),
'tusende': ('tusende',),
'tusendels': ('tusendels',),
'tusentallig': ('tusentallig',),
'tusentallige': ('tusentallig',),
'tusentalligere': ('tusentallig',),
'tusentalligst': ('tusentallig',),
'tusentalligste': ('tusentallig',),
'tusentalls': ('tusentalls',),
'tusentals': ('tusentals',),
'tusenårig': ('tusenårig',),
'tusenårige': ('tusenårig',),
'tusenårigere': ('tusenårig',),
'tusenårigst': ('tusenårig',),
'tusenårigste': ('tusenårig',),
'tusenårs': ('tusenårs',),
'tusja': ('tusje',),
'tusjede': ('tusje',),
'tusjende': ('tusje',),
'tusjet': ('tusje',),
'tusjete': ('tusje',),
'tusjerende': ('tusjere',),
'tusjert': ('tusjere',),
'tusjerte': ('tusjere',),
'tuska': ('tuske',),
'tuskede': ('tuske',),
'tuskende': ('tuske',),
'tusket': ('tuske',),
'tuskete': ('tuske',),
'tuska': ('tuske',),
'tuskede': ('tuske',),
'tuskende': ('tuske',),
'tusket': ('tuske',),
'tuskete': ('tuske',),
'tusken': ('tusken',),
'tuskent': ('tusken',),
'tuskne': ('tusken',),
'tusknere': ('tusken',),
'tusknest': ('tusken',),
'tuskneste': ('tusken',),
'tusket': ('tusket',),
'tuskete': ('tusket',),
'tusketere': ('tusket',),
'tusketest': ('tusket',),
'tusketeste': ('tusket',),
'tuskete': ('tuskete',),
'tusla': ('tusle',),
'tuslede': ('tusle',),
'tuslende': ('tusle',),
'tuslet': ('tusle',),
'tuslete': ('tusle',),
'tuslen': ('tuslen',),
'tuslene': ('tuslen',),
'tuslenere': ('tuslen',),
'tuslenest': ('tuslen',),
'tusleneste': ('tuslen',),
'tuslent': ('tuslen',),
'tuslne': ('tuslen',),
'tuslnere': ('tuslen',),
'tuslnest': ('tuslen',),
'tuslneste': ('tuslen',),
'tuslet': ('tuslet',),
'tuslete': ('tuslet',),
'tusletere': ('tuslet',),
'tusletest': ('tuslet',),
'tusleteste': ('tuslet',),
'tuslete': ('tuslete',),
'tussa': ('tusse',),
'tussede': ('tusse',),
'tussende': ('tusse',),
'tusset': ('tusse',),
'tussete': ('tusse',),
'tusset': ('tusset',),
'tussete': ('tusset',),
'tussetere': ('tusset',),
'tussetest': ('tusset',),
'tusseteste': ('tusset',),
'tussete': ('tussete',),
'tussmørk': ('tussmørk',),
'tussmørke': ('tussmørk',),
'tussmørkere': ('tussmørk',),
'tussmørkest': ('tussmørk',),
'tussmørkeste': ('tussmørk',),
'tussmørkt': ('tussmørk',),
'tusta': ('tuste',),
'tustede': ('tuste',),
'tustende': ('tuste',),
'tustet': ('tuste',),
'tustete': ('tuste',),
'tusten': ('tusten',),
'tustent': ('tusten',),
'tustne': ('tusten',),
'tustnere': ('tusten',),
'tustnest': ('tusten',),
'tustneste': ('tusten',),
'tustet': ('tustet',),
'tustete': ('tustet',),
'tustetere': ('tustet',),
'tustetest': ('tustet',),
'tusteteste': ('tustet',),
'tustete': ('tustete',),
'tuta': ('tute',),
'tutede': ('tute',),
'tutende': ('tute',),
'tutet': ('tute',),
'tutete': ('tute',),
'tutla': ('tutle',),
'tutlede': ('tutle',),
'tutlende': ('tutle',),
'tutlet': ('tutle',),
'tutlete': ('tutle',),
'tutlet': ('tutlet',),
'tutlete': ('tutlet',),
'tutletere': ('tutlet',),
'tutletest': ('tutlet',),
'tutleteste': ('tutlet',),
'tutlete': ('tutlete',),
'tuvalsk': ('tuvalsk',),
'tuvalske': ('tuvalsk',),
'tuvalskere': ('tuvalsk',),
'tuvalskest': ('tuvalsk',),
'tuvalskeste': ('tuvalsk',),
'tuvet': ('tuvet',),
'tuvete': ('tuvet',),
'tuvetere': ('tuvet',),
'tuvetest': ('tuvet',),
'tuveteste': ('tuvet',),
'tuvete': ('tuvete',),
'tvangfri': ('tvangfri',),
'tvangfrie': ('tvangfri',),
'tvangfriere': ('tvangfri',),
'tvangfriest': ('tvangfri',),
'tvangfrieste': ('tvangfri',),
'tvangfritt': ('tvangfri',),
'tvanglaus': ('tvanglaus',),
'tvanglause': ('tvanglaus',),
'tvanglausere': ('tvanglaus',),
'tvanglausest': ('tvanglaus',),
'tvanglauseste': ('tvanglaus',),
'tvanglaust': ('tvanglaus',),
'tvangløs': ('tvangløs',),
'tvangløse': ('tvangløs',),
'tvangløsere': ('tvangløs',),
'tvangløsest': ('tvangløs',),
'tvangløseste': ('tvangløs',),
'tvangløst': ('tvangløs',),
'tvangsdirigerende': ('tvangsdirigere',),
'tvangsdirigert': ('tvangsdirigere',),
'tvangsdirigerte': ('tvangsdirigere',),
'tvangsinnlagt': ('tvangsinnlegge',),
'tvangsinnlagte': ('tvangsinnlegge',),
'tvangsinnleggende': ('tvangsinnlegge',),
'tvebo': ('tvebo',),
'tvebu': ('tvebu',),
'tvedelende': ('tvedele',),
'tvedelt': ('tvedele',),
'tvedelte': ('tvedele',),
'tveegga': ('tveegga',),
'tveeggede': ('tveegget',),
'tveegget': ('tveegget',),
'tveeggete': ('tveegget',),
'tveeggetere': ('tveegget',),
'tveeggetest': ('tveegget',),
'tveeggeteste': ('tveegget',),
'tvekjønna': ('tvekjønna',),
'tvekjønnede': ('tvekjønnet',),
'tvekjønnet': ('tvekjønnet',),
'tvekjønnete': ('tvekjønnet',),
'tvekjønnetere': ('tvekjønnet',),
'tvekjønnetest': ('tvekjønnet',),
'tvekjønneteste': ('tvekjønnet',),
'tvekrokede': ('tvekroket',),
'tvekroket': ('tvekroket',),
'tvekrokete': ('tvekroket',),
'tvekroketere': ('tvekroket',),
'tvekroketest': ('tvekroket',),
'tvekroketeste': ('tvekroket',),
'tvekrokete': ('tvekrokete',),
'tverr': ('tverr',),
'tverre': ('tverr',),
'tverrere': ('tverr',),
'tverrest': ('tverr',),
'tverreste': ('tverr',),
'tvert': ('tverr',),
'tverrfaglig': ('tverrfaglig',),
'tverrfaglige': ('tverrfaglig',),
'tverrfagligere': ('tverrfaglig',),
'tverrfagligst': ('tverrfaglig',),
'tverrfagligste': ('tverrfaglig',),
'tverrgående': ('tverrgående',),
'tverrplattfot': ('tverrplattfot',),
'tverrpolitisk': ('tverrpolitisk',),
'tverrpolitiske': ('tverrpolitisk',),
'tverrpolitiskere': ('tverrpolitisk',),
'tverrpolitiskest': ('tverrpolitisk',),
'tverrpolitiskeste': ('tverrpolitisk',),
'tverrskips': ('tverrskips',),
'tverrsnudd': ('tverrsnu',),
'tverrsnudde': ('tverrsnu',),
'tverrsnuende': ('tverrsnu',),
'tverrstansa': ('tverrstanse',),
'tverrstansede': ('tverrstanse',),
'tverrstansende': ('tverrstanse',),
'tverrstanset': ('tverrstanse',),
'tverrstansete': ('tverrstanse',),
'tverrstillende': ('tverrstille',),
'tverrstilt': ('tverrstille',),
'tverrstilte': ('tverrstille',),
'tverrstripet': ('tverrstripet',),
'tverrstripete': ('tverrstripet',),
'tverrstripetere': ('tverrstripet',),
'tverrstripetest': ('tverrstripet',),
'tverrstripeteste': ('tverrstripet',),
'tverrstripete': ('tverrstripete',),
'tverrvendende': ('tverrvende',),
'tverrvendt': ('tverrvende',),
'tverrvendte': ('tverrvende',),
'tverrvitenskapelig': ('tverrvitenskapelig',),
'tverrvitenskapelige': ('tverrvitenskapelig',),
'tverrvitenskapeligere': ('tverrvitenskapelig',),
'tverrvitenskapeligst': ('tverrvitenskapelig',),
'tverrvitenskapeligste': ('tverrvitenskapelig',),
'tversgående': ('tversgående',),
'tvetta': ('tvette',),
'tvettede': ('tvette',),
'tvettende': ('tvette',),
'tvettet': ('tvette',),
'tvettete': ('tvette',),
'tvetydig': ('tvetydig',),
'tvetydige': ('tvetydig',),
'tvetydigere': ('tvetydig',),
'tvetydigst': ('tvetydig',),
'tvetydigste': ('tvetydig',),
'tviholdende': ('tviholde',),
'tviholdt': ('tviholde',),
'tviholdte': ('tviholde',),
'tvikrokede': ('tvikroket',),
'tvikroket': ('tvikroket',),
'tvikrokete': ('tvikroket',),
'tvikroketere': ('tvikroket',),
'tvikroketest': ('tvikroket',),
'tvikroketeste': ('tvikroket',),
'tvikrokete': ('tvikrokete',),
'tvikrøkt': ('tvikrøkt',),
'tvikrøkte': ('tvikrøkt',),
'tvikrøktere': ('tvikrøkt',),
'tvikrøktest': ('tvikrøkt',),
'tvikrøkteste': ('tvikrøkt',),
'tvilende': ('tvile',),
'tvilt': ('tvile',),
'tvilte': ('tvile',),
'tvillaus': ('tvillaus',),
'tvillause': ('tvillaus',),
'tvillausere': ('tvillaus',),
'tvillausest': ('tvillaus',),
'tvillauseste': ('tvillaus',),
'tvillaust': ('tvillaus',),
'tvilløs': ('tvilløs',),
'tvilløse': ('tvilløs',),
'tvilløsere': ('tvilløs',),
'tvilløsest': ('tvilløs',),
'tvilløseste': ('tvilløs',),
'tvilløst': ('tvilløs',),
'tvilrådig': ('tvilrådig',),
'tvilrådige': ('tvilrådig',),
'tvilrådigere': ('tvilrådig',),
'tvilrådigst': ('tvilrådig',),
'tvilrådigste': ('tvilrådig',),
'tvilsom': ('tvilsom',),
'tvilsomme': ('tvilsom',),
'tvilsommere': ('tvilsom',),
'tvilsomst': ('tvilsom',),
'tvilsomste': ('tvilsom',),
'tvilsomt': ('tvilsom',),
'tvingende': ('tvinge',),
'tvungen': ('tvinge',),
'tvunget': ('tvinge',),
'tvungne': ('tvinge',),
'tvinna': ('tvinne',),
'tvinnede': ('tvinne',),
'tvinnende': ('tvinne',),
'tvinnet': ('tvinne',),
'tvinnete': ('tvinne',),
'tvunne': ('tvinne',),
'tvunnet': ('tvinne',),
'tvista': ('tviste',),
'tvistede': ('tviste',),
'tvistende': ('tviste',),
'tvistet': ('tviste',),
'tvistete': ('tviste',),
'tvisynt': ('tvisynt',),
'tvisynte': ('tvisynt',),
'tvisyntere': ('tvisynt',),
'tvisyntest': ('tvisynt',),
'tvisynteste': ('tvisynt',),
'tvungen': ('tvungen',),
'tvungent': ('tvungen',),
'tvungne': ('tvungen',),
'tvungnere': ('tvungen',),
'tvungnest': ('tvungen',),
'tvungneste': ('tvungen',),
'tværa': ('tvære',),
'tværede': ('tvære',),
'tværende': ('tvære',),
'tværet': ('tvære',),
'tværete': ('tvære',),
'twista': ('twiste',),
'twistede': ('twiste',),
'twistende': ('twiste',),
'twistet': ('twiste',),
'twistete': ('twiste',),
'tydd': ('ty',),
'tydde': ('ty',),
'tyende': ('ty',),
'ty': ('ty',),
'tye': ('ty',),
'tyere': ('ty',),
'tyest': ('ty',),
'tyeste': ('ty',),
'tytt': ('ty',),
'tydd': ('tyde',),
'tydde': ('tyde',),
'tydende': ('tyde',),
'tyda': ('tyde',),
'tydd': ('tyde',),
'tydde': ('tyde',),
'tydede': ('tyde',),
'tydende': ('tyde',),
'tydet': ('tyde',),
'tydete': ('tyde',),
'tydelig': ('tydelig',),
'tydelige': ('tydelig',),
'tydeligere': ('tydelig',),
'tydeligst': ('tydelig',),
'tydeligste': ('tydelig',),
'tydeliggjort': ('tydeliggjøre',),
'tydeliggjorte': ('tydeliggjøre',),
'tydeliggjørende': ('tydeliggjøre',),
'tyføs': ('tyføs',),
'tyføse': ('tyføs',),
'tyføsere': ('tyføs',),
'tyføsest': ('tyføs',),
'tyføseste': ('tyføs',),
'tyføst': ('tyføs',),
'tygd': ('tygge',),
'tygde': ('tygge',),
'tyggede': ('tygge',),
'tyggende': ('tygge',),
'tygget': ('tygge',),
'tyggete': ('tygge',),
'tykk': ('tykk',),
'tykke': ('tykk',),
'tykkere': ('tykk',),
'tykkest': ('tykk',),
'tykkeste': ('tykk',),
'tykt': ('tykk',),
'tykkende': ('tykke',),
'tykt': ('tykke',),
'tykte': ('tykke',),
'tykkfallen': ('tykkfallen',),
'tykkfallent': ('tykkfallen',),
'tykkfalne': ('tykkfallen',),
'tykkfalnere': ('tykkfallen',),
'tykkfalnest': ('tykkfallen',),
'tykkfalneste': ('tykkfallen',),
'tykkhuda': ('tykkhuda',),
'tykkhudede': ('tykkhudet',),
'tykkhudet': ('tykkhudet',),
'tykkhudete': ('tykkhudet',),
'tykkhudetere': ('tykkhudet',),
'tykkhudetest': ('tykkhudet',),
'tykkhudeteste': ('tykkhudet',),
'tykkskalla': ('tykkskalla',),
'tykkskallede': ('tykkskallet',),
'tykkskallet': ('tykkskallet',),
'tykkskallete': ('tykkskallet',),
'tykkskalletere': ('tykkskallet',),
'tykkskalletest': ('tykkskallet',),
'tykkskalleteste': ('tykkskallet',),
'tykna': ('tykne',),
'tyknede': ('tykne',),
'tyknende': ('tykne',),
'tyknet': ('tykne',),
'tyknete': ('tykne',),
'tylla': ('tylle',),
'tyllede': ('tylle',),
'tyllende': ('tylle',),
'tyllet': ('tylle',),
'tyllete': ('tylle',),
'tynende': ('tyne',),
'tynt': ('tyne',),
'tynte': ('tyne',),
'tynga': ('tynge',),
'tyngd': ('tynge',),
'tyngde': ('tynge',),
'tyngede': ('tynge',),
'tyngende': ('tynge',),
'tynget': ('tynge',),
'tyngete': ('tynge',),
'tyngre': ('tyngre',),
'tyngst': ('tyngst',),
'tyngste': ('tyngst',),
'tynn': ('tynn',),
'tynne': ('tynn',),
'tynnere': ('tynn',),
'tynnest': ('tynn',),
'tynneste': ('tynn',),
'tynt': ('tynn',),
'tynna': ('tynne',),
'tynnede': ('tynne',),
'tynnende': ('tynne',),
'tynnet': ('tynne',),
'tynnete': ('tynne',),
'tynnhuda': ('tynnhuda',),
'tynnhudede': ('tynnhudet',),
'tynnhudet': ('tynnhudet',),
'tynnhudete': ('tynnhudet',),
'tynnhudetere': ('tynnhudet',),
'tynnhudetest': ('tynnhudet',),
'tynnhudeteste': ('tynnhudet',),
'tynnhåra': ('tynnhåra',),
'tynnhårede': ('tynnhåret',),
'tynnhåret': ('tynnhåret',),
'tynnhårete': ('tynnhåret',),
'tynnhåretere': ('tynnhåret',),
'tynnhåretest': ('tynnhåret',),
'tynnhåreteste': ('tynnhåret',),
'tynnkledd': ('tynnkledd',),
'tynnkledde': ('tynnkledd',),
'tynnkleddere': ('tynnkledd',),
'tynnkleddest': ('tynnkledd',),
'tynnkleddeste': ('tynnkledd',),
'tynnslitt': ('tynnslitt',),
'tynnslitte': ('tynnslitt',),
'tynnslittere': ('tynnslitt',),
'tynnslittest': ('tynnslitt',),
'tynnslitteste': ('tynnslitt',),
'tyntflytende': ('tyntflytende',),
'typa': ('type',),
'typede': ('type',),
'typende': ('type',),
'typet': ('type',),
'typete': ('type',),
'typebestemmende': ('typebestemme',),
'typebestemt': ('typebestemme',),
'typebestemte': ('typebestemme',),
'typegodkjennende': ('typegodkjenne',),
'typegodkjent': ('typegodkjenne',),
'typegodkjente': ('typegodkjenne',),
'typifiserende': ('typifisere',),
'typifisert': ('typifisere',),
'typifiserte': ('typifisere',),
'typiserende': ('typisere',),
'typisert': ('typisere',),
'typiserte': ('typisere',),
'typisk': ('typisk',),
'typiske': ('typisk',),
'typiskere': ('typisk',),
'typiskest': ('typisk',),
'typiskeste': ('typisk',),
'typografisk': ('typografisk',),
'typografiske': ('typografisk',),
'typografiskere': ('typografisk',),
'typografiskest': ('typografisk',),
'typografiskeste': ('typografisk',),
'typologiserende': ('typologisere',),
'typologisert': ('typologisere',),
'typologiserte': ('typologisere',),
'typologisk': ('typologisk',),
'typologiske': ('typologisk',),
'typologiskere': ('typologisk',),
'typologiskest': ('typologisk',),
'typologiskeste': ('typologisk',),
'tyranniserende': ('tyrannisere',),
'tyrannisert': ('tyrannisere',),
'tyranniserte': ('tyrannisere',),
'tyrannisk': ('tyrannisk',),
'tyranniske': ('tyrannisk',),
'tyranniskere': ('tyrannisk',),
'tyranniskest': ('tyrannisk',),
'tyranniskeste': ('tyrannisk',),
'tyrkisk': ('tyrkisk',),
'tyrkiske': ('tyrkisk',),
'tyrkiskere': ('tyrkisk',),
'tyrkiskest': ('tyrkisk',),
'tyrkiskeste': ('tyrkisk',),
'tyrolsk': ('tyrolsk',),
'tyrolske': ('tyrolsk',),
'tyrolskere': ('tyrolsk',),
'tyrolskest': ('tyrolsk',),
'tyrolskeste': ('tyrolsk',),
'tysk': ('tysk',),
'tyske': ('tysk',),
'tyskere': ('tysk',),
'tyskest': ('tysk',),
'tyskeste': ('tysk',),
'tyssa': ('tysse',),
'tyssede': ('tysse',),
'tyssende': ('tysse',),
'tysset': ('tysse',),
'tyssete': ('tysse',),
'tyst': ('tyst',),
'tyste': ('tyst',),
'tystere': ('tyst',),
'tystest': ('tyst',),
'tysteste': ('tyst',),
'tysta': ('tyste',),
'tystede': ('tyste',),
'tystende': ('tyste',),
'tystet': ('tyste',),
'tystete': ('tyste',),
'tystna': ('tystne',),
'tystnede': ('tystne',),
'tystnende': ('tystne',),
'tystnet': ('tystne',),
'tystnete': ('tystne',),
'tytende': ('tyte',),
'tytt': ('tyte',),
'tytte': ('tyte',),
'tyvaktig': ('tyvaktig',),
'tyvaktige': ('tyvaktig',),
'tyvaktigere': ('tyvaktig',),
'tyvaktigst': ('tyvaktig',),
'tyvaktigste': ('tyvaktig',),
'tyvlytta': ('tyvlytte',),
'tyvlyttede': ('tyvlytte',),
'tyvlyttende': ('tyvlytte',),
'tyvlyttet': ('tyvlytte',),
'tyvlyttete': ('tyvlytte',),
'tyvlånende': ('tyvlåne',),
'tyvlånt': ('tyvlåne',),
'tyvlånte': ('tyvlåne',),
'tyvslakta': ('tyvslakte',),
'tyvslaktede': ('tyvslakte',),
'tyvslaktende': ('tyvslakte',),
'tyvslaktet': ('tyvslakte',),
'tyvslaktete': ('tyvslakte',),
'tyvstarta': ('tyvstarte',),
'tyvstartede': ('tyvstarte',),
'tyvstartende': ('tyvstarte',),
'tyvstartet': ('tyvstarte',),
'tyvstartete': ('tyvstarte',),
'tyvtitta': ('tyvtitte',),
'tyvtittede': ('tyvtitte',),
'tyvtittende': ('tyvtitte',),
'tyvtittet': ('tyvtitte',),
'tyvtittete': ('tyvtitte',),
'tyvtitta': ('tyvtitte',),
'tyvtittede': ('tyvtitte',),
'tyvtittende': ('tyvtitte',),
'tyvtittet': ('tyvtitte',),
'tyvtittete': ('tyvtitte',),
'tyvtrena': ('tyvtrene',),
'tyvtrenede': ('tyvtrene',),
'tyvtrenende': ('tyvtrene',),
'tyvtrenet': ('tyvtrene',),
'tyvtrenete': ('tyvtrene',),
'tyvtrent': ('tyvtrene',),
'tyvtrente': ('tyvtrene',),
'tåkelagt': ('tåkelegge',),
'tåkelagte': ('tåkelegge',),
'tåkeleggende': ('tåkelegge',),
'tåket': ('tåket',),
'tåkete': ('tåket',),
'tåketere': ('tåket',),
'tåketest': ('tåket',),
'tåketeste': ('tåket',),
'tåkete': ('tåkete',),
'tålende': ('tåle',),
'tålt': ('tåle',),
'tålte': ('tåle',),
'tålelig': ('tålelig',),
'tålelige': ('tålelig',),
'tåleligere': ('tålelig',),
'tåleligst': ('tålelig',),
'tåleligste': ('tålelig',),
'tålmodig': ('tålmodig',),
'tålmodige': ('tålmodig',),
'tålmodigere': ('tålmodig',),
'tålmodigst': ('tålmodig',),
'tålmodigste': ('tålmodig',),
'tålsom': ('tålsom',),
'tålsomme': ('tålsom',),
'tålsommere': ('tålsom',),
'tålsomst': ('tålsom',),
'tålsomste': ('tålsom',),
'tålsomt': ('tålsom',),
'tåpelig': ('tåpelig',),
'tåpelige': ('tåpelig',),
'tåpeligere': ('tåpelig',),
'tåpeligst': ('tåpelig',),
'tåpeligste': ('tåpelig',),
'tåpen': ('tåpen',),
'tåpent': ('tåpen',),
'tåpne': ('tåpen',),
'tåpnere': ('tåpen',),
'tåpnest': ('tåpen',),
'tåpneste': ('tåpen',),
'tåredryppende': ('tåredryppende',),
'tårekvalt': ('tårekvalt',),
'tårekvalte': ('tårekvalt',),
'tårekvaltere': ('tårekvalt',),
'tårekvaltest': ('tårekvalt',),
'tårekvalteste': ('tårekvalt',),
'tåret': ('tåret',),
'tårete': ('tåret',),
'tåretere': ('tåret',),
'tåretest': ('tåret',),
'tåreteste': ('tåret',),
'tårete': ('tårete',),
'tårevåt': ('tårevåt',),
'tårevåte': ('tårevåt',),
'tårevåtere': ('tårevåt',),
'tårevåtest': ('tårevåt',),
'tårevåteste': ('tårevåt',),
'tårevått': ('tårevåt',),
'tårna': ('tårne',),
'tårnede': ('tårne',),
'tårnende': ('tårne',),
'tårnet': ('tårne',),
'tårnete': ('tårne',),
'tårnhøg': ('tårnhøg',),
'tårnhøge': ('tårnhøg',),
'tårnhøgere': ('tårnhøg',),
'tårnhøgest': ('tårnhøg',),
'tårnhøgeste': ('tårnhøg',),
'tårnhøgre': ('tårnhøg',),
'tårnhøgst': ('tårnhøg',),
'tårnhøgste': ('tårnhøg',),
'tårnhøgt': ('tårnhøg',),
'tårnhøy': ('tårnhøy',),
'tårnhøye': ('tårnhøy',),
'tårnhøyere': ('tårnhøy',),
'tårnhøyest': ('tårnhøy',),
'tårnhøyeste': ('tårnhøy',),
'tårnhøyt': ('tårnhøy',),
'tåta': ('tåte',),
'tåtede': ('tåte',),
'tåtende': ('tåte',),
'tåtet': ('tåte',),
'tåtete': ('tåte',),
'tæra': ('tære',),
'tærede': ('tære',),
'tærende': ('tære',),
'tæret': ('tære',),
'tærete': ('tære',),
'tært': ('tære',),
'tærte': ('tære',),
'tæringssjuk': ('tæringssjuk',),
'tæringssjuke': ('tæringssjuk',),
'tæringssjukere': ('tæringssjuk',),
'tæringssjukest': ('tæringssjuk',),
'tæringssjukeste': ('tæringssjuk',),
'tæringssjukt': ('tæringssjuk',),
'tæringssyk': ('tæringssyk',),
'tæringssyke': ('tæringssyk',),
'tæringssykere': ('tæringssyk',),
'tæringssykest': ('tæringssyk',),
'tæringssykeste': ('tæringssyk',),
'tæringssykt': ('tæringssyk',),
'tødd': ('tø',),
'tødde': ('tø',),
'tøende': ('tø',),
'tøff': ('tøff',),
'tøffe': ('tøff',),
'tøffere': ('tøff',),
'tøffest': ('tøff',),
'tøffeste': ('tøff',),
'tøft': ('tøff',),
'tøffa': ('tøffe',),
'tøffede': ('tøffe',),
'tøffende': ('tøffe',),
'tøffet': ('tøffe',),
'tøffete': ('tøffe',),
'tøffa': ('tøffe',),
'tøffede': ('tøffe',),
'tøffende': ('tøffe',),
'tøffet': ('tøffe',),
'tøffete': ('tøffe',),
'tøfla': ('tøfle',),
'tøflede': ('tøfle',),
'tøflende': ('tøfle',),
'tøflet': ('tøfle',),
'tøflete': ('tøfle',),
'tølperaktig': ('tølperaktig',),
'tølperaktige': ('tølperaktig',),
'tølperaktigere': ('tølperaktig',),
'tølperaktigst': ('tølperaktig',),
'tølperaktigste': ('tølperaktig',),
'tømmende': ('tømme',),
'tømt': ('tømme',),
'tømte': ('tømme',),
'tømra': ('tømre',),
'tømrede': ('tømre',),
'tømrende': ('tømre',),
'tømret': ('tømre',),
'tømrete': ('tømre',),
'tørka': ('tørke',),
'tørkede': ('tørke',),
'tørkende': ('tørke',),
'tørket': ('tørke',),
'tørkete': ('tørke',),
'tørkesterk': ('tørkesterk',),
'tørkesterke': ('tørkesterk',),
'tørkesterkere': ('tørkesterk',),
'tørkesterkest': ('tørkesterk',),
'tørkesterkeste': ('tørkesterk',),
'tørkesterkt': ('tørkesterk',),
'tørkesvak': ('tørkesvak',),
'tørkesvake': ('tørkesvak',),
'tørkesvakere': ('tørkesvak',),
'tørkesvakest': ('tørkesvak',),
'tørkesvakeste': ('tørkesvak',),
'tørkesvakt': ('tørkesvak',),
'tørna': ('tørne',),
'tørnede': ('tørne',),
'tørnende': ('tørne',),
'tørnet': ('tørne',),
'tørnete': ('tørne',),
'tørr': ('tørr',),
'tørre': ('tørr',),
'tørrere': ('tørr',),
'tørrest': ('tørr',),
'tørreste': ('tørr',),
'tørt': ('tørr',),
'tørrhosta': ('tørrhoste',),
'tørrhostede': ('tørrhoste',),
'tørrhostende': ('tørrhoste',),
'tørrhostet': ('tørrhoste',),
'tørrhostete': ('tørrhoste',),
'tørrkokende': ('tørrkoke',),
'tørrkokt': ('tørrkoke',),
'tørrkokte': ('tørrkoke',),
'tørrlagt': ('tørrlegge',),
'tørrlagte': ('tørrlegge',),
'tørrleggende': ('tørrlegge',),
'tørrskodd': ('tørrskodd',),
'tørrskodde': ('tørrskodd',),
'tørrskoddere': ('tørrskodd',),
'tørrskoddest': ('tørrskodd',),
'tørrskoddeste': ('tørrskodd',),
'tørrtrena': ('tørrtrene',),
'tørrtrenede': ('tørrtrene',),
'tørrtrenende': ('tørrtrene',),
'tørrtrenet': ('tørrtrene',),
'tørrtrenete': ('tørrtrene',),
'tørrtrent': ('tørrtrene',),
'tørrtrente': ('tørrtrene',),
'tørrvittig': ('tørrvittig',),
'tørrvittige': ('tørrvittig',),
'tørrvittigere': ('tørrvittig',),
'tørrvittigst': ('tørrvittig',),
'tørrvittigste': ('tørrvittig',),
'tørst': ('tørst',),
'tørste': ('tørst',),
'tørstere': ('tørst',),
'tørstest': ('tørst',),
'tørsteste': ('tørst',),
'tørsta': ('tørste',),
'tørstede': ('tørste',),
'tørstende': ('tørste',),
'tørstet': ('tørste',),
'tørstete': ('tørste',),
'tøsaktig': ('tøsaktig',),
'tøsaktige': ('tøsaktig',),
'tøsaktigere': ('tøsaktig',),
'tøsaktigst': ('tøsaktig',),
'tøsaktigste': ('tøsaktig',),
'tøset': ('tøset',),
'tøsete': ('tøset',),
'tøsetere': ('tøset',),
'tøsetest': ('tøset',),
'tøseteste': ('tøset',),
'tøsete': ('tøsete',),
'tøtsja': ('tøtsje',),
'tøtsjede': ('tøtsje',),
'tøtsjende': ('tøtsje',),
'tøtsjet': ('tøtsje',),
'tøtsjete': ('tøtsje',),
'tøva': ('tøve',),
'tøvd': ('tøve',),
'tøvde': ('tøve',),
'tøvede': ('tøve',),
'tøvende': ('tøve',),
'tøvet': ('tøve',),
'tøvete': ('tøve',),
'tøvet': ('tøvet',),
'tøvete': ('tøvet',),
'tøvetere': ('tøvet',),
'tøvetest': ('tøvet',),
'tøveteste': ('tøvet',),
'tøvete': ('tøvete',),
'tøybar': ('tøybar',),
'tøybare': ('tøybar',),
'tøybarere': ('tøybar',),
'tøybarest': ('tøybar',),
'tøybareste': ('tøybar',),
'tøybart': ('tøybar',),
'tøyd': ('tøye',),
'tøyde': ('tøye',),
'tøyede': ('tøye',),
'tøyende': ('tøye',),
'tøyet': ('tøye',),
'tøyete': ('tøye',),
'tøyelig': ('tøyelig',),
'tøyelige': ('tøyelig',),
'tøyeligere': ('tøyelig',),
'tøyeligst': ('tøyelig',),
'tøyeligste': ('tøyelig',),
'tøyla': ('tøyle',),
'tøylede': ('tøyle',),
'tøylende': ('tøyle',),
'tøylet': ('tøyle',),
'tøylete': ('tøyle',),
'tøylesløs': ('tøylesløs',),
'tøylesløse': ('tøylesløs',),
'tøylesløsere': ('tøylesløs',),
'tøylesløsest': ('tøylesløs',),
'tøylesløseste': ('tøylesløs',),
'tøylesløst': ('tøylesløs',),
'tøysa': ('tøyse',),
'tøysede': ('tøyse',),
'tøysende': ('tøyse',),
'tøyset': ('tøyse',),
'tøysete': ('tøyse',),
'tøyst': ('tøyse',),
'tøyste': ('tøyse',),
'tøyset': ('tøyset',),
'tøysete': ('tøyset',),
'tøysetere': ('tøyset',),
'tøysetest': ('tøyset',),
'tøyseteste': ('tøyset',),
'tøysete': ('tøysete',),
'uaktsom': ('uaktsom',),
'uaktsomme': ('uaktsom',),
'uaktsommere': ('uaktsom',),
'uaktsommest': ('uaktsom',),
'uaktsommeste': ('uaktsom',),
'uaktsomt': ('uaktsom',),
'ualminnelig': ('ualminnelig',),
'ualminnelige': ('ualminnelig',),
'ualminneligere': ('ualminnelig',),
'ualminneligst': ('ualminnelig',),
'ualminneligste': ('ualminnelig',),
'uamerikansk': ('uamerikansk',),
'uamerikanske': ('uamerikansk',),
'uamerikanskere': ('uamerikansk',),
'uamerikanskest': ('uamerikansk',),
'uamerikanskeste': ('uamerikansk',),
'uanede': ('uanet',),
'uanet': ('uanet',),
'uanete': ('uanet',),
'uanetere': ('uanet',),
'uanetest': ('uanet',),
'uaneteste': ('uanet',),
'uanfekta': ('uanfekta',),
'uanfektede': ('uanfektet',),
'uanfektet': ('uanfektet',),
'uanfektete': ('uanfektet',),
'uanfektetere': ('uanfektet',),
'uanfektetest': ('uanfektet',),
'uanfekteteste': ('uanfektet',),
'uangripelig': ('uangripelig',),
'uangripelige': ('uangripelig',),
'uangripeligere': ('uangripelig',),
'uangripeligst': ('uangripelig',),
'uangripeligste': ('uangripelig',),
'uanmeldt': ('uanmeldt',),
'uanmeldte': ('uanmeldt',),
'uanmeldtere': ('uanmeldt',),
'uanmeldtest': ('uanmeldt',),
'uanmeldteste': ('uanmeldt',),
'uanselig': ('uanselig',),
'uanselige': ('uanselig',),
'uanseligere': ('uanselig',),
'uanseligst': ('uanselig',),
'uanseligste': ('uanselig',),
'uanstendig': ('uanstendig',),
'uanstendige': ('uanstendig',),
'uanstendigere': ('uanstendig',),
'uanstendigst': ('uanstendig',),
'uanstendigste': ('uanstendig',),
'uanstrengt': ('uanstrengt',),
'uanstrengte': ('uanstrengt',),
'uanstrengtere': ('uanstrengt',),
'uanstrengtest': ('uanstrengt',),
'uanstrengteste': ('uanstrengt',),
'uansvarlig': ('uansvarlig',),
'uansvarlige': ('uansvarlig',),
'uansvarligere': ('uansvarlig',),
'uansvarligst': ('uansvarlig',),
'uansvarligste': ('uansvarlig',),
'uant': ('uant',),
'uante': ('uant',),
'uantere': ('uant',),
'uantest': ('uant',),
'uanteste': ('uant',),
'uantakelig': ('uantakelig',),
'uantakelige': ('uantakelig',),
'uantakeligere': ('uantakelig',),
'uantakeligst': ('uantakelig',),
'uantakeligste': ('uantakelig',),
'uanvendelig': ('uanvendelig',),
'uanvendelige': ('uanvendelig',),
'uanvendeligere': ('uanvendelig',),
'uanvendeligst': ('uanvendelig',),
'uanvendeligste': ('uanvendelig',),
'uappetittlig': ('uappetittlig',),
'uappetittlige': ('uappetittlig',),
'uappetittligere': ('uappetittlig',),
'uappetittligst': ('uappetittlig',),
'uappetittligste': ('uappetittlig',),
'uartig': ('uartig',),
'uartige': ('uartig',),
'uartigere': ('uartig',),
'uartigst': ('uartig',),
'uartigste': ('uartig',),
'uartikulert': ('uartikulert',),
'uartikulerte': ('uartikulert',),
'uartikulertere': ('uartikulert',),
'uartikulertest': ('uartikulert',),
'uartikulerteste': ('uartikulert',),
'uatskillelig': ('uatskillelig',),
'uatskillelige': ('uatskillelig',),
'uatskilleligere': ('uatskillelig',),
'uatskilleligst': ('uatskillelig',),
'uatskilleligste': ('uatskillelig',),
'uavbrutt': ('uavbrutt',),
'uavbrutte': ('uavbrutt',),
'uavbruttere': ('uavbrutt',),
'uavbruttest': ('uavbrutt',),
'uavbrutteste': ('uavbrutt',),
'uavgjort': ('uavgjort',),
'uavgjorte': ('uavgjort',),
'uavgjortere': ('uavgjort',),
'uavgjortest': ('uavgjort',),
'uavgjorteste': ('uavgjort',),
'uavhendelig': ('uavhendelig',),
'uavhendelige': ('uavhendelig',),
'uavhendeligere': ('uavhendelig',),
'uavhendeligst': ('uavhendelig',),
'uavhendeligste': ('uavhendelig',),
'uavhengig': ('uavhengig',),
'uavhengige': ('uavhengig',),
'uavhengigere': ('uavhengig',),
'uavhengigst': ('uavhengig',),
'uavhengigste': ('uavhengig',),
'uavhenta': ('uavhenta',),
'uavhentede': ('uavhentet',),
'uavhentet': ('uavhentet',),
'uavhentete': ('uavhentet',),
'uavhentetere': ('uavhentet',),
'uavhentetest': ('uavhentet',),
'uavhenteteste': ('uavhentet',),
'uavklart': ('uavklart',),
'uavklarte': ('uavklart',),
'uavklartere': ('uavklart',),
'uavklartest': ('uavklart',),
'uavklarteste': ('uavklart',),
'uavkorta': ('uavkorta',),
'uavkortede': ('uavkortet',),
'uavkortet': ('uavkortet',),
'uavkortete': ('uavkortet',),
'uavkortetere': ('uavkortet',),
'uavkortetest': ('uavkortet',),
'uavkorteteste': ('uavkortet',),
'uavlatelig': ('uavlatelig',),
'uavlatelige': ('uavlatelig',),
'uavlateligere': ('uavlatelig',),
'uavlateligst': ('uavlatelig',),
'uavlateligste': ('uavlatelig',),
'uavsettelig': ('uavsettelig',),
'uavsettelige': ('uavsettelig',),
'uavsetteligere': ('uavsettelig',),
'uavsetteligst': ('uavsettelig',),
'uavsetteligste': ('uavsettelig',),
'uavslutta': ('uavslutta',),
'uavsluttede': ('uavsluttet',),
'uavsluttet': ('uavsluttet',),
'uavsluttete': ('uavsluttet',),
'uavsluttetere': ('uavsluttet',),
'uavsluttetest': ('uavsluttet',),
'uavslutteteste': ('uavsluttet',),
'uavvendelig': ('uavvendelig',),
'uavvendelige': ('uavvendelig',),
'uavvendeligere': ('uavvendelig',),
'uavvendeligst': ('uavvendelig',),
'uavvendeligste': ('uavvendelig',),
'uavviselig': ('uavviselig',),
'uavviselige': ('uavviselig',),
'uavviseligere': ('uavviselig',),
'uavviseligst': ('uavviselig',),
'uavviseligste': ('uavviselig',),
'uavvitende': ('uavvitende',),
'ubalansert': ('ubalansert',),
'ubalanserte': ('ubalansert',),
'ubalansertere': ('ubalansert',),
'ubalansertest': ('ubalansert',),
'ubalanserteste': ('ubalansert',),
'ubarbert': ('ubarbert',),
'ubarberte': ('ubarbert',),
'ubarbertere': ('ubarbert',),
'ubarbertest': ('ubarbert',),
'ubarberteste': ('ubarbert',),
'ubarmhjertig': ('ubarmhjertig',),
'ubarmhjertige': ('ubarmhjertig',),
'ubarmhjertigere': ('ubarmhjertig',),
'ubarmhjertigst': ('ubarmhjertig',),
'ubarmhjertigste': ('ubarmhjertig',),
'ubebodd': ('ubebodd',),
'ubebodde': ('ubebodd',),
'ubeboddere': ('ubebodd',),
'ubeboddest': ('ubebodd',),
'ubeboddeste': ('ubebodd',),
'ubeboelig': ('ubeboelig',),
'ubeboelige': ('ubeboelig',),
'ubeboeligere': ('ubeboelig',),
'ubeboeligst': ('ubeboelig',),
'ubeboeligste': ('ubeboelig',),
'ubebygd': ('ubebygd',),
'ubebygde': ('ubebygd',),
'ubebygdere': ('ubebygd',),
'ubebygdest': ('ubebygd',),
'ubebygdeste': ('ubebygd',),
'ubederva': ('ubederva',),
'ubedervede': ('ubedervet',),
'ubedervet': ('ubedervet',),
'ubedervete': ('ubedervet',),
'ubedervetere': ('ubedervet',),
'ubedervetest': ('ubedervet',),
'ubederveteste': ('ubedervet',),
'ubedt': ('ubedt',),
'ubedte': ('ubedt',),
'ubedtere': ('ubedt',),
'ubedtest': ('ubedt',),
'ubedteste': ('ubedt',),
'ubeferda': ('ubeferda',),
'ubeferdede': ('ubeferdet',),
'ubeferdet': ('ubeferdet',),
'ubeferdete': ('ubeferdet',),
'ubeferdetere': ('ubeferdet',),
'ubeferdetest': ('ubeferdet',),
'ubeferdeteste': ('ubeferdet',),
'ubefesta': ('ubefesta',),
'ubefestede': ('ubefestet',),
'ubefestet': ('ubefestet',),
'ubefestete': ('ubefestet',),
'ubefestetere': ('ubefestet',),
'ubefestetest': ('ubefestet',),
'ubefesteteste': ('ubefestet',),
'ubefolka': ('ubefolka',),
'ubefolkede': ('ubefolket',),
'ubefolket': ('ubefolket',),
'ubefolkete': ('ubefolket',),
'ubefolketere': ('ubefolket',),
'ubefolketest': ('ubefolket',),
'ubefolketeste': ('ubefolket',),
'ubeføya': ('ubeføya',),
'ubeføyede': ('ubeføyet',),
'ubeføyet': ('ubeføyet',),
'ubeføyete': ('ubeføyet',),
'ubeføyetere': ('ubeføyet',),
'ubeføyetest': ('ubeføyet',),
'ubeføyeteste': ('ubeføyet',),
'ubegava': ('ubegava',),
'ubegavede': ('ubegavet',),
'ubegavet': ('ubegavet',),
'ubegavete': ('ubegavet',),
'ubegavetere': ('ubegavet',),
'ubegavetest': ('ubegavet',),
'ubegaveteste': ('ubegavet',),
'ubegrensa': ('ubegrensa',),
'ubegrensede': ('ubegrenset',),
'ubegrenset': ('ubegrenset',),
'ubegrensete': ('ubegrenset',),
'ubegrensetere': ('ubegrenset',),
'ubegrensetest': ('ubegrenset',),
'ubegrenseteste': ('ubegrenset',),
'ubegripelig': ('ubegripelig',),
'ubegripelige': ('ubegripelig',),
'ubegripeligere': ('ubegripelig',),
'ubegripeligst': ('ubegripelig',),
'ubegripeligste': ('ubegripelig',),
'ubegrunna': ('ubegrunna',),
'ubegrunnede': ('ubegrunnet',),
'ubegrunnet': ('ubegrunnet',),
'ubegrunnete': ('ubegrunnet',),
'ubegrunnetere': ('ubegrunnet',),
'ubegrunnetest': ('ubegrunnet',),
'ubegrunneteste': ('ubegrunnet',),
'ubehagelig': ('ubehagelig',),
'ubehagelige': ('ubehagelig',),
'ubehageligere': ('ubehagelig',),
'ubehageligst': ('ubehagelig',),
'ubehageligste': ('ubehagelig',),
'ubehandla': ('ubehandla',),
'ubehandlede': ('ubehandlet',),
'ubehandlet': ('ubehandlet',),
'ubehandlete': ('ubehandlet',),
'ubehandletere': ('ubehandlet',),
'ubehandletest': ('ubehandlet',),
'ubehandleteste': ('ubehandlet',),
'ubeherska': ('ubeherska',),
'ubeherskede': ('ubehersket',),
'ubehersket': ('ubehersket',),
'ubeherskete': ('ubehersket',),
'ubehersketere': ('ubehersket',),
'ubehersketest': ('ubehersket',),
'ubehersketeste': ('ubehersket',),
'ubehjelpelig': ('ubehjelpelig',),
'ubehjelpelige': ('ubehjelpelig',),
'ubehjelpeligere': ('ubehjelpelig',),
'ubehjelpeligst': ('ubehjelpelig',),
'ubehjelpeligste': ('ubehjelpelig',),
'ubehjelpsom': ('ubehjelpsom',),
'ubehjelpsomme': ('ubehjelpsom',),
'ubehjelpsommere': ('ubehjelpsom',),
'ubehjelpsomst': ('ubehjelpsom',),
'ubehjelpsomste': ('ubehjelpsom',),
'ubehjelpsomt': ('ubehjelpsom',),
'ubehøvla': ('ubehøvla',),
'ubehøvlede': ('ubehøvlet',),
'ubehøvlet': ('ubehøvlet',),
'ubehøvlete': ('ubehøvlet',),
'ubehøvletere': ('ubehøvlet',),
'ubehøvletest': ('ubehøvlet',),
'ubehøvleteste': ('ubehøvlet',),
'ubekjent': ('ubekjent',),
'ubekjente': ('ubekjent',),
'ubekjentere': ('ubekjent',),
'ubekjentest': ('ubekjent',),
'ubekjenteste': ('ubekjent',),
'ubekrefta': ('ubekrefta',),
'ubekreftede': ('ubekreftet',),
'ubekreftet': ('ubekreftet',),
'ubekreftete': ('ubekreftet',),
'ubekreftetere': ('ubekreftet',),
'ubekreftetest': ('ubekreftet',),
'ubekrefteteste': ('ubekreftet',),
'ubekvem': ('ubekvem',),
'ubekvemme': ('ubekvem',),
'ubekvemmere': ('ubekvem',),
'ubekvemmest': ('ubekvem',),
'ubekvemmeste': ('ubekvem',),
'ubekvemt': ('ubekvem',),
'ubeleilig': ('ubeleilig',),
'ubeleilige': ('ubeleilig',),
'ubeleiligere': ('ubeleilig',),
'ubeleiligst': ('ubeleilig',),
'ubeleiligste': ('ubeleilig',),
'ubemanna': ('ubemanna',),
'ubemannede': ('ubemannet',),
'ubemannet': ('ubemannet',),
'ubemannete': ('ubemannet',),
'ubemannetere': ('ubemannet',),
'ubemannetest': ('ubemannet',),
'ubemanneteste': ('ubemannet',),
'ubemerka': ('ubemerka',),
'ubemerkede': ('ubemerket',),
'ubemerket': ('ubemerket',),
'ubemerkete': ('ubemerket',),
'ubemerketere': ('ubemerket',),
'ubemerketest': ('ubemerket',),
'ubemerketeste': ('ubemerket',),
'ubemidla': ('ubemidla',),
'ubemidlede': ('ubemidlet',),
'ubemidlet': ('ubemidlet',),
'ubemidlete': ('ubemidlet',),
'ubemidletere': ('ubemidlet',),
'ubemidletest': ('ubemidlet',),
'ubemidleteste': ('ubemidlet',),
'ubendig': ('ubendig',),
'ubendige': ('ubendig',),
'ubendigere': ('ubendig',),
'ubendigst': ('ubendig',),
'ubendigste': ('ubendig',),
'uberegnelig': ('uberegnelig',),
'uberegnelige': ('uberegnelig',),
'uberegneligere': ('uberegnelig',),
'uberegneligst': ('uberegnelig',),
'uberegneligste': ('uberegnelig',),
'ubereknelig': ('ubereknelig',),
'ubereknelige': ('ubereknelig',),
'uberekneligere': ('ubereknelig',),
'uberekneligst': ('ubereknelig',),
'uberekneligste': ('ubereknelig',),
'uberettiga': ('uberettiga',),
'uberettigede': ('uberettiget',),
'uberettiget': ('uberettiget',),
'uberettigete': ('uberettiget',),
'uberettigetere': ('uberettiget',),
'uberettigetest': ('uberettiget',),
'uberettigeteste': ('uberettiget',),
'ubergelig': ('ubergelig',),
'ubergelige': ('ubergelig',),
'ubergeligere': ('ubergelig',),
'ubergeligst': ('ubergelig',),
'ubergeligste': ('ubergelig',),
'uberoende': ('uberoende',),
'uberørt': ('uberørt',),
'uberørte': ('uberørt',),
'uberørtere': ('uberørt',),
'uberørtest': ('uberørt',),
'uberørteste': ('uberørt',),
'ubesatt': ('ubesatt',),
'ubesatte': ('ubesatt',),
'ubesattere': ('ubesatt',),
'ubesattest': ('ubesatt',),
'ubesatteste': ('ubesatt',),
'ubeseira': ('ubeseira',),
'ubeseirede': ('ubeseiret',),
'ubeseiret': ('ubeseiret',),
'ubeseirete': ('ubeseiret',),
'ubeseiretere': ('ubeseiret',),
'ubeseiretest': ('ubeseiret',),
'ubeseireteste': ('ubeseiret',),
'ubesindig': ('ubesindig',),
'ubesindige': ('ubesindig',),
'ubesindigere': ('ubesindig',),
'ubesindigst': ('ubesindig',),
'ubesindigste': ('ubesindig',),
'ubeskadiga': ('ubeskadiga',),
'ubeskadigede': ('ubeskadiget',),
'ubeskadiget': ('ubeskadiget',),
'ubeskadigete': ('ubeskadiget',),
'ubeskadigetere': ('ubeskadiget',),
'ubeskadigetest': ('ubeskadiget',),
'ubeskadigeteste': ('ubeskadiget',),
'ubeskjeden': ('ubeskjeden',),
'ubeskjedent': ('ubeskjeden',),
'ubeskjedne': ('ubeskjeden',),
'ubeskjednere': ('ubeskjeden',),
'ubeskjednest': ('ubeskjeden',),
'ubeskjedneste': ('ubeskjeden',),
'ubeskjeftiga': ('ubeskjeftiga',),
'ubeskjeftigede': ('ubeskjeftiget',),
'ubeskjeftiget': ('ubeskjeftiget',),
'ubeskjeftigete': ('ubeskjeftiget',),
'ubeskjeftigetere': ('ubeskjeftiget',),
'ubeskjeftigetest': ('ubeskjeftiget',),
'ubeskjeftigeteste': ('ubeskjeftiget',),
'ubeskreven': ('ubeskreven',),
'ubeskrevet': ('ubeskreven',),
'ubeskrevne': ('ubeskreven',),
'ubeskrevnere': ('ubeskreven',),
'ubeskrevnest': ('ubeskreven',),
'ubeskrevneste': ('ubeskreven',),
'ubeskrevet': ('ubeskrevet',),
'ubeskrevne': ('ubeskrevet',),
'ubeskrevnere': ('ubeskrevet',),
'ubeskrevnest': ('ubeskrevet',),
'ubeskrevneste': ('ubeskrevet',),
'ubeskrivelig': ('ubeskrivelig',),
'ubeskrivelige': ('ubeskrivelig',),
'ubeskriveligere': ('ubeskrivelig',),
'ubeskriveligst': ('ubeskrivelig',),
'ubeskriveligste': ('ubeskrivelig',),
'ubeskytta': ('ubeskytta',),
'ubeskyttede': ('ubeskyttet',),
'ubeskyttet': ('ubeskyttet',),
'ubeskyttete': ('ubeskyttet',),
'ubeskyttetere': ('ubeskyttet',),
'ubeskyttetest': ('ubeskyttet',),
'ubeskytteteste': ('ubeskyttet',),
'ubeskåren': ('ubeskåren',),
'ubeskåret': ('ubeskåren',),
'ubeskårne': ('ubeskåren',),
'ubeskårnere': ('ubeskåren',),
'ubeskårnest': ('ubeskåren',),
'ubeskårneste': ('ubeskåren',),
'ubeskåret': ('ubeskåret',),
'ubeskårne': ('ubeskåret',),
'ubeskårnere': ('ubeskåret',),
'ubeskårnest': ('ubeskåret',),
'ubeskårneste': ('ubeskåret',),
'ubesluttsom': ('ubesluttsom',),
'ubesluttsomme': ('ubesluttsom',),
'ubesluttsommere': ('ubesluttsom',),
'ubesluttsomst': ('ubesluttsom',),
'ubesluttsomste': ('ubesluttsom',),
'ubesluttsomt': ('ubesluttsom',),
'ubesmitta': ('ubesmitta',),
'ubesmittede': ('ubesmittet',),
'ubesmittet': ('ubesmittet',),
'ubesmittete': ('ubesmittet',),
'ubesmittetere': ('ubesmittet',),
'ubesmittetest': ('ubesmittet',),
'ubesmitteteste': ('ubesmittet',),
'ubestandig': ('ubestandig',),
'ubestandige': ('ubestandig',),
'ubestandigere': ('ubestandig',),
'ubestandigst': ('ubestandig',),
'ubestandigste': ('ubestandig',),
'ubestemmelig': ('ubestemmelig',),
'ubestemmelige': ('ubestemmelig',),
'ubestemmeligere': ('ubestemmelig',),
'ubestemmeligst': ('ubestemmelig',),
'ubestemmeligste': ('ubestemmelig',),
'ubestemt': ('ubestemt',),
'ubestemte': ('ubestemt',),
'ubestemtere': ('ubestemt',),
'ubestemtest': ('ubestemt',),
'ubestemteste': ('ubestemt',),
'ubestigelig': ('ubestigelig',),
'ubestigelige': ('ubestigelig',),
'ubestigeligere': ('ubestigelig',),
'ubestigeligst': ('ubestigelig',),
'ubestigeligste': ('ubestigelig',),
'ubestikkelig': ('ubestikkelig',),
'ubestikkelige': ('ubestikkelig',),
'ubestikkeligere': ('ubestikkelig',),
'ubestikkeligst': ('ubestikkelig',),
'ubestikkeligste': ('ubestikkelig',),
'ubestridd': ('ubestridd',),
'ubestridde': ('ubestridd',),
'ubestriddere': ('ubestridd',),
'ubestriddest': ('ubestridd',),
'ubestriddeste': ('ubestridd',),
'ubestridelig': ('ubestridelig',),
'ubestridelige': ('ubestridelig',),
'ubestrideligere': ('ubestridelig',),
'ubestrideligst': ('ubestridelig',),
'ubestrideligste': ('ubestridelig',),
'ubestridt': ('ubestridt',),
'ubestridte': ('ubestridt',),
'ubestridtere': ('ubestridt',),
'ubestridtest': ('ubestridt',),
'ubestridteste': ('ubestridt',),
'ubesvart': ('ubesvart',),
'ubesvarte': ('ubesvart',),
'ubesvartere': ('ubesvart',),
'ubesvartest': ('ubesvart',),
'ubesvarteste': ('ubesvart',),
'ubesværa': ('ubesværa',),
'ubesværede': ('ubesværet',),
'ubesværet': ('ubesværet',),
'ubesværete': ('ubesværet',),
'ubesværetere': ('ubesværet',),
'ubesværetest': ('ubesværet',),
'ubesværeteste': ('ubesværet',),
'ubesvært': ('ubesvært',),
'ubesværte': ('ubesvært',),
'ubesværtere': ('ubesvært',),
'ubesværtest': ('ubesvært',),
'ubesværteste': ('ubesvært',),
'ubesørga': ('ubesørga',),
'ubesørgede': ('ubesørget',),
'ubesørget': ('ubesørget',),
'ubesørgete': ('ubesørget',),
'ubesørgetere': ('ubesørget',),
'ubesørgetest': ('ubesørget',),
'ubesørgeteste': ('ubesørget',),
'ubetalelig': ('ubetalelig',),
'ubetalelige': ('ubetalelig',),
'ubetaleligere': ('ubetalelig',),
'ubetaleligst': ('ubetalelig',),
'ubetaleligste': ('ubetalelig',),
'ubetalt': ('ubetalt',),
'ubetalte': ('ubetalt',),
'ubetaltere': ('ubetalt',),
'ubetaltest': ('ubetalt',),
'ubetalteste': ('ubetalt',),
'ubetenksom': ('ubetenksom',),
'ubetenksomme': ('ubetenksom',),
'ubetenksommere': ('ubetenksom',),
'ubetenksomst': ('ubetenksom',),
'ubetenksomste': ('ubetenksom',),
'ubetenksomt': ('ubetenksom',),
'ubetenkt': ('ubetenkt',),
'ubetenkte': ('ubetenkt',),
'ubetenktere': ('ubetenkt',),
'ubetenktest': ('ubetenkt',),
'ubetenkteste': ('ubetenkt',),
'ubetinga': ('ubetinga',),
'ubetingede': ('ubetinget',),
'ubetinget': ('ubetinget',),
'ubetingete': ('ubetinget',),
'ubetingetere': ('ubetinget',),
'ubetingetest': ('ubetinget',),
'ubetingeteste': ('ubetinget',),
'ubetona': ('ubetona',),
'ubetonede': ('ubetonet',),
'ubetonet': ('ubetonet',),
'ubetonete': ('ubetonet',),
'ubetonetere': ('ubetonet',),
'ubetonetest': ('ubetonet',),
'ubetoneteste': ('ubetonet',),
'ubetont': ('ubetont',),
'ubetonte': ('ubetont',),
'ubetontere': ('ubetont',),
'ubetontest': ('ubetont',),
'ubetonteste': ('ubetont',),
'ubetvingelig': ('ubetvingelig',),
'ubetvingelige': ('ubetvingelig',),
'ubetvingeligere': ('ubetvingelig',),
'ubetvingeligst': ('ubetvingelig',),
'ubetvingeligste': ('ubetvingelig',),
'ubetydelig': ('ubetydelig',),
'ubetydelige': ('ubetydelig',),
'ubetydeligere': ('ubetydelig',),
'ubetydeligst': ('ubetydelig',),
'ubetydeligste': ('ubetydelig',),
'ubevegelig': ('ubevegelig',),
'ubevegelige': ('ubevegelig',),
'ubevegeligere': ('ubevegelig',),
'ubevegeligst': ('ubevegelig',),
'ubevegeligste': ('ubevegelig',),
'ubevisst': ('ubevisst',),
'ubevisste': ('ubevisst',),
'ubevisstere': ('ubevisst',),
'ubevisstest': ('ubevisst',),
'ubevissteste': ('ubevisst',),
'ubevokta': ('ubevokta',),
'ubevoktede': ('ubevoktet',),
'ubevoktet': ('ubevoktet',),
'ubevoktete': ('ubevoktet',),
'ubevoktetere': ('ubevoktet',),
'ubevoktetest': ('ubevoktet',),
'ubevokteteste': ('ubevoktet',),
'ubevæpna': ('ubevæpna',),
'ubevæpnede': ('ubevæpnet',),
'ubevæpnet': ('ubevæpnet',),
'ubevæpnete': ('ubevæpnet',),
'ubevæpnetere': ('ubevæpnet',),
'ubevæpnetest': ('ubevæpnet',),
'ubevæpneteste': ('ubevæpnet',),
'ubillig': ('ubillig',),
'ubillige': ('ubillig',),
'ubilligere': ('ubillig',),
'ubilligst': ('ubillig',),
'ubilligste': ('ubillig',),
'ublanda': ('ublanda',),
'ublandede': ('ublandet',),
'ublandet': ('ublandet',),
'ublandete': ('ublandet',),
'ublandetere': ('ublandet',),
'ublandetest': ('ublandet',),
'ublandeteste': ('ublandet',),
'ubleikt': ('ubleikt',),
'ubleikte': ('ubleikt',),
'ubleiktere': ('ubleikt',),
'ubleiktest': ('ubleikt',),
'ubleikteste': ('ubleikt',),
'ublekede': ('ubleket',),
'ubleket': ('ubleket',),
'ublekete': ('ubleket',),
'ubleketere': ('ubleket',),
'ubleketest': ('ubleket',),
'ubleketeste': ('ubleket',),
'ublekt': ('ublekt',),
'ublekte': ('ublekt',),
'ublektere': ('ublekt',),
'ublektest': ('ublekt',),
'ublekteste': ('ublekt',),
'ublid': ('ublid',),
'ublide': ('ublid',),
'ublidere': ('ublid',),
'ublidest': ('ublid',),
'ublideste': ('ublid',),
'ublidt': ('ublid',),
'ublodig': ('ublodig',),
'ublodige': ('ublodig',),
'ublodigere': ('ublodig',),
'ublodigst': ('ublodig',),
'ublodigste': ('ublodig',),
'ublu': ('ublu',),
'ublue': ('ublu',),
'ubluere': ('ublu',),
'ubluest': ('ublu',),
'ublueste': ('ublu',),
'ublutt': ('ublu',),
'ubona': ('ubona',),
'ubonede': ('ubonet',),
'ubonet': ('ubonet',),
'ubonete': ('ubonet',),
'ubonetere': ('ubonet',),
'ubonetest': ('ubonet',),
'uboneteste': ('ubonet',),
'ubont': ('ubont',),
'ubonte': ('ubont',),
'ubontere': ('ubont',),
'ubontest': ('ubont',),
'ubonteste': ('ubont',),
'ubotelig': ('ubotelig',),
'ubotelige': ('ubotelig',),
'uboteligere': ('ubotelig',),
'uboteligst': ('ubotelig',),
'uboteligste': ('ubotelig',),
'ubrukbar': ('ubrukbar',),
'ubrukbare': ('ubrukbar',),
'ubrukbarere': ('ubrukbar',),
'ubrukbarest': ('ubrukbar',),
'ubrukbareste': ('ubrukbar',),
'ubrukbart': ('ubrukbar',),
'ubrukelig': ('ubrukelig',),
'ubrukelige': ('ubrukelig',),
'ubrukeligere': ('ubrukelig',),
'ubrukeligst': ('ubrukelig',),
'ubrukeligste': ('ubrukelig',),
'ubrukt': ('ubrukt',),
'ubrukte': ('ubrukt',),
'ubruktere': ('ubrukt',),
'ubruktest': ('ubrukt',),
'ubrukteste': ('ubrukt',),
'ubrutt': ('ubrutt',),
'ubrutte': ('ubrutt',),
'ubruttere': ('ubrutt',),
'ubruttest': ('ubrutt',),
'ubrutteste': ('ubrutt',),
'ubrytelig': ('ubrytelig',),
'ubrytelige': ('ubrytelig',),
'ubryteligere': ('ubrytelig',),
'ubryteligst': ('ubrytelig',),
'ubryteligste': ('ubrytelig',),
'ubuden': ('ubuden',),
'ubudent': ('ubuden',),
'ubudne': ('ubuden',),
'ubudnere': ('ubuden',),
'ubudnest': ('ubuden',),
'ubudneste': ('ubuden',),
'ubunden': ('ubunden',),
'ubundet': ('ubunden',),
'ubundne': ('ubunden',),
'ubundnere': ('ubunden',),
'ubundnest': ('ubunden',),
'ubundneste': ('ubunden',),
'ubundet': ('ubundet',),
'ubundne': ('ubundet',),
'ubundnere': ('ubundet',),
'ubundnest': ('ubundet',),
'ubundneste': ('ubundet',),
'ubønnhørlig': ('ubønnhørlig',),
'ubønnhørlige': ('ubønnhørlig',),
'ubønnhørligere': ('ubønnhørlig',),
'ubønnhørligst': ('ubønnhørlig',),
'ubønnhørligste': ('ubønnhørlig',),
'ubøyelig': ('ubøyelig',),
'ubøyelige': ('ubøyelig',),
'ubøyeligere': ('ubøyelig',),
'ubøyeligst': ('ubøyelig',),
'ubøyeligste': ('ubøyelig',),
'udadlelig': ('udadlelig',),
'udadlelige': ('udadlelig',),
'udadleligere': ('udadlelig',),
'udadleligst': ('udadlelig',),
'udadleligste': ('udadlelig',),
'udanna': ('udanna',),
'udannede': ('udannet',),
'udannet': ('udannet',),
'udannete': ('udannet',),
'udannetere': ('udannet',),
'udannetest': ('udannet',),
'udanneteste': ('udannet',),
'udefinerbar': ('udefinerbar',),
'udefinerbare': ('udefinerbar',),
'udefinerbarere': ('udefinerbar',),
'udefinerbarest': ('udefinerbar',),
'udefinerbareste': ('udefinerbar',),
'udefinerbart': ('udefinerbar',),
'udekka': ('udekka',),
'udekkede': ('udekket',),
'udekket': ('udekket',),
'udekkete': ('udekket',),
'udekketere': ('udekket',),
'udekketest': ('udekket',),
'udekketeste': ('udekket',),
'udekt': ('udekt',),
'udekte': ('udekt',),
'udektere': ('udekt',),
'udektest': ('udekt',),
'udekteste': ('udekt',),
'udelelig': ('udelelig',),
'udelelige': ('udelelig',),
'udeleligere': ('udelelig',),
'udeleligst': ('udelelig',),
'udeleligste': ('udelelig',),
'udelt': ('udelt',),
'udelte': ('udelt',),
'udeltere': ('udelt',),
'udeltest': ('udelt',),
'udelteste': ('udelt',),
'udifferensiert': ('udifferensiert',),
'udifferensierte': ('udifferensiert',),
'udifferensiertere': ('udifferensiert',),
'udifferensiertest': ('udifferensiert',),
'udifferensierteste': ('udifferensiert',),
'udiskutabel': ('udiskutabel',),
'udiskutabelt': ('udiskutabel',),
'udiskutable': ('udiskutabel',),
'udiskutablere': ('udiskutabel',),
'udiskutablest': ('udiskutabel',),
'udiskutableste': ('udiskutabel',),
'udogmatisk': ('udogmatisk',),
'udogmatiske': ('udogmatisk',),
'udogmatiskere': ('udogmatisk',),
'udogmatiskest': ('udogmatisk',),
'udogmatiskeste': ('udogmatisk',),
'udoktrinær': ('udoktrinær',),
'udoktrinære': ('udoktrinær',),
'udoktrinærere': ('udoktrinær',),
'udoktrinærest': ('udoktrinær',),
'udoktrinæreste': ('udoktrinær',),
'udoktrinært': ('udoktrinær',),
'udokumentert': ('udokumentert',),
'udokumenterte': ('udokumentert',),
'udokumentertere': ('udokumentert',),
'udokumentertest': ('udokumentert',),
'udokumenterteste': ('udokumentert',),
'udramatisk': ('udramatisk',),
'udramatiske': ('udramatisk',),
'udramatiskere': ('udramatisk',),
'udramatiskest': ('udramatisk',),
'udramatiskeste': ('udramatisk',),
'udrepelig': ('udrepelig',),
'udrepelige': ('udrepelig',),
'udrepeligere': ('udrepelig',),
'udrepeligst': ('udrepelig',),
'udrepeligste': ('udrepelig',),
'udrikkelig': ('udrikkelig',),
'udrikkelige': ('udrikkelig',),
'udrikkeligere': ('udrikkelig',),
'udrikkeligst': ('udrikkelig',),
'udrikkeligste': ('udrikkelig',),
'udryg': ('udryg',),
'udryge': ('udryg',),
'udrygere': ('udryg',),
'udrygest': ('udryg',),
'udrygeste': ('udryg',),
'udrygt': ('udryg',),
'udrøy': ('udrøy',),
'udrøye': ('udrøy',),
'udrøyere': ('udrøy',),
'udrøyest': ('udrøy',),
'udrøyeste': ('udrøy',),
'udrøyt': ('udrøy',),
'udugelig': ('udugelig',),
'udugelige': ('udugelig',),
'udugeligere': ('udugelig',),
'udugeligst': ('udugelig',),
'udugeligste': ('udugelig',),
'udydig': ('udydig',),
'udydige': ('udydig',),
'udydigere': ('udydig',),
'udydigst': ('udydig',),
'udydigste': ('udydig',),
'udyktig': ('udyktig',),
'udyktige': ('udyktig',),
'udyktigere': ('udyktig',),
'udyktigst': ('udyktig',),
'udyktigste': ('udyktig',),
'udyrka': ('udyrka',),
'udyrkbar': ('udyrkbar',),
'udyrkbare': ('udyrkbar',),
'udyrkbarere': ('udyrkbar',),
'udyrkbarest': ('udyrkbar',),
'udyrkbareste': ('udyrkbar',),
'udyrkbart': ('udyrkbar',),
'udyrkede': ('udyrket',),
'udyrket': ('udyrket',),
'udyrkete': ('udyrket',),
'udyrketere': ('udyrket',),
'udyrketest': ('udyrket',),
'udyrketeste': ('udyrket',),
'udødelig': ('udødelig',),
'udødelige': ('udødelig',),
'udødeligere': ('udødelig',),
'udødeligst': ('udødelig',),
'udødeligste': ('udødelig',),
'udødeliggjort': ('udødeliggjøre',),
'udødeliggjorte': ('udødeliggjøre',),
'udødeliggjørende': ('udødeliggjøre',),
'udøpt': ('udøpt',),
'udøpte': ('udøpt',),
'udøptere': ('udøpt',),
'udøptest': ('udøpt',),
'udøpteste': ('udøpt',),
'uedel': ('uedel',),
'uedelt': ('uedel',),
'uedle': ('uedel',),
'uedlere': ('uedel',),
'uedlest': ('uedel',),
'uedleste': ('uedel',),
'ueffen': ('ueffen',),
'ueffent': ('ueffen',),
'uefne': ('ueffen',),
'uefnere': ('ueffen',),
'uefnest': ('ueffen',),
'uefneste': ('ueffen',),
'uegennyttig': ('uegennyttig',),
'uegennyttige': ('uegennyttig',),
'uegennyttigere': ('uegennyttig',),
'uegennyttigst': ('uegennyttig',),
'uegennyttigste': ('uegennyttig',),
'uegentlig': ('uegentlig',),
'uegentlige': ('uegentlig',),
'uegentligere': ('uegentlig',),
'uegentligst': ('uegentlig',),
'uegentligste': ('uegentlig',),
'uegna': ('uegna',),
'uegnede': ('uegnet',),
'uegnet': ('uegnet',),
'uegnete': ('uegnet',),
'uegnetere': ('uegnet',),
'uegnetest': ('uegnet',),
'uegneteste': ('uegnet',),
'uekspedert': ('uekspedert',),
'uekspederte': ('uekspedert',),
'uekspedertere': ('uekspedert',),
'uekspedertest': ('uekspedert',),
'uekspederteste': ('uekspedert',),
'ueksplodert': ('ueksplodert',),
'ueksploderte': ('ueksplodert',),
'ueksplodertere': ('ueksplodert',),
'ueksplodertest': ('ueksplodert',),
'ueksploderteste': ('ueksplodert',),
'uekte': ('uekte',),
'uelegant': ('uelegant',),
'uelegante': ('uelegant',),
'uelegantere': ('uelegant',),
'uelegantest': ('uelegant',),
'ueleganteste': ('uelegant',),
'uelskverdig': ('uelskverdig',),
'uelskverdige': ('uelskverdig',),
'uelskverdigere': ('uelskverdig',),
'uelskverdigst': ('uelskverdig',),
'uelskverdigste': ('uelskverdig',),
'uendelig': ('uendelig',),
'uendelige': ('uendelig',),
'uendeligere': ('uendelig',),
'uendeligst': ('uendelig',),
'uendeligste': ('uendelig',),
'uendra': ('uendra',),
'uendrede': ('uendret',),
'uendret': ('uendret',),
'uendrete': ('uendret',),
'uendretere': ('uendret',),
'uendretest': ('uendret',),
'uendreteste': ('uendret',),
'uenig': ('uenig',),
'uenige': ('uenig',),
'uenigere': ('uenig',),
'uenigst': ('uenig',),
'uenigste': ('uenig',),
'uens': ('uens',),
'uensarta': ('uensarta',),
'uensartede': ('uensartet',),
'uensartet': ('uensartet',),
'uensartete': ('uensartet',),
'uensartetere': ('uensartet',),
'uensartetest': ('uensartet',),
'uensarteteste': ('uensartet',),
'uerfaren': ('uerfaren',),
'uerfarent': ('uerfaren',),
'uerfarne': ('uerfaren',),
'uerfarnere': ('uerfaren',),
'uerfarnest': ('uerfaren',),
'uerfarneste': ('uerfaren',),
'uerstattelig': ('uerstattelig',),
'uerstattelige': ('uerstattelig',),
'uerstatteligere': ('uerstattelig',),
'uerstatteligst': ('uerstattelig',),
'uerstatteligste': ('uerstattelig',),
'uestetisk': ('uestetisk',),
'uestetiske': ('uestetisk',),
'uestetiskere': ('uestetisk',),
'uestetiskest': ('uestetisk',),
'uestetiskeste': ('uestetisk',),
'uetterrettelig': ('uetterrettelig',),
'uetterrettelige': ('uetterrettelig',),
'uetterretteligere': ('uetterrettelig',),
'uetterretteligst': ('uetterrettelig',),
'uetterretteligste': ('uetterrettelig',),
'ufaglært': ('ufaglært',),
'ufaglærte': ('ufaglært',),
'ufaglærtere': ('ufaglært',),
'ufaglærtest': ('ufaglært',),
'ufaglærteste': ('ufaglært',),
'ufarbar': ('ufarbar',),
'ufarbare': ('ufarbar',),
'ufarbarere': ('ufarbar',),
'ufarbarest': ('ufarbar',),
'ufarbareste': ('ufarbar',),
'ufarbart': ('ufarbar',),
'ufarga': ('ufarga',),
'ufargede': ('ufarget',),
'ufarget': ('ufarget',),
'ufargete': ('ufarget',),
'ufargetere': ('ufarget',),
'ufargetest': ('ufarget',),
'ufargeteste': ('ufarget',),
'ufarlig': ('ufarlig',),
'ufarlige': ('ufarlig',),
'ufarligere': ('ufarlig',),
'ufarligst': ('ufarlig',),
'ufarligste': ('ufarlig',),
'ufarliggjort': ('ufarliggjøre',),
'ufarliggjorte': ('ufarliggjøre',),
'ufarliggjørende': ('ufarliggjøre',),
'ufattelig': ('ufattelig',),
'ufattelige': ('ufattelig',),
'ufatteligere': ('ufattelig',),
'ufatteligst': ('ufattelig',),
'ufatteligste': ('ufattelig',),
'ufeilbar': ('ufeilbar',),
'ufeilbare': ('ufeilbar',),
'ufeilbarere': ('ufeilbar',),
'ufeilbarest': ('ufeilbar',),
'ufeilbareste': ('ufeilbar',),
'ufeilbart': ('ufeilbar',),
'ufeilbarlig': ('ufeilbarlig',),
'ufeilbarlige': ('ufeilbarlig',),
'ufeilbarligere': ('ufeilbarlig',),
'ufeilbarligst': ('ufeilbarlig',),
'ufeilbarligste': ('ufeilbarlig',),
'uferdig': ('uferdig',),
'uferdige': ('uferdig',),
'uferdigere': ('uferdig',),
'uferdigst': ('uferdig',),
'uferdigste': ('uferdig',),
'uffa': ('uffe',),
'uffede': ('uffe',),
'uffende': ('uffe',),
'uffet': ('uffe',),
'uffete': ('uffe',),
'ufiks': ('ufiks',),
'ufikse': ('ufiks',),
'ufiksere': ('ufiks',),
'ufiksest': ('ufiks',),
'ufikseste': ('ufiks',),
'ufikst': ('ufiks',),
'ufin': ('ufin',),
'ufine': ('ufin',),
'ufinere': ('ufin',),
'ufinest': ('ufin',),
'ufineste': ('ufin',),
'ufint': ('ufin',),
'ufjelg': ('ufjelg',),
'ufjelge': ('ufjelg',),
'ufjelgere': ('ufjelg',),
'ufjelgest': ('ufjelg',),
'ufjelgeste': ('ufjelg',),
'ufjelgt': ('ufjelg',),
'uflidd': ('uflidd',),
'uflidde': ('uflidd',),
'ufliddere': ('uflidd',),
'ufliddest': ('uflidd',),
'ufliddeste': ('uflidd',),
'ufolkelig': ('ufolkelig',),
'ufolkelige': ('ufolkelig',),
'ufolkeligere': ('ufolkelig',),
'ufolkeligst': ('ufolkelig',),
'ufolkeligste': ('ufolkelig',),
'ufologisk': ('ufologisk',),
'ufologiske': ('ufologisk',),
'ufologiskere': ('ufologisk',),
'ufologiskest': ('ufologisk',),
'ufologiskeste': ('ufologisk',),
'ufora': ('ufora',),
'uforanderlig': ('uforanderlig',),
'uforanderlige': ('uforanderlig',),
'uforanderligere': ('uforanderlig',),
'uforanderligst': ('uforanderlig',),
'uforanderligste': ('uforanderlig',),
'uforandra': ('uforandra',),
'uforandrede': ('uforandret',),
'uforandret': ('uforandret',),
'uforandrete': ('uforandret',),
'uforandretere': ('uforandret',),
'uforandretest': ('uforandret',),
'uforandreteste': ('uforandret',),
'uforbederlig': ('uforbederlig',),
'uforbederlige': ('uforbederlig',),
'uforbederligere': ('uforbederlig',),
'uforbederligst': ('uforbederlig',),
'uforbederligste': ('uforbederlig',),
'uforbeholden': ('uforbeholden',),
'uforbeholdent': ('uforbeholden',),
'uforbeholdne': ('uforbeholden',),
'uforbeholdnere': ('uforbeholden',),
'uforbeholdnest': ('uforbeholden',),
'uforbeholdneste': ('uforbeholden',),
'uforberedt': ('uforberedt',),
'uforberedte': ('uforberedt',),
'uforberedtere': ('uforberedt',),
'uforberedtest': ('uforberedt',),
'uforberedteste': ('uforberedt',),
'uforbindtlig': ('uforbindtlig',),
'uforbindtlige': ('uforbindtlig',),
'uforbindtligere': ('uforbindtlig',),
'uforbindtligst': ('uforbindtlig',),
'uforbindtligste': ('uforbindtlig',),
'ufordelaktig': ('ufordelaktig',),
'ufordelaktige': ('ufordelaktig',),
'ufordelaktigere': ('ufordelaktig',),
'ufordelaktigst': ('ufordelaktig',),
'ufordelaktigste': ('ufordelaktig',),
'uforderva': ('uforderva',),
'ufordervelig': ('ufordervelig',),
'ufordervelige': ('ufordervelig',),
'uforderveligere': ('ufordervelig',),
'uforderveligst': ('ufordervelig',),
'uforderveligste': ('ufordervelig',),
'ufordervede': ('ufordervet',),
'ufordervet': ('ufordervet',),
'ufordervete': ('ufordervet',),
'ufordervetere': ('ufordervet',),
'ufordervetest': ('ufordervet',),
'uforderveteste': ('ufordervet',),
'ufordragelig': ('ufordragelig',),
'ufordragelige': ('ufordragelig',),
'ufordrageligere': ('ufordragelig',),
'ufordrageligst': ('ufordragelig',),
'ufordrageligste': ('ufordragelig',),
'ufordøya': ('ufordøya',),
'ufordøyd': ('ufordøyd',),
'ufordøyde': ('ufordøyd',),
'ufordøydere': ('ufordøyd',),
'ufordøydest': ('ufordøyd',),
'ufordøydeste': ('ufordøyd',),
'ufordøyelig': ('ufordøyelig',),
'ufordøyelige': ('ufordøyelig',),
'ufordøyeligere': ('ufordøyelig',),
'ufordøyeligst': ('ufordøyelig',),
'ufordøyeligste': ('ufordøyelig',),
'ufordøyede': ('ufordøyet',),
'ufordøyet': ('ufordøyet',),
'ufordøyete': ('ufordøyet',),
'ufordøyetere': ('ufordøyet',),
'ufordøyetest': ('ufordøyet',),
'ufordøyeteste': ('ufordøyet',),
'uforenelig': ('uforenelig',),
'uforenelige': ('uforenelig',),
'uforeneligere': ('uforenelig',),
'uforeneligst': ('uforenelig',),
'uforeneligste': ('uforenelig',),
'uforenlig': ('uforenlig',),
'uforenlige': ('uforenlig',),
'uforenligere': ('uforenlig',),
'uforenligst': ('uforenlig',),
'uforenligste': ('uforenlig',),
'uforede': ('uforet',),
'uforet': ('uforet',),
'uforete': ('uforet',),
'uforetere': ('uforet',),
'uforetest': ('uforet',),
'uforeteste': ('uforet',),
'uforfalska': ('uforfalska',),
'uforfalskede': ('uforfalsket',),
'uforfalsket': ('uforfalsket',),
'uforfalskete': ('uforfalsket',),
'uforfalsketere': ('uforfalsket',),
'uforfalsketest': ('uforfalsket',),
'uforfalsketeste': ('uforfalsket',),
'uforferda': ('uforferda',),
'uforferdede': ('uforferdet',),
'uforferdet': ('uforferdet',),
'uforferdete': ('uforferdet',),
'uforferdetere': ('uforferdet',),
'uforferdetest': ('uforferdet',),
'uforferdeteste': ('uforferdet',),
'uforgjengelig': ('uforgjengelig',),
'uforgjengelige': ('uforgjengelig',),
'uforgjengeligere': ('uforgjengelig',),
'uforgjengeligst': ('uforgjengelig',),
'uforgjengeligste': ('uforgjengelig',),
'uforglemmelig': ('uforglemmelig',),
'uforglemmelige': ('uforglemmelig',),
'uforglemmeligere': ('uforglemmelig',),
'uforglemmeligst': ('uforglemmelig',),
'uforglemmeligste': ('uforglemmelig',),
'uforholdsmessig': ('uforholdsmessig',),
'uforholdsmessige': ('uforholdsmessig',),
'uforholdsmessigere': ('uforholdsmessig',),
'uforholdsmessigst': ('uforholdsmessig',),
'uforholdsmessigste': ('uforholdsmessig',),
'uforklarlig': ('uforklarlig',),
'uforklarlige': ('uforklarlig',),
'uforklarligere': ('uforklarlig',),
'uforklarligst': ('uforklarlig',),
'uforklarligste': ('uforklarlig',),
'uforklart': ('uforklart',),
'uforklarte': ('uforklart',),
'uforklartere': ('uforklart',),
'uforklartest': ('uforklart',),
'uforklarteste': ('uforklart',),
'uforkrenkelig': ('uforkrenkelig',),
'uforkrenkelige': ('uforkrenkelig',),
'uforkrenkeligere': ('uforkrenkelig',),
'uforkrenkeligst': ('uforkrenkelig',),
'uforkrenkeligste': ('uforkrenkelig',),
'uforlignelig': ('uforlignelig',),
'uforlignelige': ('uforlignelig',),
'uforligneligere': ('uforlignelig',),
'uforligneligst': ('uforlignelig',),
'uforligneligste': ('uforlignelig',),
'uforlikelig': ('uforlikelig',),
'uforlikelige': ('uforlikelig',),
'uforlikeligere': ('uforlikelig',),
'uforlikeligst': ('uforlikelig',),
'uforlikeligste': ('uforlikelig',),
'uforliknelig': ('uforliknelig',),
'uforliknelige': ('uforliknelig',),
'uforlikneligere': ('uforliknelig',),
'uforlikneligst': ('uforliknelig',),
'uforlikneligste': ('uforliknelig',),
'uforlikt': ('uforlikt',),
'uforlikte': ('uforlikt',),
'uforliktere': ('uforlikt',),
'uforliktest': ('uforlikt',),
'uforlikteste': ('uforlikt',),
'uforløst': ('uforløst',),
'uforløste': ('uforløst',),
'uforløstere': ('uforløst',),
'uforløstest': ('uforløst',),
'uforløsteste': ('uforløst',),
'uforma': ('uforma',),
'uformelig': ('uformelig',),
'uformelige': ('uformelig',),
'uformeligere': ('uformelig',),
'uformeligst': ('uformelig',),
'uformeligste': ('uformelig',),
'uformell': ('uformell',),
'uformelle': ('uformell',),
'uformellere': ('uformell',),
'uformellest': ('uformell',),
'uformelleste': ('uformell',),
'uformelt': ('uformell',),
'uformede': ('uformet',),
'uformet': ('uformet',),
'uformete': ('uformet',),
'uformetere': ('uformet',),
'uformetest': ('uformet',),
'uformeteste': ('uformet',),
'uforminska': ('uforminska',),
'uforminskede': ('uforminsket',),
'uforminsket': ('uforminsket',),
'uforminskete': ('uforminsket',),
'uforminsketere': ('uforminsket',),
'uforminsketest': ('uforminsket',),
'uforminsketeste': ('uforminsket',),
'uformuende': ('uformuende',),
'ufornuftig': ('ufornuftig',),
'ufornuftige': ('ufornuftig',),
'ufornuftigere': ('ufornuftig',),
'ufornuftigst': ('ufornuftig',),
'ufornuftigste': ('ufornuftig',),
'uforpliktende': ('uforpliktende',),
'uforretta': ('uforretta',),
'uforrettede': ('uforrettet',),
'uforrettet': ('uforrettet',),
'uforrettete': ('uforrettet',),
'uforrettetere': ('uforrettet',),
'uforrettetest': ('uforrettet',),
'uforretteteste': ('uforrettet',),
'uforsettlig': ('uforsettlig',),
'uforsettlige': ('uforsettlig',),
'uforsettligere': ('uforsettlig',),
'uforsettligst': ('uforsettlig',),
'uforsettligste': ('uforsettlig',),
'uforsiktig': ('uforsiktig',),
'uforsiktige': ('uforsiktig',),
'uforsiktigere': ('uforsiktig',),
'uforsiktigst': ('uforsiktig',),
'uforsiktigste': ('uforsiktig',),
'uforskamma': ('uforskamma',),
'uforskammede': ('uforskammet',),
'uforskammet': ('uforskammet',),
'uforskammete': ('uforskammet',),
'uforskammetere': ('uforskammet',),
'uforskammetest': ('uforskammet',),
'uforskammeteste': ('uforskammet',),
'uforskyldt': ('uforskyldt',),
'uforskyldte': ('uforskyldt',),
'uforskyldtere': ('uforskyldt',),
'uforskyldtest': ('uforskyldt',),
'uforskyldteste': ('uforskyldt',),
'uforsonlig': ('uforsonlig',),
'uforsonlige': ('uforsonlig',),
'uforsonligere': ('uforsonlig',),
'uforsonligst': ('uforsonlig',),
'uforsonligste': ('uforsonlig',),
'uforstandig': ('uforstandig',),
'uforstandige': ('uforstandig',),
'uforstandigere': ('uforstandig',),
'uforstandigst': ('uforstandig',),
'uforstandigste': ('uforstandig',),
'uforstyrra': ('uforstyrra',),
'uforstyrrelig': ('uforstyrrelig',),
'uforstyrrelige': ('uforstyrrelig',),
'uforstyrreligere': ('uforstyrrelig',),
'uforstyrreligst': ('uforstyrrelig',),
'uforstyrreligste': ('uforstyrrelig',),
'uforstyrrede': ('uforstyrret',),
'uforstyrret': ('uforstyrret',),
'uforstyrrete': ('uforstyrret',),
'uforstyrretere': ('uforstyrret',),
'uforstyrretest': ('uforstyrret',),
'uforstyrreteste': ('uforstyrret',),
'uforståelig': ('uforståelig',),
'uforståelige': ('uforståelig',),
'uforståeligere': ('uforståelig',),
'uforståeligst': ('uforståelig',),
'uforståeligste': ('uforståelig',),
'uforstående': ('uforstående',),
'uforsvarlig': ('uforsvarlig',),
'uforsvarlige': ('uforsvarlig',),
'uforsvarligere': ('uforsvarlig',),
'uforsvarligst': ('uforsvarlig',),
'uforsvarligste': ('uforsvarlig',),
'uforsøkt': ('uforsøkt',),
'uforsøkte': ('uforsøkt',),
'uforsøktere': ('uforsøkt',),
'uforsøktest': ('uforsøkt',),
'uforsøkteste': ('uforsøkt',),
'uforsørga': ('uforsørga',),
'uforsørgede': ('uforsørget',),
'uforsørget': ('uforsørget',),
'uforsørgete': ('uforsørget',),
'uforsørgetere': ('uforsørget',),
'uforsørgetest': ('uforsørget',),
'uforsørgeteste': ('uforsørget',),
'ufortjent': ('ufortjent',),
'ufortjente': ('ufortjent',),
'ufortjentere': ('ufortjent',),
'ufortjentest': ('ufortjent',),
'ufortjenteste': ('ufortjent',),
'ufortrøden': ('ufortrøden',),
'ufortrødent': ('ufortrøden',),
'ufortrødne': ('ufortrøden',),
'ufortrødnere': ('ufortrøden',),
'ufortrødnest': ('ufortrøden',),
'ufortrødneste': ('ufortrøden',),
'uforutsett': ('uforutsett',),
'uforutsette': ('uforutsett',),
'uforutsettere': ('uforutsett',),
'uforutsettest': ('uforutsett',),
'uforutsetteste': ('uforutsett',),
'uforutsigbar': ('uforutsigbar',),
'uforutsigbare': ('uforutsigbar',),
'uforutsigbarere': ('uforutsigbar',),
'uforutsigbarest': ('uforutsigbar',),
'uforutsigbareste': ('uforutsigbar',),
'uforutsigbart': ('uforutsigbar',),
'uforutsigelig': ('uforutsigelig',),
'uforutsigelige': ('uforutsigelig',),
'uforutsigeligere': ('uforutsigelig',),
'uforutsigeligst': ('uforutsigelig',),
'uforutsigeligste': ('uforutsigelig',),
'uforvarende': ('uforvarende',),
'uframkommelig': ('uframkommelig',),
'uframkommelige': ('uframkommelig',),
'uframkommeligere': ('uframkommelig',),
'uframkommeligst': ('uframkommelig',),
'uframkommeligste': ('uframkommelig',),
'ufravikelig': ('ufravikelig',),
'ufravikelige': ('ufravikelig',),
'ufravikeligere': ('ufravikelig',),
'ufravikeligst': ('ufravikelig',),
'ufravikeligste': ('ufravikelig',),
'ufrelst': ('ufrelst',),
'ufrelste': ('ufrelst',),
'ufrelstere': ('ufrelst',),
'ufrelstest': ('ufrelst',),
'ufrelsteste': ('ufrelst',),
'ufremkommelig': ('ufremkommelig',),
'ufremkommelige': ('ufremkommelig',),
'ufremkommeligere': ('ufremkommelig',),
'ufremkommeligst': ('ufremkommelig',),
'ufremkommeligste': ('ufremkommelig',),
'ufri': ('ufri',),
'ufrie': ('ufri',),
'ufriere': ('ufri',),
'ufriest': ('ufri',),
'ufrieste': ('ufri',),
'ufritt': ('ufri',),
'ufrivillig': ('ufrivillig',),
'ufrivillige': ('ufrivillig',),
'ufrivilligere': ('ufrivillig',),
'ufrivilligst': ('ufrivillig',),
'ufrivilligste': ('ufrivillig',),
'ufruktbar': ('ufruktbar',),
'ufruktbare': ('ufruktbar',),
'ufruktbarere': ('ufruktbar',),
'ufruktbarest': ('ufruktbar',),
'ufruktbareste': ('ufruktbar',),
'ufruktbart': ('ufruktbar',),
'ufset': ('ufset',),
'ufsete': ('ufset',),
'ufsetere': ('ufset',),
'ufsetest': ('ufset',),
'ufseteste': ('ufset',),
'ufsete': ('ufsete',),
'ufullbåren': ('ufullbåren',),
'ufullbårent': ('ufullbåren',),
'ufullbårne': ('ufullbåren',),
'ufullbårnere': ('ufullbåren',),
'ufullbårnest': ('ufullbåren',),
'ufullbårneste': ('ufullbåren',),
'ufullendt': ('ufullendt',),
'ufullendte': ('ufullendt',),
'ufullendtere': ('ufullendt',),
'ufullendtest': ('ufullendt',),
'ufullendteste': ('ufullendt',),
'ufullkommen': ('ufullkommen',),
'ufullkomment': ('ufullkommen',),
'ufullkomne': ('ufullkommen',),
'ufullkomnere': ('ufullkommen',),
'ufullkomnest': ('ufullkommen',),
'ufullkomneste': ('ufullkommen',),
'ufullstendig': ('ufullstendig',),
'ufullstendige': ('ufullstendig',),
'ufullstendigere': ('ufullstendig',),
'ufullstendigst': ('ufullstendig',),
'ufullstendigste': ('ufullstendig',),
'ufyselig': ('ufyselig',),
'ufyselige': ('ufyselig',),
'ufyseligere': ('ufyselig',),
'ufyseligst': ('ufyselig',),
'ufyseligste': ('ufyselig',),
'ufysen': ('ufysen',),
'ufysent': ('ufysen',),
'ufysne': ('ufysen',),
'ufysnere': ('ufysen',),
'ufysnest': ('ufysen',),
'ufysneste': ('ufysen',),
'ufødd': ('ufødd',),
'ufødde': ('ufødd',),
'uføddere': ('ufødd',),
'uføddest': ('ufødd',),
'uføddeste': ('ufødd',),
'ufødt': ('ufødt',),
'ufødte': ('ufødt',),
'ufødtere': ('ufødt',),
'ufødtest': ('ufødt',),
'ufødteste': ('ufødt',),
'ufølsom': ('ufølsom',),
'ufølsomme': ('ufølsom',),
'ufølsommere': ('ufølsom',),
'ufølsomst': ('ufølsom',),
'ufølsomste': ('ufølsom',),
'ufølsomt': ('ufølsom',),
'ufør': ('ufør',),
'uføre': ('ufør',),
'uførere': ('ufør',),
'uførest': ('ufør',),
'uføreste': ('ufør',),
'uført': ('ufør',),
'uførepensjonert': ('uførepensjonert',),
'uførepensjonerte': ('uførepensjonert',),
'uførepensjonertere': ('uførepensjonert',),
'uførepensjonertest': ('uførepensjonert',),
'uførepensjonerteste': ('uførepensjonert',),
'uføretrygda': ('uføretrygde',),
'uføretrygdede': ('uføretrygde',),
'uføretrygdende': ('uføretrygde',),
'uføretrygdet': ('uføretrygde',),
'uføretrygdete': ('uføretrygde',),
'ugandisk': ('ugandisk',),
'ugandiske': ('ugandisk',),
'ugandiskere': ('ugandisk',),
'ugandiskest': ('ugandisk',),
'ugandiskeste': ('ugandisk',),
'ugga': ('ugge',),
'uggede': ('ugge',),
'uggende': ('ugge',),
'ugget': ('ugge',),
'uggete': ('ugge',),
'uggen': ('uggen',),
'uggent': ('uggen',),
'ugne': ('uggen',),
'ugnere': ('uggen',),
'ugnest': ('uggen',),
'ugneste': ('uggen',),
'ugget': ('ugget',),
'uggete': ('ugget',),
'uggetere': ('ugget',),
'uggetest': ('ugget',),
'uggeteste': ('ugget',),
'uggete': ('uggete',),
'ugiddelig': ('ugiddelig',),
'ugiddelige': ('ugiddelig',),
'ugiddeligere': ('ugiddelig',),
'ugiddeligst': ('ugiddelig',),
'ugiddeligste': ('ugiddelig',),
'ugift': ('ugift',),
'ugifte': ('ugift',),
'ugiftere': ('ugift',),
'ugiftest': ('ugift',),
'ugifteste': ('ugift',),
'ugild': ('ugild',),
'ugilde': ('ugild',),
'ugildere': ('ugild',),
'ugildest': ('ugild',),
'ugildeste': ('ugild',),
'ugildt': ('ugild',),
'ugjendrivelig': ('ugjendrivelig',),
'ugjendrivelige': ('ugjendrivelig',),
'ugjendriveligere': ('ugjendrivelig',),
'ugjendriveligst': ('ugjendrivelig',),
'ugjendriveligste': ('ugjendrivelig',),
'ugjenkallelig': ('ugjenkallelig',),
'ugjenkallelige': ('ugjenkallelig',),
'ugjenkalleligere': ('ugjenkallelig',),
'ugjenkalleligst': ('ugjenkallelig',),
'ugjenkalleligste': ('ugjenkallelig',),
'ugjenkjennelig': ('ugjenkjennelig',),
'ugjenkjennelige': ('ugjenkjennelig',),
'ugjenkjenneligere': ('ugjenkjennelig',),
'ugjenkjenneligst': ('ugjenkjennelig',),
'ugjenkjenneligste': ('ugjenkjennelig',),
'ugjennomførlig': ('ugjennomførlig',),
'ugjennomførlige': ('ugjennomførlig',),
'ugjennomførligere': ('ugjennomførlig',),
'ugjennomførligst': ('ugjennomførlig',),
'ugjennomførligste': ('ugjennomførlig',),
'ugjennomsiktig': ('ugjennomsiktig',),
'ugjennomsiktige': ('ugjennomsiktig',),
'ugjennomsiktigere': ('ugjennomsiktig',),
'ugjennomsiktigst': ('ugjennomsiktig',),
'ugjennomsiktigste': ('ugjennomsiktig',),
'ugjennomtrengelig': ('ugjennomtrengelig',),
'ugjennomtrengelige': ('ugjennomtrengelig',),
'ugjennomtrengeligere': ('ugjennomtrengelig',),
'ugjennomtrengeligst': ('ugjennomtrengelig',),
'ugjennomtrengeligste': ('ugjennomtrengelig',),
'ugjestmild': ('ugjestmild',),
'ugjestmilde': ('ugjestmild',),
'ugjestmildere': ('ugjestmild',),
'ugjestmildest': ('ugjestmild',),
'ugjestmildeste': ('ugjestmild',),
'ugjestmildt': ('ugjestmild',),
'ugjort': ('ugjort',),
'ugjorte': ('ugjort',),
'ugjortere': ('ugjort',),
'ugjortest': ('ugjort',),
'ugjorteste': ('ugjort',),
'ugjørlig': ('ugjørlig',),
'ugjørlige': ('ugjørlig',),
'ugjørligere': ('ugjørlig',),
'ugjørligst': ('ugjørlig',),
'ugjørligste': ('ugjørlig',),
'uglad': ('uglad',),
'uglade': ('uglad',),
'ugladere': ('uglad',),
'ugladest': ('uglad',),
'ugladeste': ('uglad',),
'ugleseende': ('uglese',),
'uglesett': ('uglese',),
'uglesette': ('uglese',),
'ugodslig': ('ugodslig',),
'ugodslige': ('ugodslig',),
'ugodsligere': ('ugodslig',),
'ugodsligst': ('ugodslig',),
'ugodsligste': ('ugodslig',),
'ugradert': ('ugradert',),
'ugraderte': ('ugradert',),
'ugradertere': ('ugradert',),
'ugradertest': ('ugradert',),
'ugraderteste': ('ugradert',),
'ugrammatikalsk': ('ugrammatikalsk',),
'ugrammatikalske': ('ugrammatikalsk',),
'ugrammatikalskere': ('ugrammatikalsk',),
'ugrammatikalskest': ('ugrammatikalsk',),
'ugrammatikalskeste': ('ugrammatikalsk',),
'ugrammatisk': ('ugrammatisk',),
'ugrammatiske': ('ugrammatisk',),
'ugrammatiskere': ('ugrammatisk',),
'ugrammatiskest': ('ugrammatisk',),
'ugrammatiskeste': ('ugrammatisk',),
'ugrasdrepende': ('ugrasdrepende',),
'ugrei': ('ugrei',),
'ugreie': ('ugrei',),
'ugreiere': ('ugrei',),
'ugreiest': ('ugrei',),
'ugreieste': ('ugrei',),
'ugreit': ('ugrei',),
'ugreitt': ('ugrei',),
'ugressdrepende': ('ugressdrepende',),
'ugrisk': ('ugrisk',),
'ugriske': ('ugrisk',),
'ugriskere': ('ugrisk',),
'ugriskest': ('ugrisk',),
'ugriskeste': ('ugrisk',),
'ugrunna': ('ugrunna',),
'ugrunnede': ('ugrunnet',),
'ugrunnet': ('ugrunnet',),
'ugrunnete': ('ugrunnet',),
'ugrunnetere': ('ugrunnet',),
'ugrunnetest': ('ugrunnet',),
'ugrunneteste': ('ugrunnet',),
'ugudelig': ('ugudelig',),
'ugudelige': ('ugudelig',),
'ugudeligere': ('ugudelig',),
'ugudeligst': ('ugudelig',),
'ugudeligste': ('ugudelig',),
'ugunstig': ('ugunstig',),
'ugunstige': ('ugunstig',),
'ugunstigere': ('ugunstig',),
'ugunstigst': ('ugunstig',),
'ugunstigste': ('ugunstig',),
'ugyldig': ('ugyldig',),
'ugyldige': ('ugyldig',),
'ugyldigere': ('ugyldig',),
'ugyldigst': ('ugyldig',),
'ugyldigste': ('ugyldig',),
'ugyldiggjort': ('ugyldiggjøre',),
'ugyldiggjorte': ('ugyldiggjøre',),
'ugyldiggjørende': ('ugyldiggjøre',),
'uhandgripelig': ('uhandgripelig',),
'uhandgripelige': ('uhandgripelig',),
'uhandgripeligere': ('uhandgripelig',),
'uhandgripeligst': ('uhandgripelig',),
'uhandgripeligste': ('uhandgripelig',),
'uhandterlig': ('uhandterlig',),
'uhandterlige': ('uhandterlig',),
'uhandterligere': ('uhandterlig',),
'uhandterligst': ('uhandterlig',),
'uhandterligste': ('uhandterlig',),
'uharmonisk': ('uharmonisk',),
'uharmoniske': ('uharmonisk',),
'uharmoniskere': ('uharmonisk',),
'uharmoniskest': ('uharmonisk',),
'uharmoniskeste': ('uharmonisk',),
'uhederlig': ('uhederlig',),
'uhederlige': ('uhederlig',),
'uhederligere': ('uhederlig',),
'uhederligst': ('uhederlig',),
'uhederligste': ('uhederlig',),
'uheil': ('uheil',),
'uheile': ('uheil',),
'uheilere': ('uheil',),
'uheilest': ('uheil',),
'uheileste': ('uheil',),
'uheilt': ('uheil',),
'uheimla': ('uheimla',),
'uheimlede': ('uheimlet',),
'uheimlet': ('uheimlet',),
'uheimlete': ('uheimlet',),
'uheimletere': ('uheimlet',),
'uheimletest': ('uheimlet',),
'uheimleteste': ('uheimlet',),
'uhel': ('uhel',),
'uhele': ('uhel',),
'uhelere': ('uhel',),
'uhelest': ('uhel',),
'uheleste': ('uhel',),
'uhelt': ('uhel',),
'uhelbredelig': ('uhelbredelig',),
'uhelbredelige': ('uhelbredelig',),
'uhelbredeligere': ('uhelbredelig',),
'uhelbredeligst': ('uhelbredelig',),
'uhelbredeligste': ('uhelbredelig',),
'uheldig': ('uheldig',),
'uheldige': ('uheldig',),
'uheldigere': ('uheldig',),
'uheldigst': ('uheldig',),
'uheldigste': ('uheldig',),
'uhellsvanger': ('uhellsvanger',),
'uhellsvangert': ('uhellsvanger',),
'uhellsvangre': ('uhellsvanger',),
'uhellsvangrere': ('uhellsvanger',),
'uhellsvangrest': ('uhellsvanger',),
'uhellsvangreste': ('uhellsvanger',),
'uhemma': ('uhemma',),
'uhemmede': ('uhemmet',),
'uhemmet': ('uhemmet',),
'uhemmete': ('uhemmet',),
'uhemmetere': ('uhemmet',),
'uhemmetest': ('uhemmet',),
'uhemmeteste': ('uhemmet',),
'uhendig': ('uhendig',),
'uhendige': ('uhendig',),
'uhendigere': ('uhendig',),
'uhendigst': ('uhendig',),
'uhendigste': ('uhendig',),
'uhensiktsmessig': ('uhensiktsmessig',),
'uhensiktsmessige': ('uhensiktsmessig',),
'uhensiktsmessigere': ('uhensiktsmessig',),
'uhensiktsmessigst': ('uhensiktsmessig',),
'uhensiktsmessigste': ('uhensiktsmessig',),
'uhilda': ('uhilda',),
'uhildede': ('uhildet',),
'uhildet': ('uhildet',),
'uhildete': ('uhildet',),
'uhildetere': ('uhildet',),
'uhildetest': ('uhildet',),
'uhildeteste': ('uhildet',),
'uhindra': ('uhindra',),
'uhindrede': ('uhindret',),
'uhindret': ('uhindret',),
'uhindrete': ('uhindret',),
'uhindretere': ('uhindret',),
'uhindretest': ('uhindret',),
'uhindreteste': ('uhindret',),
'uhistorisk': ('uhistorisk',),
'uhistoriske': ('uhistorisk',),
'uhistoriskere': ('uhistorisk',),
'uhistoriskest': ('uhistorisk',),
'uhistoriskeste': ('uhistorisk',),
'uhjelpelig': ('uhjelpelig',),
'uhjelpelige': ('uhjelpelig',),
'uhjelpeligere': ('uhjelpelig',),
'uhjelpeligst': ('uhjelpelig',),
'uhjelpeligste': ('uhjelpelig',),
'uhjelpelig': ('uhjelpelig',),
'uhjelpelige': ('uhjelpelig',),
'uhjelpeligere': ('uhjelpelig',),
'uhjelpeligst': ('uhjelpelig',),
'uhjelpeligste': ('uhjelpelig',),
'uhjemla': ('uhjemla',),
'uhjemlede': ('uhjemlet',),
'uhjemlet': ('uhjemlet',),
'uhjemlete': ('uhjemlet',),
'uhjemletere': ('uhjemlet',),
'uhjemletest': ('uhjemlet',),
'uhjemleteste': ('uhjemlet',),
'uholdbar': ('uholdbar',),
'uholdbare': ('uholdbar',),
'uholdbarere': ('uholdbar',),
'uholdbarest': ('uholdbar',),
'uholdbareste': ('uholdbar',),
'uholdbart': ('uholdbar',),
'uhorvelig': ('uhorvelig',),
'uhorvelige': ('uhorvelig',),
'uhorveligere': ('uhorvelig',),
'uhorveligst': ('uhorvelig',),
'uhorveligste': ('uhorvelig',),
'uhuga': ('uhuga',),
'uhumsk': ('uhumsk',),
'uhumske': ('uhumsk',),
'uhumskere': ('uhumsk',),
'uhumskest': ('uhumsk',),
'uhumskeste': ('uhumsk',),
'uhumskt': ('uhumsk',),
'uhvass': ('uhvass',),
'uhvasse': ('uhvass',),
'uhvassere': ('uhvass',),
'uhvassest': ('uhvass',),
'uhvasseste': ('uhvass',),
'uhvast': ('uhvass',),
'uhyggelig': ('uhyggelig',),
'uhyggelige': ('uhyggelig',),
'uhyggeligere': ('uhyggelig',),
'uhyggeligst': ('uhyggelig',),
'uhyggeligste': ('uhyggelig',),
'uhygienisk': ('uhygienisk',),
'uhygieniske': ('uhygienisk',),
'uhygieniskere': ('uhygienisk',),
'uhygieniskest': ('uhygienisk',),
'uhygieniskeste': ('uhygienisk',),
'uhyre': ('uhyre',),
'uhyrlig': ('uhyrlig',),
'uhyrlige': ('uhyrlig',),
'uhyrligere': ('uhyrlig',),
'uhyrligst': ('uhyrlig',),
'uhyrligste': ('uhyrlig',),
'uhåndgripelig': ('uhåndgripelig',),
'uhåndgripelige': ('uhåndgripelig',),
'uhåndgripeligere': ('uhåndgripelig',),
'uhåndgripeligst': ('uhåndgripelig',),
'uhåndgripeligste': ('uhåndgripelig',),
'uhåndterlig': ('uhåndterlig',),
'uhåndterlige': ('uhåndterlig',),
'uhåndterligere': ('uhåndterlig',),
'uhåndterligst': ('uhåndterlig',),
'uhåndterligste': ('uhåndterlig',),
'uhøflig': ('uhøflig',),
'uhøflige': ('uhøflig',),
'uhøfligere': ('uhøflig',),
'uhøfligst': ('uhøflig',),
'uhøfligste': ('uhøflig',),
'uhørlig': ('uhørlig',),
'uhørlige': ('uhørlig',),
'uhørligere': ('uhørlig',),
'uhørligst': ('uhørlig',),
'uhørligste': ('uhørlig',),
'uhørt': ('uhørt',),
'uhørte': ('uhørt',),
'uhørtere': ('uhørt',),
'uhørtest': ('uhørt',),
'uhørteste': ('uhørt',),
'uhøvla': ('uhøvla',),
'uhøvlede': ('uhøvlet',),
'uhøvlet': ('uhøvlet',),
'uhøvlete': ('uhøvlet',),
'uhøvletere': ('uhøvlet',),
'uhøvletest': ('uhøvlet',),
'uhøvleteste': ('uhøvlet',),
'uimotsagt': ('uimotsagt',),
'uimotsagte': ('uimotsagt',),
'uimotsagtere': ('uimotsagt',),
'uimotsagtest': ('uimotsagt',),
'uimotsagteste': ('uimotsagt',),
'uimotsigelig': ('uimotsigelig',),
'uimotsigelige': ('uimotsigelig',),
'uimotsigeligere': ('uimotsigelig',),
'uimotsigeligst': ('uimotsigelig',),
'uimotsigeligste': ('uimotsigelig',),
'uimotstridelig': ('uimotstridelig',),
'uimotstridelige': ('uimotstridelig',),
'uimotstrideligere': ('uimotstridelig',),
'uimotstrideligst': ('uimotstridelig',),
'uimotstrideligste': ('uimotstridelig',),
'uimotståelig': ('uimotståelig',),
'uimotståelige': ('uimotståelig',),
'uimotståeligere': ('uimotståelig',),
'uimotståeligst': ('uimotståelig',),
'uimotståeligste': ('uimotståelig',),
'uinnbundet': ('uinnbundet',),
'uinnbundne': ('uinnbundet',),
'uinnbundnere': ('uinnbundet',),
'uinnbundnest': ('uinnbundet',),
'uinnbundneste': ('uinnbundet',),
'uinnfridd': ('uinnfridd',),
'uinnfridde': ('uinnfridd',),
'uinnfriddere': ('uinnfridd',),
'uinnfriddest': ('uinnfridd',),
'uinnfriddeste': ('uinnfridd',),
'uinnskrenka': ('uinnskrenka',),
'uinnskrenkede': ('uinnskrenket',),
'uinnskrenket': ('uinnskrenket',),
'uinnskrenkete': ('uinnskrenket',),
'uinnskrenketere': ('uinnskrenket',),
'uinnskrenketest': ('uinnskrenket',),
'uinnskrenketeste': ('uinnskrenket',),
'uinntakelig': ('uinntakelig',),
'uinntakelige': ('uinntakelig',),
'uinntakeligere': ('uinntakelig',),
'uinntakeligst': ('uinntakelig',),
'uinntakeligste': ('uinntakelig',),
'uinnvia': ('uinnvia',),
'uinnvidd': ('uinnvidd',),
'uinnvidde': ('uinnvidd',),
'uinnviddere': ('uinnvidd',),
'uinnviddest': ('uinnvidd',),
'uinnviddeste': ('uinnvidd',),
'uinnviede': ('uinnviet',),
'uinnviet': ('uinnviet',),
'uinnviete': ('uinnviet',),
'uinnvietere': ('uinnviet',),
'uinnvietest': ('uinnviet',),
'uinnvieteste': ('uinnviet',),
'uinnvigd': ('uinnvigd',),
'uinnvigde': ('uinnvigd',),
'uinnvigdere': ('uinnvigd',),
'uinnvigdest': ('uinnvigd',),
'uinnvigdeste': ('uinnvigd',),
'uinspirert': ('uinspirert',),
'uinspirerte': ('uinspirert',),
'uinspirertere': ('uinspirert',),
'uinspirertest': ('uinspirert',),
'uinspirerteste': ('uinspirert',),
'uinteressant': ('uinteressant',),
'uinteressante': ('uinteressant',),
'uinteressantere': ('uinteressant',),
'uinteressantest': ('uinteressant',),
'uinteressanteste': ('uinteressant',),
'uinteressert': ('uinteressert',),
'uinteresserte': ('uinteressert',),
'uinteressertere': ('uinteressert',),
'uinteressertest': ('uinteressert',),
'uinteresserteste': ('uinteressert',),
'ujamn': ('ujamn',),
'ujamne': ('ujamn',),
'ujamnere': ('ujamn',),
'ujamnest': ('ujamn',),
'ujamneste': ('ujamn',),
'ujamt': ('ujamn',),
'ujevn': ('ujevn',),
'ujevne': ('ujevn',),
'ujevnere': ('ujevn',),
'ujevnest': ('ujevn',),
'ujevneste': ('ujevn',),
'ujevnt': ('ujevn',),
'ukehavende': ('ukehavende',),
'ukehavende': ('ukehavende',),
'ukentlig': ('ukentlig',),
'ukentlige': ('ukentlig',),
'ukentligere': ('ukentlig',),
'ukentligst': ('ukentlig',),
'ukentligste': ('ukentlig',),
'ukjemma': ('ukjemma',),
'ukjemmede': ('ukjemmet',),
'ukjemmet': ('ukjemmet',),
'ukjemmete': ('ukjemmet',),
'ukjemmetere': ('ukjemmet',),
'ukjemmetest': ('ukjemmet',),
'ukjemmeteste': ('ukjemmet',),
'ukjemt': ('ukjemt',),
'ukjemte': ('ukjemt',),
'ukjemtere': ('ukjemt',),
'ukjemtest': ('ukjemt',),
'ukjemteste': ('ukjemt',),
'ukjennelig': ('ukjennelig',),
'ukjennelige': ('ukjennelig',),
'ukjenneligere': ('ukjennelig',),
'ukjenneligst': ('ukjennelig',),
'ukjenneligste': ('ukjennelig',),
'ukjent': ('ukjent',),
'ukjente': ('ukjent',),
'ukjentere': ('ukjent',),
'ukjentest': ('ukjent',),
'ukjenteste': ('ukjent',),
'ukjuren': ('ukjuren',),
'ukjurent': ('ukjuren',),
'ukjurne': ('ukjuren',),
'ukjurnere': ('ukjuren',),
'ukjurnest': ('ukjuren',),
'ukjurneste': ('ukjuren',),
'ukjærlig': ('ukjærlig',),
'ukjærlige': ('ukjærlig',),
'ukjærligere': ('ukjærlig',),
'ukjærligst': ('ukjærlig',),
'ukjærligste': ('ukjærlig',),
'ukjønna': ('ukjønna',),
'ukjønnede': ('ukjønnet',),
'ukjønnet': ('ukjønnet',),
'ukjønnete': ('ukjønnet',),
'ukjønnetere': ('ukjønnet',),
'ukjønnetest': ('ukjønnet',),
'ukjønneteste': ('ukjønnet',),
'uklanderlig': ('uklanderlig',),
'uklanderlige': ('uklanderlig',),
'uklanderligere': ('uklanderlig',),
'uklanderligst': ('uklanderlig',),
'uklanderligste': ('uklanderlig',),
'uklar': ('uklar',),
'uklare': ('uklar',),
'uklarere': ('uklar',),
'uklarest': ('uklar',),
'uklareste': ('uklar',),
'uklart': ('uklar',),
'ukledelig': ('ukledelig',),
'ukledelige': ('ukledelig',),
'ukledeligere': ('ukledelig',),
'ukledeligst': ('ukledelig',),
'ukledeligste': ('ukledelig',),
'uklippa': ('uklippa',),
'uklippede': ('uklippet',),
'uklippet': ('uklippet',),
'uklippete': ('uklippet',),
'uklippetere': ('uklippet',),
'uklippetest': ('uklippet',),
'uklippeteste': ('uklippet',),
'uklipt': ('uklipt',),
'uklipte': ('uklipt',),
'ukliptere': ('uklipt',),
'ukliptest': ('uklipt',),
'uklipteste': ('uklipt',),
'uklok': ('uklok',),
'ukloke': ('uklok',),
'uklokere': ('uklok',),
'uklokest': ('uklok',),
'uklokeste': ('uklok',),
'uklokt': ('uklok',),
'uknuselig': ('uknuselig',),
'uknuselige': ('uknuselig',),
'uknuseligere': ('uknuselig',),
'uknuseligst': ('uknuselig',),
'uknuseligste': ('uknuselig',),
'ukollegial': ('ukollegial',),
'ukollegiale': ('ukollegial',),
'ukollegialere': ('ukollegial',),
'ukollegialest': ('ukollegial',),
'ukollegialeste': ('ukollegial',),
'ukollegialt': ('ukollegial',),
'ukontrollerbar': ('ukontrollerbar',),
'ukontrollerbare': ('ukontrollerbar',),
'ukontrollerbarere': ('ukontrollerbar',),
'ukontrollerbarest': ('ukontrollerbar',),
'ukontrollerbareste': ('ukontrollerbar',),
'ukontrollerbart': ('ukontrollerbar',),
'ukontrollert': ('ukontrollert',),
'ukontrollerte': ('ukontrollert',),
'ukontrollertere': ('ukontrollert',),
'ukontrollertest': ('ukontrollert',),
'ukontrollerteste': ('ukontrollert',),
'ukorrekt': ('ukorrekt',),
'ukorrekte': ('ukorrekt',),
'ukorrektere': ('ukorrekt',),
'ukorrektest': ('ukorrekt',),
'ukorrekteste': ('ukorrekt',),
'ukoselig': ('ukoselig',),
'ukoselige': ('ukoselig',),
'ukoseligere': ('ukoselig',),
'ukoseligst': ('ukoselig',),
'ukoseligste': ('ukoselig',),
'ukrainsk': ('ukrainsk',),
'ukrainske': ('ukrainsk',),
'ukrainskere': ('ukrainsk',),
'ukrainskest': ('ukrainsk',),
'ukrainskeste': ('ukrainsk',),
'ukrenkelig': ('ukrenkelig',),
'ukrenkelige': ('ukrenkelig',),
'ukrenkeligere': ('ukrenkelig',),
'ukrenkeligst': ('ukrenkelig',),
'ukrenkeligste': ('ukrenkelig',),
'ukring': ('ukring',),
'ukringe': ('ukring',),
'ukringere': ('ukring',),
'ukringest': ('ukring',),
'ukringeste': ('ukring',),
'ukringt': ('ukring',),
'ukristelig': ('ukristelig',),
'ukristelige': ('ukristelig',),
'ukristeligere': ('ukristelig',),
'ukristeligst': ('ukristelig',),
'ukristeligste': ('ukristelig',),
'ukritisk': ('ukritisk',),
'ukritiske': ('ukritisk',),
'ukritiskere': ('ukritisk',),
'ukritiskest': ('ukritisk',),
'ukritiskeste': ('ukritisk',),
'ukrona': ('ukrona',),
'ukronede': ('ukronet',),
'ukronet': ('ukronet',),
'ukronete': ('ukronet',),
'ukronetere': ('ukronet',),
'ukronetest': ('ukronet',),
'ukroneteste': ('ukronet',),
'ukront': ('ukront',),
'ukronte': ('ukront',),
'ukrontere': ('ukront',),
'ukrontest': ('ukront',),
'ukronteste': ('ukront',),
'ukrydra': ('ukrydra',),
'ukrydrede': ('ukrydret',),
'ukrydret': ('ukrydret',),
'ukrydrete': ('ukrydret',),
'ukrydretere': ('ukrydret',),
'ukrydretest': ('ukrydret',),
'ukrydreteste': ('ukrydret',),
'ukuelig': ('ukuelig',),
'ukuelige': ('ukuelig',),
'ukueligere': ('ukuelig',),
'ukueligst': ('ukuelig',),
'ukueligste': ('ukuelig',),
'ukultivert': ('ukultivert',),
'ukultiverte': ('ukultivert',),
'ukultivertere': ('ukultivert',),
'ukultivertest': ('ukultivert',),
'ukultiverteste': ('ukultivert',),
'ukunstla': ('ukunstla',),
'ukunstlede': ('ukunstlet',),
'ukunstlet': ('ukunstlet',),
'ukunstlete': ('ukunstlet',),
'ukunstletere': ('ukunstlet',),
'ukunstletest': ('ukunstlet',),
'ukunstleteste': ('ukunstlet',),
'ukurant': ('ukurant',),
'ukurante': ('ukurant',),
'ukurantere': ('ukurant',),
'ukurantest': ('ukurant',),
'ukuranteste': ('ukurant',),
'ukvalifisert': ('ukvalifisert',),
'ukvalifiserte': ('ukvalifisert',),
'ukvalifisertere': ('ukvalifisert',),
'ukvalifisertest': ('ukvalifisert',),
'ukvalifiserteste': ('ukvalifisert',),
'ukvass': ('ukvass',),
'ukvasse': ('ukvass',),
'ukvassere': ('ukvass',),
'ukvassest': ('ukvass',),
'ukvasseste': ('ukvass',),
'ukvast': ('ukvass',),
'ukvinnelig': ('ukvinnelig',),
'ukvinnelige': ('ukvinnelig',),
'ukvinneligere': ('ukvinnelig',),
'ukvinneligst': ('ukvinnelig',),
'ukvinneligste': ('ukvinnelig',),
'ukyndig': ('ukyndig',),
'ukyndige': ('ukyndig',),
'ukyndigere': ('ukyndig',),
'ukyndigst': ('ukyndig',),
'ukyndigste': ('ukyndig',),
'ukyssa': ('ukyssa',),
'ukyssede': ('ukysset',),
'ukysset': ('ukysset',),
'ukyssete': ('ukysset',),
'ukyssetere': ('ukysset',),
'ukyssetest': ('ukysset',),
'ukysseteste': ('ukysset',),
'ukysst': ('ukysst',),
'ukysste': ('ukysst',),
'ukysstere': ('ukysst',),
'ukysstest': ('ukysst',),
'ukyssteste': ('ukysst',),
'ul': ('ul',),
'ule': ('ul',),
'ulere': ('ul',),
'ulest': ('ul',),
'uleste': ('ul',),
'ult': ('ul',),
'ulada': ('ulada',),
'uladd': ('uladd',),
'uladde': ('uladd',),
'uladdere': ('uladd',),
'uladdest': ('uladd',),
'uladdeste': ('uladd',),
'uladede': ('uladet',),
'uladet': ('uladet',),
'uladete': ('uladet',),
'uladetere': ('uladet',),
'uladetest': ('uladet',),
'uladeteste': ('uladet',),
'ulagelig': ('ulagelig',),
'ulagelige': ('ulagelig',),
'ulageligere': ('ulagelig',),
'ulageligst': ('ulagelig',),
'ulageligste': ('ulagelig',),
'ulaglig': ('ulaglig',),
'ulaglige': ('ulaglig',),
'ulagligere': ('ulaglig',),
'ulagligst': ('ulaglig',),
'ulagligste': ('ulaglig',),
'ulaseggjørlig': ('ulaseggjørlig',),
'ulaseggjørlige': ('ulaseggjørlig',),
'ulaseggjørligere': ('ulaseggjørlig',),
'ulaseggjørligst': ('ulaseggjørlig',),
'ulaseggjørligste': ('ulaseggjørlig',),
'ulastelig': ('ulastelig',),
'ulastelige': ('ulastelig',),
'ulasteligere': ('ulastelig',),
'ulasteligst': ('ulastelig',),
'ulasteligste': ('ulastelig',),
'ulende': ('ule',),
'ult': ('ule',),
'ulte': ('ule',),
'ulegelig': ('ulegelig',),
'ulegelige': ('ulegelig',),
'ulegeligere': ('ulegelig',),
'ulegeligst': ('ulegelig',),
'ulegeligste': ('ulegelig',),
'uleilig': ('uleilig',),
'uleilige': ('uleilig',),
'uleiligere': ('uleilig',),
'uleiligst': ('uleilig',),
'uleiligste': ('uleilig',),
'uleiliga': ('uleilige',),
'uleiligede': ('uleilige',),
'uleiligende': ('uleilige',),
'uleiliget': ('uleilige',),
'uleiligete': ('uleilige',),
'ulempelig': ('ulempelig',),
'ulempelige': ('ulempelig',),
'ulempeligere': ('ulempelig',),
'ulempeligst': ('ulempelig',),
'ulempeligste': ('ulempelig',),
'ulendt': ('ulendt',),
'ulendte': ('ulendt',),
'ulendtere': ('ulendt',),
'ulendtest': ('ulendt',),
'ulendteste': ('ulendt',),
'ulenkelig': ('ulenkelig',),
'ulenkelige': ('ulenkelig',),
'ulenkeligere': ('ulenkelig',),
'ulenkeligst': ('ulenkelig',),
'ulenkeligste': ('ulenkelig',),
'uleselig': ('uleselig',),
'uleselige': ('uleselig',),
'uleseligere': ('uleselig',),
'uleseligst': ('uleselig',),
'uleseligste': ('uleselig',),
'uleska': ('uleska',),
'uleskede': ('ulesket',),
'ulesket': ('ulesket',),
'uleskete': ('ulesket',),
'ulesketere': ('ulesket',),
'ulesketest': ('ulesket',),
'ulesketeste': ('ulesket',),
'ulest': ('ulest',),
'uleste': ('ulest',),
'ulestere': ('ulest',),
'ulestest': ('ulest',),
'ulesteste': ('ulest',),
'ulevelig': ('ulevelig',),
'ulevelige': ('ulevelig',),
'uleveligere': ('ulevelig',),
'uleveligst': ('ulevelig',),
'uleveligste': ('ulevelig',),
'ulidelig': ('ulidelig',),
'ulidelige': ('ulidelig',),
'ulideligere': ('ulidelig',),
'ulideligst': ('ulidelig',),
'ulideligste': ('ulidelig',),
'ulik': ('ulik',),
'ulike': ('ulik',),
'ulikere': ('ulik',),
'ulikest': ('ulik',),
'ulikeste': ('ulik',),
'ulikt': ('ulik',),
'ulike': ('ulike',),
'ulikefinnete': ('ulikefinnete',),
'ulka': ('ulke',),
'ulkede': ('ulke',),
'ulkende': ('ulke',),
'ulket': ('ulke',),
'ulkete': ('ulke',),
'ullen': ('ullen',),
'ullent': ('ullen',),
'ulne': ('ullen',),
'ulnere': ('ullen',),
'ulnest': ('ullen',),
'ulneste': ('ullen',),
'ulma': ('ulme',),
'ulmede': ('ulme',),
'ulmende': ('ulme',),
'ulmet': ('ulme',),
'ulmete': ('ulme',),
'ulna': ('ulne',),
'ulnede': ('ulne',),
'ulnende': ('ulne',),
'ulnet': ('ulne',),
'ulnete': ('ulne',),
'ulovlig': ('ulovlig',),
'ulovlige': ('ulovlig',),
'ulovligere': ('ulovlig',),
'ulovligst': ('ulovlig',),
'ulovligste': ('ulovlig',),
'ulsblakk': ('ulsblakk',),
'ulsblakke': ('ulsblakk',),
'ulsblakkere': ('ulsblakk',),
'ulsblakkest': ('ulsblakk',),
'ulsblakkeste': ('ulsblakk',),
'ulsblakt': ('ulsblakk',),
'ultimativ': ('ultimativ',),
'ultimative': ('ultimativ',),
'ultimativere': ('ultimativ',),
'ultimativest': ('ultimativ',),
'ultimativeste': ('ultimativ',),
'ultimativt': ('ultimativ',),
'ultrafiolett': ('ultrafiolett',),
'ultrafiolette': ('ultrafiolett',),
'ultrafiolettere': ('ultrafiolett',),
'ultrafiolettest': ('ultrafiolett',),
'ultrafioletteste': ('ultrafiolett',),
'ultrakonservativ': ('ultrakonservativ',),
'ultrakonservative': ('ultrakonservativ',),
'ultrakonservativere': ('ultrakonservativ',),
'ultrakonservativest': ('ultrakonservativ',),
'ultrakonservativeste': ('ultrakonservativ',),
'ultrakonservativt': ('ultrakonservativ',),
'ultramarin': ('ultramarin',),
'ultramarine': ('ultramarin',),
'ultramarinere': ('ultramarin',),
'ultramarinest': ('ultramarin',),
'ultramarineste': ('ultramarin',),
'ultramarint': ('ultramarin',),
'ultramoderne': ('ultramoderne',),
'ultraradikal': ('ultraradikal',),
'ultraradikale': ('ultraradikal',),
'ultraradikalere': ('ultraradikal',),
'ultraradikalest': ('ultraradikal',),
'ultraradikaleste': ('ultraradikal',),
'ultraradikalt': ('ultraradikal',),
'ultrarapid': ('ultrarapid',),
'ultrarapide': ('ultrarapid',),
'ultrarapidere': ('ultrarapid',),
'ultrarapidest': ('ultrarapid',),
'ultrarapideste': ('ultrarapid',),
'ultrarød': ('ultrarød',),
'ultrarøde': ('ultrarød',),
'ultrarødere': ('ultrarød',),
'ultrarødest': ('ultrarød',),
'ultrarødeste': ('ultrarød',),
'ultrarødt': ('ultrarød',),
'ulvaktig': ('ulvaktig',),
'ulvaktige': ('ulvaktig',),
'ulvaktigere': ('ulvaktig',),
'ulvaktigst': ('ulvaktig',),
'ulvaktigste': ('ulvaktig',),
'ulveaktig': ('ulveaktig',),
'ulveaktige': ('ulveaktig',),
'ulveaktigere': ('ulveaktig',),
'ulveaktigst': ('ulveaktig',),
'ulveaktigste': ('ulveaktig',),
'ulvegrå': ('ulvegrå',),
'ulvegråe': ('ulvegrå',),
'ulvegråere': ('ulvegrå',),
'ulvegråest': ('ulvegrå',),
'ulvegråeste': ('ulvegrå',),
'ulvegrått': ('ulvegrå',),
'ulydig': ('ulydig',),
'ulydige': ('ulydig',),
'ulydigere': ('ulydig',),
'ulydigst': ('ulydig',),
'ulydigste': ('ulydig',),
'ulykkebringende': ('ulykkebringende',),
'ulykkelig': ('ulykkelig',),
'ulykkelige': ('ulykkelig',),
'ulykkeligere': ('ulykkelig',),
'ulykkeligst': ('ulykkelig',),
'ulykkeligste': ('ulykkelig',),
'ulykkesforsikra': ('ulykkesforsikre',),
'ulykkesforsikrede': ('ulykkesforsikre',),
'ulykkesforsikrende': ('ulykkesforsikre',),
'ulykkesforsikret': ('ulykkesforsikre',),
'ulykkesforsikrete': ('ulykkesforsikre',),
'ulykkevarslende': ('ulykkevarslende',),
'ulykksalig': ('ulykksalig',),
'ulykksalige': ('ulykksalig',),
'ulykksaligere': ('ulykksalig',),
'ulykksaligst': ('ulykksalig',),
'ulykksaligste': ('ulykksalig',),
'ulystbetona': ('ulystbetona',),
'ulystbetonede': ('ulystbetonet',),
'ulystbetonet': ('ulystbetonet',),
'ulystbetonete': ('ulystbetonet',),
'ulystbetonetere': ('ulystbetonet',),
'ulystbetonetest': ('ulystbetonet',),
'ulystbetoneteste': ('ulystbetonet',),
'ulystbetont': ('ulystbetont',),
'ulystbetonte': ('ulystbetont',),
'ulystbetontere': ('ulystbetont',),
'ulystbetontest': ('ulystbetont',),
'ulystbetonteste': ('ulystbetont',),
'ulåst': ('ulåst',),
'ulåste': ('ulåst',),
'ulåstere': ('ulåst',),
'ulåstest': ('ulåst',),
'ulåsteste': ('ulåst',),
'ulærd': ('ulærd',),
'ulærde': ('ulærd',),
'ulærdere': ('ulærd',),
'ulærdest': ('ulærd',),
'ulærdeste': ('ulærd',),
'ulært': ('ulært',),
'ulærte': ('ulært',),
'ulærtere': ('ulært',),
'ulærtest': ('ulært',),
'ulærteste': ('ulært',),
'ulønna': ('ulønna',),
'ulønnede': ('ulønnet',),
'ulønnet': ('ulønnet',),
'ulønnete': ('ulønnet',),
'ulønnetere': ('ulønnet',),
'ulønnetest': ('ulønnet',),
'ulønneteste': ('ulønnet',),
'ulønt': ('ulønt',),
'ulønte': ('ulønt',),
'uløntere': ('ulønt',),
'uløntest': ('ulønt',),
'ulønteste': ('ulønt',),
'uløselig': ('uløselig',),
'uløselige': ('uløselig',),
'uløseligere': ('uløselig',),
'uløseligst': ('uløselig',),
'uløseligste': ('uløselig',),
'uløst': ('uløst',),
'uløste': ('uløst',),
'uløstere': ('uløst',),
'uløstest': ('uløst',),
'uløsteste': ('uløst',),
'uløyselig': ('uløyselig',),
'uløyselige': ('uløyselig',),
'uløyseligere': ('uløyselig',),
'uløyseligst': ('uløyselig',),
'uløyseligste': ('uløyselig',),
'uløyst': ('uløyst',),
'uløyste': ('uløyst',),
'uløystere': ('uløyst',),
'uløystest': ('uløyst',),
'uløysteste': ('uløyst',),
'umaka': ('umake',),
'umakede': ('umake',),
'umakende': ('umake',),
'umaket': ('umake',),
'umakete': ('umake',),
'umake': ('umake',),
'umalt': ('umalt',),
'umalte': ('umalt',),
'umaltere': ('umalt',),
'umaltest': ('umalt',),
'umalteste': ('umalt',),
'umalt': ('umalt',),
'umalte': ('umalt',),
'umaltere': ('umalt',),
'umaltest': ('umalt',),
'umalteste': ('umalt',),
'umandig': ('umandig',),
'umandige': ('umandig',),
'umandigere': ('umandig',),
'umandigst': ('umandig',),
'umandigste': ('umandig',),
'umanerlig': ('umanerlig',),
'umanerlige': ('umanerlig',),
'umanerligere': ('umanerlig',),
'umanerligst': ('umanerlig',),
'umanerligste': ('umanerlig',),
'umbrisk': ('umbrisk',),
'umbriske': ('umbrisk',),
'umbriskere': ('umbrisk',),
'umbriskest': ('umbrisk',),
'umbriskeste': ('umbrisk',),
'umedgjørlig': ('umedgjørlig',),
'umedgjørlige': ('umedgjørlig',),
'umedgjørligere': ('umedgjørlig',),
'umedgjørligst': ('umedgjørlig',),
'umedgjørligste': ('umedgjørlig',),
'umeldt': ('umeldt',),
'umeldte': ('umeldt',),
'umeldtere': ('umeldt',),
'umeldtest': ('umeldt',),
'umeldteste': ('umeldt',),
'umenneskelig': ('umenneskelig',),
'umenneskelige': ('umenneskelig',),
'umenneskeligere': ('umenneskelig',),
'umenneskeligst': ('umenneskelig',),
'umenneskeligste': ('umenneskelig',),
'umenneskeliggjort': ('umenneskeliggjøre',),
'umenneskeliggjorte': ('umenneskeliggjøre',),
'umenneskeliggjørende': ('umenneskeliggjøre',),
'umerkelig': ('umerkelig',),
'umerkelige': ('umerkelig',),
'umerkeligere': ('umerkelig',),
'umerkeligst': ('umerkelig',),
'umerkeligste': ('umerkelig',),
'umetta': ('umetta',),
'umettelig': ('umettelig',),
'umettelige': ('umettelig',),
'umetteligere': ('umettelig',),
'umetteligst': ('umettelig',),
'umetteligste': ('umettelig',),
'umettede': ('umettet',),
'umettet': ('umettet',),
'umettete': ('umettet',),
'umettetere': ('umettet',),
'umettetest': ('umettet',),
'umetteteste': ('umettet',),
'umiddelbar': ('umiddelbar',),
'umiddelbare': ('umiddelbar',),
'umiddelbarere': ('umiddelbar',),
'umiddelbarest': ('umiddelbar',),
'umiddelbareste': ('umiddelbar',),
'umiddelbart': ('umiddelbar',),
'uminnelig': ('uminnelig',),
'uminnelige': ('uminnelig',),
'uminneligere': ('uminnelig',),
'uminneligst': ('uminnelig',),
'uminneligste': ('uminnelig',),
'uminska': ('uminska',),
'uminskede': ('uminsket',),
'uminsket': ('uminsket',),
'uminskete': ('uminsket',),
'uminsketere': ('uminsket',),
'uminsketest': ('uminsket',),
'uminsketeste': ('uminsket',),
'umiskjennelig': ('umiskjennelig',),
'umiskjennelige': ('umiskjennelig',),
'umiskjenneligere': ('umiskjennelig',),
'umiskjenneligst': ('umiskjennelig',),
'umiskjenneligste': ('umiskjennelig',),
'umistelig': ('umistelig',),
'umistelige': ('umistelig',),
'umisteligere': ('umistelig',),
'umisteligst': ('umistelig',),
'umisteligste': ('umistelig',),
'umoden': ('umoden',),
'umodent': ('umoden',),
'umodne': ('umoden',),
'umodnere': ('umoden',),
'umodnest': ('umoden',),
'umodneste': ('umoden',),
'umoderne': ('umoderne',),
'umoralsk': ('umoralsk',),
'umoralske': ('umoralsk',),
'umoralskere': ('umoralsk',),
'umoralskest': ('umoralsk',),
'umoralskeste': ('umoralsk',),
'umorsom': ('umorsom',),
'umorsomme': ('umorsom',),
'umorsommere': ('umorsom',),
'umorsomst': ('umorsom',),
'umorsomste': ('umorsom',),
'umorsomt': ('umorsom',),
'umotivert': ('umotivert',),
'umotiverte': ('umotivert',),
'umotivertere': ('umotivert',),
'umotivertest': ('umotivert',),
'umotiverteste': ('umotivert',),
'umulig': ('umulig',),
'umulige': ('umulig',),
'umuligere': ('umulig',),
'umuligst': ('umulig',),
'umuligste': ('umulig',),
'umuliggjort': ('umuliggjøre',),
'umuliggjorte': ('umuliggjøre',),
'umuliggjørende': ('umuliggjøre',),
'umusikalsk': ('umusikalsk',),
'umusikalske': ('umusikalsk',),
'umusikalskere': ('umusikalsk',),
'umusikalskest': ('umusikalsk',),
'umusikalskeste': ('umusikalsk',),
'umyndig': ('umyndig',),
'umyndige': ('umyndig',),
'umyndigere': ('umyndig',),
'umyndigst': ('umyndig',),
'umyndigste': ('umyndig',),
'umyndiggjort': ('umyndiggjøre',),
'umyndiggjorte': ('umyndiggjøre',),
'umyndiggjørende': ('umyndiggjøre',),
'umåtelig': ('umåtelig',),
'umåtelige': ('umåtelig',),
'umåteligere': ('umåtelig',),
'umåteligst': ('umåtelig',),
'umåteligste': ('umåtelig',),
'umælende': ('umælende',),
'umøblert': ('umøblert',),
'umøblerte': ('umøblert',),
'umøblertere': ('umøblert',),
'umøblertest': ('umøblert',),
'umøblerteste': ('umøblert',),
'unasjonal': ('unasjonal',),
'unasjonale': ('unasjonal',),
'unasjonalere': ('unasjonal',),
'unasjonalest': ('unasjonal',),
'unasjonaleste': ('unasjonal',),
'unasjonalt': ('unasjonal',),
'unaturlig': ('unaturlig',),
'unaturlige': ('unaturlig',),
'unaturligere': ('unaturlig',),
'unaturligst': ('unaturlig',),
'unaturligste': ('unaturlig',),
'underbar': ('underbar',),
'underbare': ('underbar',),
'underbarere': ('underbar',),
'underbarest': ('underbar',),
'underbareste': ('underbar',),
'underbart': ('underbar',),
'underbegava': ('underbegava',),
'underbegavede': ('underbegavet',),
'underbegavet': ('underbegavet',),
'underbegavete': ('underbegavet',),
'underbegavetere': ('underbegavet',),
'underbegavetest': ('underbegavet',),
'underbegaveteste': ('underbegavet',),
'underbemanna': ('underbemanna',),
'underbemannede': ('underbemannet',),
'underbemannet': ('underbemannet',),
'underbemannete': ('underbemannet',),
'underbemannetere': ('underbemannet',),
'underbemannetest': ('underbemannet',),
'underbemanneteste': ('underbemannet',),
'underbetalende': ('underbetale',),
'underbetalt': ('underbetale',),
'underbetalte': ('underbetale',),
'underbevisst': ('underbevisst',),
'underbevisste': ('underbevisst',),
'underbevisstere': ('underbevisst',),
'underbevisstest': ('underbevisst',),
'underbevissteste': ('underbevisst',),
'underbindende': ('underbinde',),
'underbunden': ('underbinde',),
'underbundet': ('underbinde',),
'underbundne': ('underbinde',),
'underbragt': ('underbringe',),
'underbragte': ('underbringe',),
'underbrakt': ('underbringe',),
'underbrakte': ('underbringe',),
'underbringende': ('underbringe',),
'underbudt': ('underby',),
'underbudte': ('underby',),
'underbydd': ('underby',),
'underbydde': ('underby',),
'underbyende': ('underby',),
'underbygd': ('underbygge',),
'underbygde': ('underbygge',),
'underbygga': ('underbygge',),
'underbyggede': ('underbygge',),
'underbyggende': ('underbygge',),
'underbygget': ('underbygge',),
'underbyggete': ('underbygge',),
'underdanig': ('underdanig',),
'underdanige': ('underdanig',),
'underdanigere': ('underdanig',),
'underdanigst': ('underdanig',),
'underdanigste': ('underdanig',),
'underdimensjonerende': ('underdimensjonere',),
'underdimensjonert': ('underdimensjonere',),
'underdimensjonerte': ('underdimensjonere',),
'underdreven': ('underdrive',),
'underdrevet': ('underdrive',),
'underdrevne': ('underdrive',),
'underdrivende': ('underdrive',),
'undereksponerende': ('undereksponere',),
'undereksponert': ('undereksponere',),
'undereksponerte': ('undereksponere',),
'underernært': ('underernært',),
'underernærte': ('underernært',),
'underernærtere': ('underernært',),
'underernærtest': ('underernært',),
'underernærteste': ('underernært',),
'underforsikra': ('underforsikre',),
'underforsikrede': ('underforsikre',),
'underforsikrende': ('underforsikre',),
'underforsikret': ('underforsikre',),
'underforsikrete': ('underforsikre',),
'underforstående': ('underforstå',),
'underforstått': ('underforstå',),
'underforståtte': ('underforstå',),
'underfull': ('underfull',),
'underfulle': ('underfull',),
'underfullere': ('underfull',),
'underfullest': ('underfull',),
'underfulleste': ('underfull',),
'underfullt': ('underfull',),
'underfundig': ('underfundig',),
'underfundige': ('underfundig',),
'underfundigere': ('underfundig',),
'underfundigst': ('underfundig',),
'underfundigste': ('underfundig',),
'undergiende': ('undergi',),
'undergitt': ('undergi',),
'undergitte': ('undergi',),
'undergivende': ('undergi',),
'undergiven': ('undergiven',),
'undergivent': ('undergiven',),
'undergivne': ('undergiven',),
'undergivnere': ('undergiven',),
'undergivnest': ('undergiven',),
'undergivneste': ('undergiven',),
'undergjæra': ('undergjære',),
'undergjærede': ('undergjære',),
'undergjærende': ('undergjære',),
'undergjæret': ('undergjære',),
'undergjærete': ('undergjære',),
'undergjært': ('undergjære',),
'undergjærte': ('undergjære',),
'undergjørende': ('undergjørende',),
'undergravd': ('undergrave',),
'undergravde': ('undergrave',),
'undergravede': ('undergrave',),
'undergravende': ('undergrave',),
'undergravet': ('undergrave',),
'undergravete': ('undergrave',),
'undergående': ('undergå',),
'undergått': ('undergå',),
'undergåtte': ('undergå',),
'underhandla': ('underhandle',),
'underhandlede': ('underhandle',),
'underhandlende': ('underhandle',),
'underhandlet': ('underhandle',),
'underhandlete': ('underhandle',),
'underholdende': ('underholde',),
'underholdt': ('underholde',),
'underholdte': ('underholde',),
'underholdende': ('underholdende',),
'underjordisk': ('underjordisk',),
'underjordiske': ('underjordisk',),
'underjordiskere': ('underjordisk',),
'underjordiskest': ('underjordisk',),
'underjordiskeste': ('underjordisk',),
'underkasta': ('underkaste',),
'underkastede': ('underkaste',),
'underkastende': ('underkaste',),
'underkastet': ('underkaste',),
'underkastete': ('underkaste',),
'underkjennende': ('underkjenne',),
'underkjent': ('underkjenne',),
'underkjente': ('underkjenne',),
'underkjølende': ('underkjøle',),
'underkjølt': ('underkjøle',),
'underkjølte': ('underkjøle',),
'underkua': ('underkue',),
'underkuede': ('underkue',),
'underkuende': ('underkue',),
'underkuet': ('underkue',),
'underkuete': ('underkue',),
'underkvalifisert': ('underkvalifisert',),
'underkvalifiserte': ('underkvalifisert',),
'underkvalifisertere': ('underkvalifisert',),
'underkvalifisertest': ('underkvalifisert',),
'underkvalifiserteste': ('underkvalifisert',),
'underlegen': ('underlegen',),
'underlegent': ('underlegen',),
'underlegne': ('underlegen',),
'underlegnere': ('underlegen',),
'underlegnest': ('underlegen',),
'underlegneste': ('underlegen',),
'underlagt': ('underlegge',),
'underlagte': ('underlegge',),
'underleggende': ('underlegge',),
'underletta': ('underlette',),
'underlettede': ('underlette',),
'underlettende': ('underlette',),
'underlettet': ('underlette',),
'underlettete': ('underlette',),
'underlig': ('underlig',),
'underlige': ('underlig',),
'underligere': ('underlig',),
'underligst': ('underlig',),
'underligste': ('underlig',),
'underliggende': ('underliggende',),
'undermenneskelig': ('undermenneskelig',),
'undermenneskelige': ('undermenneskelig',),
'undermenneskeligere': ('undermenneskelig',),
'undermenneskeligst': ('undermenneskelig',),
'undermenneskeligste': ('undermenneskelig',),
'underminerende': ('underminere',),
'underminert': ('underminere',),
'underminerte': ('underminere',),
'undermåls': ('undermåls',),
'underordna': ('underordna',),
'underordna': ('underordne',),
'underordnede': ('underordne',),
'underordnende': ('underordne',),
'underordnet': ('underordne',),
'underordnete': ('underordne',),
'underordnede': ('underordnet',),
'underordnet': ('underordnet',),
'underordnete': ('underordnet',),
'underordnetere': ('underordnet',),
'underordnetest': ('underordnet',),
'underordneteste': ('underordnet',),
'underrepresenterende': ('underrepresentere',),
'underrepresentert': ('underrepresentere',),
'underrepresenterte': ('underrepresentere',),
'underretta': ('underrette',),
'underrettede': ('underrette',),
'underrettende': ('underrette',),
'underrettet': ('underrette',),
'underrettete': ('underrette',),
'underselgende': ('underselge',),
'undersolgt': ('underselge',),
'undersolgte': ('underselge',),
'undersetsig': ('undersetsig',),
'undersetsige': ('undersetsig',),
'undersetsigere': ('undersetsig',),
'undersetsigst': ('undersetsig',),
'undersetsigste': ('undersetsig',),
'undersittende': ('undersittende',),
'undersjøisk': ('undersjøisk',),
'undersjøiske': ('undersjøisk',),
'undersjøiskere': ('undersjøisk',),
'undersjøiskest': ('undersjøisk',),
'undersjøiskeste': ('undersjøisk',),
'underskjønn': ('underskjønn',),
'underskjønne': ('underskjønn',),
'underskjønnere': ('underskjønn',),
'underskjønnest': ('underskjønn',),
'underskjønneste': ('underskjønn',),
'underskjønt': ('underskjønn',),
'underskredet': ('underskride',),
'underskredne': ('underskride',),
'underskridende': ('underskride',),
'underskridt': ('underskride',),
'underskreven': ('underskrive',),
'underskrevet': ('underskrive',),
'underskrevne': ('underskrive',),
'underskrivende': ('underskrive',),
'underspillende': ('underspille',),
'underspilt': ('underspille',),
'underspilte': ('underspille',),
'underst': ('underst',),
'underste': ('underst',),
'understellsbehandla': ('understellsbehandle',),
'understellsbehandlede': ('understellsbehandle',),
'understellsbehandlende': ('understellsbehandle',),
'understellsbehandlet': ('understellsbehandle',),
'understellsbehandlete': ('understellsbehandle',),
'understreka': ('understreke',),
'understrekede': ('understreke',),
'understrekende': ('understreke',),
'understreket': ('understreke',),
'understrekete': ('understreke',),
'understrekt': ('understreke',),
'understrekte': ('understreke',),
'understrykende': ('understryke',),
'understrøken': ('understryke',),
'understrøket': ('understryke',),
'understrøkne': ('understryke',),
'understyrt': ('understyrt',),
'understyrte': ('understyrt',),
'understyrtere': ('understyrt',),
'understyrtest': ('understyrt',),
'understyrteste': ('understyrt',),
'understående': ('understå',),
'understått': ('understå',),
'underståtte': ('understå',),
'understøtta': ('understøtte',),
'understøttede': ('understøtte',),
'understøttende': ('understøtte',),
'understøttet': ('understøtte',),
'understøttete': ('understøtte',),
'undersøkende': ('undersøke',),
'undersøkt': ('undersøke',),
'undersøkte': ('undersøke',),
'undertallig': ('undertallig',),
'undertallige': ('undertallig',),
'undertalligere': ('undertallig',),
'undertalligst': ('undertallig',),
'undertalligste': ('undertallig',),
'undertegna': ('undertegne',),
'undertegnede': ('undertegne',),
'undertegnende': ('undertegne',),
'undertegnet': ('undertegne',),
'undertegnete': ('undertegne',),
'undertrykka': ('undertrykke',),
'undertrykkede': ('undertrykke',),
'undertrykkende': ('undertrykke',),
'undertrykket': ('undertrykke',),
'undertrykkete': ('undertrykke',),
'undertrykt': ('undertrykke',),
'undertrykte': ('undertrykke',),
'undertvingende': ('undertvinge',),
'undertvungen': ('undertvinge',),
'undertvunget': ('undertvinge',),
'undertvungne': ('undertvinge',),
'underutvikla': ('underutvikla',),
'underutviklede': ('underutviklet',),
'underutviklet': ('underutviklet',),
'underutviklete': ('underutviklet',),
'underutvikletere': ('underutviklet',),
'underutvikletest': ('underutviklet',),
'underutvikleteste': ('underutviklet',),
'undervektig': ('undervektig',),
'undervektige': ('undervektig',),
'undervektigere': ('undervektig',),
'undervektigst': ('undervektig',),
'undervektigste': ('undervektig',),
'undervisende': ('undervise',),
'undervist': ('undervise',),
'underviste': ('undervise',),
'undervurderende': ('undervurdere',),
'undervurdert': ('undervurdere',),
'undervurderte': ('undervurdere',),
'underårig': ('underårig',),
'underårige': ('underårig',),
'underårigere': ('underårig',),
'underårigst': ('underårig',),
'underårigste': ('underårig',),
'undra': ('undre',),
'undrede': ('undre',),
'undrende': ('undre',),
'undret': ('undre',),
'undrete': ('undre',),
'underst': ('undre',),
'underste': ('undre',),
'undre': ('undre',),
'undren': ('undren',),
'undrene': ('undren',),
'undrenere': ('undren',),
'undrenest': ('undren',),
'undreneste': ('undren',),
'undrent': ('undren',),
'undrne': ('undren',),
'undrnere': ('undren',),
'undrnest': ('undren',),
'undrneste': ('undren',),
'undrende': ('undrende',),
'unektelig': ('unektelig',),
'unektelige': ('unektelig',),
'unekteligere': ('unektelig',),
'unekteligst': ('unektelig',),
'unekteligste': ('unektelig',),
'unett': ('unett',),
'unette': ('unett',),
'unettere': ('unett',),
'unettest': ('unett',),
'unetteste': ('unett',),
'unevnelig': ('unevnelig',),
'unevnelige': ('unevnelig',),
'unevneligere': ('unevnelig',),
'unevneligst': ('unevnelig',),
'unevneligste': ('unevnelig',),
'unevnt': ('unevnt',),
'unevnte': ('unevnt',),
'unevntere': ('unevnt',),
'unevntest': ('unevnt',),
'unevnteste': ('unevnt',),
'unfair': ('unfair',),
'ung': ('ung',),
'unge': ('ung',),
'ungt': ('ung',),
'yngre': ('ung',),
'yngst': ('ung',),
'yngste': ('ung',),
'ungarsk': ('ungarsk',),
'ungarske': ('ungarsk',),
'ungarskere': ('ungarsk',),
'ungarskest': ('ungarsk',),
'ungarskeste': ('ungarsk',),
'ungdommelig': ('ungdommelig',),
'ungdommelige': ('ungdommelig',),
'ungdommeligere': ('ungdommelig',),
'ungdommeligst': ('ungdommelig',),
'ungdommeligste': ('ungdommelig',),
'uniform': ('uniform',),
'uniforme': ('uniform',),
'uniformere': ('uniform',),
'uniformest': ('uniform',),
'uniformeste': ('uniform',),
'uniformt': ('uniform',),
'uniformerende': ('uniformere',),
'uniformert': ('uniformere',),
'uniformerte': ('uniformere',),
'uniformistisk': ('uniformistisk',),
'uniformistiske': ('uniformistisk',),
'uniformistiskere': ('uniformistisk',),
'uniformistiskest': ('uniformistisk',),
'uniformistiskeste': ('uniformistisk',),
'unik': ('unik',),
'unike': ('unik',),
'unikere': ('unik',),
'unikest': ('unik',),
'unikeste': ('unik',),
'unikt': ('unik',),
'unilateral': ('unilateral',),
'unilaterale': ('unilateral',),
'unilateralere': ('unilateral',),
'unilateralest': ('unilateral',),
'unilateraleste': ('unilateral',),
'unilateralt': ('unilateral',),
'unional': ('unional',),
'unionale': ('unional',),
'unionalere': ('unional',),
'unionalest': ('unional',),
'unionaleste': ('unional',),
'unionalt': ('unional',),
'unionell': ('unionell',),
'unionelle': ('unionell',),
'unionellere': ('unionell',),
'unionellest': ('unionell',),
'unionelleste': ('unionell',),
'unionelt': ('unionell',),
'unionistisk': ('unionistisk',),
'unionistiske': ('unionistisk',),
'unionistiskere': ('unionistisk',),
'unionistiskest': ('unionistisk',),
'unionistiskeste': ('unionistisk',),
'unison': ('unison',),
'unisone': ('unison',),
'unisonere': ('unison',),
'unisonest': ('unison',),
'unisoneste': ('unison',),
'unisont': ('unison',),
'unitarisk': ('unitarisk',),
'unitariske': ('unitarisk',),
'unitariskere': ('unitarisk',),
'unitariskest': ('unitarisk',),
'unitariskeste': ('unitarisk',),
'universal': ('universal',),
'universale': ('universal',),
'universalere': ('universal',),
'universalest': ('universal',),
'universaleste': ('universal',),
'universalt': ('universal',),
'universaliserende': ('universalisere',),
'universalisert': ('universalisere',),
'universaliserte': ('universalisere',),
'universalistisk': ('universalistisk',),
'universalistiske': ('universalistisk',),
'universalistiskere': ('universalistisk',),
'universalistiskest': ('universalistisk',),
'universalistiskeste': ('universalistisk',),
'universell': ('universell',),
'universelle': ('universell',),
'universellere': ('universell',),
'universellest': ('universell',),
'universelleste': ('universell',),
'universelt': ('universell',),
'unnagjort': ('unnagjort',),
'unnagjorte': ('unnagjort',),
'unnagjortere': ('unnagjort',),
'unnagjortest': ('unnagjort',),
'unnagjorteste': ('unnagjort',),
'unnbedt': ('unnbe',),
'unnbedte': ('unnbe',),
'unnbeende': ('unnbe',),
'unndradd': ('unndra',),
'unndradde': ('unndra',),
'unndragende': ('unndra',),
'unndratt': ('unndra',),
'unndratte': ('unndra',),
'unnede': ('unne',),
'unnende': ('unne',),
'unnet': ('unne',),
'unnete': ('unne',),
'unt': ('unne',),
'unte': ('unne',),
'unnfallen': ('unnfallen',),
'unnfallent': ('unnfallen',),
'unnfalne': ('unnfallen',),
'unnfalnere': ('unnfallen',),
'unnfalnest': ('unnfallen',),
'unnfalneste': ('unnfallen',),
'unnfallende': ('unnfallende',),
'unnfanga': ('unnfange',),
'unnfangede': ('unnfange',),
'unnfangende': ('unnfange',),
'unnfanget': ('unnfange',),
'unnfangete': ('unnfange',),
'unnflydd': ('unnfly',),
'unnflydde': ('unnfly',),
'unnflyende': ('unnfly',),
'unnfløyen': ('unnfly',),
'unnfløyet': ('unnfly',),
'unnfløyne': ('unnfly',),
'unngjeldende': ('unngjelde',),
'unngjeldt': ('unngjelde',),
'unngjeldte': ('unngjelde',),
'unngående': ('unngå',),
'unngått': ('unngå',),
'unngåtte': ('unngå',),
'unngåelig': ('unngåelig',),
'unngåelige': ('unngåelig',),
'unngåeligere': ('unngåelig',),
'unngåeligst': ('unngåelig',),
'unngåeligste': ('unngåelig',),
'unnkommen': ('unnkomme',),
'unnkommende': ('unnkomme',),
'unnkommet': ('unnkomme',),
'unnkomne': ('unnkomme',),
'unnlatende': ('unnlate',),
'unnlatt': ('unnlate',),
'unnlatte': ('unnlate',),
'unnseende': ('unnse',),
'unnsett': ('unnse',),
'unnsette': ('unnse',),
'unnselig': ('unnselig',),
'unnselige': ('unnselig',),
'unnseligere': ('unnselig',),
'unnseligst': ('unnselig',),
'unnseligste': ('unnselig',),
'unnsatt': ('unnsette',),
'unnsatte': ('unnsette',),
'unnsettende': ('unnsette',),
'unnsagt': ('unnsi',),
'unnsagte': ('unnsi',),
'unnsiende': ('unnsi',),
'unnskyldende': ('unnskylde',),
'unnskyldt': ('unnskylde',),
'unnskyldte': ('unnskylde',),
'unnskyldelig': ('unnskyldelig',),
'unnskyldelige': ('unnskyldelig',),
'unnskyldeligere': ('unnskyldelig',),
'unnskyldeligst': ('unnskyldelig',),
'unnskyldeligste': ('unnskyldelig',),
'unnslående': ('unnslå',),
'unnslått': ('unnslå',),
'unnslåtte': ('unnslå',),
'unntakende': ('unnta',),
'unntatt': ('unnta',),
'unntatte': ('unnta',),
'unntakelseslaus': ('unntakelseslaus',),
'unntakelseslause': ('unntakelseslaus',),
'unntakelseslausere': ('unntakelseslaus',),
'unntakelseslausest': ('unntakelseslaus',),
'unntakelseslauseste': ('unntakelseslaus',),
'unntakelseslaust': ('unntakelseslaus',),
'unntakelsesløs': ('unntakelsesløs',),
'unntakelsesløse': ('unntakelsesløs',),
'unntakelsesløsere': ('unntakelsesløs',),
'unntakelsesløsest': ('unntakelsesløs',),
'unntakelsesløseste': ('unntakelsesløs',),
'unntakelsesløst': ('unntakelsesløs',),
'unntakslaus': ('unntakslaus',),
'unntakslause': ('unntakslaus',),
'unntakslausere': ('unntakslaus',),
'unntakslausest': ('unntakslaus',),
'unntakslauseste': ('unntakslaus',),
'unntakslaust': ('unntakslaus',),
'unntaksløs': ('unntaksløs',),
'unntaksløse': ('unntaksløs',),
'unntaksløsere': ('unntaksløs',),
'unntaksløsest': ('unntaksløs',),
'unntaksløseste': ('unntaksløs',),
'unntaksløst': ('unntaksløs',),
'unnveken': ('unnvike',),
'unnveket': ('unnvike',),
'unnvekne': ('unnvike',),
'unnvikende': ('unnvike',),
'unnvikende': ('unnvikende',),
'unnværende': ('unnvære',),
'unnvært': ('unnvære',),
'unnværte': ('unnvære',),
'unnværlig': ('unnværlig',),
'unnværlige': ('unnværlig',),
'unnværligere': ('unnværlig',),
'unnværligst': ('unnværlig',),
'unnværligste': ('unnværlig',),
'unormal': ('unormal',),
'unormale': ('unormal',),
'unormalere': ('unormal',),
'unormalest': ('unormal',),
'unormaleste': ('unormal',),
'unormalt': ('unormal',),
'unorsk': ('unorsk',),
'unorske': ('unorsk',),
'unorskere': ('unorsk',),
'unorskest': ('unorsk',),
'unorskeste': ('unorsk',),
'unyansert': ('unyansert',),
'unyanserte': ('unyansert',),
'unyansertere': ('unyansert',),
'unyansertest': ('unyansert',),
'unyanserteste': ('unyansert',),
'unyttig': ('unyttig',),
'unyttige': ('unyttig',),
'unyttigere': ('unyttig',),
'unyttigst': ('unyttig',),
'unyttigste': ('unyttig',),
'unådig': ('unådig',),
'unådige': ('unådig',),
'unådigere': ('unådig',),
'unådigst': ('unådig',),
'unådigste': ('unådig',),
'unødig': ('unødig',),
'unødige': ('unødig',),
'unødigere': ('unødig',),
'unødigst': ('unødig',),
'unødigste': ('unødig',),
'unødvendig': ('unødvendig',),
'unødvendige': ('unødvendig',),
'unødvendigere': ('unødvendig',),
'unødvendigst': ('unødvendig',),
'unødvendigste': ('unødvendig',),
'unøyaktig': ('unøyaktig',),
'unøyaktige': ('unøyaktig',),
'unøyaktigere': ('unøyaktig',),
'unøyaktigst': ('unøyaktig',),
'unøyaktigste': ('unøyaktig',),
'uoffisiell': ('uoffisiell',),
'uoffisielle': ('uoffisiell',),
'uoffisiellere': ('uoffisiell',),
'uoffisiellest': ('uoffisiell',),
'uoffisielleste': ('uoffisiell',),
'uoffisielt': ('uoffisiell',),
'uomgjengelig': ('uomgjengelig',),
'uomgjengelige': ('uomgjengelig',),
'uomgjengeligere': ('uomgjengelig',),
'uomgjengeligst': ('uomgjengelig',),
'uomgjengeligste': ('uomgjengelig',),
'uomlydt': ('uomlydt',),
'uomlydte': ('uomlydt',),
'uomlydtere': ('uomlydt',),
'uomlydtest': ('uomlydt',),
'uomlydteste': ('uomlydt',),
'uomsettelig': ('uomsettelig',),
'uomsettelige': ('uomsettelig',),
'uomsetteligere': ('uomsettelig',),
'uomsetteligst': ('uomsettelig',),
'uomsetteligste': ('uomsettelig',),
'uomstøtelig': ('uomstøtelig',),
'uomstøtelige': ('uomstøtelig',),
'uomstøteligere': ('uomstøtelig',),
'uomstøteligst': ('uomstøtelig',),
'uomstøteligste': ('uomstøtelig',),
'uomtala': ('uomtala',),
'uomtalt': ('uomtalt',),
'uomtalte': ('uomtalt',),
'uomtaltere': ('uomtalt',),
'uomtaltest': ('uomtalt',),
'uomtalteste': ('uomtalt',),
'uomtvista': ('uomtvista',),
'uomtvistelig': ('uomtvistelig',),
'uomtvistelige': ('uomtvistelig',),
'uomtvisteligere': ('uomtvistelig',),
'uomtvisteligst': ('uomtvistelig',),
'uomtvisteligste': ('uomtvistelig',),
'uomtvistede': ('uomtvistet',),
'uomtvistet': ('uomtvistet',),
'uomtvistete': ('uomtvistet',),
'uomtvistetere': ('uomtvistet',),
'uomtvistetest': ('uomtvistet',),
'uomtvisteteste': ('uomtvistet',),
'uoppdaga': ('uoppdaga',),
'uoppdagede': ('uoppdaget',),
'uoppdaget': ('uoppdaget',),
'uoppdagete': ('uoppdaget',),
'uoppdagetere': ('uoppdaget',),
'uoppdagetest': ('uoppdaget',),
'uoppdageteste': ('uoppdaget',),
'uoppdragen': ('uoppdragen',),
'uoppdragent': ('uoppdragen',),
'uoppdragne': ('uoppdragen',),
'uoppdragnere': ('uoppdragen',),
'uoppdragnest': ('uoppdragen',),
'uoppdragneste': ('uoppdragen',),
'uoppdrivelig': ('uoppdrivelig',),
'uoppdrivelige': ('uoppdrivelig',),
'uoppdriveligere': ('uoppdrivelig',),
'uoppdriveligst': ('uoppdrivelig',),
'uoppdriveligste': ('uoppdrivelig',),
'uoppfordra': ('uoppfordra',),
'uoppfordrede': ('uoppfordret',),
'uoppfordret': ('uoppfordret',),
'uoppfordrete': ('uoppfordret',),
'uoppfordretere': ('uoppfordret',),
'uoppfordretest': ('uoppfordret',),
'uoppfordreteste': ('uoppfordret',),
'uoppfyllelig': ('uoppfyllelig',),
'uoppfyllelige': ('uoppfyllelig',),
'uoppfylleligere': ('uoppfyllelig',),
'uoppfylleligst': ('uoppfyllelig',),
'uoppfylleligste': ('uoppfyllelig',),
'uoppfylt': ('uoppfylt',),
'uoppfylte': ('uoppfylt',),
'uoppfyltere': ('uoppfylt',),
'uoppfyltest': ('uoppfylt',),
'uoppfylteste': ('uoppfylt',),
'uoppførlig': ('uoppførlig',),
'uoppførlige': ('uoppførlig',),
'uoppførligere': ('uoppførlig',),
'uoppførligst': ('uoppførlig',),
'uoppførligste': ('uoppførlig',),
'uoppført': ('uoppført',),
'uoppførte': ('uoppført',),
'uoppførtere': ('uoppført',),
'uoppførtest': ('uoppført',),
'uoppførteste': ('uoppført',),
'uoppgjort': ('uoppgjort',),
'uoppgjorte': ('uoppgjort',),
'uoppgjortere': ('uoppgjort',),
'uoppgjortest': ('uoppgjort',),
'uoppgjorteste': ('uoppgjort',),
'uoppholdelig': ('uoppholdelig',),
'uoppholdelige': ('uoppholdelig',),
'uoppholdeligere': ('uoppholdelig',),
'uoppholdeligst': ('uoppholdelig',),
'uoppholdeligste': ('uoppholdelig',),
'uopphørlig': ('uopphørlig',),
'uopphørlige': ('uopphørlig',),
'uopphørligere': ('uopphørlig',),
'uopphørligst': ('uopphørlig',),
'uopphørligste': ('uopphørlig',),
'uoppklarlig': ('uoppklarlig',),
'uoppklarlige': ('uoppklarlig',),
'uoppklarligere': ('uoppklarlig',),
'uoppklarligst': ('uoppklarlig',),
'uoppklarligste': ('uoppklarlig',),
'uoppklart': ('uoppklart',),
'uoppklarte': ('uoppklart',),
'uoppklartere': ('uoppklart',),
'uoppklartest': ('uoppklart',),
'uoppklarteste': ('uoppklart',),
'uopplagt': ('uopplagt',),
'uopplagte': ('uopplagt',),
'uopplagtere': ('uopplagt',),
'uopplagtest': ('uopplagt',),
'uopplagteste': ('uopplagt',),
'uopplyst': ('uopplyst',),
'uopplyste': ('uopplyst',),
'uopplystere': ('uopplyst',),
'uopplystest': ('uopplyst',),
'uopplysteste': ('uopplyst',),
'uoppløselig': ('uoppløselig',),
'uoppløselige': ('uoppløselig',),
'uoppløseligere': ('uoppløselig',),
'uoppløseligst': ('uoppløselig',),
'uoppløseligste': ('uoppløselig',),
'uoppløyselig': ('uoppløyselig',),
'uoppløyselige': ('uoppløyselig',),
'uoppløyseligere': ('uoppløyselig',),
'uoppløyseligst': ('uoppløyselig',),
'uoppløyseligste': ('uoppløyselig',),
'uoppmerksom': ('uoppmerksom',),
'uoppmerksomme': ('uoppmerksom',),
'uoppmerksommere': ('uoppmerksom',),
'uoppmerksomst': ('uoppmerksom',),
'uoppmerksomste': ('uoppmerksom',),
'uoppmerksomt': ('uoppmerksom',),
'uoppnåelig': ('uoppnåelig',),
'uoppnåelige': ('uoppnåelig',),
'uoppnåeligere': ('uoppnåelig',),
'uoppnåeligst': ('uoppnåelig',),
'uoppnåeligste': ('uoppnåelig',),
'uoppredd': ('uoppredd',),
'uoppredde': ('uoppredd',),
'uoppreddere': ('uoppredd',),
'uoppreddest': ('uoppredd',),
'uoppreddeste': ('uoppredd',),
'uoppreid': ('uoppreid',),
'uoppreide': ('uoppreid',),
'uoppreidere': ('uoppreid',),
'uoppreidest': ('uoppreid',),
'uoppreideste': ('uoppreid',),
'uopprettelig': ('uopprettelig',),
'uopprettelige': ('uopprettelig',),
'uoppretteligere': ('uopprettelig',),
'uoppretteligst': ('uopprettelig',),
'uoppretteligste': ('uopprettelig',),
'uoppsettelig': ('uoppsettelig',),
'uoppsettelige': ('uoppsettelig',),
'uoppsetteligere': ('uoppsettelig',),
'uoppsetteligst': ('uoppsettelig',),
'uoppsetteligste': ('uoppsettelig',),
'uoppsigelig': ('uoppsigelig',),
'uoppsigelige': ('uoppsigelig',),
'uoppsigeligere': ('uoppsigelig',),
'uoppsigeligst': ('uoppsigelig',),
'uoppsigeligste': ('uoppsigelig',),
'uoppskåren': ('uoppskåren',),
'uoppskåret': ('uoppskåren',),
'uoppskårne': ('uoppskåren',),
'uoppskårnere': ('uoppskåren',),
'uoppskårnest': ('uoppskåren',),
'uoppskårneste': ('uoppskåren',),
'uoppskåret': ('uoppskåret',),
'uoppskårne': ('uoppskåret',),
'uoppskårnere': ('uoppskåret',),
'uoppskårnest': ('uoppskåret',),
'uoppskårneste': ('uoppskåret',),
'uoppslitelig': ('uoppslitelig',),
'uoppslitelige': ('uoppslitelig',),
'uoppsliteligere': ('uoppslitelig',),
'uoppsliteligst': ('uoppslitelig',),
'uoppsliteligste': ('uoppslitelig',),
'uordentlig': ('uordentlig',),
'uordentlige': ('uordentlig',),
'uordentligere': ('uordentlig',),
'uordentligst': ('uordentlig',),
'uordentligste': ('uordentlig',),
'uordna': ('uordna',),
'uordnede': ('uordnet',),
'uordnet': ('uordnet',),
'uordnete': ('uordnet',),
'uordnetere': ('uordnet',),
'uordnetest': ('uordnet',),
'uordneteste': ('uordnet',),
'uorganisert': ('uorganisert',),
'uorganiserte': ('uorganisert',),
'uorganisertere': ('uorganisert',),
'uorganisertest': ('uorganisert',),
'uorganiserteste': ('uorganisert',),
'uorganisk': ('uorganisk',),
'uorganiske': ('uorganisk',),
'uorganiskere': ('uorganisk',),
'uorganiskest': ('uorganisk',),
'uorganiskeste': ('uorganisk',),
'uortodoks': ('uortodoks',),
'uortodokse': ('uortodoks',),
'uortodoksere': ('uortodoks',),
'uortodoksest': ('uortodoks',),
'uortodokseste': ('uortodoks',),
'uortodokst': ('uortodoks',),
'uoverensstemmende': ('uoverensstemmende',),
'uoverkommelig': ('uoverkommelig',),
'uoverkommelige': ('uoverkommelig',),
'uoverkommeligere': ('uoverkommelig',),
'uoverkommeligst': ('uoverkommelig',),
'uoverkommeligste': ('uoverkommelig',),
'uoverlagt': ('uoverlagt',),
'uoverlagte': ('uoverlagt',),
'uoverlagtere': ('uoverlagt',),
'uoverlagtest': ('uoverlagt',),
'uoverlagteste': ('uoverlagt',),
'uoversettelig': ('uoversettelig',),
'uoversettelige': ('uoversettelig',),
'uoversetteligere': ('uoversettelig',),
'uoversetteligst': ('uoversettelig',),
'uoversetteligste': ('uoversettelig',),
'uoversiktlig': ('uoversiktlig',),
'uoversiktlige': ('uoversiktlig',),
'uoversiktligere': ('uoversiktlig',),
'uoversiktligst': ('uoversiktlig',),
'uoversiktligste': ('uoversiktlig',),
'uoverskuelig': ('uoverskuelig',),
'uoverskuelige': ('uoverskuelig',),
'uoverskueligere': ('uoverskuelig',),
'uoverskueligst': ('uoverskuelig',),
'uoverskueligste': ('uoverskuelig',),
'uoverstigelig': ('uoverstigelig',),
'uoverstigelige': ('uoverstigelig',),
'uoverstigeligere': ('uoverstigelig',),
'uoverstigeligst': ('uoverstigelig',),
'uoverstigeligste': ('uoverstigelig',),
'uovertreffelig': ('uovertreffelig',),
'uovertreffelige': ('uovertreffelig',),
'uovertreffeligere': ('uovertreffelig',),
'uovertreffeligst': ('uovertreffelig',),
'uovertreffeligste': ('uovertreffelig',),
'uovertruffen': ('uovertruffen',),
'uovertruffent': ('uovertruffen',),
'uovertrufne': ('uovertruffen',),
'uovertrufnere': ('uovertruffen',),
'uovertrufnest': ('uovertruffen',),
'uovertrufneste': ('uovertruffen',),
'uoverveid': ('uoverveid',),
'uoverveide': ('uoverveid',),
'uoverveidere': ('uoverveid',),
'uoverveidest': ('uoverveid',),
'uoverveideste': ('uoverveid',),
'uovervinnelig': ('uovervinnelig',),
'uovervinnelige': ('uovervinnelig',),
'uovervinneligere': ('uovervinnelig',),
'uovervinneligst': ('uovervinnelig',),
'uovervinneligste': ('uovervinnelig',),
'up to date': ('up to date',),
'upar': ('upar',),
'upara': ('upara',),
'uparede': ('uparet',),
'uparet': ('uparet',),
'uparete': ('uparet',),
'uparetere': ('uparet',),
'uparetest': ('uparet',),
'upareteste': ('uparet',),
'uparlamentarisk': ('uparlamentarisk',),
'uparlamentariske': ('uparlamentarisk',),
'uparlamentariskere': ('uparlamentarisk',),
'uparlamentariskest': ('uparlamentarisk',),
'uparlamentariskeste': ('uparlamentarisk',),
'upartisk': ('upartisk',),
'upartiske': ('upartisk',),
'upartiskere': ('upartisk',),
'upartiskest': ('upartisk',),
'upartiskeste': ('upartisk',),
'upartåa': ('upartåa',),
'upartåede': ('upartået',),
'upartået': ('upartået',),
'upartåete': ('upartået',),
'upartåetere': ('upartået',),
'upartåetest': ('upartået',),
'upartåeteste': ('upartået',),
'upasselig': ('upasselig',),
'upasselige': ('upasselig',),
'upasseligere': ('upasselig',),
'upasseligst': ('upasselig',),
'upasseligste': ('upasselig',),
'upassende': ('upassende',),
'upedagogisk': ('upedagogisk',),
'upedagogiske': ('upedagogisk',),
'upedagogiskere': ('upedagogisk',),
'upedagogiskest': ('upedagogisk',),
'upedagogiskeste': ('upedagogisk',),
'upersonlig': ('upersonlig',),
'upersonlige': ('upersonlig',),
'upersonligere': ('upersonlig',),
'upersonligst': ('upersonlig',),
'upersonligste': ('upersonlig',),
'uplassert': ('uplassert',),
'uplasserte': ('uplassert',),
'uplassertere': ('uplassert',),
'uplassertest': ('uplassert',),
'uplasserteste': ('uplassert',),
'upleia': ('upleia',),
'upleid': ('upleid',),
'upleide': ('upleid',),
'upleidere': ('upleid',),
'upleidest': ('upleid',),
'upleideste': ('upleid',),
'upleiede': ('upleiet',),
'upleiet': ('upleiet',),
'upleiete': ('upleiet',),
'upleietere': ('upleiet',),
'upleietest': ('upleiet',),
'upleieteste': ('upleiet',),
'upletta': ('upletta',),
'uplettede': ('uplettet',),
'uplettet': ('uplettet',),
'uplettete': ('uplettet',),
'uplettetere': ('uplettet',),
'uplettetest': ('uplettet',),
'upletteteste': ('uplettet',),
'upløgd': ('upløgd',),
'upløgde': ('upløgd',),
'upløgdere': ('upløgd',),
'upløgdest': ('upløgd',),
'upløgdeste': ('upløgd',),
'upløyd': ('upløyd',),
'upløyde': ('upløyd',),
'upløydere': ('upløyd',),
'upløydest': ('upløyd',),
'upløydeste': ('upløyd',),
'upoetisk': ('upoetisk',),
'upoetiske': ('upoetisk',),
'upoetiskere': ('upoetisk',),
'upoetiskest': ('upoetisk',),
'upoetiskeste': ('upoetisk',),
'upolert': ('upolert',),
'upolerte': ('upolert',),
'upolertere': ('upolert',),
'upolertest': ('upolert',),
'upolerteste': ('upolert',),
'upolitisk': ('upolitisk',),
'upolitiske': ('upolitisk',),
'upolitiskere': ('upolitisk',),
'upolitiskest': ('upolitisk',),
'upolitiskeste': ('upolitisk',),
'upop': ('upop',),
'upope': ('upop',),
'upopere': ('upop',),
'upopest': ('upop',),
'upopeste': ('upop',),
'upopt': ('upop',),
'upopp': ('upopp',),
'upoppe': ('upopp',),
'upoppere': ('upopp',),
'upoppest': ('upopp',),
'upoppeste': ('upopp',),
'upopt': ('upopp',),
'upopulær': ('upopulær',),
'upopulære': ('upopulær',),
'upopulærere': ('upopulær',),
'upopulærest': ('upopulær',),
'upopulæreste': ('upopulær',),
'upopulært': ('upopulær',),
'upraktisk': ('upraktisk',),
'upraktiske': ('upraktisk',),
'upraktiskere': ('upraktisk',),
'upraktiskest': ('upraktisk',),
'upraktiskeste': ('upraktisk',),
'upresis': ('upresis',),
'upresise': ('upresis',),
'upresisere': ('upresis',),
'upresisest': ('upresis',),
'upresiseste': ('upresis',),
'upresist': ('upresis',),
'upressa': ('upressa',),
'upressede': ('upresset',),
'upresset': ('upresset',),
'upressete': ('upresset',),
'upressetere': ('upresset',),
'upressetest': ('upresset',),
'upresseteste': ('upresset',),
'upretensiøs': ('upretensiøs',),
'upretensiøse': ('upretensiøs',),
'upretensiøsere': ('upretensiøs',),
'upretensiøsest': ('upretensiøs',),
'upretensiøseste': ('upretensiøs',),
'upretensiøst': ('upretensiøs',),
'uprioritert': ('uprioritert',),
'uprioriterte': ('uprioritert',),
'uprioritertere': ('uprioritert',),
'uprioritertest': ('uprioritert',),
'uprioriterteste': ('uprioritert',),
'uprivilegert': ('uprivilegert',),
'uprivilegerte': ('uprivilegert',),
'uprivilegertere': ('uprivilegert',),
'uprivilegertest': ('uprivilegert',),
'uprivilegerteste': ('uprivilegert',),
'uproduktiv': ('uproduktiv',),
'uproduktive': ('uproduktiv',),
'uproduktivere': ('uproduktiv',),
'uproduktivest': ('uproduktiv',),
'uproduktiveste': ('uproduktiv',),
'uproduktivt': ('uproduktiv',),
'uprogrammert': ('uprogrammert',),
'uprogrammerte': ('uprogrammert',),
'uprogrammertere': ('uprogrammert',),
'uprogrammertest': ('uprogrammert',),
'uprogrammerteste': ('uprogrammert',),
'uprovosert': ('uprovosert',),
'uprovoserte': ('uprovosert',),
'uprovosertere': ('uprovosert',),
'uprovosertest': ('uprovosert',),
'uprovoserteste': ('uprovosert',),
'uprøvd': ('uprøvd',),
'uprøvde': ('uprøvd',),
'uprøvdere': ('uprøvd',),
'uprøvdest': ('uprøvd',),
'uprøvdeste': ('uprøvd',),
'upsykologisk': ('upsykologisk',),
'upsykologiske': ('upsykologisk',),
'upsykologiskere': ('upsykologisk',),
'upsykologiskest': ('upsykologisk',),
'upsykologiskeste': ('upsykologisk',),
'upåakta': ('upåakta',),
'upåaktede': ('upåaktet',),
'upåaktet': ('upåaktet',),
'upåaktete': ('upåaktet',),
'upåaktetere': ('upåaktet',),
'upåaktetest': ('upåaktet',),
'upåakteteste': ('upåaktet',),
'upåklagelig': ('upåklagelig',),
'upåklagelige': ('upåklagelig',),
'upåklageligere': ('upåklagelig',),
'upåklageligst': ('upåklagelig',),
'upåklageligste': ('upåklagelig',),
'upåkrevd': ('upåkrevd',),
'upåkrevde': ('upåkrevd',),
'upåkrevdere': ('upåkrevd',),
'upåkrevdest': ('upåkrevd',),
'upåkrevdeste': ('upåkrevd',),
'upålitelig': ('upålitelig',),
'upålitelige': ('upålitelig',),
'upåliteligere': ('upålitelig',),
'upåliteligst': ('upålitelig',),
'upåliteligste': ('upålitelig',),
'upåtalt': ('upåtalt',),
'upåtalte': ('upåtalt',),
'upåtaltere': ('upåtalt',),
'upåtaltest': ('upåtalt',),
'upåtalteste': ('upåtalt',),
'upåvirka': ('upåvirka',),
'upåvirkelig': ('upåvirkelig',),
'upåvirkelige': ('upåvirkelig',),
'upåvirkeligere': ('upåvirkelig',),
'upåvirkeligst': ('upåvirkelig',),
'upåvirkeligste': ('upåvirkelig',),
'upåvirkede': ('upåvirket',),
'upåvirket': ('upåvirket',),
'upåvirkete': ('upåvirket',),
'upåvirketere': ('upåvirket',),
'upåvirketest': ('upåvirket',),
'upåvirketeste': ('upåvirket',),
'ural-altaisk': ('ural-altaisk',),
'ural-altaiske': ('ural-altaisk',),
'ural-altaiskere': ('ural-altaisk',),
'ural-altaiskest': ('ural-altaisk',),
'ural-altaiskeste': ('ural-altaisk',),
'uralsk': ('uralsk',),
'uralske': ('uralsk',),
'uralskere': ('uralsk',),
'uralskest': ('uralsk',),
'uralskeste': ('uralsk',),
'uransakelig': ('uransakelig',),
'uransakelige': ('uransakelig',),
'uransakeligere': ('uransakelig',),
'uransakeligst': ('uransakelig',),
'uransakeligste': ('uransakelig',),
'urasjonell': ('urasjonell',),
'urasjonelle': ('urasjonell',),
'urasjonellere': ('urasjonell',),
'urasjonellest': ('urasjonell',),
'urasjonelleste': ('urasjonell',),
'urasjonelt': ('urasjonell',),
'urban': ('urban',),
'urbane': ('urban',),
'urbanere': ('urban',),
'urbanest': ('urban',),
'urbaneste': ('urban',),
'urbant': ('urban',),
'urbaniserende': ('urbanisere',),
'urbanisert': ('urbanisere',),
'urbaniserte': ('urbanisere',),
'ura': ('ure',),
'urede': ('ure',),
'urende': ('ure',),
'uret': ('ure',),
'urete': ('ure',),
'urt': ('ure',),
'urte': ('ure',),
'urealistisk': ('urealistisk',),
'urealistiske': ('urealistisk',),
'urealistiskere': ('urealistisk',),
'urealistiskest': ('urealistisk',),
'urealistiskeste': ('urealistisk',),
'uredd': ('uredd',),
'uredde': ('uredd',),
'ureddere': ('uredd',),
'ureddest': ('uredd',),
'ureddeste': ('uredd',),
'uredelig': ('uredelig',),
'uredelige': ('uredelig',),
'uredeligere': ('uredelig',),
'uredeligst': ('uredelig',),
'uredeligste': ('uredelig',),
'uredig': ('uredig',),
'uredige': ('uredig',),
'uredigere': ('uredig',),
'uredigst': ('uredig',),
'uredigste': ('uredig',),
'ureflektert': ('ureflektert',),
'ureflekterte': ('ureflektert',),
'ureflektertere': ('ureflektert',),
'ureflektertest': ('ureflektert',),
'ureflekterteste': ('ureflektert',),
'uregelmessig': ('uregelmessig',),
'uregelmessige': ('uregelmessig',),
'uregelmessigere': ('uregelmessig',),
'uregelmessigst': ('uregelmessig',),
'uregelmessigste': ('uregelmessig',),
'uregelrett': ('uregelrett',),
'uregelrette': ('uregelrett',),
'uregelrettere': ('uregelrett',),
'uregelrettest': ('uregelrett',),
'uregelretteste': ('uregelrett',),
'uregjerlig': ('uregjerlig',),
'uregjerlige': ('uregjerlig',),
'uregjerligere': ('uregjerlig',),
'uregjerligst': ('uregjerlig',),
'uregjerligste': ('uregjerlig',),
'ureglementert': ('ureglementert',),
'ureglementerte': ('ureglementert',),
'ureglementertere': ('ureglementert',),
'ureglementertest': ('ureglementert',),
'ureglementerteste': ('ureglementert',),
'uregulert': ('uregulert',),
'uregulerte': ('uregulert',),
'uregulertere': ('uregulert',),
'uregulertest': ('uregulert',),
'uregulerteste': ('uregulert',),
'urein': ('urein',),
'ureine': ('urein',),
'ureinere': ('urein',),
'ureinest': ('urein',),
'ureineste': ('urein',),
'ureint': ('urein',),
'ureinslig': ('ureinslig',),
'ureinslige': ('ureinslig',),
'ureinsligere': ('ureinslig',),
'ureinsligst': ('ureinslig',),
'ureinsligste': ('ureinslig',),
'uren': ('uren',),
'urene': ('uren',),
'urenere': ('uren',),
'urenest': ('uren',),
'ureneste': ('uren',),
'urent': ('uren',),
'urensa': ('urensa',),
'urensede': ('urenset',),
'urenset': ('urenset',),
'urensete': ('urenset',),
'urensetere': ('urenset',),
'urensetest': ('urenset',),
'urenseteste': ('urenset',),
'urenska': ('urenska',),
'urenskede': ('urensket',),
'urensket': ('urensket',),
'urenskete': ('urensket',),
'urensketere': ('urensket',),
'urensketest': ('urensket',),
'urensketeste': ('urensket',),
'urenslig': ('urenslig',),
'urenslige': ('urenslig',),
'urensligere': ('urenslig',),
'urensligst': ('urenslig',),
'urensligste': ('urenslig',),
'uret': ('uret',),
'urete': ('uret',),
'uretere': ('uret',),
'uretest': ('uret',),
'ureteste': ('uret',),
'urete': ('urete',),
'urett': ('urett',),
'urette': ('urett',),
'urettere': ('urett',),
'urettest': ('urett',),
'uretteste': ('urett',),
'urettferdig': ('urettferdig',),
'urettferdige': ('urettferdig',),
'urettferdigere': ('urettferdig',),
'urettferdigst': ('urettferdig',),
'urettferdigste': ('urettferdig',),
'urettmessig': ('urettmessig',),
'urettmessige': ('urettmessig',),
'urettmessigere': ('urettmessig',),
'urettmessigst': ('urettmessig',),
'urettmessigste': ('urettmessig',),
'urframførende': ('urframføre',),
'urframført': ('urframføre',),
'urframførte': ('urframføre',),
'urfremførende': ('urfremføre',),
'urfremført': ('urfremføre',),
'urfremførte': ('urfremføre',),
'ureldre': ('urgammel',),
'ureldst': ('urgammel',),
'ureldste': ('urgammel',),
'urgamle': ('urgammel',),
'urgammel': ('urgammel',),
'urgammelt': ('urgammel',),
'urgerende': ('urgere',),
'urgert': ('urgere',),
'urgerte': ('urgere',),
'urgermansk': ('urgermansk',),
'urgermanske': ('urgermansk',),
'urgermanskere': ('urgermansk',),
'urgermanskest': ('urgermansk',),
'urgermanskeste': ('urgermansk',),
'urikkelig': ('urikkelig',),
'urikkelige': ('urikkelig',),
'urikkeligere': ('urikkelig',),
'urikkeligst': ('urikkelig',),
'urikkeligste': ('urikkelig',),
'uriktig': ('uriktig',),
'uriktige': ('uriktig',),
'uriktigere': ('uriktig',),
'uriktigst': ('uriktig',),
'uriktigste': ('uriktig',),
'urimelig': ('urimelig',),
'urimelige': ('urimelig',),
'urimeligere': ('urimelig',),
'urimeligst': ('urimelig',),
'urimeligste': ('urimelig',),
'urindrivende': ('urindrivende',),
'urinerende': ('urinere',),
'urinert': ('urinere',),
'urinerte': ('urinere',),
'urkomisk': ('urkomisk',),
'urkomiske': ('urkomisk',),
'urkomiskere': ('urkomisk',),
'urkomiskest': ('urkomisk',),
'urkomiskeste': ('urkomisk',),
'urnordisk': ('urnordisk',),
'urnordiske': ('urnordisk',),
'urnordiskere': ('urnordisk',),
'urnordiskest': ('urnordisk',),
'urnordiskeste': ('urnordisk',),
'uroa': ('uroe',),
'urodd': ('uroe',),
'urodde': ('uroe',),
'uroede': ('uroe',),
'uroende': ('uroe',),
'uroet': ('uroe',),
'uroete': ('uroe',),
'urokka': ('urokka',),
'urokkelig': ('urokkelig',),
'urokkelige': ('urokkelig',),
'urokkeligere': ('urokkelig',),
'urokkeligst': ('urokkelig',),
'urokkeligste': ('urokkelig',),
'urokkede': ('urokket',),
'urokket': ('urokket',),
'urokkete': ('urokket',),
'urokketere': ('urokket',),
'urokketest': ('urokket',),
'urokketeste': ('urokket',),
'urolig': ('urolig',),
'urolige': ('urolig',),
'uroligere': ('urolig',),
'uroligst': ('urolig',),
'uroligste': ('urolig',),
'urologisk': ('urologisk',),
'urologiske': ('urologisk',),
'urologiskere': ('urologisk',),
'urologiskest': ('urologisk',),
'urologiskeste': ('urologisk',),
'uromantisk': ('uromantisk',),
'uromantiske': ('uromantisk',),
'uromantiskere': ('uromantisk',),
'uromantiskest': ('uromantisk',),
'uromantiskeste': ('uromantisk',),
'uroppførende': ('uroppføre',),
'uroppført': ('uroppføre',),
'uroppførte': ('uroppføre',),
'urosverdig': ('urosverdig',),
'urosverdige': ('urosverdig',),
'urosverdigere': ('urosverdig',),
'urosverdigst': ('urosverdig',),
'urosverdigste': ('urosverdig',),
'urovekkende': ('urovekkende',),
'urteaktig': ('urteaktig',),
'urteaktige': ('urteaktig',),
'urteaktigere': ('urteaktig',),
'urteaktigst': ('urteaktig',),
'urteaktigste': ('urteaktig',),
'uruguayansk': ('uruguayansk',),
'uruguayanske': ('uruguayansk',),
'uruguayanskere': ('uruguayansk',),
'uruguayanskest': ('uruguayansk',),
'uruguayanskeste': ('uruguayansk',),
'urund': ('urund',),
'urunde': ('urund',),
'urundere': ('urund',),
'urundest': ('urund',),
'urundeste': ('urund',),
'urundt': ('urund',),
'urunda': ('urunda',),
'urundede': ('urundet',),
'urundet': ('urundet',),
'urundete': ('urundet',),
'urundetere': ('urundet',),
'urundetest': ('urundet',),
'urundeteste': ('urundet',),
'urven': ('urven',),
'urvent': ('urven',),
'urvne': ('urven',),
'urvnere': ('urven',),
'urvnest': ('urven',),
'urvneste': ('urven',),
'urydda': ('urydde',),
'uryddede': ('urydde',),
'uryddende': ('urydde',),
'uryddet': ('urydde',),
'uryddete': ('urydde',),
'uryddig': ('uryddig',),
'uryddige': ('uryddig',),
'uryddigere': ('uryddig',),
'uryddigst': ('uryddig',),
'uryddigste': ('uryddig',),
'uryggelig': ('uryggelig',),
'uryggelige': ('uryggelig',),
'uryggeligere': ('uryggelig',),
'uryggeligst': ('uryggelig',),
'uryggeligste': ('uryggelig',),
'urådelig': ('urådelig',),
'urådelige': ('urådelig',),
'urådeligere': ('urådelig',),
'urådeligst': ('urådelig',),
'urådeligste': ('urådelig',),
'urørlig': ('urørlig',),
'urørlige': ('urørlig',),
'urørligere': ('urørlig',),
'urørligst': ('urørlig',),
'urørligste': ('urørlig',),
'urørt': ('urørt',),
'urørte': ('urørt',),
'urørtere': ('urørt',),
'urørtest': ('urørt',),
'urørteste': ('urørt',),
'urøykt': ('urøykt',),
'urøykte': ('urøykt',),
'urøyktere': ('urøykt',),
'urøyktest': ('urøykt',),
'urøykteste': ('urøykt',),
'usagt': ('usagt',),
'usagte': ('usagt',),
'usagtere': ('usagt',),
'usagtest': ('usagt',),
'usagteste': ('usagt',),
'usaklig': ('usaklig',),
'usaklige': ('usaklig',),
'usakligere': ('usaklig',),
'usakligst': ('usaklig',),
'usakligste': ('usaklig',),
'usalig': ('usalig',),
'usalige': ('usalig',),
'usaligere': ('usalig',),
'usaligst': ('usalig',),
'usaligste': ('usalig',),
'usalta': ('usalta',),
'usaltede': ('usaltet',),
'usaltet': ('usaltet',),
'usaltete': ('usaltet',),
'usaltetere': ('usaltet',),
'usaltetest': ('usaltet',),
'usalteteste': ('usaltet',),
'usammenhengende': ('usammenhengende',),
'usammenlignbar': ('usammenlignbar',),
'usammenlignbare': ('usammenlignbar',),
'usammenlignbarere': ('usammenlignbar',),
'usammenlignbarest': ('usammenlignbar',),
'usammenlignbareste': ('usammenlignbar',),
'usammenlignbart': ('usammenlignbar',),
'usammenliknbar': ('usammenliknbar',),
'usammenliknbare': ('usammenliknbar',),
'usammenliknbarere': ('usammenliknbar',),
'usammenliknbarest': ('usammenliknbar',),
'usammenliknbareste': ('usammenliknbar',),
'usammenliknbart': ('usammenliknbar',),
'usammensatt': ('usammensatt',),
'usammensatte': ('usammensatt',),
'usammensattere': ('usammensatt',),
'usammensattest': ('usammensatt',),
'usammensatteste': ('usammensatt',),
'usams': ('usams',),
'usann': ('usann',),
'usanne': ('usann',),
'usannere': ('usann',),
'usannest': ('usann',),
'usanneste': ('usann',),
'usant': ('usann',),
'usannferdig': ('usannferdig',),
'usannferdige': ('usannferdig',),
'usannferdigere': ('usannferdig',),
'usannferdigst': ('usannferdig',),
'usannferdigste': ('usannferdig',),
'usannsynlig': ('usannsynlig',),
'usannsynlige': ('usannsynlig',),
'usannsynligere': ('usannsynlig',),
'usannsynligst': ('usannsynlig',),
'usannsynligste': ('usannsynlig',),
'usbekisk': ('usbekisk',),
'usbekiske': ('usbekisk',),
'usbekiskere': ('usbekisk',),
'usbekiskest': ('usbekisk',),
'usbekiskeste': ('usbekisk',),
'usedelig': ('usedelig',),
'usedelige': ('usedelig',),
'usedeligere': ('usedelig',),
'usedeligst': ('usedelig',),
'usedeligste': ('usedelig',),
'usedvanlig': ('usedvanlig',),
'usedvanlige': ('usedvanlig',),
'usedvanligere': ('usedvanlig',),
'usedvanligst': ('usedvanlig',),
'usedvanligste': ('usedvanlig',),
'uselgelig': ('uselgelig',),
'uselgelige': ('uselgelig',),
'uselgeligere': ('uselgelig',),
'uselgeligst': ('uselgelig',),
'uselgeligste': ('uselgelig',),
'uselskapelig': ('uselskapelig',),
'uselskapelige': ('uselskapelig',),
'uselskapeligere': ('uselskapelig',),
'uselskapeligst': ('uselskapelig',),
'uselskapeligste': ('uselskapelig',),
'uselvisk': ('uselvisk',),
'uselviske': ('uselvisk',),
'uselviskere': ('uselvisk',),
'uselviskest': ('uselvisk',),
'uselviskeste': ('uselvisk',),
'uselvstendig': ('uselvstendig',),
'uselvstendige': ('uselvstendig',),
'uselvstendigere': ('uselvstendig',),
'uselvstendigst': ('uselvstendig',),
'uselvstendigste': ('uselvstendig',),
'usett': ('usett',),
'usette': ('usett',),
'usettere': ('usett',),
'usettest': ('usett',),
'usetteste': ('usett',),
'usigelig': ('usigelig',),
'usigelige': ('usigelig',),
'usigeligere': ('usigelig',),
'usigeligst': ('usigelig',),
'usigeligste': ('usigelig',),
'usikker': ('usikker',),
'usikkert': ('usikker',),
'usikre': ('usikker',),
'usikrere': ('usikker',),
'usikrest': ('usikker',),
'usikreste': ('usikker',),
'usikra': ('usikra',),
'usikrede': ('usikret',),
'usikret': ('usikret',),
'usikrete': ('usikret',),
'usikretere': ('usikret',),
'usikretest': ('usikret',),
'usikreteste': ('usikret',),
'usikta': ('usikta',),
'usiktede': ('usiktet',),
'usiktet': ('usiktet',),
'usiktete': ('usiktet',),
'usiktetere': ('usiktet',),
'usiktetest': ('usiktet',),
'usikteteste': ('usiktet',),
'usjenert': ('usjenert',),
'usjenerte': ('usjenert',),
'usjenertere': ('usjenert',),
'usjenertest': ('usjenert',),
'usjenerteste': ('usjenert',),
'usjølstendig': ('usjølstendig',),
'usjølstendige': ('usjølstendig',),
'usjølstendigere': ('usjølstendig',),
'usjølstendigst': ('usjølstendig',),
'usjølstendigste': ('usjølstendig',),
'uskada': ('uskada',),
'uskadd': ('uskadd',),
'uskadde': ('uskadd',),
'uskaddere': ('uskadd',),
'uskaddest': ('uskadd',),
'uskaddeste': ('uskadd',),
'uskadelig': ('uskadelig',),
'uskadelige': ('uskadelig',),
'uskadeligere': ('uskadelig',),
'uskadeligst': ('uskadelig',),
'uskadeligste': ('uskadelig',),
'uskadeliggjort': ('uskadeliggjøre',),
'uskadeliggjorte': ('uskadeliggjøre',),
'uskadeliggjørende': ('uskadeliggjøre',),
'uskadede': ('uskadet',),
'uskadet': ('uskadet',),
'uskadete': ('uskadet',),
'uskadetere': ('uskadet',),
'uskadetest': ('uskadet',),
'uskadeteste': ('uskadet',),
'uskapelig': ('uskapelig',),
'uskapelige': ('uskapelig',),
'uskapeligere': ('uskapelig',),
'uskapeligst': ('uskapelig',),
'uskapeligste': ('uskapelig',),
'uskarp': ('uskarp',),
'uskarpe': ('uskarp',),
'uskarpere': ('uskarp',),
'uskarpest': ('uskarp',),
'uskarpeste': ('uskarp',),
'uskarpt': ('uskarp',),
'uskifta': ('uskifta',),
'uskiftede': ('uskiftet',),
'uskiftet': ('uskiftet',),
'uskiftete': ('uskiftet',),
'uskiftetere': ('uskiftet',),
'uskiftetest': ('uskiftet',),
'uskifteteste': ('uskiftet',),
'uskikka': ('uskikka',),
'uskikkelig': ('uskikkelig',),
'uskikkelige': ('uskikkelig',),
'uskikkeligere': ('uskikkelig',),
'uskikkeligst': ('uskikkelig',),
'uskikkeligste': ('uskikkelig',),
'uskikkede': ('uskikket',),
'uskikket': ('uskikket',),
'uskikkete': ('uskikket',),
'uskikketere': ('uskikket',),
'uskikketest': ('uskikket',),
'uskikketeste': ('uskikket',),
'uskjønn': ('uskjønn',),
'uskjønne': ('uskjønn',),
'uskjønnere': ('uskjønn',),
'uskjønnest': ('uskjønn',),
'uskjønneste': ('uskjønn',),
'uskjønt': ('uskjønn',),
'uskjønnelig': ('uskjønnelig',),
'uskjønnelige': ('uskjønnelig',),
'uskjønneligere': ('uskjønnelig',),
'uskjønneligst': ('uskjønnelig',),
'uskjønneligste': ('uskjønnelig',),
'uskjøtta': ('uskjøtta',),
'uskjøttede': ('uskjøttet',),
'uskjøttet': ('uskjøttet',),
'uskjøttete': ('uskjøttet',),
'uskjøttetere': ('uskjøttet',),
'uskjøttetest': ('uskjøttet',),
'uskjøtteteste': ('uskjøttet',),
'uskodd': ('uskodd',),
'uskodde': ('uskodd',),
'uskoddere': ('uskodd',),
'uskoddest': ('uskodd',),
'uskoddeste': ('uskodd',),
'uskolert': ('uskolert',),
'uskolerte': ('uskolert',),
'uskolertere': ('uskolert',),
'uskolertest': ('uskolert',),
'uskolerteste': ('uskolert',),
'uskrelt': ('uskrelt',),
'uskrelte': ('uskrelt',),
'uskreltere': ('uskrelt',),
'uskreltest': ('uskrelt',),
'uskrelteste': ('uskrelt',),
'uskreven': ('uskreven',),
'uskrevet': ('uskreven',),
'uskrevne': ('uskreven',),
'uskrevnere': ('uskreven',),
'uskrevnest': ('uskreven',),
'uskrevneste': ('uskreven',),
'uskrevet': ('uskrevet',),
'uskrevne': ('uskrevet',),
'uskrevnere': ('uskrevet',),
'uskrevnest': ('uskrevet',),
'uskrevneste': ('uskrevet',),
'uskrømta': ('uskrømta',),
'uskrømtede': ('uskrømtet',),
'uskrømtet': ('uskrømtet',),
'uskrømtete': ('uskrømtet',),
'uskrømtetere': ('uskrømtet',),
'uskrømtetest': ('uskrømtet',),
'uskrømteteste': ('uskrømtet',),
'uskyldig': ('uskyldig',),
'uskyldige': ('uskyldig',),
'uskyldigere': ('uskyldig',),
'uskyldigst': ('uskyldig',),
'uskyldigste': ('uskyldig',),
'uskyldsblå': ('uskyldsblå',),
'uskyldsblåe': ('uskyldsblå',),
'uskyldsblåere': ('uskyldsblå',),
'uskyldsblåest': ('uskyldsblå',),
'uskyldsblåeste': ('uskyldsblå',),
'uskyldsblått': ('uskyldsblå',),
'uskyldsrein': ('uskyldsrein',),
'uskyldsreine': ('uskyldsrein',),
'uskyldsreinere': ('uskyldsrein',),
'uskyldsreinest': ('uskyldsrein',),
'uskyldsreineste': ('uskyldsrein',),
'uskyldsreint': ('uskyldsrein',),
'uskyldsren': ('uskyldsren',),
'uskyldsrene': ('uskyldsren',),
'uskyldsrenere': ('uskyldsren',),
'uskyldsrenest': ('uskyldsren',),
'uskyldsreneste': ('uskyldsren',),
'uskyldsrent': ('uskyldsren',),
'uslepen': ('uslepen',),
'uslepent': ('uslepen',),
'uslepet': ('uslepen',),
'uslepne': ('uslepen',),
'uslepnere': ('uslepen',),
'uslepnest': ('uslepen',),
'uslepneste': ('uslepen',),
'uslepede': ('uslepet',),
'uslepet': ('uslepet',),
'uslepete': ('uslepet',),
'uslepetere': ('uslepet',),
'uslepetest': ('uslepet',),
'uslepeteste': ('uslepet',),
'uslipt': ('uslipt',),
'uslipte': ('uslipt',),
'usliptere': ('uslipt',),
'usliptest': ('uslipt',),
'uslipteste': ('uslipt',),
'uslitelig': ('uslitelig',),
'uslitelige': ('uslitelig',),
'usliteligere': ('uslitelig',),
'usliteligst': ('uslitelig',),
'usliteligste': ('uslitelig',),
'uslokkelig': ('uslokkelig',),
'uslokkelige': ('uslokkelig',),
'uslokkeligere': ('uslokkelig',),
'uslokkeligst': ('uslokkelig',),
'uslokkeligste': ('uslokkelig',),
'uslukkelig': ('uslukkelig',),
'uslukkelige': ('uslukkelig',),
'uslukkeligere': ('uslukkelig',),
'uslukkeligst': ('uslukkelig',),
'uslukkeligste': ('uslukkelig',),
'uslåelig': ('uslåelig',),
'uslåelige': ('uslåelig',),
'uslåeligere': ('uslåelig',),
'uslåeligst': ('uslåelig',),
'uslåeligste': ('uslåelig',),
'uslått': ('uslått',),
'uslåtte': ('uslått',),
'uslåttere': ('uslått',),
'uslåttest': ('uslått',),
'uslåtteste': ('uslått',),
'usmakelig': ('usmakelig',),
'usmakelige': ('usmakelig',),
'usmakeligere': ('usmakelig',),
'usmakeligst': ('usmakelig',),
'usmakeligste': ('usmakelig',),
'usmelta': ('usmelta',),
'usmeltede': ('usmeltet',),
'usmeltet': ('usmeltet',),
'usmeltete': ('usmeltet',),
'usmeltetere': ('usmeltet',),
'usmeltetest': ('usmeltet',),
'usmelteteste': ('usmeltet',),
'usminka': ('usminka',),
'usminkede': ('usminket',),
'usminket': ('usminket',),
'usminkete': ('usminket',),
'usminketere': ('usminket',),
'usminketest': ('usminket',),
'usminketeste': ('usminket',),
'usmykka': ('usmykka',),
'usmykkede': ('usmykket',),
'usmykket': ('usmykket',),
'usmykkete': ('usmykket',),
'usmykketere': ('usmykket',),
'usmykketest': ('usmykket',),
'usmykketeste': ('usmykket',),
'usnakka': ('usnakka',),
'usnakkede': ('usnakket',),
'usnakket': ('usnakket',),
'usnakkete': ('usnakket',),
'usnakketere': ('usnakket',),
'usnakketest': ('usnakket',),
'usnakketeste': ('usnakket',),
'usnobbet': ('usnobbet',),
'usnobbete': ('usnobbet',),
'usnobbetere': ('usnobbet',),
'usnobbetest': ('usnobbet',),
'usnobbeteste': ('usnobbet',),
'usnobbete': ('usnobbete',),
'usoignert': ('usoignert',),
'usoignerte': ('usoignert',),
'usoignertere': ('usoignert',),
'usoignertest': ('usoignert',),
'usoignerteste': ('usoignert',),
'usolidarisk': ('usolidarisk',),
'usolidariske': ('usolidarisk',),
'usolidariskere': ('usolidarisk',),
'usolidariskest': ('usolidarisk',),
'usolidariskeste': ('usolidarisk',),
'usona': ('usona',),
'usonede': ('usonet',),
'usonet': ('usonet',),
'usonete': ('usonet',),
'usonetere': ('usonet',),
'usonetest': ('usonet',),
'usoneteste': ('usonet',),
'usont': ('usont',),
'usonte': ('usont',),
'usontere': ('usont',),
'usontest': ('usont',),
'usonteste': ('usont',),
'usortert': ('usortert',),
'usorterte': ('usortert',),
'usortertere': ('usortert',),
'usortertest': ('usortert',),
'usorterteste': ('usortert',),
'usosial': ('usosial',),
'usosiale': ('usosial',),
'usosialere': ('usosial',),
'usosialest': ('usosial',),
'usosialeste': ('usosial',),
'usosialt': ('usosial',),
'uspalta': ('uspalta',),
'uspaltede': ('uspaltet',),
'uspaltet': ('uspaltet',),
'uspaltete': ('uspaltet',),
'uspaltetere': ('uspaltet',),
'uspaltetest': ('uspaltet',),
'uspalteteste': ('uspaltet',),
'uspart': ('uspart',),
'usparte': ('uspart',),
'uspartere': ('uspart',),
'uspartest': ('uspart',),
'usparteste': ('uspart',),
'uspillelig': ('uspillelig',),
'uspillelige': ('uspillelig',),
'uspilleligere': ('uspillelig',),
'uspilleligst': ('uspillelig',),
'uspilleligste': ('uspillelig',),
'uspiselig': ('uspiselig',),
'uspiselige': ('uspiselig',),
'uspiseligere': ('uspiselig',),
'uspiseligst': ('uspiselig',),
'uspiseligste': ('uspiselig',),
'usportslig': ('usportslig',),
'usportslige': ('usportslig',),
'usportsligere': ('usportslig',),
'usportsligst': ('usportslig',),
'usportsligste': ('usportslig',),
'uspretta': ('uspretta',),
'usprettede': ('usprettet',),
'usprettet': ('usprettet',),
'usprettete': ('usprettet',),
'usprettetere': ('usprettet',),
'usprettetest': ('usprettet',),
'uspretteteste': ('usprettet',),
'uspurt': ('uspurt',),
'uspurte': ('uspurt',),
'uspurtere': ('uspurt',),
'uspurtest': ('uspurt',),
'uspurteste': ('uspurt',),
'usle': ('ussel',),
'uslere': ('ussel',),
'uslest': ('ussel',),
'usleste': ('ussel',),
'ussel': ('ussel',),
'usselt': ('ussel',),
'ustabil': ('ustabil',),
'ustabile': ('ustabil',),
'ustabilere': ('ustabil',),
'ustabilest': ('ustabil',),
'ustabileste': ('ustabil',),
'ustabilt': ('ustabil',),
'ustadig': ('ustadig',),
'ustadige': ('ustadig',),
'ustadigere': ('ustadig',),
'ustadigst': ('ustadig',),
'ustadigste': ('ustadig',),
'ustanselig': ('ustanselig',),
'ustanselige': ('ustanselig',),
'ustanseligere': ('ustanselig',),
'ustanseligst': ('ustanselig',),
'ustanseligste': ('ustanselig',),
'ustelt': ('ustelt',),
'ustelte': ('ustelt',),
'usteltere': ('ustelt',),
'usteltest': ('ustelt',),
'ustelteste': ('ustelt',),
'ustemt': ('ustemt',),
'ustemte': ('ustemt',),
'ustemtere': ('ustemt',),
'ustemtest': ('ustemt',),
'ustemteste': ('ustemt',),
'ustoppelig': ('ustoppelig',),
'ustoppelige': ('ustoppelig',),
'ustoppeligere': ('ustoppelig',),
'ustoppeligst': ('ustoppelig',),
'ustoppeligste': ('ustoppelig',),
'ustraffa': ('ustraffa',),
'ustraffede': ('ustraffet',),
'ustraffet': ('ustraffet',),
'ustraffete': ('ustraffet',),
'ustraffetere': ('ustraffet',),
'ustraffetest': ('ustraffet',),
'ustraffeteste': ('ustraffet',),
'ustrukturert': ('ustrukturert',),
'ustrukturerte': ('ustrukturert',),
'ustrukturertere': ('ustrukturert',),
'ustrukturertest': ('ustrukturert',),
'ustrukturerteste': ('ustrukturert',),
'ustyrlig': ('ustyrlig',),
'ustyrlige': ('ustyrlig',),
'ustyrligere': ('ustyrlig',),
'ustyrligst': ('ustyrlig',),
'ustyrligste': ('ustyrlig',),
'ustyrtelig': ('ustyrtelig',),
'ustyrtelige': ('ustyrtelig',),
'ustyrteligere': ('ustyrtelig',),
'ustyrteligst': ('ustyrtelig',),
'ustyrteligste': ('ustyrtelig',),
'ustø': ('ustø',),
'ustøe': ('ustø',),
'ustøere': ('ustø',),
'ustøest': ('ustø',),
'ustøeste': ('ustø',),
'ustøtt': ('ustø',),
'usukra': ('usukra',),
'usukrede': ('usukret',),
'usukret': ('usukret',),
'usukrete': ('usukret',),
'usukretere': ('usukret',),
'usukretest': ('usukret',),
'usukreteste': ('usukret',),
'usunn': ('usunn',),
'usunne': ('usunn',),
'usunnere': ('usunn',),
'usunnest': ('usunn',),
'usunneste': ('usunn',),
'usunt': ('usunn',),
'usurperende': ('usurpere',),
'usurpert': ('usurpere',),
'usurperte': ('usurpere',),
'usvekka': ('usvekka',),
'usvekkede': ('usvekket',),
'usvekket': ('usvekket',),
'usvekkete': ('usvekket',),
'usvekketere': ('usvekket',),
'usvekketest': ('usvekket',),
'usvekketeste': ('usvekket',),
'usvekt': ('usvekt',),
'usvekte': ('usvekt',),
'usvektere': ('usvekt',),
'usvektest': ('usvekt',),
'usvekteste': ('usvekt',),
'usvikelig': ('usvikelig',),
'usvikelige': ('usvikelig',),
'usvikeligere': ('usvikelig',),
'usvikeligst': ('usvikelig',),
'usvikeligste': ('usvikelig',),
'usymmetrisk': ('usymmetrisk',),
'usymmetriske': ('usymmetrisk',),
'usymmetriskere': ('usymmetrisk',),
'usymmetriskest': ('usymmetrisk',),
'usymmetriskeste': ('usymmetrisk',),
'usympatisk': ('usympatisk',),
'usympatiske': ('usympatisk',),
'usympatiskere': ('usympatisk',),
'usympatiskest': ('usympatisk',),
'usympatiskeste': ('usympatisk',),
'usynlig': ('usynlig',),
'usynlige': ('usynlig',),
'usynligere': ('usynlig',),
'usynligst': ('usynlig',),
'usynligste': ('usynlig',),
'usynliggjort': ('usynliggjøre',),
'usynliggjorte': ('usynliggjøre',),
'usynliggjørende': ('usynliggjøre',),
'usyra': ('usyra',),
'usyrede': ('usyret',),
'usyret': ('usyret',),
'usyrete': ('usyret',),
'usyretere': ('usyret',),
'usyretest': ('usyret',),
'usyreteste': ('usyret',),
'usyrt': ('usyrt',),
'usyrte': ('usyrt',),
'usyrtere': ('usyrt',),
'usyrtest': ('usyrt',),
'usyrteste': ('usyrt',),
'usystematisk': ('usystematisk',),
'usystematiske': ('usystematisk',),
'usystematiskere': ('usystematisk',),
'usystematiskest': ('usystematisk',),
'usystematiskeste': ('usystematisk',),
'usådd': ('usådd',),
'usådde': ('usådd',),
'usåddere': ('usådd',),
'usåddest': ('usådd',),
'usåddeste': ('usådd',),
'usåra': ('usåra',),
'usårbar': ('usårbar',),
'usårbare': ('usårbar',),
'usårbarere': ('usårbar',),
'usårbarest': ('usårbar',),
'usårbareste': ('usårbar',),
'usårbart': ('usårbar',),
'usårede': ('usåret',),
'usåret': ('usåret',),
'usårete': ('usåret',),
'usåretere': ('usåret',),
'usåretest': ('usåret',),
'usåreteste': ('usåret',),
'usårlig': ('usårlig',),
'usårlige': ('usårlig',),
'usårligere': ('usårlig',),
'usårligst': ('usårlig',),
'usårligste': ('usårlig',),
'usæl': ('usæl',),
'usæle': ('usæl',),
'usælere': ('usæl',),
'usælest': ('usæl',),
'usæleste': ('usæl',),
'usælt': ('usæl',),
'usømmelig': ('usømmelig',),
'usømmelige': ('usømmelig',),
'usømmeligere': ('usømmelig',),
'usømmeligst': ('usømmelig',),
'usømmeligste': ('usømmelig',),
'utabords': ('utabords',),
'utabygds': ('utabygds',),
'utabys': ('utabys',),
'utabysboende': ('utabysboende',),
'utabysbuende': ('utabysbuende',),
'utadretta': ('utadretta',),
'utadrettede': ('utadrettet',),
'utadrettet': ('utadrettet',),
'utadrettete': ('utadrettet',),
'utadrettetere': ('utadrettet',),
'utadrettetest': ('utadrettet',),
'utadretteteste': ('utadrettet',),
'utadvendt': ('utadvendt',),
'utadvendte': ('utadvendt',),
'utadvendtere': ('utadvendt',),
'utadvendtest': ('utadvendt',),
'utadvendteste': ('utadvendt',),
'utadørs': ('utadørs',),
'utaforliggende': ('utaforliggende',),
'utaforstående': ('utaforstående',),
'utakbar': ('utakbar',),
'utakbare': ('utakbar',),
'utakbarere': ('utakbar',),
'utakbarest': ('utakbar',),
'utakbareste': ('utakbar',),
'utakbart': ('utakbar',),
'utakknemlig': ('utakknemlig',),
'utakknemlige': ('utakknemlig',),
'utakknemligere': ('utakknemlig',),
'utakknemligst': ('utakknemlig',),
'utakknemligste': ('utakknemlig',),
'utalandsk': ('utalandsk',),
'utalandske': ('utalandsk',),
'utalandskere': ('utalandsk',),
'utalandskest': ('utalandsk',),
'utalandskeste': ('utalandsk',),
'utallig': ('utallig',),
'utallige': ('utallig',),
'utalligere': ('utallig',),
'utalligst': ('utallig',),
'utalligste': ('utallig',),
'utapåhengt': ('utapåhengt',),
'utapåhengte': ('utapåhengt',),
'utapåhengtere': ('utapåhengt',),
'utapåhengtest': ('utapåhengt',),
'utapåhengteste': ('utapåhengt',),
'utapåklint': ('utapåklint',),
'utapåklinte': ('utapåklint',),
'utapåklintere': ('utapåklint',),
'utapåklintest': ('utapåklint',),
'utapåklinteste': ('utapåklint',),
'utapåklistra': ('utapåklistra',),
'utapåklistrede': ('utapåklistret',),
'utapåklistret': ('utapåklistret',),
'utapåklistrete': ('utapåklistret',),
'utapåklistretere': ('utapåklistret',),
'utapåklistretest': ('utapåklistret',),
'utapåklistreteste': ('utapåklistret',),
'utarbeida': ('utarbeide',),
'utarbeidd': ('utarbeide',),
'utarbeidde': ('utarbeide',),
'utarbeidede': ('utarbeide',),
'utarbeidende': ('utarbeide',),
'utarbeidet': ('utarbeide',),
'utarbeidete': ('utarbeide',),
'utarettslig': ('utarettslig',),
'utarettslige': ('utarettslig',),
'utarettsligere': ('utarettslig',),
'utarettsligst': ('utarettslig',),
'utarettsligste': ('utarettslig',),
'utariks': ('utariks',),
'utariksk': ('utariksk',),
'utarikske': ('utariksk',),
'utarikskere': ('utariksk',),
'utarikskest': ('utariksk',),
'utarikskeste': ('utariksk',),
'utarikspolitisk': ('utarikspolitisk',),
'utarikspolitiske': ('utarikspolitisk',),
'utarikspolitiskere': ('utarikspolitisk',),
'utarikspolitiskest': ('utarikspolitisk',),
'utarikspolitiskeste': ('utarikspolitisk',),
'utarma': ('utarma',),
'utarmede': ('utarmet',),
'utarmet': ('utarmet',),
'utarmete': ('utarmet',),
'utarmetere': ('utarmet',),
'utarmetest': ('utarmet',),
'utarmeteste': ('utarmet',),
'utarta': ('utarte',),
'utartede': ('utarte',),
'utartende': ('utarte',),
'utartet': ('utarte',),
'utartete': ('utarte',),
'utasa': ('utasa',),
'utasa': ('utasa',),
'utaskjærs': ('utaskjærs',),
'utast': ('utast',),
'utaste': ('utast',),
'utastere': ('utast',),
'utastest': ('utast',),
'utasteste': ('utast',),
'utast': ('utast',),
'utaste': ('utast',),
'utastere': ('utast',),
'utastest': ('utast',),
'utasteste': ('utast',),
'utausende': ('utause',),
'utaust': ('utause',),
'utauste': ('utause',),
'utbasunerende': ('utbasunere',),
'utbasunert': ('utbasunere',),
'utbasunerte': ('utbasunere',),
'utbedt': ('utbe',),
'utbedte': ('utbe',),
'utbeende': ('utbe',),
'utbedra': ('utbedre',),
'utbedrede': ('utbedre',),
'utbedrende': ('utbedre',),
'utbedret': ('utbedre',),
'utbedrete': ('utbedre',),
'utbetalende': ('utbetale',),
'utbetalt': ('utbetale',),
'utbetalte': ('utbetale',),
'utblokka': ('utblokka',),
'utblokkede': ('utblokket',),
'utblokket': ('utblokket',),
'utblokkete': ('utblokket',),
'utblokketere': ('utblokket',),
'utblokketest': ('utblokket',),
'utblokketeste': ('utblokket',),
'utblåst': ('utblåst',),
'utblåste': ('utblåst',),
'utblåstere': ('utblåst',),
'utblåstest': ('utblåst',),
'utblåsteste': ('utblåst',),
'utbløtt': ('utbløtt',),
'utbløtte': ('utbløtt',),
'utbløttere': ('utbløtt',),
'utbløttest': ('utbløtt',),
'utbløtteste': ('utbløtt',),
'utbløytt': ('utbløytt',),
'utbløytte': ('utbløytt',),
'utbløyttere': ('utbløytt',),
'utbløyttest': ('utbløytt',),
'utbløytteste': ('utbløytt',),
'utbomba': ('utbomba',),
'utbombede': ('utbombet',),
'utbombet': ('utbombet',),
'utbombete': ('utbombet',),
'utbombetere': ('utbombet',),
'utbombetest': ('utbombet',),
'utbombeteste': ('utbombet',),
'utbreia': ('utbreie',),
'utbreid': ('utbreie',),
'utbreide': ('utbreie',),
'utbreiede': ('utbreie',),
'utbreiende': ('utbreie',),
'utbreiet': ('utbreie',),
'utbreiete': ('utbreie',),
'utbrent': ('utbrent',),
'utbrente': ('utbrent',),
'utbrentere': ('utbrent',),
'utbrentest': ('utbrent',),
'utbrenteste': ('utbrent',),
'utbragt': ('utbringe',),
'utbragte': ('utbringe',),
'utbrakt': ('utbringe',),
'utbrakte': ('utbringe',),
'utbringende': ('utbringe',),
'utbroderende': ('utbrodere',),
'utbrodert': ('utbrodere',),
'utbroderte': ('utbrodere',),
'utbrukt': ('utbrukt',),
'utbrukte': ('utbrukt',),
'utbruktere': ('utbrukt',),
'utbruktest': ('utbrukt',),
'utbrukteste': ('utbrukt',),
'utbrutt': ('utbryte',),
'utbrutte': ('utbryte',),
'utbrytende': ('utbryte',),
'utbudt': ('utby',),
'utbudte': ('utby',),
'utbydd': ('utby',),
'utbydde': ('utby',),
'utbyende': ('utby',),
'utbygd': ('utbygge',),
'utbygde': ('utbygge',),
'utbygga': ('utbygge',),
'utbyggede': ('utbygge',),
'utbyggende': ('utbygge',),
'utbygget': ('utbygge',),
'utbyggete': ('utbygge',),
'utbytta': ('utbytte',),
'utbyttede': ('utbytte',),
'utbyttende': ('utbytte',),
'utbyttet': ('utbytte',),
'utbyttete': ('utbytte',),
'utbytterik': ('utbytterik',),
'utbytterike': ('utbytterik',),
'utbytterikere': ('utbytterik',),
'utbytterikest': ('utbytterik',),
'utbytterikeste': ('utbytterik',),
'utbytterikt': ('utbytterik',),
'utdanna': ('utdanne',),
'utdannede': ('utdanne',),
'utdannende': ('utdanne',),
'utdannet': ('utdanne',),
'utdannete': ('utdanne',),
'utdannelsessøkende': ('utdannelsessøkende',),
'utdanningssøkende': ('utdanningssøkende',),
'utdebatterende': ('utdebattere',),
'utdebattert': ('utdebattere',),
'utdebatterte': ('utdebattere',),
'utdelende': ('utdele',),
'utdelt': ('utdele',),
'utdelte': ('utdele',),
'utdjupa': ('utdjupe',),
'utdjupede': ('utdjupe',),
'utdjupende': ('utdjupe',),
'utdjupet': ('utdjupe',),
'utdjupete': ('utdjupe',),
'utdypa': ('utdype',),
'utdypede': ('utdype',),
'utdypende': ('utdype',),
'utdypet': ('utdype',),
'utdypete': ('utdype',),
'utdødd': ('utdø',),
'utdødde': ('utdø',),
'utdøende': ('utdø',),
'utdødd': ('utdødd',),
'utdødde': ('utdødd',),
'utdøddere': ('utdødd',),
'utdøddest': ('utdødd',),
'utdøddeste': ('utdødd',),
'utdøende': ('utdøende',),
'utearbeidende': ('utearbeidende',),
'uteblitt': ('utebli',),
'uteblitte': ('utebli',),
'uteblivende': ('utebli',),
'uteglemmende': ('uteglemme',),
'uteglemt': ('uteglemme',),
'uteglemte': ('uteglemme',),
'uteglømmende': ('uteglømme',),
'uteglømt': ('uteglømme',),
'uteglømte': ('uteglømme',),
'utekkelig': ('utekkelig',),
'utekkelige': ('utekkelig',),
'utekkeligere': ('utekkelig',),
'utekkeligst': ('utekkelig',),
'utekkeligste': ('utekkelig',),
'uteksaminerende': ('uteksaminere',),
'uteksaminert': ('uteksaminere',),
'uteksaminerte': ('uteksaminere',),
'uteksperimenterende': ('uteksperimentere',),
'uteksperimentert': ('uteksperimentere',),
'uteksperimenterte': ('uteksperimentere',),
'uteksta': ('uteksta',),
'utekstede': ('utekstet',),
'utekstet': ('utekstet',),
'utekstete': ('utekstet',),
'utekstetere': ('utekstet',),
'utekstetest': ('utekstet',),
'uteksteteste': ('utekstet',),
'utelatende': ('utelate',),
'utelatt': ('utelate',),
'utelatte': ('utelate',),
'utellelig': ('utellelig',),
'utellelige': ('utellelig',),
'utelleligere': ('utellelig',),
'utelleligst': ('utellelig',),
'utelleligste': ('utellelig',),
'utelukka': ('utelukka',),
'utelukka': ('utelukke',),
'utelukkede': ('utelukke',),
'utelukkende': ('utelukke',),
'utelukket': ('utelukke',),
'utelukkete': ('utelukke',),
'utelukkede': ('utelukket',),
'utelukket': ('utelukket',),
'utelukkete': ('utelukket',),
'utelukketere': ('utelukket',),
'utelukketest': ('utelukket',),
'utelukketeste': ('utelukket',),
'utemma': ('utemma',),
'utemmede': ('utemmet',),
'utemmet': ('utemmet',),
'utemmete': ('utemmet',),
'utemmetere': ('utemmet',),
'utemmetest': ('utemmet',),
'utemmeteste': ('utemmet',),
'utemt': ('utemt',),
'utemte': ('utemt',),
'utemtere': ('utemt',),
'utemtest': ('utemt',),
'utemteste': ('utemt',),
'utenbords': ('utenbords',),
'utenbygds': ('utenbygds',),
'utenbys': ('utenbys',),
'utenbysboende': ('utenbysboende',),
'utenbysbuende': ('utenbysbuende',),
'utendørs': ('utendørs',),
'utenforliggende': ('utenforliggende',),
'utenforstående': ('utenforstående',),
'utenkelig': ('utenkelig',),
'utenkelige': ('utenkelig',),
'utenkeligere': ('utenkelig',),
'utenkeligst': ('utenkelig',),
'utenkeligste': ('utenkelig',),
'utenlandsk': ('utenlandsk',),
'utenlandske': ('utenlandsk',),
'utenlandskere': ('utenlandsk',),
'utenlandskest': ('utenlandsk',),
'utenlandskeste': ('utenlandsk',),
'utenomekteskapelig': ('utenomekteskapelig',),
'utenomekteskapelige': ('utenomekteskapelig',),
'utenomekteskapeligere': ('utenomekteskapelig',),
'utenomekteskapeligst': ('utenomekteskapelig',),
'utenomekteskapeligste': ('utenomekteskapelig',),
'utenomparlamentarisk': ('utenomparlamentarisk',),
'utenomparlamentariske': ('utenomparlamentarisk',),
'utenomparlamentariskere': ('utenomparlamentarisk',),
'utenomparlamentariskest': ('utenomparlamentarisk',),
'utenomparlamentariskeste': ('utenomparlamentarisk',),
'utenomrettslig': ('utenomrettslig',),
'utenomrettslige': ('utenomrettslig',),
'utenomrettsligere': ('utenomrettslig',),
'utenomrettsligst': ('utenomrettslig',),
'utenomrettsligste': ('utenomrettslig',),
'utenpåhengt': ('utenpåhengt',),
'utenpåhengte': ('utenpåhengt',),
'utenpåhengtere': ('utenpåhengt',),
'utenpåhengtest': ('utenpåhengt',),
'utenpåhengteste': ('utenpåhengt',),
'utenpåklint': ('utenpåklint',),
'utenpåklinte': ('utenpåklint',),
'utenpåklintere': ('utenpåklint',),
'utenpåklintest': ('utenpåklint',),
'utenpåklinteste': ('utenpåklint',),
'utenpåklistra': ('utenpåklistra',),
'utenpåklistrede': ('utenpåklistret',),
'utenpåklistret': ('utenpåklistret',),
'utenpåklistrete': ('utenpåklistret',),
'utenpåklistretere': ('utenpåklistret',),
'utenpåklistretest': ('utenpåklistret',),
'utenpåklistreteste': ('utenpåklistret',),
'utenrettslig': ('utenrettslig',),
'utenrettslige': ('utenrettslig',),
'utenrettsligere': ('utenrettslig',),
'utenrettsligst': ('utenrettslig',),
'utenrettsligste': ('utenrettslig',),
'utenriks': ('utenriks',),
'utenriksk': ('utenriksk',),
'utenrikske': ('utenriksk',),
'utenrikskere': ('utenriksk',),
'utenrikskest': ('utenriksk',),
'utenrikskeste': ('utenriksk',),
'utenrikspolitisk': ('utenrikspolitisk',),
'utenrikspolitiske': ('utenrikspolitisk',),
'utenrikspolitiskere': ('utenrikspolitisk',),
'utenrikspolitiskest': ('utenrikspolitisk',),
'utenrikspolitiskeste': ('utenrikspolitisk',),
'utenskjærs': ('utenskjærs',),
'uterlig': ('uterlig',),
'uterlige': ('uterlig',),
'uterligere': ('uterlig',),
'uterligst': ('uterlig',),
'uterligste': ('uterlig',),
'uteska': ('uteske',),
'uteskede': ('uteske',),
'uteskende': ('uteske',),
'utesket': ('uteske',),
'uteskete': ('uteske',),
'utestengende': ('utestenge',),
'utestengt': ('utestenge',),
'utestengte': ('utestenge',),
'utestående': ('utestående',),
'utett': ('utett',),
'utette': ('utett',),
'utettere': ('utett',),
'utettest': ('utett',),
'utetteste': ('utett',),
'utfattig': ('utfattig',),
'utfattige': ('utfattig',),
'utfattigere': ('utfattig',),
'utfattigst': ('utfattig',),
'utfattigste': ('utfattig',),
'utfellende': ('utfelle',),
'utfelt': ('utfelle',),
'utfelte': ('utfelle',),
'utferdiga': ('utferdige',),
'utferdigede': ('utferdige',),
'utferdigende': ('utferdige',),
'utferdiget': ('utferdige',),
'utferdigete': ('utferdige',),
'utflippa': ('utflippa',),
'utflippede': ('utflippet',),
'utflippet': ('utflippet',),
'utflippete': ('utflippet',),
'utflippetere': ('utflippet',),
'utflippetest': ('utflippet',),
'utflippeteste': ('utflippet',),
'utflytende': ('utflytende',),
'utflytta': ('utflytta',),
'utflyttede': ('utflyttet',),
'utflyttet': ('utflyttet',),
'utflyttete': ('utflyttet',),
'utflyttetere': ('utflyttet',),
'utflyttetest': ('utflyttet',),
'utflytteteste': ('utflyttet',),
'utfolda': ('utfolde',),
'utfoldede': ('utfolde',),
'utfoldende': ('utfolde',),
'utfoldet': ('utfolde',),
'utfoldete': ('utfolde',),
'utfordra': ('utfordre',),
'utfordrede': ('utfordre',),
'utfordrende': ('utfordre',),
'utfordret': ('utfordre',),
'utfordrete': ('utfordre',),
'utfordrende': ('utfordrende',),
'utforma': ('utforme',),
'utformede': ('utforme',),
'utformende': ('utforme',),
'utformet': ('utforme',),
'utformete': ('utforme',),
'utforska': ('utforske',),
'utforskede': ('utforske',),
'utforskende': ('utforske',),
'utforsket': ('utforske',),
'utforskete': ('utforske',),
'utfridd': ('utfri',),
'utfridde': ('utfri',),
'utfriende': ('utfri',),
'utfritta': ('utfritte',),
'utfrittede': ('utfritte',),
'utfrittende': ('utfritte',),
'utfrittet': ('utfritte',),
'utfrittete': ('utfritte',),
'utfyllende': ('utfylle',),
'utfylt': ('utfylle',),
'utfylte': ('utfylle',),
'utførende': ('utføre',),
'utført': ('utføre',),
'utførte': ('utføre',),
'utførlig': ('utførlig',),
'utførlige': ('utførlig',),
'utførligere': ('utførlig',),
'utførligst': ('utførlig',),
'utførligste': ('utførlig',),
'uteldre': ('utgammal',),
'uteldst': ('utgammal',),
'uteldste': ('utgammal',),
'utgamle': ('utgammal',),
'utgammal': ('utgammal',),
'utgammalt': ('utgammal',),
'uteldre': ('utgammel',),
'uteldst': ('utgammel',),
'uteldste': ('utgammel',),
'utgamle': ('utgammel',),
'utgammel': ('utgammel',),
'utgammelt': ('utgammel',),
'utgiende': ('utgi',),
'utgitt': ('utgi',),
'utgitte': ('utgi',),
'utgivende': ('utgi',),
'utgiftsførende': ('utgiftsføre',),
'utgiftsført': ('utgiftsføre',),
'utgiftsførte': ('utgiftsføre',),
'utgjort': ('utgjort',),
'utgjorte': ('utgjort',),
'utgjortere': ('utgjort',),
'utgjortest': ('utgjort',),
'utgjorteste': ('utgjort',),
'utgjort': ('utgjøre',),
'utgjorte': ('utgjøre',),
'utgjørende': ('utgjøre',),
'utgravd': ('utgravd',),
'utgravde': ('utgravd',),
'utgravdere': ('utgravd',),
'utgravdest': ('utgravd',),
'utgravdeste': ('utgravd',),
'utgrunna': ('utgrunne',),
'utgrunnede': ('utgrunne',),
'utgrunnende': ('utgrunne',),
'utgrunnet': ('utgrunne',),
'utgrunnete': ('utgrunne',),
'utgytende': ('utgyte',),
'utgytt': ('utgyte',),
'utgytte': ('utgyte',),
'utgytt': ('utgytt',),
'utgytte': ('utgytt',),
'utgyttere': ('utgytt',),
'utgyttest': ('utgytt',),
'utgytteste': ('utgytt',),
'utgående': ('utgå',),
'utgått': ('utgå',),
'utgåtte': ('utgå',),
'utgående': ('utgående',),
'uthengt': ('uthengt',),
'uthengte': ('uthengt',),
'uthengtere': ('uthengt',),
'uthengtest': ('uthengt',),
'uthengteste': ('uthengt',),
'utheva': ('utheve',),
'uthevd': ('utheve',),
'uthevde': ('utheve',),
'uthevede': ('utheve',),
'uthevende': ('utheve',),
'uthevet': ('utheve',),
'uthevete': ('utheve',),
'uthogd': ('uthogd',),
'uthogde': ('uthogd',),
'uthogdere': ('uthogd',),
'uthogdest': ('uthogd',),
'uthogdeste': ('uthogd',),
'utholdende': ('utholde',),
'utholdt': ('utholde',),
'utholdte': ('utholde',),
'utholdelig': ('utholdelig',),
'utholdelige': ('utholdelig',),
'utholdeligere': ('utholdelig',),
'utholdeligst': ('utholdelig',),
'utholdeligste': ('utholdelig',),
'utholdende': ('utholdende',),
'uthola': ('uthole',),
'utholende': ('uthole',),
'utholt': ('uthole',),
'utholte': ('uthole',),
'uthugd': ('uthugd',),
'uthugde': ('uthugd',),
'uthugdere': ('uthugd',),
'uthugdest': ('uthugd',),
'uthugdeste': ('uthugd',),
'uthula': ('uthule',),
'uthulede': ('uthule',),
'uthulende': ('uthule',),
'uthulet': ('uthule',),
'uthulete': ('uthule',),
'uthult': ('uthule',),
'uthulte': ('uthule',),
'uthungra': ('uthungra',),
'uthungrede': ('uthungret',),
'uthungret': ('uthungret',),
'uthungrete': ('uthungret',),
'uthungretere': ('uthungret',),
'uthungretest': ('uthungret',),
'uthungreteste': ('uthungret',),
'uthvilt': ('uthvilt',),
'uthvilte': ('uthvilt',),
'uthviltere': ('uthvilt',),
'uthviltest': ('uthvilt',),
'uthvilteste': ('uthvilt',),
'utidig': ('utidig',),
'utidige': ('utidig',),
'utidigere': ('utidig',),
'utidigst': ('utidig',),
'utidigste': ('utidig',),
'utidsmessig': ('utidsmessig',),
'utidsmessige': ('utidsmessig',),
'utidsmessigere': ('utidsmessig',),
'utidsmessigst': ('utidsmessig',),
'utidsmessigste': ('utidsmessig',),
'utilbørlig': ('utilbørlig',),
'utilbørlige': ('utilbørlig',),
'utilbørligere': ('utilbørlig',),
'utilbørligst': ('utilbørlig',),
'utilbørligste': ('utilbørlig',),
'utilbøyelig': ('utilbøyelig',),
'utilbøyelige': ('utilbøyelig',),
'utilbøyeligere': ('utilbøyelig',),
'utilbøyeligst': ('utilbøyelig',),
'utilbøyeligste': ('utilbøyelig',),
'utildekka': ('utildekka',),
'utildekkede': ('utildekket',),
'utildekket': ('utildekket',),
'utildekkete': ('utildekket',),
'utildekketere': ('utildekket',),
'utildekketest': ('utildekket',),
'utildekketeste': ('utildekket',),
'utildekt': ('utildekt',),
'utildekte': ('utildekt',),
'utildektere': ('utildekt',),
'utildektest': ('utildekt',),
'utildekteste': ('utildekt',),
'utilfreds': ('utilfreds',),
'utilfredse': ('utilfreds',),
'utilfredsere': ('utilfreds',),
'utilfredsest': ('utilfreds',),
'utilfredseste': ('utilfreds',),
'utilfredsstillende': ('utilfredsstillende',),
'utilfredsstilt': ('utilfredsstilt',),
'utilfredsstilte': ('utilfredsstilt',),
'utilfredsstiltere': ('utilfredsstilt',),
'utilfredsstiltest': ('utilfredsstilt',),
'utilfredsstilteste': ('utilfredsstilt',),
'utilgivelig': ('utilgivelig',),
'utilgivelige': ('utilgivelig',),
'utilgiveligere': ('utilgivelig',),
'utilgiveligst': ('utilgivelig',),
'utilgiveligste': ('utilgivelig',),
'utilgjengelig': ('utilgjengelig',),
'utilgjengelige': ('utilgjengelig',),
'utilgjengeligere': ('utilgjengelig',),
'utilgjengeligst': ('utilgjengelig',),
'utilgjengeligste': ('utilgjengelig',),
'utilhylla': ('utilhylla',),
'utilhyllede': ('utilhyllet',),
'utilhyllet': ('utilhyllet',),
'utilhyllete': ('utilhyllet',),
'utilhylletere': ('utilhyllet',),
'utilhylletest': ('utilhyllet',),
'utilhylleteste': ('utilhyllet',),
'utilistisk': ('utilistisk',),
'utilistiske': ('utilistisk',),
'utilistiskere': ('utilistisk',),
'utilistiskest': ('utilistisk',),
'utilistiskeste': ('utilistisk',),
'utilitaristisk': ('utilitaristisk',),
'utilitaristiske': ('utilitaristisk',),
'utilitaristiskere': ('utilitaristisk',),
'utilitaristiskest': ('utilitaristisk',),
'utilitaristiskeste': ('utilitaristisk',),
'utillatelig': ('utillatelig',),
'utillatelige': ('utillatelig',),
'utillateligere': ('utillatelig',),
'utillateligst': ('utillatelig',),
'utillateligste': ('utillatelig',),
'utilnærmelig': ('utilnærmelig',),
'utilnærmelige': ('utilnærmelig',),
'utilnærmeligere': ('utilnærmelig',),
'utilnærmeligst': ('utilnærmelig',),
'utilnærmeligste': ('utilnærmelig',),
'utilpass': ('utilpass',),
'utilpasse': ('utilpass',),
'utilpassere': ('utilpass',),
'utilpassest': ('utilpass',),
'utilpasseste': ('utilpass',),
'utilregnelig': ('utilregnelig',),
'utilregnelige': ('utilregnelig',),
'utilregneligere': ('utilregnelig',),
'utilregneligst': ('utilregnelig',),
'utilregneligste': ('utilregnelig',),
'utilreknelig': ('utilreknelig',),
'utilreknelige': ('utilreknelig',),
'utilrekneligere': ('utilreknelig',),
'utilrekneligst': ('utilreknelig',),
'utilrekneligste': ('utilreknelig',),
'utilrådelig': ('utilrådelig',),
'utilrådelige': ('utilrådelig',),
'utilrådeligere': ('utilrådelig',),
'utilrådeligst': ('utilrådelig',),
'utilrådeligste': ('utilrådelig',),
'utilsikta': ('utilsikta',),
'utilsiktede': ('utilsiktet',),
'utilsiktet': ('utilsiktet',),
'utilsiktete': ('utilsiktet',),
'utilsiktetere': ('utilsiktet',),
'utilsiktetest': ('utilsiktet',),
'utilsikteteste': ('utilsiktet',),
'utilslørt': ('utilslørt',),
'utilslørte': ('utilslørt',),
'utilslørtere': ('utilslørt',),
'utilslørtest': ('utilslørt',),
'utilslørteste': ('utilslørt',),
'utilstedelig': ('utilstedelig',),
'utilstedelige': ('utilstedelig',),
'utilstedeligere': ('utilstedelig',),
'utilstedeligst': ('utilstedelig',),
'utilstedeligste': ('utilstedelig',),
'utilstrekkelig': ('utilstrekkelig',),
'utilstrekkelige': ('utilstrekkelig',),
'utilstrekkeligere': ('utilstrekkelig',),
'utilstrekkeligst': ('utilstrekkelig',),
'utilstrekkeligste': ('utilstrekkelig',),
'utiltalende': ('utiltalende',),
'utjamna': ('utjamne',),
'utjamnede': ('utjamne',),
'utjamnende': ('utjamne',),
'utjamnet': ('utjamne',),
'utjamnete': ('utjamne',),
'utjenlig': ('utjenlig',),
'utjenlige': ('utjenlig',),
'utjenligere': ('utjenlig',),
'utjenligst': ('utjenlig',),
'utjenligste': ('utjenlig',),
'utjevna': ('utjevne',),
'utjevnede': ('utjevne',),
'utjevnende': ('utjevne',),
'utjevnet': ('utjevne',),
'utjevnete': ('utjevne',),
'utkallende': ('utkalle',),
'utkalt': ('utkalle',),
'utkalte': ('utkalle',),
'utkasta': ('utkaste',),
'utkastede': ('utkaste',),
'utkastende': ('utkaste',),
'utkastet': ('utkaste',),
'utkastete': ('utkaste',),
'utkjast': ('utkjast',),
'utkjaste': ('utkjast',),
'utkjastere': ('utkjast',),
'utkjastest': ('utkjast',),
'utkjasteste': ('utkjast',),
'utkjempa': ('utkjempe',),
'utkjempede': ('utkjempe',),
'utkjempende': ('utkjempe',),
'utkjempet': ('utkjempe',),
'utkjempete': ('utkjempe',),
'utkjørt': ('utkjørt',),
'utkjørte': ('utkjørt',),
'utkjørtere': ('utkjørt',),
'utkjørtest': ('utkjørt',),
'utkjørteste': ('utkjørt',),
'utklarerende': ('utklarere',),
'utklarert': ('utklarere',),
'utklarerte': ('utklarere',),
'utklassa': ('utklasse',),
'utklassede': ('utklasse',),
'utklassende': ('utklasse',),
'utklasset': ('utklasse',),
'utklassete': ('utklasse',),
'utkledd': ('utkledd',),
'utkledde': ('utkledd',),
'utkleddere': ('utkledd',),
'utkleddest': ('utkledd',),
'utkleddeste': ('utkledd',),
'utklekka': ('utklekke',),
'utklekkede': ('utklekke',),
'utklekkende': ('utklekke',),
'utklekket': ('utklekke',),
'utklekkete': ('utklekke',),
'utklekt': ('utklekke',),
'utklekte': ('utklekke',),
'utkobla': ('utkoble',),
'utkoblede': ('utkoble',),
'utkoblende': ('utkoble',),
'utkoblet': ('utkoble',),
'utkoblete': ('utkoble',),
'utkokt': ('utkokt',),
'utkokte': ('utkokt',),
'utkoktere': ('utkokt',),
'utkoktest': ('utkokt',),
'utkokteste': ('utkokt',),
'utkommanderende': ('utkommandere',),
'utkommandert': ('utkommandere',),
'utkommanderte': ('utkommandere',),
'utkommen': ('utkomme',),
'utkommende': ('utkomme',),
'utkommet': ('utkomme',),
'utkomne': ('utkomme',),
'utkonkurrerende': ('utkonkurrere',),
'utkonkurrert': ('utkonkurrere',),
'utkonkurrerte': ('utkonkurrere',),
'utkopla': ('utkople',),
'utkoplede': ('utkople',),
'utkoplende': ('utkople',),
'utkoplet': ('utkople',),
'utkoplete': ('utkople',),
'utkreva': ('utkreve',),
'utkrevd': ('utkreve',),
'utkrevde': ('utkreve',),
'utkrevede': ('utkreve',),
'utkrevende': ('utkreve',),
'utkrevet': ('utkreve',),
'utkrevete': ('utkreve',),
'utkrota': ('utkrota',),
'utkrotede': ('utkrotet',),
'utkrotet': ('utkrotet',),
'utkrotete': ('utkrotet',),
'utkrotetere': ('utkrotet',),
'utkrotetest': ('utkrotet',),
'utkroteteste': ('utkrotet',),
'utkrystalliserende': ('utkrystallisere',),
'utkrystallisert': ('utkrystallisere',),
'utkrystalliserte': ('utkrystallisere',),
'utkrøpen': ('utkrøpen',),
'utkrøpent': ('utkrøpen',),
'utkrøpne': ('utkrøpen',),
'utkrøpnere': ('utkrøpen',),
'utkrøpnest': ('utkrøpen',),
'utkrøpneste': ('utkrøpen',),
'utkvilt': ('utkvilt',),
'utkvilte': ('utkvilt',),
'utkviltere': ('utkvilt',),
'utkviltest': ('utkvilt',),
'utkvilteste': ('utkvilt',),
'utkåra': ('utkåre',),
'utkårede': ('utkåre',),
'utkårende': ('utkåre',),
'utkåret': ('utkåre',),
'utkårete': ('utkåre',),
'utlada': ('utlade',),
'utladd': ('utlade',),
'utladde': ('utlade',),
'utladede': ('utlade',),
'utladende': ('utlade',),
'utladet': ('utlade',),
'utladete': ('utlade',),
'utlagt': ('utlagt',),
'utlagte': ('utlagt',),
'utlagtere': ('utlagt',),
'utlagtest': ('utlagt',),
'utlagteste': ('utlagt',),
'utlatende': ('utlate',),
'utlatt': ('utlate',),
'utlatte': ('utlate',),
'utledd': ('utledd',),
'utledde': ('utledd',),
'utleddere': ('utledd',),
'utleddest': ('utledd',),
'utleddeste': ('utledd',),
'utleda': ('utlede',),
'utledede': ('utlede',),
'utledende': ('utlede',),
'utledet': ('utlede',),
'utledete': ('utlede',),
'utleg': ('utleg',),
'utlege': ('utleg',),
'utlegere': ('utleg',),
'utlegest': ('utleg',),
'utlegeste': ('utleg',),
'utlegt': ('utleg',),
'utlagt': ('utlegge',),
'utlagte': ('utlegge',),
'utleggende': ('utlegge',),
'utlendig': ('utlendig',),
'utlendige': ('utlendig',),
'utlendigere': ('utlendig',),
'utlendigst': ('utlendig',),
'utlendigste': ('utlendig',),
'utlevd': ('utlevd',),
'utlevde': ('utlevd',),
'utlevdere': ('utlevd',),
'utlevdest': ('utlevd',),
'utlevdeste': ('utlevd',),
'utleverende': ('utlevere',),
'utlevert': ('utlevere',),
'utleverte': ('utlevere',),
'utligna': ('utligne',),
'utlignede': ('utligne',),
'utlignende': ('utligne',),
'utlignet': ('utligne',),
'utlignete': ('utligne',),
'utlikna': ('utlikne',),
'utliknede': ('utlikne',),
'utliknende': ('utlikne',),
'utliknet': ('utlikne',),
'utliknete': ('utlikne',),
'utlodda': ('utlodde',),
'utloddede': ('utlodde',),
'utloddende': ('utlodde',),
'utloddet': ('utlodde',),
'utloddete': ('utlodde',),
'utlossa': ('utlosse',),
'utlossede': ('utlosse',),
'utlossende': ('utlosse',),
'utlosset': ('utlosse',),
'utlossete': ('utlosse',),
'utlova': ('utlove',),
'utlovd': ('utlove',),
'utlovde': ('utlove',),
'utlovede': ('utlove',),
'utlovende': ('utlove',),
'utlovet': ('utlove',),
'utlovete': ('utlove',),
'utlovt': ('utlove',),
'utlovte': ('utlove',),
'utlufta': ('utlufta',),
'utluftede': ('utluftet',),
'utluftet': ('utluftet',),
'utluftete': ('utluftet',),
'utluftetere': ('utluftet',),
'utluftetest': ('utluftet',),
'utlufteteste': ('utluftet',),
'utlydd': ('utlyde',),
'utlydde': ('utlyde',),
'utlydende': ('utlyde',),
'utlydt': ('utlyde',),
'utlydte': ('utlyde',),
'utlydende': ('utlydende',),
'utlysende': ('utlyse',),
'utlyst': ('utlyse',),
'utlyste': ('utlyse',),
'utlånende': ('utlåne',),
'utlånt': ('utlåne',),
'utlånte': ('utlåne',),
'utlært': ('utlært',),
'utlærte': ('utlært',),
'utlærtere': ('utlært',),
'utlærtest': ('utlært',),
'utlærteste': ('utlært',),
'utløpende': ('utløpe',),
'utløpet': ('utløpe',),
'utløpt': ('utløpe',),
'utløpte': ('utløpe',),
'utløsende': ('utløse',),
'utløst': ('utløse',),
'utløste': ('utløse',),
'utløselig': ('utløselig',),
'utløselige': ('utløselig',),
'utløseligere': ('utløselig',),
'utløseligst': ('utløselig',),
'utløseligste': ('utløselig',),
'utløysende': ('utløyse',),
'utløyst': ('utløyse',),
'utløyste': ('utløyse',),
'utløyselig': ('utløyselig',),
'utløyselige': ('utløyselig',),
'utløyseligere': ('utløyselig',),
'utløyseligst': ('utløyselig',),
'utløyseligste': ('utløyselig',),
'utmagra': ('utmagra',),
'utmagrede': ('utmagret',),
'utmagret': ('utmagret',),
'utmagrete': ('utmagret',),
'utmagretere': ('utmagret',),
'utmagretest': ('utmagret',),
'utmagreteste': ('utmagret',),
'utmaia': ('utmaie',),
'utmaiede': ('utmaie',),
'utmaiende': ('utmaie',),
'utmaiet': ('utmaie',),
'utmaiete': ('utmaie',),
'utmalende': ('utmale',),
'utmalt': ('utmale',),
'utmalte': ('utmale',),
'utmalt': ('utmalt',),
'utmalte': ('utmalt',),
'utmaltere': ('utmalt',),
'utmaltest': ('utmalt',),
'utmalteste': ('utmalt',),
'utmanøvrerende': ('utmanøvrere',),
'utmanøvrert': ('utmanøvrere',),
'utmanøvrerte': ('utmanøvrere',),
'utmasa': ('utmasa',),
'utmasede': ('utmaset',),
'utmaset': ('utmaset',),
'utmasete': ('utmaset',),
'utmasetere': ('utmaset',),
'utmasetest': ('utmaset',),
'utmaseteste': ('utmaset',),
'utmast': ('utmast',),
'utmaste': ('utmast',),
'utmastere': ('utmast',),
'utmastest': ('utmast',),
'utmasteste': ('utmast',),
'utmatta': ('utmatte',),
'utmattede': ('utmatte',),
'utmattende': ('utmatte',),
'utmattet': ('utmatte',),
'utmattete': ('utmatte',),
'utmeisla': ('utmeisle',),
'utmeislede': ('utmeisle',),
'utmeislende': ('utmeisle',),
'utmeislet': ('utmeisle',),
'utmeislete': ('utmeisle',),
'utmeldt': ('utmeldt',),
'utmeldte': ('utmeldt',),
'utmeldtere': ('utmeldt',),
'utmeldtest': ('utmeldt',),
'utmeldteste': ('utmeldt',),
'utmerka': ('utmerka',),
'utmerka': ('utmerke',),
'utmerkede': ('utmerke',),
'utmerkende': ('utmerke',),
'utmerket': ('utmerke',),
'utmerkete': ('utmerke',),
'utmerkede': ('utmerket',),
'utmerket': ('utmerket',),
'utmerkete': ('utmerket',),
'utmerketere': ('utmerket',),
'utmerketest': ('utmerket',),
'utmerketeste': ('utmerket',),
'utmynta': ('utmynte',),
'utmyntede': ('utmynte',),
'utmyntende': ('utmynte',),
'utmyntet': ('utmynte',),
'utmyntete': ('utmynte',),
'utmålende': ('utmåle',),
'utmålt': ('utmåle',),
'utmålte': ('utmåle',),
'utnevnende': ('utnevne',),
'utnevnt': ('utnevne',),
'utnevnte': ('utnevne',),
'utnista': ('utnista',),
'utnistede': ('utnistet',),
'utnistet': ('utnistet',),
'utnistete': ('utnistet',),
'utnistetere': ('utnistet',),
'utnistetest': ('utnistet',),
'utnisteteste': ('utnistet',),
'utnyttbar': ('utnyttbar',),
'utnyttbare': ('utnyttbar',),
'utnyttbarere': ('utnyttbar',),
'utnyttbarest': ('utnyttbar',),
'utnyttbareste': ('utnyttbar',),
'utnyttbart': ('utnyttbar',),
'utnytta': ('utnytte',),
'utnyttede': ('utnytte',),
'utnyttende': ('utnytte',),
'utnyttet': ('utnytte',),
'utnyttete': ('utnytte',),
'utopisk': ('utopisk',),
'utopiske': ('utopisk',),
'utopiskere': ('utopisk',),
'utopiskest': ('utopisk',),
'utopiskeste': ('utopisk',),
'utpakka': ('utpakka',),
'utpakkede': ('utpakket',),
'utpakket': ('utpakket',),
'utpakkete': ('utpakket',),
'utpakketere': ('utpakket',),
'utpakketest': ('utpakket',),
'utpakketeste': ('utpakket',),
'utpanta': ('utpante',),
'utpantede': ('utpante',),
'utpantende': ('utpante',),
'utpantet': ('utpante',),
'utpantete': ('utpante',),
'utparsellerende': ('utparsellere',),
'utparsellert': ('utparsellere',),
'utparsellerte': ('utparsellere',),
'utpekende': ('utpeke',),
'utpekt': ('utpeke',),
'utpekte': ('utpeke',),
'utpensla': ('utpensle',),
'utpenslede': ('utpensle',),
'utpenslende': ('utpensle',),
'utpenslet': ('utpensle',),
'utpenslete': ('utpensle',),
'utpint': ('utpint',),
'utpinte': ('utpint',),
'utpintere': ('utpint',),
'utpintest': ('utpint',),
'utpinteste': ('utpint',),
'utplanta': ('utplanta',),
'utplantede': ('utplantet',),
'utplantet': ('utplantet',),
'utplantete': ('utplantet',),
'utplantetere': ('utplantet',),
'utplantetest': ('utplantet',),
'utplanteteste': ('utplantet',),
'utplasserende': ('utplassere',),
'utplassert': ('utplassere',),
'utplasserte': ('utplassere',),
'utplukka': ('utplukka',),
'utplukkede': ('utplukket',),
'utplukket': ('utplukket',),
'utplukkete': ('utplukket',),
'utplukketere': ('utplukket',),
'utplukketest': ('utplukket',),
'utplukketeste': ('utplukket',),
'utplyndra': ('utplyndre',),
'utplyndrede': ('utplyndre',),
'utplyndrende': ('utplyndre',),
'utplyndret': ('utplyndre',),
'utplyndrete': ('utplyndre',),
'utporsjonerende': ('utporsjonere',),
'utporsjonert': ('utporsjonere',),
'utporsjonerte': ('utporsjonere',),
'utprega': ('utprega',),
'utprega': ('utprege',),
'utpregede': ('utprege',),
'utpregende': ('utprege',),
'utpreget': ('utprege',),
'utpregete': ('utprege',),
'utpregede': ('utpreget',),
'utpreget': ('utpreget',),
'utpregete': ('utpreget',),
'utpregetere': ('utpreget',),
'utpregetest': ('utpreget',),
'utpregeteste': ('utpreget',),
'utpressa': ('utpressa',),
'utpressede': ('utpresset',),
'utpresset': ('utpresset',),
'utpressete': ('utpresset',),
'utpressetere': ('utpresset',),
'utpressetest': ('utpresset',),
'utpresseteste': ('utpresset',),
'utprøvd': ('utprøve',),
'utprøvde': ('utprøve',),
'utprøvende': ('utprøve',),
'utpønsa': ('utpønse',),
'utpønsede': ('utpønse',),
'utpønsende': ('utpønse',),
'utpønset': ('utpønse',),
'utpønsete': ('utpønse',),
'utpønska': ('utpønske',),
'utpønskede': ('utpønske',),
'utpønskende': ('utpønske',),
'utpønsket': ('utpønske',),
'utpønskete': ('utpønske',),
'utraderende': ('utradere',),
'utradert': ('utradere',),
'utraderte': ('utradere',),
'utrangerende': ('utrangere',),
'utrangert': ('utrangere',),
'utrangerte': ('utrangere',),
'utrangla': ('utrangla',),
'utranglede': ('utranglet',),
'utranglet': ('utranglet',),
'utranglete': ('utranglet',),
'utrangletere': ('utranglet',),
'utrangletest': ('utranglet',),
'utrangleteste': ('utranglet',),
'utreda': ('utrede',),
'utredede': ('utrede',),
'utredende': ('utrede',),
'utredet': ('utrede',),
'utredete': ('utrede',),
'utregna': ('utregna',),
'utregna': ('utregna',),
'utregnede': ('utregnet',),
'utregnet': ('utregnet',),
'utregnete': ('utregnet',),
'utregnetere': ('utregnet',),
'utregnetest': ('utregnet',),
'utregneteste': ('utregnet',),
'utregnede': ('utregnet',),
'utregnet': ('utregnet',),
'utregnete': ('utregnet',),
'utregnetere': ('utregnet',),
'utregnetest': ('utregnet',),
'utregneteste': ('utregnet',),
'utreist': ('utreist',),
'utreiste': ('utreist',),
'utreistere': ('utreist',),
'utreistest': ('utreist',),
'utreisteste': ('utreist',),
'utrekna': ('utrekna',),
'utrekna': ('utrekna',),
'utreknede': ('utreknet',),
'utreknet': ('utreknet',),
'utreknete': ('utreknet',),
'utreknetere': ('utreknet',),
'utreknetest': ('utreknet',),
'utrekneteste': ('utreknet',),
'utreknede': ('utreknet',),
'utreknet': ('utreknet',),
'utreknete': ('utreknet',),
'utreknetere': ('utreknet',),
'utreknetest': ('utreknet',),
'utrekneteste': ('utreknet',),
'utrensa': ('utrensa',),
'utrensede': ('utrenset',),
'utrenset': ('utrenset',),
'utrensete': ('utrenset',),
'utrensetere': ('utrenset',),
'utrensetest': ('utrenset',),
'utrenseteste': ('utrenset',),
'utrenska': ('utrenska',),
'utrenskede': ('utrensket',),
'utrensket': ('utrensket',),
'utrenskete': ('utrensket',),
'utrensketere': ('utrensket',),
'utrensketest': ('utrensket',),
'utrensketeste': ('utrensket',),
'utrert': ('utrert',),
'utrerte': ('utrert',),
'utrertere': ('utrert',),
'utrertest': ('utrert',),
'utrerteste': ('utrert',),
'utretta': ('utrette',),
'utrettede': ('utrette',),
'utrettende': ('utrette',),
'utrettet': ('utrette',),
'utrettete': ('utrette',),
'utrettelig': ('utrettelig',),
'utrettelige': ('utrettelig',),
'utretteligere': ('utrettelig',),
'utretteligst': ('utrettelig',),
'utretteligste': ('utrettelig',),
'utrigga': ('utrigga',),
'utriggede': ('utrigget',),
'utrigget': ('utrigget',),
'utriggete': ('utrigget',),
'utriggetere': ('utrigget',),
'utriggetest': ('utrigget',),
'utriggeteste': ('utrigget',),
'utringa': ('utringe',),
'utringede': ('utringe',),
'utringende': ('utringe',),
'utringet': ('utringe',),
'utringete': ('utringe',),
'utrivelig': ('utrivelig',),
'utrivelige': ('utrivelig',),
'utriveligere': ('utrivelig',),
'utriveligst': ('utrivelig',),
'utriveligste': ('utrivelig',),
'utro': ('utro',),
'utrolig': ('utrolig',),
'utrolige': ('utrolig',),
'utroligere': ('utrolig',),
'utroligst': ('utrolig',),
'utroligste': ('utrolig',),
'utropende': ('utrope',),
'utropt': ('utrope',),
'utropte': ('utrope',),
'utru': ('utru',),
'utrue': ('utru',),
'utruere': ('utru',),
'utruest': ('utru',),
'utrueste': ('utru',),
'utrulig': ('utrulig',),
'utrulige': ('utrulig',),
'utruligere': ('utrulig',),
'utruligst': ('utrulig',),
'utruligste': ('utrulig',),
'utrusta': ('utruste',),
'utrustede': ('utruste',),
'utrustende': ('utruste',),
'utrustet': ('utruste',),
'utrustete': ('utruste',),
'utrydda': ('utrydde',),
'utryddede': ('utrydde',),
'utryddende': ('utrydde',),
'utryddet': ('utrydde',),
'utryddete': ('utrydde',),
'utrygg': ('utrygg',),
'utrygge': ('utrygg',),
'utryggere': ('utrygg',),
'utryggest': ('utrygg',),
'utryggeste': ('utrygg',),
'utrygt': ('utrygg',),
'utrøstelig': ('utrøstelig',),
'utrøstelige': ('utrøstelig',),
'utrøsteligere': ('utrøstelig',),
'utrøsteligst': ('utrøstelig',),
'utrøsteligste': ('utrøstelig',),
'utrøttelig': ('utrøttelig',),
'utrøttelige': ('utrøttelig',),
'utrøtteligere': ('utrøttelig',),
'utrøtteligst': ('utrøttelig',),
'utrøtteligste': ('utrøttelig',),
'utsatt': ('utsatt',),
'utsatte': ('utsatt',),
'utsattere': ('utsatt',),
'utsattest': ('utsatt',),
'utsatteste': ('utsatt',),
'utseende': ('utse',),
'utsett': ('utse',),
'utsette': ('utse',),
'utseende': ('utseende',),
'utsegla': ('utsegla',),
'utseglede': ('utseglet',),
'utseglet': ('utseglet',),
'utseglete': ('utseglet',),
'utsegletere': ('utseglet',),
'utsegletest': ('utseglet',),
'utsegleteste': ('utseglet',),
'utseilt': ('utseilt',),
'utseilte': ('utseilt',),
'utseiltere': ('utseilt',),
'utseiltest': ('utseilt',),
'utseilteste': ('utseilt',),
'utsendende': ('utsende',),
'utsendt': ('utsende',),
'utsendte': ('utsende',),
'utsendt': ('utsendt',),
'utsendte': ('utsendt',),
'utsendtere': ('utsendt',),
'utsendtest': ('utsendt',),
'utsendteste': ('utsendt',),
'utsatt': ('utsette',),
'utsatte': ('utsette',),
'utsettende': ('utsette',),
'utsagt': ('utsi',),
'utsagte': ('utsi',),
'utsiende': ('utsi',),
'utsjalta': ('utsjalta',),
'utsjaltede': ('utsjaltet',),
'utsjaltet': ('utsjaltet',),
'utsjaltete': ('utsjaltet',),
'utsjaltetere': ('utsjaltet',),
'utsjaltetest': ('utsjaltet',),
'utsjalteteste': ('utsjaltet',),
'utsjaska': ('utsjaska',),
'utsjaskede': ('utsjasket',),
'utsjasket': ('utsjasket',),
'utsjaskete': ('utsjasket',),
'utsjasketere': ('utsjasket',),
'utsjasketest': ('utsjasket',),
'utsjasketeste': ('utsjasket',),
'utskiftbar': ('utskiftbar',),
'utskiftbare': ('utskiftbar',),
'utskiftbarere': ('utskiftbar',),
'utskiftbarest': ('utskiftbar',),
'utskiftbareste': ('utskiftbar',),
'utskiftbart': ('utskiftbar',),
'utskiftelig': ('utskiftelig',),
'utskiftelige': ('utskiftelig',),
'utskifteligere': ('utskiftelig',),
'utskifteligst': ('utskiftelig',),
'utskifteligste': ('utskiftelig',),
'utskillende': ('utskille',),
'utskilt': ('utskille',),
'utskilte': ('utskille',),
'utskipa': ('utskipe',),
'utskipede': ('utskipe',),
'utskipende': ('utskipe',),
'utskipet': ('utskipe',),
'utskipete': ('utskipe',),
'utskjelt': ('utskjelt',),
'utskjelte': ('utskjelt',),
'utskjeltere': ('utskjelt',),
'utskjeltest': ('utskjelt',),
'utskjelteste': ('utskjelt',),
'utskjemt': ('utskjemt',),
'utskjemte': ('utskjemt',),
'utskjemtere': ('utskjemt',),
'utskjemtest': ('utskjemt',),
'utskjemteste': ('utskjemt',),
'utskreven': ('utskrive',),
'utskrevet': ('utskrive',),
'utskrevne': ('utskrive',),
'utskrivende': ('utskrive',),
'utskrådd': ('utskrådd',),
'utskrådde': ('utskrådd',),
'utskråddere': ('utskrådd',),
'utskråddest': ('utskrådd',),
'utskråddeste': ('utskrådd',),
'utskutt': ('utskutt',),
'utskutte': ('utskutt',),
'utskuttere': ('utskutt',),
'utskuttest': ('utskutt',),
'utskutteste': ('utskutt',),
'utskylt': ('utskylt',),
'utskylte': ('utskylt',),
'utskyltere': ('utskylt',),
'utskyltest': ('utskylt',),
'utskylteste': ('utskylt',),
'utskutt': ('utskyte',),
'utskutte': ('utskyte',),
'utskytende': ('utskyte',),
'utskåren': ('utskåren',),
'utskåret': ('utskåren',),
'utskårne': ('utskåren',),
'utskårnere': ('utskåren',),
'utskårnest': ('utskåren',),
'utskårneste': ('utskåren',),
'utskåret': ('utskåret',),
'utskårne': ('utskåret',),
'utskårnere': ('utskåret',),
'utskårnest': ('utskåret',),
'utskårneste': ('utskåret',),
'utslagsgivende': ('utslagsgivende',),
'utsletta': ('utslette',),
'utslettede': ('utslette',),
'utslettende': ('utslette',),
'utslettet': ('utslette',),
'utslettete': ('utslette',),
'utslitt': ('utslitt',),
'utslitte': ('utslitt',),
'utslittere': ('utslitt',),
'utslittest': ('utslitt',),
'utslitteste': ('utslitt',),
'utslokka': ('utslokka',),
'utslokkede': ('utslokket',),
'utslokket': ('utslokket',),
'utslokkete': ('utslokket',),
'utslokketere': ('utslokket',),
'utslokketest': ('utslokket',),
'utslokketeste': ('utslokket',),
'utslokt': ('utslokt',),
'utslokte': ('utslokt',),
'utsloktere': ('utslokt',),
'utsloktest': ('utslokt',),
'utslokteste': ('utslokt',),
'utslukka': ('utslukka',),
'utslukkede': ('utslukket',),
'utslukket': ('utslukket',),
'utslukkete': ('utslukket',),
'utslukketere': ('utslukket',),
'utslukketest': ('utslukket',),
'utslukketeste': ('utslukket',),
'utslukt': ('utslukt',),
'utslukte': ('utslukt',),
'utsluktere': ('utslukt',),
'utsluktest': ('utslukt',),
'utslukteste': ('utslukt',),
'utslupne': ('utsluppen',),
'utslupnere': ('utsluppen',),
'utslupnest': ('utsluppen',),
'utslupneste': ('utsluppen',),
'utsluppen': ('utsluppen',),
'utsluppet': ('utsluppen',),
'utslupne': ('utsluppet',),
'utslupnere': ('utsluppet',),
'utslupnest': ('utsluppet',),
'utslupneste': ('utsluppet',),
'utsluppet': ('utsluppet',),
'utslynga': ('utslynge',),
'utslyngede': ('utslynge',),
'utslyngende': ('utslynge',),
'utslynget': ('utslynge',),
'utslyngete': ('utslynge',),
'utslyngt': ('utslynge',),
'utslyngte': ('utslynge',),
'utslått': ('utslått',),
'utslåtte': ('utslått',),
'utslåttere': ('utslått',),
'utslåttest': ('utslått',),
'utslåtteste': ('utslått',),
'utslått': ('utslått',),
'utslåtte': ('utslått',),
'utslåttere': ('utslått',),
'utslåttest': ('utslått',),
'utslåtteste': ('utslått',),
'utsmykka': ('utsmykke',),
'utsmykkede': ('utsmykke',),
'utsmykkende': ('utsmykke',),
'utsmykket': ('utsmykke',),
'utsmykkete': ('utsmykke',),
'utsolgt': ('utsolgt',),
'utsolgte': ('utsolgt',),
'utsolgtere': ('utsolgt',),
'utsolgtest': ('utsolgt',),
'utsolgteste': ('utsolgt',),
'utsondra': ('utsondre',),
'utsondrede': ('utsondre',),
'utsondrende': ('utsondre',),
'utsondret': ('utsondre',),
'utsondrete': ('utsondre',),
'utsona': ('utsone',),
'utsonede': ('utsone',),
'utsonende': ('utsone',),
'utsonet': ('utsone',),
'utsonete': ('utsone',),
'utsont': ('utsone',),
'utsonte': ('utsone',),
'utsorterende': ('utsortere',),
'utsortert': ('utsortere',),
'utsorterte': ('utsortere',),
'utsovet': ('utsovet',),
'utsovne': ('utsovet',),
'utsovnere': ('utsovet',),
'utsovnest': ('utsovet',),
'utsovneste': ('utsovet',),
'utspara': ('utspare',),
'utsparende': ('utspare',),
'utspart': ('utspare',),
'utsparte': ('utspare',),
'utspedd': ('utspedd',),
'utspedde': ('utspedd',),
'utspeddere': ('utspedd',),
'utspeddest': ('utspedd',),
'utspeddeste': ('utspedd',),
'utspekulert': ('utspekulert',),
'utspekulerte': ('utspekulert',),
'utspekulertere': ('utspekulert',),
'utspekulertest': ('utspekulert',),
'utspekulerteste': ('utspekulert',),
'utspent': ('utspent',),
'utspente': ('utspent',),
'utspentere': ('utspent',),
'utspentest': ('utspent',),
'utspenteste': ('utspent',),
'utspillende': ('utspille',),
'utspilt': ('utspille',),
'utspilte': ('utspille',),
'utspilt': ('utspilt',),
'utspilte': ('utspilt',),
'utspiltere': ('utspilt',),
'utspiltest': ('utspilt',),
'utspilteste': ('utspilt',),
'utspinnende': ('utspinne',),
'utspunne': ('utspinne',),
'utspunnen': ('utspinne',),
'utspunnet': ('utspinne',),
'utspionerende': ('utspionere',),
'utspionert': ('utspionere',),
'utspionerte': ('utspionere',),
'utspjåka': ('utspjåka',),
'utspjåkede': ('utspjåket',),
'utspjåket': ('utspjåket',),
'utspjåkete': ('utspjåket',),
'utspjåketere': ('utspjåket',),
'utspjåketest': ('utspjåket',),
'utspjåketeste': ('utspjåket',),
'utspjåkt': ('utspjåkt',),
'utspjåkte': ('utspjåkt',),
'utspjåktere': ('utspjåkt',),
'utspjåktest': ('utspjåkt',),
'utspjåkteste': ('utspjåkt',),
'utspredd': ('utspre',),
'utspredde': ('utspre',),
'utspredt': ('utspre',),
'utspredte': ('utspre',),
'utspreende': ('utspre',),
'utspredd': ('utsprede',),
'utspredde': ('utsprede',),
'utspredende': ('utsprede',),
'utspredt': ('utsprede',),
'utspredte': ('utsprede',),
'utsprengt': ('utsprengt',),
'utsprengte': ('utsprengt',),
'utsprengtere': ('utsprengt',),
'utsprengtest': ('utsprengt',),
'utsprengteste': ('utsprengt',),
'utsprungen': ('utsprungen',),
'utsprunget': ('utsprungen',),
'utsprungne': ('utsprungen',),
'utsprungnere': ('utsprungen',),
'utsprungnest': ('utsprungen',),
'utsprungneste': ('utsprungen',),
'utsprunget': ('utsprunget',),
'utsprungne': ('utsprunget',),
'utsprungnere': ('utsprunget',),
'utsprungnest': ('utsprunget',),
'utsprungneste': ('utsprunget',),
'utspurt': ('utspørre',),
'utspurte': ('utspørre',),
'utspørrende': ('utspørre',),
'utstafferende': ('utstaffere',),
'utstaffert': ('utstaffere',),
'utstafferte': ('utstaffere',),
'utstasa': ('utstasa',),
'utstasede': ('utstaset',),
'utstaset': ('utstaset',),
'utstasete': ('utstaset',),
'utstasetere': ('utstaset',),
'utstasetest': ('utstaset',),
'utstaseteste': ('utstaset',),
'utstast': ('utstast',),
'utstaste': ('utstast',),
'utstastere': ('utstast',),
'utstastest': ('utstast',),
'utstasteste': ('utstast',),
'utstedende': ('utstede',),
'utstedt': ('utstede',),
'utstedte': ('utstede',),
'utstillende': ('utstille',),
'utstilt': ('utstille',),
'utstilte': ('utstille',),
'utstoppa': ('utstoppe',),
'utstoppede': ('utstoppe',),
'utstoppende': ('utstoppe',),
'utstoppet': ('utstoppe',),
'utstoppete': ('utstoppe',),
'utstrakt': ('utstrakt',),
'utstrakte': ('utstrakt',),
'utstraktere': ('utstrakt',),
'utstraktest': ('utstrakt',),
'utstrakteste': ('utstrakt',),
'utstrålende': ('utstråle',),
'utstrålt': ('utstråle',),
'utstrålte': ('utstråle',),
'utstudert': ('utstudert',),
'utstuderte': ('utstudert',),
'utstudertere': ('utstudert',),
'utstudertest': ('utstudert',),
'utstuderteste': ('utstudert',),
'utstukket': ('utstukket',),
'utstukne': ('utstukket',),
'utstuknere': ('utstukket',),
'utstuknest': ('utstukket',),
'utstukneste': ('utstukket',),
'utstykka': ('utstykke',),
'utstykkede': ('utstykke',),
'utstykkende': ('utstykke',),
'utstykket': ('utstykke',),
'utstykkete': ('utstykke',),
'utstykt': ('utstykke',),
'utstykte': ('utstykke',),
'utstyrende': ('utstyre',),
'utstyrt': ('utstyre',),
'utstyrte': ('utstyre',),
'utstående': ('utstå',),
'utstått': ('utstå',),
'utståtte': ('utstå',),
'utstående': ('utstående',),
'utstøtende': ('utstøte',),
'utstøtt': ('utstøte',),
'utstøtte': ('utstøte',),
'utstøytende': ('utstøyte',),
'utstøytt': ('utstøyte',),
'utstøytte': ('utstøyte',),
'utsuga': ('utsuge',),
'utsugd': ('utsuge',),
'utsugde': ('utsuge',),
'utsugede': ('utsuge',),
'utsugende': ('utsuge',),
'utsuget': ('utsuge',),
'utsugete': ('utsuge',),
'utsulta': ('utsulta',),
'utsultede': ('utsultet',),
'utsultet': ('utsultet',),
'utsultete': ('utsultet',),
'utsultetere': ('utsultet',),
'utsultetest': ('utsultet',),
'utsulteteste': ('utsultet',),
'utsvelta': ('utsvelta',),
'utsveltede': ('utsveltet',),
'utsveltet': ('utsveltet',),
'utsveltete': ('utsveltet',),
'utsveltetere': ('utsveltet',),
'utsveltetest': ('utsveltet',),
'utsvelteteste': ('utsveltet',),
'utsvett': ('utsvett',),
'utsvette': ('utsvett',),
'utsvettere': ('utsvett',),
'utsvettest': ('utsvett',),
'utsvetteste': ('utsvett',),
'utsvetta': ('utsvetta',),
'utsvettede': ('utsvettet',),
'utsvettet': ('utsvettet',),
'utsvettete': ('utsvettet',),
'utsvettetere': ('utsvettet',),
'utsvettetest': ('utsvettet',),
'utsvetteteste': ('utsvettet',),
'utsvevende': ('utsvevende',),
'utsvinga': ('utsvinga',),
'utsvingede': ('utsvinget',),
'utsvinget': ('utsvinget',),
'utsvingete': ('utsvinget',),
'utsvingetere': ('utsvinget',),
'utsvingetest': ('utsvinget',),
'utsvingeteste': ('utsvinget',),
'utsvingt': ('utsvingt',),
'utsvingte': ('utsvingt',),
'utsvingtere': ('utsvingt',),
'utsvingtest': ('utsvingt',),
'utsvingteste': ('utsvingt',),
'utsvømmende': ('utsvømmende',),
'utsydd': ('utsydd',),
'utsydde': ('utsydd',),
'utsyddere': ('utsydd',),
'utsyddest': ('utsydd',),
'utsyddeste': ('utsydd',),
'utsøkt': ('utsøkt',),
'utsøkte': ('utsøkt',),
'utsøktere': ('utsøkt',),
'utsøktest': ('utsøkt',),
'utsøkteste': ('utsøkt',),
'uttakende': ('utta',),
'uttatt': ('utta',),
'uttatte': ('utta',),
'uttala': ('uttale',),
'uttalende': ('uttale',),
'uttalt': ('uttale',),
'uttalte': ('uttale',),
'uttegna': ('uttegne',),
'uttegnede': ('uttegne',),
'uttegnende': ('uttegne',),
'uttegnet': ('uttegne',),
'uttegnete': ('uttegne',),
'uttenkt': ('uttenkt',),
'uttenkte': ('uttenkt',),
'uttenktere': ('uttenkt',),
'uttenktest': ('uttenkt',),
'uttenkteste': ('uttenkt',),
'uttilbeins': ('uttilbeins',),
'uttilbens': ('uttilbens',),
'uttjent': ('uttjent',),
'uttjente': ('uttjent',),
'uttjentere': ('uttjent',),
'uttjentest': ('uttjent',),
'uttjenteste': ('uttjent',),
'uttrukken': ('uttrukken',),
'uttrukket': ('uttrukken',),
'uttrukne': ('uttrukken',),
'uttruknere': ('uttrukken',),
'uttruknest': ('uttrukken',),
'uttrukneste': ('uttrukken',),
'uttrukket': ('uttrukket',),
'uttrukne': ('uttrukket',),
'uttruknere': ('uttrukket',),
'uttruknest': ('uttrukket',),
'uttrukneste': ('uttrukket',),
'uttrykkende': ('uttrykke',),
'uttrykt': ('uttrykke',),
'uttrykte': ('uttrykke',),
'uttrykkelig': ('uttrykkelig',),
'uttrykkelige': ('uttrykkelig',),
'uttrykkeligere': ('uttrykkelig',),
'uttrykkeligst': ('uttrykkelig',),
'uttrykkeligste': ('uttrykkelig',),
'uttrykksfull': ('uttrykksfull',),
'uttrykksfulle': ('uttrykksfull',),
'uttrykksfullere': ('uttrykksfull',),
'uttrykksfullest': ('uttrykksfull',),
'uttrykksfulleste': ('uttrykksfull',),
'uttrykksfullt': ('uttrykksfull',),
'uttrykkslaus': ('uttrykkslaus',),
'uttrykkslause': ('uttrykkslaus',),
'uttrykkslausere': ('uttrykkslaus',),
'uttrykkslausest': ('uttrykkslaus',),
'uttrykkslauseste': ('uttrykkslaus',),
'uttrykkslaust': ('uttrykkslaus',),
'uttrykksløs': ('uttrykksløs',),
'uttrykksløse': ('uttrykksløs',),
'uttrykksløsere': ('uttrykksløs',),
'uttrykksløsest': ('uttrykksløs',),
'uttrykksløseste': ('uttrykksløs',),
'uttrykksløst': ('uttrykksløs',),
'uttrådd': ('uttrådd',),
'uttrådde': ('uttrådd',),
'uttråddere': ('uttrådd',),
'uttråddest': ('uttrådd',),
'uttråddeste': ('uttrådd',),
'uttrådt': ('uttrådt',),
'uttrådte': ('uttrådt',),
'uttrådtere': ('uttrådt',),
'uttrådtest': ('uttrådt',),
'uttrådteste': ('uttrådt',),
'uttværa': ('uttvære',),
'uttværede': ('uttvære',),
'uttværende': ('uttvære',),
'uttværet': ('uttvære',),
'uttværete': ('uttvære',),
'uttyda': ('uttyde',),
'uttydd': ('uttyde',),
'uttydde': ('uttyde',),
'uttydede': ('uttyde',),
'uttydende': ('uttyde',),
'uttydet': ('uttyde',),
'uttydete': ('uttyde',),
'uttynna': ('uttynna',),
'uttynnede': ('uttynnet',),
'uttynnet': ('uttynnet',),
'uttynnete': ('uttynnet',),
'uttynnetere': ('uttynnet',),
'uttynnetest': ('uttynnet',),
'uttynneteste': ('uttynnet',),
'uttært': ('uttært',),
'uttærte': ('uttært',),
'uttærtere': ('uttært',),
'uttærtest': ('uttært',),
'uttærteste': ('uttært',),
'uttømmende': ('uttømmende',),
'uttømt': ('uttømt',),
'uttømte': ('uttømt',),
'uttømtere': ('uttømt',),
'uttømtest': ('uttømt',),
'uttømteste': ('uttømt',),
'uttørka': ('uttørka',),
'uttørkede': ('uttørket',),
'uttørket': ('uttørket',),
'uttørkete': ('uttørket',),
'uttørketere': ('uttørket',),
'uttørketest': ('uttørket',),
'uttørketeste': ('uttørket',),
'uttørra': ('uttørra',),
'uttørrede': ('uttørret',),
'uttørret': ('uttørret',),
'uttørrete': ('uttørret',),
'uttørretere': ('uttørret',),
'uttørretest': ('uttørret',),
'uttørreteste': ('uttørret',),
'utuktig': ('utuktig',),
'utuktige': ('utuktig',),
'utuktigere': ('utuktig',),
'utuktigst': ('utuktig',),
'utuktigste': ('utuktig',),
'utvalgt': ('utvalgt',),
'utvalgte': ('utvalgt',),
'utvalgtere': ('utvalgt',),
'utvalgtest': ('utvalgt',),
'utvalgteste': ('utvalgt',),
'utvandra': ('utvandre',),
'utvandrede': ('utvandre',),
'utvandrende': ('utvandre',),
'utvandret': ('utvandre',),
'utvandrete': ('utvandre',),
'utvanna': ('utvanna',),
'utvanna': ('utvanne',),
'utvannede': ('utvanne',),
'utvannende': ('utvanne',),
'utvannet': ('utvanne',),
'utvannete': ('utvanne',),
'utvannede': ('utvannet',),
'utvannet': ('utvannet',),
'utvannete': ('utvannet',),
'utvannetere': ('utvannet',),
'utvannetest': ('utvannet',),
'utvanneteste': ('utvannet',),
'utvaska': ('utvaska',),
'utvaskede': ('utvasket',),
'utvasket': ('utvasket',),
'utvaskete': ('utvasket',),
'utvasketere': ('utvasket',),
'utvasketest': ('utvasket',),
'utvasketeste': ('utvasket',),
'utvatna': ('utvatna',),
'utvatna': ('utvatne',),
'utvatnede': ('utvatne',),
'utvatnende': ('utvatne',),
'utvatnet': ('utvatne',),
'utvatnete': ('utvatne',),
'utvatnede': ('utvatnet',),
'utvatnet': ('utvatnet',),
'utvatnete': ('utvatnet',),
'utvatnetere': ('utvatnet',),
'utvatnetest': ('utvatnet',),
'utvatneteste': ('utvatnet',),
'utveksla': ('utveksle',),
'utvekslede': ('utveksle',),
'utvekslende': ('utveksle',),
'utvekslet': ('utveksle',),
'utvekslete': ('utveksle',),
'utvendig': ('utvendig',),
'utvendige': ('utvendig',),
'utvendigere': ('utvendig',),
'utvendigst': ('utvendig',),
'utvendigste': ('utvendig',),
'utvetydig': ('utvetydig',),
'utvetydige': ('utvetydig',),
'utvetydigere': ('utvetydig',),
'utvetydigst': ('utvetydig',),
'utvetydigste': ('utvetydig',),
'utvida': ('utvide',),
'utvidede': ('utvide',),
'utvidende': ('utvide',),
'utvidet': ('utvide',),
'utvidete': ('utvide',),
'utvikla': ('utvikle',),
'utviklede': ('utvikle',),
'utviklende': ('utvikle',),
'utviklet': ('utvikle',),
'utviklete': ('utvikle',),
'utviklingsdyktig': ('utviklingsdyktig',),
'utviklingsdyktige': ('utviklingsdyktig',),
'utviklingsdyktigere': ('utviklingsdyktig',),
'utviklingsdyktigst': ('utviklingsdyktig',),
'utviklingsdyktigste': ('utviklingsdyktig',),
'utviklingsfremmende': ('utviklingsfremmende',),
'utviklingshemma': ('utviklingshemma',),
'utviklingshemmede': ('utviklingshemmet',),
'utviklingshemmet': ('utviklingshemmet',),
'utviklingshemmete': ('utviklingshemmet',),
'utviklingshemmetere': ('utviklingshemmet',),
'utviklingshemmetest': ('utviklingshemmet',),
'utviklingshemmeteste': ('utviklingshemmet',),
'utvilsom': ('utvilsom',),
'utvilsomme': ('utvilsom',),
'utvilsommere': ('utvilsom',),
'utvilsommest': ('utvilsom',),
'utvilsommeste': ('utvilsom',),
'utvilsomt': ('utvilsom',),
'utvinna': ('utvinna',),
'utvinnende': ('utvinne',),
'utvunne': ('utvinne',),
'utvunnen': ('utvinne',),
'utvunnet': ('utvinne',),
'utvinnede': ('utvinnet',),
'utvinnet': ('utvinnet',),
'utvinnete': ('utvinnet',),
'utvinnetere': ('utvinnet',),
'utvinnetest': ('utvinnet',),
'utvinneteste': ('utvinnet',),
'utvirka': ('utvirke',),
'utvirkede': ('utvirke',),
'utvirkende': ('utvirke',),
'utvirket': ('utvirke',),
'utvirkete': ('utvirke',),
'utvisende': ('utvise',),
'utvist': ('utvise',),
'utviste': ('utvise',),
'utviska': ('utviska',),
'utviskede': ('utvisket',),
'utvisket': ('utvisket',),
'utviskete': ('utvisket',),
'utvisketere': ('utvisket',),
'utvisketest': ('utvisket',),
'utvisketeste': ('utvisket',),
'utvokst': ('utvokst',),
'utvokste': ('utvokst',),
'utvokstere': ('utvokst',),
'utvokstest': ('utvokst',),
'utvoksteste': ('utvokst',),
'utvortes': ('utvortes',),
'utvungen': ('utvungen',),
'utvungent': ('utvungen',),
'utvungne': ('utvungen',),
'utvungnere': ('utvungen',),
'utvungnest': ('utvungen',),
'utvungneste': ('utvungen',),
'utydelig': ('utydelig',),
'utydelige': ('utydelig',),
'utydeligere': ('utydelig',),
'utydeligst': ('utydelig',),
'utydeligste': ('utydelig',),
'utålelig': ('utålelig',),
'utålelige': ('utålelig',),
'utåleligere': ('utålelig',),
'utåleligst': ('utålelig',),
'utåleligste': ('utålelig',),
'utålmodig': ('utålmodig',),
'utålmodige': ('utålmodig',),
'utålmodigere': ('utålmodig',),
'utålmodigst': ('utålmodig',),
'utålmodigste': ('utålmodig',),
'utånda': ('utånde',),
'utåndede': ('utånde',),
'utåndende': ('utånde',),
'utåndet': ('utånde',),
'utåndete': ('utånde',),
'utømmelig': ('utømmelig',),
'utømmelige': ('utømmelig',),
'utømmeligere': ('utømmelig',),
'utømmeligst': ('utømmelig',),
'utømmeligste': ('utømmelig',),
'utørst': ('utørst',),
'utørste': ('utørst',),
'utørstere': ('utørst',),
'utørstest': ('utørst',),
'utørsteste': ('utørst',),
'utøsende': ('utøse',),
'utøst': ('utøse',),
'utøste': ('utøse',),
'utøva': ('utøve',),
'utøvd': ('utøve',),
'utøvde': ('utøve',),
'utøvede': ('utøve',),
'utøvende': ('utøve',),
'utøvet': ('utøve',),
'utøvete': ('utøve',),
'utøvende': ('utøvende',),
'utøyla': ('utøyla',),
'utøylede': ('utøylet',),
'utøylet': ('utøylet',),
'utøylete': ('utøylet',),
'utøyletere': ('utøylet',),
'utøyletest': ('utøylet',),
'utøyleteste': ('utøylet',),
'uunngåelig': ('uunngåelig',),
'uunngåelige': ('uunngåelig',),
'uunngåeligere': ('uunngåelig',),
'uunngåeligst': ('uunngåelig',),
'uunngåeligste': ('uunngåelig',),
'uunnværlig': ('uunnværlig',),
'uunnværlige': ('uunnværlig',),
'uunnværligere': ('uunnværlig',),
'uunnværligst': ('uunnværlig',),
'uunnværligste': ('uunnværlig',),
'uutgrunnelig': ('uutgrunnelig',),
'uutgrunnelige': ('uutgrunnelig',),
'uutgrunneligere': ('uutgrunnelig',),
'uutgrunneligst': ('uutgrunnelig',),
'uutgrunneligste': ('uutgrunnelig',),
'uutholdelig': ('uutholdelig',),
'uutholdelige': ('uutholdelig',),
'uutholdeligere': ('uutholdelig',),
'uutholdeligst': ('uutholdelig',),
'uutholdeligste': ('uutholdelig',),
'uutryddelig': ('uutryddelig',),
'uutryddelige': ('uutryddelig',),
'uutryddeligere': ('uutryddelig',),
'uutryddeligst': ('uutryddelig',),
'uutryddeligste': ('uutryddelig',),
'uutsigelig': ('uutsigelig',),
'uutsigelige': ('uutsigelig',),
'uutsigeligere': ('uutsigelig',),
'uutsigeligst': ('uutsigelig',),
'uutsigeligste': ('uutsigelig',),
'uutslettelig': ('uutslettelig',),
'uutslettelige': ('uutslettelig',),
'uutsletteligere': ('uutslettelig',),
'uutsletteligst': ('uutslettelig',),
'uutsletteligste': ('uutslettelig',),
'uutslokkelig': ('uutslokkelig',),
'uutslokkelige': ('uutslokkelig',),
'uutslokkeligere': ('uutslokkelig',),
'uutslokkeligst': ('uutslokkelig',),
'uutslokkeligste': ('uutslokkelig',),
'uutslukkelig': ('uutslukkelig',),
'uutslukkelige': ('uutslukkelig',),
'uutslukkeligere': ('uutslukkelig',),
'uutslukkeligst': ('uutslukkelig',),
'uutslukkeligste': ('uutslukkelig',),
'uutsprungen': ('uutsprungen',),
'uutsprunget': ('uutsprungen',),
'uutsprungne': ('uutsprungen',),
'uutsprungnere': ('uutsprungen',),
'uutsprungnest': ('uutsprungen',),
'uutsprungneste': ('uutsprungen',),
'uutsprunget': ('uutsprunget',),
'uutsprungne': ('uutsprunget',),
'uutsprungnere': ('uutsprunget',),
'uutsprungnest': ('uutsprunget',),
'uutsprungneste': ('uutsprunget',),
'uuttalt': ('uuttalt',),
'uuttalte': ('uuttalt',),
'uuttaltere': ('uuttalt',),
'uuttaltest': ('uuttalt',),
'uuttalteste': ('uuttalt',),
'uuttømmelig': ('uuttømmelig',),
'uuttømmelige': ('uuttømmelig',),
'uuttømmeligere': ('uuttømmelig',),
'uuttømmeligst': ('uuttømmelig',),
'uuttømmeligste': ('uuttømmelig',),
'uutvikla': ('uutvikla',),
'uutviklede': ('uutviklet',),
'uutviklet': ('uutviklet',),
'uutviklete': ('uutviklet',),
'uutvikletere': ('uutviklet',),
'uutvikletest': ('uutviklet',),
'uutvikleteste': ('uutviklet',),
'uvanlig': ('uvanlig',),
'uvanlige': ('uvanlig',),
'uvanligere': ('uvanlig',),
'uvanligst': ('uvanlig',),
'uvanligste': ('uvanlig',),
'uvant': ('uvant',),
'uvante': ('uvant',),
'uvantere': ('uvant',),
'uvantest': ('uvant',),
'uvanteste': ('uvant',),
'uvaska': ('uvaska',),
'uvaskede': ('uvasket',),
'uvasket': ('uvasket',),
'uvaskete': ('uvasket',),
'uvasketere': ('uvasket',),
'uvasketest': ('uvasket',),
'uvasketeste': ('uvasket',),
'uvederheftig': ('uvederheftig',),
'uvederheftige': ('uvederheftig',),
'uvederheftigere': ('uvederheftig',),
'uvederheftigst': ('uvederheftig',),
'uvederheftigste': ('uvederheftig',),
'uvedkommende': ('uvedkommende',),
'uvegsam': ('uvegsam',),
'uvegsamme': ('uvegsam',),
'uvegsammere': ('uvegsam',),
'uvegsamst': ('uvegsam',),
'uvegsamste': ('uvegsam',),
'uvegsamt': ('uvegsam',),
'uveisom': ('uveisom',),
'uveisomme': ('uveisom',),
'uveisommere': ('uveisom',),
'uveisomst': ('uveisom',),
'uveisomste': ('uveisom',),
'uveisomt': ('uveisom',),
'uvel': ('uvel',),
'uvelkommen': ('uvelkommen',),
'uvelkomment': ('uvelkommen',),
'uvelkomne': ('uvelkommen',),
'uvelkomnere': ('uvelkommen',),
'uvelkomnest': ('uvelkommen',),
'uvelkomneste': ('uvelkommen',),
'uvennlig': ('uvennlig',),
'uvennlige': ('uvennlig',),
'uvennligere': ('uvennlig',),
'uvennligst': ('uvennlig',),
'uvennligste': ('uvennlig',),
'uvennskapelig': ('uvennskapelig',),
'uvennskapelige': ('uvennskapelig',),
'uvennskapeligere': ('uvennskapelig',),
'uvennskapeligst': ('uvennskapelig',),
'uvennskapeligste': ('uvennskapelig',),
'uventa': ('uventa',),
'uventede': ('uventet',),
'uventet': ('uventet',),
'uventete': ('uventet',),
'uventetere': ('uventet',),
'uventetest': ('uventet',),
'uventeteste': ('uventet',),
'uverdig': ('uverdig',),
'uverdige': ('uverdig',),
'uverdigere': ('uverdig',),
'uverdigst': ('uverdig',),
'uverdigste': ('uverdig',),
'uvesentlig': ('uvesentlig',),
'uvesentlige': ('uvesentlig',),
'uvesentligere': ('uvesentlig',),
'uvesentligst': ('uvesentlig',),
'uvesentligste': ('uvesentlig',),
'uvettig': ('uvettig',),
'uvettige': ('uvettig',),
'uvettigere': ('uvettig',),
'uvettigst': ('uvettig',),
'uvettigste': ('uvettig',),
'uviktig': ('uviktig',),
'uviktige': ('uviktig',),
'uviktigere': ('uviktig',),
'uviktigst': ('uviktig',),
'uviktigste': ('uviktig',),
'uvilkårlig': ('uvilkårlig',),
'uvilkårlige': ('uvilkårlig',),
'uvilkårligere': ('uvilkårlig',),
'uvilkårligst': ('uvilkårlig',),
'uvilkårligste': ('uvilkårlig',),
'uvillig': ('uvillig',),
'uvillige': ('uvillig',),
'uvilligere': ('uvillig',),
'uvilligst': ('uvillig',),
'uvilligste': ('uvillig',),
'uvillig': ('uvillig',),
'uvillige': ('uvillig',),
'uvilligere': ('uvillig',),
'uvilligst': ('uvillig',),
'uvilligste': ('uvillig',),
'uvirkelig': ('uvirkelig',),
'uvirkelige': ('uvirkelig',),
'uvirkeligere': ('uvirkelig',),
'uvirkeligst': ('uvirkelig',),
'uvirkeligste': ('uvirkelig',),
'uvirksom': ('uvirksom',),
'uvirksomme': ('uvirksom',),
'uvirksommere': ('uvirksom',),
'uvirksomst': ('uvirksom',),
'uvirksomste': ('uvirksom',),
'uvirksomt': ('uvirksom',),
'uvislig': ('uvislig',),
'uvislige': ('uvislig',),
'uvisligere': ('uvislig',),
'uvisligst': ('uvislig',),
'uvisligste': ('uvislig',),
'uvisnelig': ('uvisnelig',),
'uvisnelige': ('uvisnelig',),
'uvisneligere': ('uvisnelig',),
'uvisneligst': ('uvisnelig',),
'uvisneligste': ('uvisnelig',),
'uviss': ('uviss',),
'uvisse': ('uviss',),
'uvissere': ('uviss',),
'uvissest': ('uviss',),
'uvisseste': ('uviss',),
'uvisst': ('uviss',),
'uvitende': ('uvitende',),
'uvitenskapelig': ('uvitenskapelig',),
'uvitenskapelige': ('uvitenskapelig',),
'uvitenskapeligere': ('uvitenskapelig',),
'uvitenskapeligst': ('uvitenskapelig',),
'uvitenskapeligste': ('uvitenskapelig',),
'uvitskapelig': ('uvitskapelig',),
'uvitskapelige': ('uvitskapelig',),
'uvitskapeligere': ('uvitskapelig',),
'uvitskapeligst': ('uvitskapelig',),
'uvitskapeligste': ('uvitskapelig',),
'uvittig': ('uvittig',),
'uvittige': ('uvittig',),
'uvittigere': ('uvittig',),
'uvittigst': ('uvittig',),
'uvittigste': ('uvittig',),
'uvoksen': ('uvoksen',),
'uvoksent': ('uvoksen',),
'uvoksne': ('uvoksen',),
'uvoksnere': ('uvoksen',),
'uvoksnest': ('uvoksen',),
'uvoksneste': ('uvoksen',),
'uvular': ('uvular',),
'uvulare': ('uvular',),
'uvularere': ('uvular',),
'uvularest': ('uvular',),
'uvulareste': ('uvular',),
'uvulart': ('uvular',),
'uvurderlig': ('uvurderlig',),
'uvurderlige': ('uvurderlig',),
'uvurderligere': ('uvurderlig',),
'uvurderligst': ('uvurderlig',),
'uvurderligste': ('uvurderlig',),
'uvæpna': ('uvæpna',),
'uvæpnede': ('uvæpnet',),
'uvæpnet': ('uvæpnet',),
'uvæpnete': ('uvæpnet',),
'uvæpnetere': ('uvæpnet',),
'uvæpnetest': ('uvæpnet',),
'uvæpneteste': ('uvæpnet',),
'uvørden': ('uvørden',),
'uvørdent': ('uvørden',),
'uvørdne': ('uvørden',),
'uvørdnere': ('uvørden',),
'uvørdnest': ('uvørden',),
'uvørdneste': ('uvørden',),
'uvørdslig': ('uvørdslig',),
'uvørdslige': ('uvørdslig',),
'uvørdsligere': ('uvørdslig',),
'uvørdsligst': ('uvørdslig',),
'uvørdsligste': ('uvørdslig',),
'uvøren': ('uvøren',),
'uvørent': ('uvøren',),
'uvørne': ('uvøren',),
'uvørnere': ('uvøren',),
'uvørnest': ('uvøren',),
'uvørneste': ('uvøren',),
'uvørslig': ('uvørslig',),
'uvørslige': ('uvørslig',),
'uvørsligere': ('uvørslig',),
'uvørsligst': ('uvørslig',),
'uvørsligste': ('uvørslig',),
'uåpna': ('uåpna',),
'uåpnede': ('uåpnet',),
'uåpnet': ('uåpnet',),
'uåpnete': ('uåpnet',),
'uåpnetere': ('uåpnet',),
'uåpnetest': ('uåpnet',),
'uåpneteste': ('uåpnet',),
'uærbødig': ('uærbødig',),
'uærbødige': ('uærbødig',),
'uærbødigere': ('uærbødig',),
'uærbødigst': ('uærbødig',),
'uærbødigste': ('uærbødig',),
'uærlig': ('uærlig',),
'uærlige': ('uærlig',),
'uærligere': ('uærlig',),
'uærligst': ('uærlig',),
'uærligste': ('uærlig',),
'uøkonomisk': ('uøkonomisk',),
'uøkonomiske': ('uøkonomisk',),
'uøkonomiskere': ('uøkonomisk',),
'uøkonomiskest': ('uøkonomisk',),
'uøkonomiskeste': ('uøkonomisk',),
'uønska': ('uønska',),
'uønskede': ('uønsket',),
'uønsket': ('uønsket',),
'uønskete': ('uønsket',),
'uønsketere': ('uønsket',),
'uønsketest': ('uønsket',),
'uønsketeste': ('uønsket',),
'uønskt': ('uønskt',),
'uønskte': ('uønskt',),
'uønsktere': ('uønskt',),
'uønsktest': ('uønskt',),
'uønskteste': ('uønskt',),
'uøvd': ('uøvd',),
'uøvde': ('uøvd',),
'uøvdere': ('uøvd',),
'uøvdest': ('uøvd',),
'uøvdeste': ('uøvd',),
'uøvede': ('uøvet',),
'uøvet': ('uøvet',),
'uøvete': ('uøvet',),
'uøvetere': ('uøvet',),
'uøvetest': ('uøvet',),
'uøveteste': ('uøvet',),
'vadd': ('va',),
'vadde': ('va',),
'vaende': ('va',),
'vabba': ('vabbe',),
'vabbede': ('vabbe',),
'vabbende': ('vabbe',),
'vabbet': ('vabbe',),
'vabbete': ('vabbe',),
'vablet': ('vablet',),
'vablete': ('vablet',),
'vabletere': ('vablet',),
'vabletest': ('vablet',),
'vableteste': ('vablet',),
'vablete': ('vablete',),
'vada': ('vade',),
'vadd': ('vade',),
'vadde': ('vade',),
'vadede': ('vade',),
'vadende': ('vade',),
'vadet': ('vade',),
'vadete': ('vade',),
'vadra': ('vadre',),
'vadrede': ('vadre',),
'vadrende': ('vadre',),
'vadret': ('vadre',),
'vadrete': ('vadre',),
'vafla': ('vafle',),
'vaflede': ('vafle',),
'vaflende': ('vafle',),
'vaflet': ('vafle',),
'vaflete': ('vafle',),
'vaflet': ('vaflet',),
'vaflete': ('vaflet',),
'vafletere': ('vaflet',),
'vafletest': ('vaflet',),
'vafleteste': ('vaflet',),
'vaflete': ('vaflete',),
'vag': ('vag',),
'vage': ('vag',),
'vagere': ('vag',),
'vagest': ('vag',),
'vageste': ('vag',),
'vagt': ('vag',),
'vagabonderende': ('vagabondere',),
'vagabondert': ('vagabondere',),
'vagabonderte': ('vagabondere',),
'vagga': ('vagge',),
'vaggede': ('vagge',),
'vaggende': ('vagge',),
'vagget': ('vagge',),
'vaggete': ('vagge',),
'vaginal': ('vaginal',),
'vaginale': ('vaginal',),
'vaginalere': ('vaginal',),
'vaginalest': ('vaginal',),
'vaginaleste': ('vaginal',),
'vaginalt': ('vaginal',),
'vagla': ('vagle',),
'vaglede': ('vagle',),
'vaglende': ('vagle',),
'vaglet': ('vagle',),
'vaglete': ('vagle',),
'vaia': ('vaie',),
'vaiede': ('vaie',),
'vaiende': ('vaie',),
'vaiet': ('vaie',),
'vaiete': ('vaie',),
'vak': ('vak',),
'vake': ('vak',),
'vakere': ('vak',),
'vakest': ('vak',),
'vakeste': ('vak',),
'vakt': ('vak',),
'vakant': ('vakant',),
'vakante': ('vakant',),
'vakantere': ('vakant',),
'vakantest': ('vakant',),
'vakanteste': ('vakant',),
'vaka': ('vake',),
'vakede': ('vake',),
'vakende': ('vake',),
'vaket': ('vake',),
'vakete': ('vake',),
'vakt': ('vake',),
'vakte': ('vake',),
'vaka': ('vake',),
'vakede': ('vake',),
'vakende': ('vake',),
'vaket': ('vake',),
'vakete': ('vake',),
'vakt': ('vake',),
'vakte': ('vake',),
'vaken': ('vaken',),
'vakent': ('vaken',),
'vakne': ('vaken',),
'vaknere': ('vaken',),
'vaknest': ('vaken',),
'vakneste': ('vaken',),
'vakker': ('vakker',),
'vakkert': ('vakker',),
'vakre': ('vakker',),
'vakrere': ('vakker',),
'vakrest': ('vakker',),
'vakreste': ('vakker',),
'vakla': ('vakle',),
'vaklede': ('vakle',),
'vaklende': ('vakle',),
'vaklet': ('vakle',),
'vaklete': ('vakle',),
'vaklevoren': ('vaklevoren',),
'vaklevorent': ('vaklevoren',),
'vaklevorne': ('vaklevoren',),
'vaklevornere': ('vaklevoren',),
'vaklevornest': ('vaklevoren',),
'vaklevorneste': ('vaklevoren',),
'vakna': ('vakne',),
'vaknede': ('vakne',),
'vaknende': ('vakne',),
'vaknet': ('vakne',),
'vaknete': ('vakne',),
'vaksinerende': ('vaksinere',),
'vaksinert': ('vaksinere',),
'vaksinerte': ('vaksinere',),
'vakt': ('vakt',),
'vakte': ('vakt',),
'vaktere': ('vakt',),
'vaktest': ('vakt',),
'vakteste': ('vakt',),
'vakta': ('vakte',),
'vaktede': ('vakte',),
'vaktende': ('vakte',),
'vaktet': ('vakte',),
'vaktete': ('vakte',),
'vakthavende': ('vakthavende',),
'vaktsom': ('vaktsom',),
'vaktsomme': ('vaktsom',),
'vaktsommere': ('vaktsom',),
'vaktsomst': ('vaktsom',),
'vaktsomste': ('vaktsom',),
'vaktsomt': ('vaktsom',),
'vakuumpakka': ('vakuumpakke',),
'vakuumpakkede': ('vakuumpakke',),
'vakuumpakkende': ('vakuumpakke',),
'vakuumpakket': ('vakuumpakke',),
'vakuumpakkete': ('vakuumpakke',),
'valanderende': ('valandere',),
'valandert': ('valandere',),
'valanderte': ('valandere',),
'valen': ('valen',),
'valent': ('valen',),
'valne': ('valen',),
'valnere': ('valen',),
'valnest': ('valen',),
'valneste': ('valen',),
'valent': ('valent',),
'valente': ('valent',),
'valentere': ('valent',),
'valentest': ('valent',),
'valenteste': ('valent',),
'valfarta': ('valfarte',),
'valfartede': ('valfarte',),
'valfartende': ('valfarte',),
'valfartet': ('valfarte',),
'valfartete': ('valfarte',),
'valgbar': ('valgbar',),
'valgbare': ('valgbar',),
'valgbarere': ('valgbar',),
'valgbarest': ('valgbar',),
'valgbareste': ('valgbar',),
'valgbart': ('valgbar',),
'valgfør': ('valgfør',),
'valgføre': ('valgfør',),
'valgførere': ('valgfør',),
'valgførest': ('valgfør',),
'valgføreste': ('valgfør',),
'valgført': ('valgfør',),
'valgteknisk': ('valgteknisk',),
'valgtekniske': ('valgteknisk',),
'valgtekniskere': ('valgteknisk',),
'valgtekniskest': ('valgteknisk',),
'valgtekniskeste': ('valgteknisk',),
'valhendt': ('valhendt',),
'valhendte': ('valhendt',),
'valhendtere': ('valhendt',),
'valhendtest': ('valhendt',),
'valhendteste': ('valhendt',),
'valid': ('valid',),
'valide': ('valid',),
'validere': ('valid',),
'validest': ('valid',),
'valideste': ('valid',),
'validerende': ('validere',),
'validert': ('validere',),
'validerte': ('validere',),
'valka': ('valke',),
'valkede': ('valke',),
'valkende': ('valke',),
'valket': ('valke',),
'valkete': ('valke',),
'valket': ('valket',),
'valkete': ('valket',),
'valketere': ('valket',),
'valketest': ('valket',),
'valketeste': ('valket',),
'valkete': ('valkete',),
'vallonsk': ('vallonsk',),
'vallonske': ('vallonsk',),
'vallonskere': ('vallonsk',),
'vallonskest': ('vallonsk',),
'vallonskeste': ('vallonsk',),
'valna': ('valne',),
'valnede': ('valne',),
'valnende': ('valne',),
'valnet': ('valne',),
'valnete': ('valne',),
'valpa': ('valpe',),
'valpede': ('valpe',),
'valpende': ('valpe',),
'valpet': ('valpe',),
'valpete': ('valpe',),
'valpet': ('valpet',),
'valpete': ('valpet',),
'valpetere': ('valpet',),
'valpetest': ('valpet',),
'valpeteste': ('valpet',),
'valpete': ('valpete',),
'valsa': ('valse',),
'valsede': ('valse',),
'valsende': ('valse',),
'valset': ('valse',),
'valsete': ('valse',),
'valsa': ('valse',),
'valsede': ('valse',),
'valsende': ('valse',),
'valset': ('valse',),
'valsete': ('valse',),
'valta': ('valte',),
'valtede': ('valte',),
'valtende': ('valte',),
'valtet': ('valte',),
'valtete': ('valte',),
'valutarisk': ('valutarisk',),
'valutariske': ('valutarisk',),
'valutariskere': ('valutarisk',),
'valutariskest': ('valutarisk',),
'valutariskeste': ('valutarisk',),
'valuterende': ('valutere',),
'valutert': ('valutere',),
'valuterte': ('valutere',),
'valverende': ('valvere',),
'valvert': ('valvere',),
'valverte': ('valvere',),
'vamle': ('vammel',),
'vamlere': ('vammel',),
'vamlest': ('vammel',),
'vamleste': ('vammel',),
'vammel': ('vammel',),
'vammelt': ('vammel',),
'vammelsøt': ('vammelsøt',),
'vammelsøte': ('vammelsøt',),
'vammelsøtere': ('vammelsøt',),
'vammelsøtest': ('vammelsøt',),
'vammelsøteste': ('vammelsøt',),
'vammelsøtt': ('vammelsøt',),
'vampet': ('vampet',),
'vampete': ('vampet',),
'vampetere': ('vampet',),
'vampetest': ('vampet',),
'vampeteste': ('vampet',),
'vampete': ('vampete',),
'vanakta': ('vanakte',),
'vanaktede': ('vanakte',),
'vanaktende': ('vanakte',),
'vanaktet': ('vanakte',),
'vanaktete': ('vanakte',),
'vanarta': ('vanarta',),
'vanartede': ('vanartet',),
'vanartet': ('vanartet',),
'vanartete': ('vanartet',),
'vanartetere': ('vanartet',),
'vanartetest': ('vanartet',),
'vanarteteste': ('vanartet',),
'vand': ('vand',),
'vande': ('vand',),
'vandere': ('vand',),
'vandest': ('vand',),
'vandeste': ('vand',),
'vandt': ('vand',),
'vandaliserende': ('vandalisere',),
'vandalisert': ('vandalisere',),
'vandaliserte': ('vandalisere',),
'vandalsk': ('vandalsk',),
'vandalske': ('vandalsk',),
'vandalskere': ('vandalsk',),
'vandalskest': ('vandalsk',),
'vandalskeste': ('vandalsk',),
'vanda': ('vande',),
'vandede': ('vande',),
'vandende': ('vande',),
'vandet': ('vande',),
'vandete': ('vande',),
'vandig': ('vandig',),
'vandige': ('vandig',),
'vandigere': ('vandig',),
'vandigst': ('vandig',),
'vandigste': ('vandig',),
'vandla': ('vandle',),
'vandlede': ('vandle',),
'vandlende': ('vandle',),
'vandlet': ('vandle',),
'vandlete': ('vandle',),
'vandra': ('vandre',),
'vandrede': ('vandre',),
'vandrende': ('vandre',),
'vandret': ('vandre',),
'vandrete': ('vandre',),
'vandrevet': ('vandrevet',),
'vandrevne': ('vandrevet',),
'vandrevnere': ('vandrevet',),
'vandrevnest': ('vandrevet',),
'vandrevneste': ('vandrevet',),
'vanebundet': ('vanebundet',),
'vanebundne': ('vanebundet',),
'vanebundnere': ('vanebundet',),
'vanebundnest': ('vanebundet',),
'vanebundneste': ('vanebundet',),
'vanedannende': ('vanedannende',),
'vanekristen': ('vanekristen',),
'vanekristent': ('vanekristen',),
'vanekristne': ('vanekristen',),
'vanekristnere': ('vanekristen',),
'vanekristnest': ('vanekristen',),
'vanekristneste': ('vanekristen',),
'vanemessig': ('vanemessig',),
'vanemessige': ('vanemessig',),
'vanemessigere': ('vanemessig',),
'vanemessigst': ('vanemessig',),
'vanemessigste': ('vanemessig',),
'vanfør': ('vanfør',),
'vanføre': ('vanfør',),
'vanførere': ('vanfør',),
'vanførest': ('vanfør',),
'vanføreste': ('vanfør',),
'vanført': ('vanfør',),
'vanhedra': ('vanhedre',),
'vanhedrede': ('vanhedre',),
'vanhedrende': ('vanhedre',),
'vanhedret': ('vanhedre',),
'vanhedrete': ('vanhedre',),
'vanhellig': ('vanhellig',),
'vanhellige': ('vanhellig',),
'vanhelligere': ('vanhellig',),
'vanhelligst': ('vanhellig',),
'vanhelligste': ('vanhellig',),
'vanhelliga': ('vanhellige',),
'vanhelligede': ('vanhellige',),
'vanhelligende': ('vanhellige',),
'vanhelliget': ('vanhellige',),
'vanhelligete': ('vanhellige',),
'vanhjulpen': ('vanhjulpen',),
'vanhjulpent': ('vanhjulpen',),
'vanhjulpne': ('vanhjulpen',),
'vanhjulpnere': ('vanhjulpen',),
'vanhjulpnest': ('vanhjulpen',),
'vanhjulpneste': ('vanhjulpen',),
'vankanta': ('vankanta',),
'vankantede': ('vankantet',),
'vankantet': ('vankantet',),
'vankantete': ('vankantet',),
'vankantetere': ('vankantet',),
'vankantetest': ('vankantet',),
'vankanteteste': ('vankantet',),
'vanka': ('vanke',),
'vankede': ('vanke',),
'vankende': ('vanke',),
'vanket': ('vanke',),
'vankete': ('vanke',),
'vankelmodig': ('vankelmodig',),
'vankelmodige': ('vankelmodig',),
'vankelmodigere': ('vankelmodig',),
'vankelmodigst': ('vankelmodig',),
'vankelmodigste': ('vankelmodig',),
'vankundig': ('vankundig',),
'vankundige': ('vankundig',),
'vankundigere': ('vankundig',),
'vankundigst': ('vankundig',),
'vankundigste': ('vankundig',),
'vanlig': ('vanlig',),
'vanlige': ('vanlig',),
'vanligere': ('vanlig',),
'vanligst': ('vanlig',),
'vanligste': ('vanlig',),
'vanmektig': ('vanmektig',),
'vanmektige': ('vanmektig',),
'vanmektigere': ('vanmektig',),
'vanmektigst': ('vanmektig',),
'vanmektigste': ('vanmektig',),
'vannaktig': ('vannaktig',),
'vannaktige': ('vannaktig',),
'vannaktigere': ('vannaktig',),
'vannaktigst': ('vannaktig',),
'vannaktigste': ('vannaktig',),
'vannavkjølt': ('vannavkjølt',),
'vannavkjølte': ('vannavkjølt',),
'vannavkjøltere': ('vannavkjølt',),
'vannavkjøltest': ('vannavkjølt',),
'vannavkjølteste': ('vannavkjølt',),
'vannavstøtende': ('vannavstøtende',),
'vannavstøytende': ('vannavstøytende',),
'vannbeisa': ('vannbeise',),
'vannbeisede': ('vannbeise',),
'vannbeisende': ('vannbeise',),
'vannbeiset': ('vannbeise',),
'vannbeisete': ('vannbeise',),
'vannbeist': ('vannbeise',),
'vannbeiste': ('vannbeise',),
'vannblå': ('vannblå',),
'vannblåe': ('vannblå',),
'vannblåere': ('vannblå',),
'vannblåest': ('vannblå',),
'vannblåeste': ('vannblå',),
'vannblått': ('vannblå',),
'vanndrivende': ('vanndrivende',),
'vanna': ('vanne',),
'vannede': ('vanne',),
'vannende': ('vanne',),
'vannet': ('vanne',),
'vannete': ('vanne',),
'vannfast': ('vannfast',),
'vannfaste': ('vannfast',),
'vannfastere': ('vannfast',),
'vannfastest': ('vannfast',),
'vannfasteste': ('vannfast',),
'vannførende': ('vannførende',),
'vannholdig': ('vannholdig',),
'vannholdige': ('vannholdig',),
'vannholdigere': ('vannholdig',),
'vannholdigst': ('vannholdig',),
'vannholdigste': ('vannholdig',),
'vannkjemma': ('vannkjemme',),
'vannkjemmede': ('vannkjemme',),
'vannkjemmende': ('vannkjemme',),
'vannkjemmet': ('vannkjemme',),
'vannkjemmete': ('vannkjemme',),
'vannkjemt': ('vannkjemme',),
'vannkjemte': ('vannkjemme',),
'vannkjølt': ('vannkjølt',),
'vannkjølte': ('vannkjølt',),
'vannkjøltere': ('vannkjølt',),
'vannkjøltest': ('vannkjølt',),
'vannkjølteste': ('vannkjølt',),
'vannklar': ('vannklar',),
'vannklare': ('vannklar',),
'vannklarere': ('vannklar',),
'vannklarest': ('vannklar',),
'vannklareste': ('vannklar',),
'vannklart': ('vannklar',),
'vannløselig': ('vannløselig',),
'vannløselige': ('vannløselig',),
'vannløseligere': ('vannløselig',),
'vannløseligst': ('vannløselig',),
'vannløseligste': ('vannløselig',),
'vannløyselig': ('vannløyselig',),
'vannløyselige': ('vannløyselig',),
'vannløyseligere': ('vannløyselig',),
'vannløyseligst': ('vannløyselig',),
'vannløyseligste': ('vannløyselig',),
'vannmetta': ('vannmetta',),
'vannmettede': ('vannmettet',),
'vannmettet': ('vannmettet',),
'vannmettete': ('vannmettet',),
'vannmettetere': ('vannmettet',),
'vannmettetest': ('vannmettet',),
'vannmetteteste': ('vannmettet',),
'vannrett': ('vannrett',),
'vannrette': ('vannrett',),
'vannrettere': ('vannrett',),
'vannrettest': ('vannrett',),
'vannretteste': ('vannrett',),
'vannrik': ('vannrik',),
'vannrike': ('vannrik',),
'vannrikere': ('vannrik',),
'vannrikest': ('vannrik',),
'vannrikeste': ('vannrik',),
'vannrikt': ('vannrik',),
'vannskada': ('vannskada',),
'vannskadd': ('vannskadd',),
'vannskadde': ('vannskadd',),
'vannskaddere': ('vannskadd',),
'vannskaddest': ('vannskadd',),
'vannskaddeste': ('vannskadd',),
'vannskadede': ('vannskadet',),
'vannskadet': ('vannskadet',),
'vannskadete': ('vannskadet',),
'vannskadetere': ('vannskadet',),
'vannskadetest': ('vannskadet',),
'vannskadeteste': ('vannskadet',),
'vannslipende': ('vannslipe',),
'vannslipt': ('vannslipe',),
'vannslipte': ('vannslipe',),
'vannsyk': ('vannsyk',),
'vannsyke': ('vannsyk',),
'vannsykere': ('vannsyk',),
'vannsykest': ('vannsyk',),
'vannsykeste': ('vannsyk',),
'vannsykt': ('vannsyk',),
'vanntett': ('vanntett',),
'vanntette': ('vanntett',),
'vanntettere': ('vanntett',),
'vanntettest': ('vanntett',),
'vanntetteste': ('vanntett',),
'vanrøkta': ('vanrøkte',),
'vanrøktede': ('vanrøkte',),
'vanrøktende': ('vanrøkte',),
'vanrøktet': ('vanrøkte',),
'vanrøktete': ('vanrøkte',),
'vansira': ('vansire',),
'vansirede': ('vansire',),
'vansirende': ('vansire',),
'vansiret': ('vansire',),
'vansirete': ('vansire',),
'vansirt': ('vansire',),
'vansirte': ('vansire',),
'vanskapt': ('vanskapt',),
'vanskapte': ('vanskapt',),
'vanskaptere': ('vanskapt',),
'vanskaptest': ('vanskapt',),
'vanskapteste': ('vanskapt',),
'vanskelig': ('vanskelig',),
'vanskelige': ('vanskelig',),
'vanskeligere': ('vanskelig',),
'vanskeligst': ('vanskelig',),
'vanskeligste': ('vanskelig',),
'vanskeliggjort': ('vanskeliggjøre',),
'vanskeliggjorte': ('vanskeliggjøre',),
'vanskeliggjørende': ('vanskeliggjøre',),
'vanskeligstilt': ('vanskeligstilt',),
'vanskeligstilte': ('vanskeligstilt',),
'vanskeligstiltere': ('vanskeligstilt',),
'vanskeligstiltest': ('vanskeligstilt',),
'vanskeligstilteste': ('vanskeligstilt',),
'vanskjøtta': ('vanskjøtte',),
'vanskjøttede': ('vanskjøtte',),
'vanskjøttende': ('vanskjøtte',),
'vanskjøttet': ('vanskjøtte',),
'vanskjøttete': ('vanskjøtte',),
'vanslekta': ('vanslekte',),
'vanslektede': ('vanslekte',),
'vanslektende': ('vanslekte',),
'vanslektet': ('vanslekte',),
'vanslektete': ('vanslekte',),
'vansmekta': ('vansmekte',),
'vansmektede': ('vansmekte',),
'vansmektende': ('vansmekte',),
'vansmektet': ('vansmekte',),
'vansmektete': ('vansmekte',),
'vanstellende': ('vanstelle',),
'vanstelt': ('vanstelle',),
'vanstelte': ('vanstelle',),
'vanstelt': ('vanstelt',),
'vanstelte': ('vanstelt',),
'vansteltere': ('vanstelt',),
'vansteltest': ('vanstelt',),
'vanstelteste': ('vanstelt',),
'vanstyrende': ('vanstyre',),
'vanstyrt': ('vanstyre',),
'vanstyrte': ('vanstyre',),
'vant': ('vant',),
'vante': ('vant',),
'vantere': ('vant',),
'vantest': ('vant',),
'vanteste': ('vant',),
'vanta': ('vante',),
'vantede': ('vante',),
'vantende': ('vante',),
'vantet': ('vante',),
'vantete': ('vante',),
'vantreven': ('vantreven',),
'vantrevent': ('vantreven',),
'vantrevne': ('vantreven',),
'vantrevnere': ('vantreven',),
'vantrevnest': ('vantreven',),
'vantrevneste': ('vantreven',),
'vantro': ('vantro',),
'vantroende': ('vantroende',),
'vantru': ('vantru',),
'vantrue': ('vantru',),
'vantruere': ('vantru',),
'vantruest': ('vantru',),
'vantrueste': ('vantru',),
'vanuatisk': ('vanuatisk',),
'vanuatiske': ('vanuatisk',),
'vanuatiskere': ('vanuatisk',),
'vanuatiskest': ('vanuatisk',),
'vanuatiskeste': ('vanuatisk',),
'vanvittig': ('vanvittig',),
'vanvittige': ('vanvittig',),
'vanvittigere': ('vanvittig',),
'vanvittigst': ('vanvittig',),
'vanvittigste': ('vanvittig',),
'vanvørdende': ('vanvørde',),
'vanvørdt': ('vanvørde',),
'vanvørdte': ('vanvørde',),
'vanvørden': ('vanvørden',),
'vanvørdent': ('vanvørden',),
'vanvørdne': ('vanvørden',),
'vanvørdnere': ('vanvørden',),
'vanvørdnest': ('vanvørden',),
'vanvørdneste': ('vanvørden',),
'vanvørende': ('vanvøre',),
'vanvørt': ('vanvøre',),
'vanvørte': ('vanvøre',),
'vanvøren': ('vanvøren',),
'vanvørent': ('vanvøren',),
'vanvørne': ('vanvøren',),
'vanvørnere': ('vanvøren',),
'vanvørnest': ('vanvøren',),
'vanvørneste': ('vanvøren',),
'vanæra': ('vanære',),
'vanærede': ('vanære',),
'vanærende': ('vanære',),
'vanæret': ('vanære',),
'vanærete': ('vanære',),
'vanært': ('vanære',),
'vanærte': ('vanære',),
'var': ('var',),
'vare': ('var',),
'varere': ('var',),
'varest': ('var',),
'vareste': ('var',),
'vart': ('var',),
'varda': ('varde',),
'vardede': ('varde',),
'vardende': ('varde',),
'vardet': ('varde',),
'vardete': ('varde',),
'varende': ('vare',),
'vart': ('vare',),
'varte': ('vare',),
'varende': ('vare',),
'vart': ('vare',),
'varte': ('vare',),
'varetakende': ('vareta',),
'varetatt': ('vareta',),
'varetatte': ('vareta',),
'varetektsfengsla': ('varetektsfengsle',),
'varetektsfengslede': ('varetektsfengsle',),
'varetektsfengslende': ('varetektsfengsle',),
'varetektsfengslet': ('varetektsfengsle',),
'varetektsfengslete': ('varetektsfengsle',),
'variabel': ('variabel',),
'variabelt': ('variabel',),
'variable': ('variabel',),
'variablere': ('variabel',),
'variablest': ('variabel',),
'variableste': ('variabel',),
'varierende': ('variere',),
'variert': ('variere',),
'varierte': ('variere',),
'varig': ('varig',),
'varige': ('varig',),
'varigere': ('varig',),
'varigst': ('varig',),
'varigste': ('varig',),
'varlig': ('varlig',),
'varlige': ('varlig',),
'varligere': ('varlig',),
'varligst': ('varlig',),
'varligste': ('varlig',),
'varm': ('varm',),
'varme': ('varm',),
'varmere': ('varm',),
'varmest': ('varm',),
'varmeste': ('varm',),
'varmt': ('varm',),
'varmblodig': ('varmblodig',),
'varmblodige': ('varmblodig',),
'varmblodigere': ('varmblodig',),
'varmblodigst': ('varmblodig',),
'varmblodigste': ('varmblodig',),
'varma': ('varme',),
'varmede': ('varme',),
'varmende': ('varme',),
'varmet': ('varme',),
'varmete': ('varme',),
'varmefast': ('varmefast',),
'varmefaste': ('varmefast',),
'varmefastere': ('varmefast',),
'varmefastest': ('varmefast',),
'varmefasteste': ('varmefast',),
'varmeisolerende': ('varmeisolerende',),
'varmekjær': ('varmekjær',),
'varmekjære': ('varmekjær',),
'varmekjærere': ('varmekjær',),
'varmekjærest': ('varmekjær',),
'varmekjæreste': ('varmekjær',),
'varmekjært': ('varmekjær',),
'varmhamra': ('varmhamre',),
'varmhamrede': ('varmhamre',),
'varmhamrende': ('varmhamre',),
'varmhamret': ('varmhamre',),
'varmhamrete': ('varmhamre',),
'varmherda': ('varmherde',),
'varmherdede': ('varmherde',),
'varmherdende': ('varmherde',),
'varmherdet': ('varmherde',),
'varmherdete': ('varmherde',),
'varmheva': ('varmheve',),
'varmhevd': ('varmheve',),
'varmhevde': ('varmheve',),
'varmhevede': ('varmheve',),
'varmhevende': ('varmheve',),
'varmhevet': ('varmheve',),
'varmhevete': ('varmheve',),
'varmhjerta': ('varmhjerta',),
'varmhjertede': ('varmhjertet',),
'varmhjertet': ('varmhjertet',),
'varmhjertete': ('varmhjertet',),
'varmhjertetere': ('varmhjertet',),
'varmhjertetest': ('varmhjertet',),
'varmhjerteteste': ('varmhjertet',),
'varmrøyka': ('varmrøyke',),
'varmrøykede': ('varmrøyke',),
'varmrøykende': ('varmrøyke',),
'varmrøyket': ('varmrøyke',),
'varmrøykete': ('varmrøyke',),
'varmrøykt': ('varmrøyke',),
'varmrøykte': ('varmrøyke',),
'varpa': ('varpe',),
'varpede': ('varpe',),
'varpende': ('varpe',),
'varpet': ('varpe',),
'varpete': ('varpe',),
'varsam': ('varsam',),
'varsamme': ('varsam',),
'varsammere': ('varsam',),
'varsamst': ('varsam',),
'varsamste': ('varsam',),
'varsamt': ('varsam',),
'varskudd': ('varsku',),
'varskudde': ('varsku',),
'varskuende': ('varsku',),
'varsla': ('varsle',),
'varslede': ('varsle',),
'varslende': ('varsle',),
'varslet': ('varsle',),
'varslete': ('varsle',),
'varsom': ('varsom',),
'varsomme': ('varsom',),
'varsommere': ('varsom',),
'varsomst': ('varsom',),
'varsomste': ('varsom',),
'varsomt': ('varsom',),
'varta': ('varte',),
'vartede': ('varte',),
'vartende': ('varte',),
'vartet': ('varte',),
'vartete': ('varte',),
'vasa': ('vase',),
'vasede': ('vase',),
'vasende': ('vase',),
'vaset': ('vase',),
'vasete': ('vase',),
'vast': ('vase',),
'vaste': ('vase',),
'vaseforma': ('vaseforma',),
'vaseformede': ('vaseformet',),
'vaseformet': ('vaseformet',),
'vaseformete': ('vaseformet',),
'vaseformetere': ('vaseformet',),
'vaseformetest': ('vaseformet',),
'vaseformeteste': ('vaseformet',),
'vaset': ('vaset',),
'vasete': ('vaset',),
'vasetere': ('vaset',),
'vasetest': ('vaset',),
'vaseteste': ('vaset',),
'vasete': ('vasete',),
'vaskbar': ('vaskbar',),
'vaskbare': ('vaskbar',),
'vaskbarere': ('vaskbar',),
'vaskbarest': ('vaskbar',),
'vaskbareste': ('vaskbar',),
'vaskbart': ('vaskbar',),
'vaska': ('vaske',),
'vaskede': ('vaske',),
'vaskende': ('vaske',),
'vasket': ('vaske',),
'vaskete': ('vaske',),
'vasomotorisk': ('vasomotorisk',),
'vasomotoriske': ('vasomotorisk',),
'vasomotoriskere': ('vasomotorisk',),
'vasomotoriskest': ('vasomotorisk',),
'vasomotoriskeste': ('vasomotorisk',),
'vass-sjuk': ('vass-sjuk',),
'vass-sjuke': ('vass-sjuk',),
'vass-sjukere': ('vass-sjuk',),
'vass-sjukest': ('vass-sjuk',),
'vass-sjukeste': ('vass-sjuk',),
'vass-sjukt': ('vass-sjuk',),
'vass-skada': ('vass-skada',),
'vass-skadd': ('vass-skadd',),
'vass-skadde': ('vass-skadd',),
'vass-skaddere': ('vass-skadd',),
'vass-skaddest': ('vass-skadd',),
'vass-skaddeste': ('vass-skadd',),
'vass-skadede': ('vass-skadet',),
'vass-skadet': ('vass-skadet',),
'vass-skadete': ('vass-skadet',),
'vass-skadetere': ('vass-skadet',),
'vass-skadetest': ('vass-skadet',),
'vass-skadeteste': ('vass-skadet',),
'vass-slipende': ('vass-slipe',),
'vass-slipt': ('vass-slipe',),
'vass-slipte': ('vass-slipe',),
'vassaktig': ('vassaktig',),
'vassaktige': ('vassaktig',),
'vassaktigere': ('vassaktig',),
'vassaktigst': ('vassaktig',),
'vassaktigste': ('vassaktig',),
'vassavkjølt': ('vassavkjølt',),
'vassavkjølte': ('vassavkjølt',),
'vassavkjøltere': ('vassavkjølt',),
'vassavkjøltest': ('vassavkjølt',),
'vassavkjølteste': ('vassavkjølt',),
'vassavstøtende': ('vassavstøtende',),
'vassavstøytende': ('vassavstøytende',),
'vassbeisa': ('vassbeise',),
'vassbeisede': ('vassbeise',),
'vassbeisende': ('vassbeise',),
'vassbeiset': ('vassbeise',),
'vassbeisete': ('vassbeise',),
'vassbeist': ('vassbeise',),
'vassbeiste': ('vassbeise',),
'vassblå': ('vassblå',),
'vassblåe': ('vassblå',),
'vassblåere': ('vassblå',),
'vassblåest': ('vassblå',),
'vassblåeste': ('vassblå',),
'vassblått': ('vassblå',),
'vassdrivende': ('vassdrivende',),
'vassa': ('vasse',),
'vassede': ('vasse',),
'vassende': ('vasse',),
'vasset': ('vasse',),
'vassete': ('vasse',),
'vasne': ('vassen',),
'vasnere': ('vassen',),
'vasnest': ('vassen',),
'vasneste': ('vassen',),
'vassen': ('vassen',),
'vassent': ('vassen',),
'vassfast': ('vassfast',),
'vassfaste': ('vassfast',),
'vassfastere': ('vassfast',),
'vassfastest': ('vassfast',),
'vassfasteste': ('vassfast',),
'vassførende': ('vassførende',),
'vassholdig': ('vassholdig',),
'vassholdige': ('vassholdig',),
'vassholdigere': ('vassholdig',),
'vassholdigst': ('vassholdig',),
'vassholdigste': ('vassholdig',),
'vassjuk': ('vassjuk',),
'vassjuke': ('vassjuk',),
'vassjukere': ('vassjuk',),
'vassjukest': ('vassjuk',),
'vassjukeste': ('vassjuk',),
'vassjukt': ('vassjuk',),
'vasskada': ('vasskada',),
'vasskadd': ('vasskadd',),
'vasskadde': ('vasskadd',),
'vasskaddere': ('vasskadd',),
'vasskaddest': ('vasskadd',),
'vasskaddeste': ('vasskadd',),
'vasskadede': ('vasskadet',),
'vasskadet': ('vasskadet',),
'vasskadete': ('vasskadet',),
'vasskadetere': ('vasskadet',),
'vasskadetest': ('vasskadet',),
'vasskadeteste': ('vasskadet',),
'vasskjemma': ('vasskjemme',),
'vasskjemmede': ('vasskjemme',),
'vasskjemmende': ('vasskjemme',),
'vasskjemmet': ('vasskjemme',),
'vasskjemmete': ('vasskjemme',),
'vasskjemt': ('vasskjemme',),
'vasskjemte': ('vasskjemme',),
'vasskjølt': ('vasskjølt',),
'vasskjølte': ('vasskjølt',),
'vasskjøltere': ('vasskjølt',),
'vasskjøltest': ('vasskjølt',),
'vasskjølteste': ('vasskjølt',),
'vassklar': ('vassklar',),
'vassklare': ('vassklar',),
'vassklarere': ('vassklar',),
'vassklarest': ('vassklar',),
'vassklareste': ('vassklar',),
'vassklart': ('vassklar',),
'vasslipende': ('vasslipe',),
'vasslipt': ('vasslipe',),
'vasslipte': ('vasslipe',),
'vassløselig': ('vassløselig',),
'vassløselige': ('vassløselig',),
'vassløseligere': ('vassløselig',),
'vassløseligst': ('vassløselig',),
'vassløseligste': ('vassløselig',),
'vassløyselig': ('vassløyselig',),
'vassløyselige': ('vassløyselig',),
'vassløyseligere': ('vassløyselig',),
'vassløyseligst': ('vassløyselig',),
'vassløyseligste': ('vassløyselig',),
'vassmetta': ('vassmetta',),
'vassmettede': ('vassmettet',),
'vassmettet': ('vassmettet',),
'vassmettete': ('vassmettet',),
'vassmettetere': ('vassmettet',),
'vassmettetest': ('vassmettet',),
'vassmetteteste': ('vassmettet',),
'vassrett': ('vassrett',),
'vassrette': ('vassrett',),
'vassrettere': ('vassrett',),
'vassrettest': ('vassrett',),
'vassretteste': ('vassrett',),
'vassrik': ('vassrik',),
'vassrike': ('vassrik',),
'vassrikere': ('vassrik',),
'vassrikest': ('vassrik',),
'vassrikeste': ('vassrik',),
'vassrikt': ('vassrik',),
'vasstett': ('vasstett',),
'vasstette': ('vasstett',),
'vasstettere': ('vasstett',),
'vasstettest': ('vasstett',),
'vasstetteste': ('vasstett',),
'vasstrukken': ('vasstrukken',),
'vasstrukkent': ('vasstrukken',),
'vasstrukne': ('vasstrukken',),
'vasstruknere': ('vasstrukken',),
'vasstruknest': ('vasstrukken',),
'vasstrukneste': ('vasstrukken',),
'vatikansk': ('vatikansk',),
'vatikanske': ('vatikansk',),
'vatikanskere': ('vatikansk',),
'vatikanskest': ('vatikansk',),
'vatikanskeste': ('vatikansk',),
'vatna': ('vatne',),
'vatnede': ('vatne',),
'vatnende': ('vatne',),
'vatnet': ('vatne',),
'vatnete': ('vatne',),
'vatra': ('vatre',),
'vatrede': ('vatre',),
'vatrende': ('vatre',),
'vatret': ('vatre',),
'vatrete': ('vatre',),
'vatra': ('vatre',),
'vatrede': ('vatre',),
'vatrende': ('vatre',),
'vatret': ('vatre',),
'vatrete': ('vatre',),
'vatterende': ('vattere',),
'vattert': ('vattere',),
'vatterte': ('vattere',),
'vavra': ('vavre',),
'vavrede': ('vavre',),
'vavrende': ('vavre',),
'vavret': ('vavre',),
'vavrete': ('vavre',),
'vedblitt': ('vedbli',),
'vedblitte': ('vedbli',),
'vedblivende': ('vedbli',),
'vedblivende': ('vedblivende',),
'vedda': ('vedde',),
'veddede': ('vedde',),
'veddende': ('vedde',),
'veddet': ('vedde',),
'veddete': ('vedde',),
'vederheftig': ('vederheftig',),
'vederheftige': ('vederheftig',),
'vederheftigere': ('vederheftig',),
'vederheftigst': ('vederheftig',),
'vederheftigste': ('vederheftig',),
'vederkvega': ('vederkvege',),
'vederkvegede': ('vederkvege',),
'vederkvegende': ('vederkvege',),
'vederkveget': ('vederkvege',),
'vederkvegete': ('vederkvege',),
'vederkvegende': ('vederkvegende',),
'vederlagsfri': ('vederlagsfri',),
'vederlagsfrie': ('vederlagsfri',),
'vederlagsfriere': ('vederlagsfri',),
'vederlagsfriest': ('vederlagsfri',),
'vederlagsfrieste': ('vederlagsfri',),
'vederlagsfritt': ('vederlagsfri',),
'vederstyggelig': ('vederstyggelig',),
'vederstyggelige': ('vederstyggelig',),
'vederstyggeligere': ('vederstyggelig',),
'vederstyggeligst': ('vederstyggelig',),
'vederstyggeligste': ('vederstyggelig',),
'vedgående': ('vedgå',),
'vedgått': ('vedgå',),
'vedgåtte': ('vedgå',),
'vedholdende': ('vedholdende',),
'vedisk': ('vedisk',),
'vediske': ('vedisk',),
'vediskere': ('vedisk',),
'vediskest': ('vedisk',),
'vediskeste': ('vedisk',),
'vedkjennende': ('vedkjenne',),
'vedkjent': ('vedkjenne',),
'vedkjente': ('vedkjenne',),
'vedkommen': ('vedkomme',),
'vedkommende': ('vedkomme',),
'vedkommet': ('vedkomme',),
'vedkomne': ('vedkomme',),
'vedkommende': ('vedkommende',),
'vedlagt': ('vedlegge',),
'vedlagte': ('vedlegge',),
'vedleggende': ('vedlegge',),
'vedlikeholdende': ('vedlikeholde',),
'vedlikeholdt': ('vedlikeholde',),
'vedlikeholdte': ('vedlikeholde',),
'vedlikeholdsfri': ('vedlikeholdsfri',),
'vedlikeholdsfrie': ('vedlikeholdsfri',),
'vedlikeholdsfriere': ('vedlikeholdsfri',),
'vedlikeholdsfriest': ('vedlikeholdsfri',),
'vedlikeholdsfrieste': ('vedlikeholdsfri',),
'vedlikeholdsfritt': ('vedlikeholdsfri',),
'vedrørende': ('vedrøre',),
'vedrørt': ('vedrøre',),
'vedrørte': ('vedrøre',),
'vedstående': ('vedstå',),
'vedstått': ('vedstå',),
'vedståtte': ('vedstå',),
'vedtakende': ('vedta',),
'vedtatt': ('vedta',),
'vedtatte': ('vedta',),
'vedtaksfør': ('vedtaksfør',),
'vedtaksføre': ('vedtaksfør',),
'vedtaksførere': ('vedtaksfør',),
'vedtaksførest': ('vedtaksfør',),
'vedtaksføreste': ('vedtaksfør',),
'vedtaksført': ('vedtaksfør',),
'vedtektsfesta': ('vedtektsfeste',),
'vedtektsfestede': ('vedtektsfeste',),
'vedtektsfestende': ('vedtektsfeste',),
'vedtektsfestet': ('vedtektsfeste',),
'vedtektsfestete': ('vedtektsfeste',),
'vedtektsmessig': ('vedtektsmessig',),
'vedtektsmessige': ('vedtektsmessig',),
'vedtektsmessigere': ('vedtektsmessig',),
'vedtektsmessigst': ('vedtektsmessig',),
'vedtektsmessigste': ('vedtektsmessig',),
'vedtektsstridig': ('vedtektsstridig',),
'vedtektsstridige': ('vedtektsstridig',),
'vedtektsstridigere': ('vedtektsstridig',),
'vedtektsstridigst': ('vedtektsstridig',),
'vedtektsstridigste': ('vedtektsstridig',),
'vedvarende': ('vedvare',),
'vedvart': ('vedvare',),
'vedvarte': ('vedvare',),
'vefta': ('vefte',),
'veftede': ('vefte',),
'veftende': ('vefte',),
'veftet': ('vefte',),
'veftete': ('vefte',),
'vegd': ('vege',),
'vegde': ('vege',),
'vegende': ('vege',),
'vegelsinna': ('vegelsinna',),
'vegelsinnede': ('vegelsinnet',),
'vegelsinnet': ('vegelsinnet',),
'vegelsinnete': ('vegelsinnet',),
'vegelsinnetere': ('vegelsinnet',),
'vegelsinnetest': ('vegelsinnet',),
'vegelsinneteste': ('vegelsinnet',),
'vegetabilsk': ('vegetabilsk',),
'vegetabilske': ('vegetabilsk',),
'vegetabilskere': ('vegetabilsk',),
'vegetabilskest': ('vegetabilsk',),
'vegetabilskeste': ('vegetabilsk',),
'vegetariansk': ('vegetariansk',),
'vegetarianske': ('vegetariansk',),
'vegetarianskere': ('vegetariansk',),
'vegetarianskest': ('vegetariansk',),
'vegetarianskeste': ('vegetariansk',),
'vegetarisk': ('vegetarisk',),
'vegetariske': ('vegetarisk',),
'vegetariskere': ('vegetarisk',),
'vegetariskest': ('vegetarisk',),
'vegetariskeste': ('vegetarisk',),
'vegetativ': ('vegetativ',),
'vegetative': ('vegetativ',),
'vegetativere': ('vegetativ',),
'vegetativest': ('vegetativ',),
'vegetativeste': ('vegetativ',),
'vegetativt': ('vegetativ',),
'vegeterende': ('vegetere',),
'vegetert': ('vegetere',),
'vegeterte': ('vegetere',),
'vegfarende': ('vegfarende',),
'veggfast': ('veggfast',),
'veggfaste': ('veggfast',),
'veggfastere': ('veggfast',),
'veggfastest': ('veggfast',),
'veggfasteste': ('veggfast',),
'veglaus': ('veglaus',),
'veglause': ('veglaus',),
'veglausere': ('veglaus',),
'veglausest': ('veglaus',),
'veglauseste': ('veglaus',),
'veglaust': ('veglaus',),
'vegløs': ('vegløs',),
'vegløse': ('vegløs',),
'vegløsere': ('vegløs',),
'vegløsest': ('vegløs',),
'vegløseste': ('vegløs',),
'vegløst': ('vegløs',),
'vegra': ('vegre',),
'vegrede': ('vegre',),
'vegrende': ('vegre',),
'vegret': ('vegre',),
'vegrete': ('vegre',),
'vegvill': ('vegvill',),
'vegville': ('vegvill',),
'vegvillere': ('vegvill',),
'vegvillest': ('vegvill',),
'vegvilleste': ('vegvill',),
'vegvilt': ('vegvill',),
'veibar': ('veibar',),
'veibare': ('veibar',),
'veibarere': ('veibar',),
'veibarest': ('veibar',),
'veibareste': ('veibar',),
'veibart': ('veibar',),
'veida': ('veide',),
'veidd': ('veide',),
'veidde': ('veide',),
'veidede': ('veide',),
'veidende': ('veide',),
'veidet': ('veide',),
'veidete': ('veide',),
'veid': ('veie',),
'veide': ('veie',),
'veiede': ('veie',),
'veiende': ('veie',),
'veiet': ('veie',),
'veiete': ('veie',),
'veielig': ('veielig',),
'veielige': ('veielig',),
'veieligere': ('veielig',),
'veieligst': ('veielig',),
'veieligste': ('veielig',),
'veifarende': ('veifarende',),
'veik': ('veik',),
'veike': ('veik',),
'veikere': ('veik',),
'veikest': ('veik',),
'veikeste': ('veik',),
'veikt': ('veik',),
'veikhelsa': ('veikhelsa',),
'veikhelsede': ('veikhelset',),
'veikhelset': ('veikhelset',),
'veikhelsete': ('veikhelset',),
'veikhelsetere': ('veikhelset',),
'veikhelsetest': ('veikhelset',),
'veikhelseteste': ('veikhelset',),
'veilaus': ('veilaus',),
'veilause': ('veilaus',),
'veilausere': ('veilaus',),
'veilausest': ('veilaus',),
'veilauseste': ('veilaus',),
'veilaust': ('veilaus',),
'veileda': ('veilede',),
'veiledede': ('veilede',),
'veiledende': ('veilede',),
'veiledet': ('veilede',),
'veiledete': ('veilede',),
'veiløs': ('veiløs',),
'veiløse': ('veiløs',),
'veiløsere': ('veiløs',),
'veiløsest': ('veiløs',),
'veiløseste': ('veiløs',),
'veiløst': ('veiløs',),
'veita': ('veite',),
'veitede': ('veite',),
'veitende': ('veite',),
'veitet': ('veite',),
'veitete': ('veite',),
'veiva': ('veive',),
'veivd': ('veive',),
'veivde': ('veive',),
'veivede': ('veive',),
'veivende': ('veive',),
'veivet': ('veive',),
'veivete': ('veive',),
'vek': ('vek',),
'veke': ('vek',),
'vekere': ('vek',),
'vekest': ('vek',),
'vekeste': ('vek',),
'vekt': ('vek',),
'vekehavende': ('vekehavende',),
'vekehavende': ('vekehavende',),
'vekhelsa': ('vekhelsa',),
'vekhelsede': ('vekhelset',),
'vekhelset': ('vekhelset',),
'vekhelsete': ('vekhelset',),
'vekhelsetere': ('vekhelset',),
'vekhelsetest': ('vekhelset',),
'vekhelseteste': ('vekhelset',),
'vakt': ('vekke',),
'vakte': ('vekke',),
'vekka': ('vekke',),
'vekkede': ('vekke',),
'vekkende': ('vekke',),
'vekket': ('vekke',),
'vekkete': ('vekke',),
'vekt': ('vekke',),
'vekte': ('vekke',),
'vekselvarm': ('vekselvarm',),
'vekselvarme': ('vekselvarm',),
'vekselvarmere': ('vekselvarm',),
'vekselvarmest': ('vekselvarm',),
'vekselvarmeste': ('vekselvarm',),
'vekselvarmt': ('vekselvarm',),
'veksla': ('veksle',),
'vekslede': ('veksle',),
'vekslende': ('veksle',),
'vekslet': ('veksle',),
'vekslete': ('veksle',),
'veksterlig': ('veksterlig',),
'veksterlige': ('veksterlig',),
'veksterligere': ('veksterlig',),
'veksterligst': ('veksterlig',),
'veksterligste': ('veksterlig',),
'vektig': ('vektig',),
'vektige': ('vektig',),
'vektigere': ('vektig',),
'vektigst': ('vektig',),
'vektigste': ('vektig',),
'vektlaus': ('vektlaus',),
'vektlause': ('vektlaus',),
'vektlausere': ('vektlaus',),
'vektlausest': ('vektlaus',),
'vektlauseste': ('vektlaus',),
'vektlaust': ('vektlaus',),
'vektløs': ('vektløs',),
'vektløse': ('vektløs',),
'vektløsere': ('vektløs',),
'vektløsest': ('vektløs',),
'vektløseste': ('vektløs',),
'vektløst': ('vektløs',),
'velar': ('velar',),
'velare': ('velar',),
'velarere': ('velar',),
'velarest': ('velar',),
'velareste': ('velar',),
'velart': ('velar',),
'velassortert': ('velassortert',),
'velassorterte': ('velassortert',),
'velassortertere': ('velassortert',),
'velassortertest': ('velassortert',),
'velassorterteste': ('velassortert',),
'velberga': ('velberga',),
'velbergede': ('velberget',),
'velberget': ('velberget',),
'velbergete': ('velberget',),
'velbergetere': ('velberget',),
'velbergetest': ('velberget',),
'velbergeteste': ('velberget',),
'velberådd': ('velberådd',),
'velberådde': ('velberådd',),
'velberåddere': ('velberådd',),
'velberåddest': ('velberådd',),
'velberåddeste': ('velberådd',),
'velbeslått': ('velbeslått',),
'velbeslåtte': ('velbeslått',),
'velbeslåttere': ('velbeslått',),
'velbeslåttest': ('velbeslått',),
'velbeslåtteste': ('velbeslått',),
'velbrukt': ('velbrukt',),
'velbrukte': ('velbrukt',),
'velbruktere': ('velbrukt',),
'velbruktest': ('velbrukt',),
'velbrukteste': ('velbrukt',),
'velbygd': ('velbygd',),
'velbygde': ('velbygd',),
'velbygdere': ('velbygd',),
'velbygdest': ('velbygd',),
'velbygdeste': ('velbygd',),
'velbåren': ('velbåren',),
'velbårent': ('velbåren',),
'velbårne': ('velbåren',),
'velbårnere': ('velbåren',),
'velbårnest': ('velbåren',),
'velbårneste': ('velbåren',),
'veldedig': ('veldedig',),
'veldedige': ('veldedig',),
'veldedigere': ('veldedig',),
'veldedigst': ('veldedig',),
'veldedigste': ('veldedig',),
'veldefinert': ('veldefinert',),
'veldefinerte': ('veldefinert',),
'veldefinertere': ('veldefinert',),
'veldefinertest': ('veldefinert',),
'veldefinerteste': ('veldefinert',),
'veldig': ('veldig',),
'veldige': ('veldig',),
'veldigere': ('veldig',),
'veldigst': ('veldig',),
'veldigste': ('veldig',),
'veldreia': ('veldreia',),
'veldreid': ('veldreid',),
'veldreide': ('veldreid',),
'veldreidere': ('veldreid',),
'veldreidest': ('veldreid',),
'veldreideste': ('veldreid',),
'veldreiede': ('veldreiet',),
'veldreiet': ('veldreiet',),
'veldreiete': ('veldreiet',),
'veldreietere': ('veldreiet',),
'veldreietest': ('veldreiet',),
'veldreieteste': ('veldreiet',),
'veldrevet': ('veldrevet',),
'veldrevne': ('veldrevet',),
'veldrevnere': ('veldrevet',),
'veldrevnest': ('veldrevet',),
'veldrevneste': ('veldrevet',),
'velegna': ('velegna',),
'velegnede': ('velegnet',),
'velegnet': ('velegnet',),
'velegnete': ('velegnet',),
'velegnetere': ('velegnet',),
'velegnetest': ('velegnet',),
'velegneteste': ('velegnet',),
'velforma': ('velforma',),
'velformede': ('velformet',),
'velformet': ('velformet',),
'velformete': ('velformet',),
'velformetere': ('velformet',),
'velformetest': ('velformet',),
'velformeteste': ('velformet',),
'velfortjent': ('velfortjent',),
'velfortjente': ('velfortjent',),
'velfortjentere': ('velfortjent',),
'velfortjentest': ('velfortjent',),
'velfortjenteste': ('velfortjent',),
'velfrisert': ('velfrisert',),
'velfriserte': ('velfrisert',),
'velfrisertere': ('velfrisert',),
'velfrisertest': ('velfrisert',),
'velfriserteste': ('velfrisert',),
'velfylt': ('velfylt',),
'velfylte': ('velfylt',),
'velfyltere': ('velfylt',),
'velfyltest': ('velfylt',),
'velfylteste': ('velfylt',),
'velfødd': ('velfødd',),
'velfødde': ('velfødd',),
'velføddere': ('velfødd',),
'velføddest': ('velfødd',),
'velføddeste': ('velfødd',),
'valgt': ('velge',),
'valgte': ('velge',),
'velgende': ('velge',),
'velgjeten': ('velgjeten',),
'velgjetent': ('velgjeten',),
'velgjetne': ('velgjeten',),
'velgjetnere': ('velgjeten',),
'velgjetnest': ('velgjeten',),
'velgjetneste': ('velgjeten',),
'velgjort': ('velgjort',),
'velgjorte': ('velgjort',),
'velgjortere': ('velgjort',),
'velgjortest': ('velgjort',),
'velgjorteste': ('velgjort',),
'velgjørende': ('velgjørende',),
'velhavende': ('velhavende',),
'velholden': ('velholden',),
'velholdent': ('velholden',),
'velholdne': ('velholden',),
'velholdnere': ('velholden',),
'velholdnest': ('velholden',),
'velholdneste': ('velholden',),
'velholdt': ('velholdt',),
'velholdte': ('velholdt',),
'velholdtere': ('velholdt',),
'velholdtest': ('velholdt',),
'velholdteste': ('velholdt',),
'velinformert': ('velinformert',),
'velinformerte': ('velinformert',),
'velinformertere': ('velinformert',),
'velinformertest': ('velinformert',),
'velinformerteste': ('velinformert',),
'velkjent': ('velkjent',),
'velkjente': ('velkjent',),
'velkjentere': ('velkjent',),
'velkjentest': ('velkjent',),
'velkjenteste': ('velkjent',),
'velkommen': ('velkommen',),
'velkomment': ('velkommen',),
'velkomne': ('velkommen',),
'velkomnere': ('velkommen',),
'velkomnest': ('velkommen',),
'velkomneste': ('velkommen',),
'velkvalifisert': ('velkvalifisert',),
'velkvalifiserte': ('velkvalifisert',),
'velkvalifisertere': ('velkvalifisert',),
'velkvalifisertest': ('velkvalifisert',),
'velkvalifiserteste': ('velkvalifisert',),
'vellaga': ('vellaga',),
'vellagd': ('vellagd',),
'vellagde': ('vellagd',),
'vellagdere': ('vellagd',),
'vellagdest': ('vellagd',),
'vellagdeste': ('vellagd',),
'vellagede': ('vellaget',),
'vellaget': ('vellaget',),
'vellagete': ('vellaget',),
'vellagetere': ('vellaget',),
'vellagetest': ('vellaget',),
'vellageteste': ('vellaget',),
'vellagra': ('vellagra',),
'vellagrede': ('vellagret',),
'vellagret': ('vellagret',),
'vellagrete': ('vellagret',),
'vellagretere': ('vellagret',),
'vellagretest': ('vellagret',),
'vellagreteste': ('vellagret',),
'vella': ('velle',),
'vellede': ('velle',),
'vellende': ('velle',),
'vellet': ('velle',),
'vellete': ('velle',),
'velt': ('velle',),
'velte': ('velle',),
'velluktende': ('velluktende',),
'vellykka': ('vellykka',),
'vellykkede': ('vellykket',),
'vellykket': ('vellykket',),
'vellykkete': ('vellykket',),
'vellykketere': ('vellykket',),
'vellykketest': ('vellykket',),
'vellykketeste': ('vellykket',),
'vellykt': ('vellykt',),
'vellykte': ('vellykt',),
'vellyktere': ('vellykt',),
'vellyktest': ('vellykt',),
'vellykteste': ('vellykt',),
'vellystig': ('vellystig',),
'vellystige': ('vellystig',),
'vellystigere': ('vellystig',),
'vellystigst': ('vellystig',),
'vellystigste': ('vellystig',),
'velmeinende': ('velmeinende',),
'velmeint': ('velmeint',),
'velmeinte': ('velmeint',),
'velmeintere': ('velmeint',),
'velmeintest': ('velmeint',),
'velmeinteste': ('velmeint',),
'velmenende': ('velmenende',),
'velment': ('velment',),
'velmente': ('velment',),
'velmentere': ('velment',),
'velmentest': ('velment',),
'velmenteste': ('velment',),
'velmålt': ('velmålt',),
'velmålte': ('velmålt',),
'velmåltere': ('velmålt',),
'velmåltest': ('velmålt',),
'velmålteste': ('velmålt',),
'velnært': ('velnært',),
'velnærte': ('velnært',),
'velnærtere': ('velnært',),
'velnærtest': ('velnært',),
'velnærteste': ('velnært',),
'velnøgd': ('velnøgd',),
'velnøgde': ('velnøgd',),
'velnøgdere': ('velnøgd',),
'velnøgdest': ('velnøgd',),
'velnøgdeste': ('velnøgd',),
'velnøyd': ('velnøyd',),
'velnøyde': ('velnøyd',),
'velnøydere': ('velnøyd',),
'velnøydest': ('velnøyd',),
'velnøydeste': ('velnøyd',),
'veloppdragen': ('veloppdragen',),
'veloppdragent': ('veloppdragen',),
'veloppdragne': ('veloppdragen',),
'veloppdragnere': ('veloppdragen',),
'veloppdragnest': ('veloppdragen',),
'veloppdragneste': ('veloppdragen',),
'velorganisert': ('velorganisert',),
'velorganiserte': ('velorganisert',),
'velorganisertere': ('velorganisert',),
'velorganisertest': ('velorganisert',),
'velorganiserteste': ('velorganisert',),
'velorientert': ('velorientert',),
'velorienterte': ('velorientert',),
'velorientertere': ('velorientert',),
'velorientertest': ('velorientert',),
'velorienterteste': ('velorientert',),
'velpleia': ('velpleia',),
'velpleid': ('velpleid',),
'velpleide': ('velpleid',),
'velpleidere': ('velpleid',),
'velpleidest': ('velpleid',),
'velpleideste': ('velpleid',),
'velpleiede': ('velpleiet',),
'velpleiet': ('velpleiet',),
'velpleiete': ('velpleiet',),
'velpleietere': ('velpleiet',),
'velpleietest': ('velpleiet',),
'velpleieteste': ('velpleiet',),
'velproporsjonert': ('velproporsjonert',),
'velproporsjonerte': ('velproporsjonert',),
'velproporsjonertere': ('velproporsjonert',),
'velproporsjonertest': ('velproporsjonert',),
'velproporsjonerteste': ('velproporsjonert',),
'velrenommert': ('velrenommert',),
'velrenommerte': ('velrenommert',),
'velrenommertere': ('velrenommert',),
'velrenommertest': ('velrenommert',),
'velrenommerteste': ('velrenommert',),
'velretta': ('velretta',),
'velrettede': ('velrettet',),
'velrettet': ('velrettet',),
'velrettete': ('velrettet',),
'velrettetere': ('velrettet',),
'velrettetest': ('velrettet',),
'velretteteste': ('velrettet',),
'velsett': ('velsett',),
'velsette': ('velsett',),
'velsettere': ('velsett',),
'velsettest': ('velsett',),
'velsetteste': ('velsett',),
'velsigna': ('velsigne',),
'velsignede': ('velsigne',),
'velsignende': ('velsigne',),
'velsignet': ('velsigne',),
'velsignete': ('velsigne',),
'velsittende': ('velsittende',),
'velsituert': ('velsituert',),
'velsituerte': ('velsituert',),
'velsituertere': ('velsituert',),
'velsituertest': ('velsituert',),
'velsituerteste': ('velsituert',),
'velsk': ('velsk',),
'velske': ('velsk',),
'velskere': ('velsk',),
'velskest': ('velsk',),
'velskeste': ('velsk',),
'velskapt': ('velskapt',),
'velskapte': ('velskapt',),
'velskaptere': ('velskapt',),
'velskaptest': ('velskapt',),
'velskapteste': ('velskapt',),
'velskreven': ('velskreven',),
'velskrevet': ('velskreven',),
'velskrevne': ('velskreven',),
'velskrevnere': ('velskreven',),
'velskrevnest': ('velskreven',),
'velskrevneste': ('velskreven',),
'velskrevet': ('velskrevet',),
'velskrevne': ('velskrevet',),
'velskrevnere': ('velskrevet',),
'velskrevnest': ('velskrevet',),
'velskrevneste': ('velskrevet',),
'velsmakende': ('velsmakende',),
'velsmurt': ('velsmurt',),
'velsmurte': ('velsmurt',),
'velsmurtere': ('velsmurt',),
'velsmurtest': ('velsmurt',),
'velsmurteste': ('velsmurt',),
'velspekka': ('velspekka',),
'velspekkede': ('velspekket',),
'velspekket': ('velspekket',),
'velspekkete': ('velspekket',),
'velspekketere': ('velspekket',),
'velspekketest': ('velspekket',),
'velspekketeste': ('velspekket',),
'velstelt': ('velstelt',),
'velstelte': ('velstelt',),
'velsteltere': ('velstelt',),
'velsteltest': ('velstelt',),
'velstelteste': ('velstelt',),
'velstyrt': ('velstyrt',),
'velstyrte': ('velstyrt',),
'velstyrtere': ('velstyrt',),
'velstyrtest': ('velstyrt',),
'velstyrteste': ('velstyrt',),
'velstående': ('velstående',),
'veltalende': ('veltalende',),
'velta': ('velte',),
'veltede': ('velte',),
'velten': ('velte',),
'veltende': ('velte',),
'veltet': ('velte',),
'veltete': ('velte',),
'veltne': ('velte',),
'velten': ('velten',),
'veltent': ('velten',),
'veltne': ('velten',),
'veltnere': ('velten',),
'veltnest': ('velten',),
'veltneste': ('velten',),
'veltilfreds': ('veltilfreds',),
'veltilfredse': ('veltilfreds',),
'veltilfredsere': ('veltilfreds',),
'veltilfredsest': ('veltilfreds',),
'veltilfredseste': ('veltilfreds',),
'veltilpassa': ('veltilpassa',),
'veltilpasset': ('veltilpasset',),
'veltilpassete': ('veltilpasset',),
'veltilpassetere': ('veltilpasset',),
'veltilpassetest': ('veltilpasset',),
'veltilpasseteste': ('veltilpasset',),
'veltjent': ('veltjent',),
'veltjente': ('veltjent',),
'veltjentere': ('veltjent',),
'veltjentest': ('veltjent',),
'veltjenteste': ('veltjent',),
'veltrena': ('veltrena',),
'veltrenede': ('veltrenet',),
'veltrenet': ('veltrenet',),
'veltrenete': ('veltrenet',),
'veltrenetere': ('veltrenet',),
'veltrenetest': ('veltrenet',),
'veltreneteste': ('veltrenet',),
'veltrent': ('veltrent',),
'veltrente': ('veltrent',),
'veltrentere': ('veltrent',),
'veltrentest': ('veltrent',),
'veltrenteste': ('veltrent',),
'veltrimma': ('veltrimma',),
'veltrimmede': ('veltrimmet',),
'veltrimmet': ('veltrimmet',),
'veltrimmete': ('veltrimmet',),
'veltrimmetere': ('veltrimmet',),
'veltrimmetest': ('veltrimmet',),
'veltrimmeteste': ('veltrimmet',),
'velutdanna': ('velutdanna',),
'velutdannede': ('velutdannet',),
'velutdannet': ('velutdannet',),
'velutdannete': ('velutdannet',),
'velutdannetere': ('velutdannet',),
'velutdannetest': ('velutdannet',),
'velutdanneteste': ('velutdannet',),
'velutrusta': ('velutrusta',),
'velutrustede': ('velutrustet',),
'velutrustet': ('velutrustet',),
'velutrustete': ('velutrustet',),
'velutrustetere': ('velutrustet',),
'velutrustetest': ('velutrustet',),
'velutrusteteste': ('velutrustet',),
'velutvikla': ('velutvikla',),
'velutviklede': ('velutviklet',),
'velutviklet': ('velutviklet',),
'velutviklete': ('velutviklet',),
'velutvikletere': ('velutviklet',),
'velutvikletest': ('velutviklet',),
'velutvikleteste': ('velutviklet',),
'velvalgt': ('velvalgt',),
'velvalgte': ('velvalgt',),
'velvalgtere': ('velvalgt',),
'velvalgtest': ('velvalgt',),
'velvalgteste': ('velvalgt',),
'velvillig': ('velvillig',),
'velvillige': ('velvillig',),
'velvilligere': ('velvillig',),
'velvilligst': ('velvillig',),
'velvilligste': ('velvillig',),
'velvoksen': ('velvoksen',),
'velvoksent': ('velvoksen',),
'velvoksne': ('velvoksen',),
'velvoksnere': ('velvoksen',),
'velvoksnest': ('velvoksen',),
'velvoksneste': ('velvoksen',),
'velærverdig': ('velærverdig',),
'velærverdige': ('velærverdig',),
'velærverdigere': ('velærverdig',),
'velærverdigst': ('velærverdig',),
'velærverdigste': ('velærverdig',),
'veløvd': ('veløvd',),
'veløvde': ('veløvd',),
'veløvdere': ('veløvd',),
'veløvdest': ('veløvd',),
'veløvdeste': ('veløvd',),
'veløvede': ('veløvet',),
'veløvet': ('veløvet',),
'veløvete': ('veløvet',),
'veløvetere': ('veløvet',),
'veløvetest': ('veløvet',),
'veløveteste': ('veløvet',),
'vemmelig': ('vemmelig',),
'vemmelige': ('vemmelig',),
'vemmeligere': ('vemmelig',),
'vemmeligst': ('vemmelig',),
'vemmeligste': ('vemmelig',),
'vemodig': ('vemodig',),
'vemodige': ('vemodig',),
'vemodigere': ('vemodig',),
'vemodigst': ('vemodig',),
'vemodigste': ('vemodig',),
'vemodsfull': ('vemodsfull',),
'vemodsfulle': ('vemodsfull',),
'vemodsfullere': ('vemodsfull',),
'vemodsfullest': ('vemodsfull',),
'vemodsfulleste': ('vemodsfull',),
'vemodsfullt': ('vemodsfull',),
'ven': ('ven',),
'vene': ('ven',),
'venere': ('ven',),
'venest': ('ven',),
'veneste': ('ven',),
'vent': ('ven',),
'vendbar': ('vendbar',),
'vendbare': ('vendbar',),
'vendbarere': ('vendbar',),
'vendbarest': ('vendbar',),
'vendbareste': ('vendbar',),
'vendbart': ('vendbar',),
'vendende': ('vende',),
'vendt': ('vende',),
'vendte': ('vende',),
'vendisk': ('vendisk',),
'vendiske': ('vendisk',),
'vendiskere': ('vendisk',),
'vendiskest': ('vendisk',),
'vendiskeste': ('vendisk',),
'venerabel': ('venerabel',),
'venerabelt': ('venerabel',),
'venerable': ('venerabel',),
'venerablere': ('venerabel',),
'venerablest': ('venerabel',),
'venerableste': ('venerabel',),
'venerisk': ('venerisk',),
'veneriske': ('venerisk',),
'veneriskere': ('venerisk',),
'veneriskest': ('venerisk',),
'veneriskeste': ('venerisk',),
'venetiansk': ('venetiansk',),
'venetianske': ('venetiansk',),
'venetianskere': ('venetiansk',),
'venetianskest': ('venetiansk',),
'venetianskeste': ('venetiansk',),
'venezuelansk': ('venezuelansk',),
'venezuelanske': ('venezuelansk',),
'venezuelanskere': ('venezuelansk',),
'venezuelanskest': ('venezuelansk',),
'venezuelanskeste': ('venezuelansk',),
'venga': ('venga',),
'venga': ('venga',),
'venga': ('venga',),
'vengeskutt': ('vengeskutt',),
'vengeskutte': ('vengeskutt',),
'vengeskuttere': ('vengeskutt',),
'vengeskuttest': ('vengeskutt',),
'vengeskutteste': ('vengeskutt',),
'vengede': ('venget',),
'venget': ('venget',),
'vengete': ('venget',),
'vengetere': ('venget',),
'vengetest': ('venget',),
'vengeteste': ('venget',),
'vengede': ('venget',),
'venget': ('venget',),
'vengete': ('venget',),
'vengetere': ('venget',),
'vengetest': ('venget',),
'vengeteste': ('venget',),
'vengede': ('venget',),
'venget': ('venget',),
'vengete': ('venget',),
'vengetere': ('venget',),
'vengetest': ('venget',),
'vengeteste': ('venget',),
'venna': ('venne',),
'vennede': ('venne',),
'vennende': ('venne',),
'vennet': ('venne',),
'vennete': ('venne',),
'vent': ('venne',),
'vente': ('venne',),
'vennelaus': ('vennelaus',),
'vennelause': ('vennelaus',),
'vennelausere': ('vennelaus',),
'vennelausest': ('vennelaus',),
'vennelauseste': ('vennelaus',),
'vennelaust': ('vennelaus',),
'venneløs': ('venneløs',),
'venneløse': ('venneløs',),
'venneløsere': ('venneløs',),
'venneløsest': ('venneløs',),
'venneløseste': ('venneløs',),
'venneløst': ('venneløs',),
'vennesæl': ('vennesæl',),
'vennesæle': ('vennesæl',),
'vennesælere': ('vennesæl',),
'vennesælest': ('vennesæl',),
'vennesæleste': ('vennesæl',),
'vennesælt': ('vennesæl',),
'vennlig': ('vennlig',),
'vennlige': ('vennlig',),
'vennligere': ('vennlig',),
'vennligst': ('vennlig',),
'vennligste': ('vennlig',),
'vennligsinna': ('vennligsinna',),
'vennligsinnede': ('vennligsinnet',),
'vennligsinnet': ('vennligsinnet',),
'vennligsinnete': ('vennligsinnet',),
'vennligsinnetere': ('vennligsinnet',),
'vennligsinnetest': ('vennligsinnet',),
'vennligsinneteste': ('vennligsinnet',),
'vennskapelig': ('vennskapelig',),
'vennskapelige': ('vennskapelig',),
'vennskapeligere': ('vennskapelig',),
'vennskapeligst': ('vennskapelig',),
'vennskapeligste': ('vennskapelig',),
'venstre': ('venstre',),
'venstrehendt': ('venstrehendt',),
'venstrehendte': ('venstrehendt',),
'venstrehendtere': ('venstrehendt',),
'venstrehendtest': ('venstrehendt',),
'venstrehendteste': ('venstrehendt',),
'venstrehengsla': ('venstrehengsla',),
'venstrehengslede': ('venstrehengslet',),
'venstrehengslet': ('venstrehengslet',),
'venstrehengslete': ('venstrehengslet',),
'venstrehengsletere': ('venstrehengslet',),
'venstrehengsletest': ('venstrehengslet',),
'venstrehengsleteste': ('venstrehengslet',),
'venstreorientert': ('venstreorientert',),
'venstreorienterte': ('venstreorientert',),
'venstreorientertere': ('venstreorientert',),
'venstreorientertest': ('venstreorientert',),
'venstreorienterteste': ('venstreorientert',),
'venstreradikal': ('venstreradikal',),
'venstreradikale': ('venstreradikal',),
'venstreradikalere': ('venstreradikal',),
'venstreradikalest': ('venstreradikal',),
'venstreradikaleste': ('venstreradikal',),
'venstreradikalt': ('venstreradikal',),
'venstrevridd': ('venstrevridd',),
'venstrevridde': ('venstrevridd',),
'venstrevriddere': ('venstrevridd',),
'venstrevriddest': ('venstrevridd',),
'venstrevriddeste': ('venstrevridd',),
'venta': ('vente',),
'ventede': ('vente',),
'ventende': ('vente',),
'ventet': ('vente',),
'ventete': ('vente',),
'ventelig': ('ventelig',),
'ventelige': ('ventelig',),
'venteligere': ('ventelig',),
'venteligst': ('ventelig',),
'venteligste': ('ventelig',),
'ventilerende': ('ventilere',),
'ventilert': ('ventilere',),
'ventilerte': ('ventilere',),
'ventral': ('ventral',),
'ventrale': ('ventral',),
'ventralere': ('ventral',),
'ventralest': ('ventral',),
'ventraleste': ('ventral',),
'ventralt': ('ventral',),
'venøs': ('venøs',),
'venøse': ('venøs',),
'venøsere': ('venøs',),
'venøsest': ('venøs',),
'venøseste': ('venøs',),
'venøst': ('venøs',),
'verbal': ('verbal',),
'verbale': ('verbal',),
'verbalere': ('verbal',),
'verbalest': ('verbal',),
'verbaleste': ('verbal',),
'verbalt': ('verbal',),
'verbaliserende': ('verbalisere',),
'verbalisert': ('verbalisere',),
'verbaliserte': ('verbalisere',),
'verd': ('verd',),
'verdensberømt': ('verdensberømt',),
'verdensberømte': ('verdensberømt',),
'verdensberømtere': ('verdensberømt',),
'verdensberømtest': ('verdensberømt',),
'verdensberømteste': ('verdensberømt',),
'verdensfjern': ('verdensfjern',),
'verdensfjerne': ('verdensfjern',),
'verdensfjernere': ('verdensfjern',),
'verdensfjernest': ('verdensfjern',),
'verdensfjerneste': ('verdensfjern',),
'verdensfjernt': ('verdensfjern',),
'verdenshistorisk': ('verdenshistorisk',),
'verdenshistoriske': ('verdenshistorisk',),
'verdenshistoriskere': ('verdenshistorisk',),
'verdenshistoriskest': ('verdenshistorisk',),
'verdenshistoriskeste': ('verdenshistorisk',),
'verdenskjent': ('verdenskjent',),
'verdenskjente': ('verdenskjent',),
'verdenskjentere': ('verdenskjent',),
'verdenskjentest': ('verdenskjent',),
'verdenskjenteste': ('verdenskjent',),
'verdensklok': ('verdensklok',),
'verdenskloke': ('verdensklok',),
'verdensklokere': ('verdensklok',),
'verdensklokest': ('verdensklok',),
'verdensklokeste': ('verdensklok',),
'verdensklokt': ('verdensklok',),
'verdensomfattende': ('verdensomfattende',),
'verdensomspennende': ('verdensomspennende',),
'verdensvant': ('verdensvant',),
'verdensvante': ('verdensvant',),
'verdensvantere': ('verdensvant',),
'verdensvantest': ('verdensvant',),
'verdensvanteste': ('verdensvant',),
'verdfull': ('verdfull',),
'verdfulle': ('verdfull',),
'verdfullere': ('verdfull',),
'verdfullest': ('verdfull',),
'verdfulleste': ('verdfull',),
'verdfullt': ('verdfull',),
'verdifull': ('verdifull',),
'verdifulle': ('verdifull',),
'verdifullere': ('verdifull',),
'verdifullest': ('verdifull',),
'verdifulleste': ('verdifull',),
'verdifullt': ('verdifull',),
'verdig': ('verdig',),
'verdige': ('verdig',),
'verdigere': ('verdig',),
'verdigst': ('verdig',),
'verdigste': ('verdig',),
'verdiga': ('verdige',),
'verdigede': ('verdige',),
'verdigende': ('verdige',),
'verdiget': ('verdige',),
'verdigete': ('verdige',),
'verdikonservativ': ('verdikonservativ',),
'verdikonservative': ('verdikonservativ',),
'verdikonservativere': ('verdikonservativ',),
'verdikonservativest': ('verdikonservativ',),
'verdikonservativeste': ('verdikonservativ',),
'verdikonservativt': ('verdikonservativ',),
'verdilada': ('verdilada',),
'verdiladd': ('verdiladd',),
'verdiladde': ('verdiladd',),
'verdiladdere': ('verdiladd',),
'verdiladdest': ('verdiladd',),
'verdiladdeste': ('verdiladd',),
'verdiladede': ('verdiladet',),
'verdiladet': ('verdiladet',),
'verdiladete': ('verdiladet',),
'verdiladetere': ('verdiladet',),
'verdiladetest': ('verdiladet',),
'verdiladeteste': ('verdiladet',),
'verdilaus': ('verdilaus',),
'verdilause': ('verdilaus',),
'verdilausere': ('verdilaus',),
'verdilausest': ('verdilaus',),
'verdilauseste': ('verdilaus',),
'verdilaust': ('verdilaus',),
'verdiløs': ('verdiløs',),
'verdiløse': ('verdiløs',),
'verdiløsere': ('verdiløs',),
'verdiløsest': ('verdiløs',),
'verdiløseste': ('verdiløs',),
'verdiløst': ('verdiløs',),
'verdinøytral': ('verdinøytral',),
'verdinøytrale': ('verdinøytral',),
'verdinøytralere': ('verdinøytral',),
'verdinøytralest': ('verdinøytral',),
'verdinøytraleste': ('verdinøytral',),
'verdinøytralt': ('verdinøytral',),
'verdsatt': ('verdsette',),
'verdsatte': ('verdsette',),
'verdsettende': ('verdsette',),
'verdslig': ('verdslig',),
'verdslige': ('verdslig',),
'verdsligere': ('verdslig',),
'verdsligst': ('verdslig',),
'verdsligste': ('verdslig',),
'verdsliggjort': ('verdsliggjøre',),
'verdsliggjorte': ('verdsliggjøre',),
'verdsliggjørende': ('verdsliggjøre',),
'verdt': ('verdt',),
'verga': ('verge',),
'vergede': ('verge',),
'vergende': ('verge',),
'verget': ('verge',),
'vergete': ('verge',),
'verga': ('verge',),
'vergede': ('verge',),
'vergende': ('verge',),
'verget': ('verge',),
'vergete': ('verge',),
'vergefør': ('vergefør',),
'vergeføre': ('vergefør',),
'vergeførere': ('vergefør',),
'vergeførest': ('vergefør',),
'vergeføreste': ('vergefør',),
'vergeført': ('vergefør',),
'vergefør': ('vergefør',),
'vergeføre': ('vergefør',),
'vergeførere': ('vergefør',),
'vergeførest': ('vergefør',),
'vergeføreste': ('vergefør',),
'vergeført': ('vergefør',),
'vergelaus': ('vergelaus',),
'vergelause': ('vergelaus',),
'vergelausere': ('vergelaus',),
'vergelausest': ('vergelaus',),
'vergelauseste': ('vergelaus',),
'vergelaust': ('vergelaus',),
'vergelaus': ('vergelaus',),
'vergelause': ('vergelaus',),
'vergelausere': ('vergelaus',),
'vergelausest': ('vergelaus',),
'vergelauseste': ('vergelaus',),
'vergelaust': ('vergelaus',),
'vergeløs': ('vergeløs',),
'vergeløse': ('vergeløs',),
'vergeløsere': ('vergeløs',),
'vergeløsest': ('vergeløs',),
'vergeløseste': ('vergeløs',),
'vergeløst': ('vergeløs',),
'vergeløs': ('vergeløs',),
'vergeløse': ('vergeløs',),
'vergeløsere': ('vergeløs',),
'vergeløsest': ('vergeløs',),
'vergeløseste': ('vergeløs',),
'vergeløst': ('vergeløs',),
'verifiserende': ('verifisere',),
'verifisert': ('verifisere',),
'verifiserte': ('verifisere',),
'veritabel': ('veritabel',),
'veritabelt': ('veritabel',),
'veritable': ('veritabel',),
'veritablere': ('veritabel',),
'veritablest': ('veritabel',),
'veritableste': ('veritabel',),
'verja': ('verje',),
'verjede': ('verje',),
'verjende': ('verje',),
'verjet': ('verje',),
'verjete': ('verje',),
'verja': ('verje',),
'verjede': ('verje',),
'verjende': ('verje',),
'verjet': ('verje',),
'verjete': ('verje',),
'verjefør': ('verjefør',),
'verjeføre': ('verjefør',),
'verjeførere': ('verjefør',),
'verjeførest': ('verjefør',),
'verjeføreste': ('verjefør',),
'verjeført': ('verjefør',),
'verjefør': ('verjefør',),
'verjeføre': ('verjefør',),
'verjeførere': ('verjefør',),
'verjeførest': ('verjefør',),
'verjeføreste': ('verjefør',),
'verjeført': ('verjefør',),
'verjelaus': ('verjelaus',),
'verjelause': ('verjelaus',),
'verjelausere': ('verjelaus',),
'verjelausest': ('verjelaus',),
'verjelauseste': ('verjelaus',),
'verjelaust': ('verjelaus',),
'verjelaus': ('verjelaus',),
'verjelause': ('verjelaus',),
'verjelausere': ('verjelaus',),
'verjelausest': ('verjelaus',),
'verjelauseste': ('verjelaus',),
'verjelaust': ('verjelaus',),
'verjeløs': ('verjeløs',),
'verjeløse': ('verjeløs',),
'verjeløsere': ('verjeløs',),
'verjeløsest': ('verjeløs',),
'verjeløseste': ('verjeløs',),
'verjeløst': ('verjeløs',),
'verjeløs': ('verjeløs',),
'verjeløse': ('verjeløs',),
'verjeløsere': ('verjeløs',),
'verjeløsest': ('verjeløs',),
'verjeløseste': ('verjeløs',),
'verjeløst': ('verjeløs',),
'verkbroten': ('verkbroten',),
'verkbrotent': ('verkbroten',),
'verkbrotne': ('verkbroten',),
'verkbrotnere': ('verkbroten',),
'verkbrotnest': ('verkbroten',),
'verkbrotneste': ('verkbroten',),
'verkbrudden': ('verkbrudden',),
'verkbruddent': ('verkbrudden',),
'verkbrudne': ('verkbrudden',),
'verkbrudnere': ('verkbrudden',),
'verkbrudnest': ('verkbrudden',),
'verkbrudneste': ('verkbrudden',),
'verka': ('verke',),
'verkede': ('verke',),
'verkende': ('verke',),
'verket': ('verke',),
'verkete': ('verke',),
'verkt': ('verke',),
'verkte': ('verke',),
'verkstedkontrollert': ('verkstedkontrollert',),
'verkstedkontrollerte': ('verkstedkontrollert',),
'verkstedkontrollertere': ('verkstedkontrollert',),
'verkstedkontrollertest': ('verkstedkontrollert',),
'verkstedkontrollerteste': ('verkstedkontrollert',),
'vernaliserende': ('vernalisere',),
'vernalisert': ('vernalisere',),
'vernaliserte': ('vernalisere',),
'verna': ('verne',),
'vernede': ('verne',),
'vernende': ('verne',),
'vernet': ('verne',),
'vernete': ('verne',),
'vernedyktig': ('vernedyktig',),
'vernedyktige': ('vernedyktig',),
'vernedyktigere': ('vernedyktig',),
'vernedyktigst': ('vernedyktig',),
'vernedyktigste': ('vernedyktig',),
'vernefør': ('vernefør',),
'verneføre': ('vernefør',),
'verneførere': ('vernefør',),
'verneførest': ('vernefør',),
'verneføreste': ('vernefør',),
'verneført': ('vernefør',),
'vernepliktig': ('vernepliktig',),
'vernepliktige': ('vernepliktig',),
'vernepliktigere': ('vernepliktig',),
'vernepliktigst': ('vernepliktig',),
'vernepliktigste': ('vernepliktig',),
'verneverdig': ('verneverdig',),
'verneverdige': ('verneverdig',),
'verneverdigere': ('verneverdig',),
'verneverdigst': ('verneverdig',),
'verneverdigste': ('verneverdig',),
'verpa': ('verpe',),
'verpede': ('verpe',),
'verpende': ('verpe',),
'verpet': ('verpe',),
'verpete': ('verpe',),
'verpt': ('verpe',),
'verpte': ('verpe',),
'verpemoden': ('verpemoden',),
'verpemodent': ('verpemoden',),
'verpemodne': ('verpemoden',),
'verpemodnere': ('verpemoden',),
'verpemodnest': ('verpemoden',),
'verpemodneste': ('verpemoden',),
'verpesjuk': ('verpesjuk',),
'verpesjuke': ('verpesjuk',),
'verpesjukere': ('verpesjuk',),
'verpesjukest': ('verpesjuk',),
'verpesjukeste': ('verpesjuk',),
'verpesjukt': ('verpesjuk',),
'verre': ('verre',),
'verst': ('verre',),
'verste': ('verre',),
'versatil': ('versatil',),
'versatile': ('versatil',),
'versatilere': ('versatil',),
'versatilest': ('versatil',),
'versatileste': ('versatil',),
'versatilt': ('versatil',),
'verserende': ('versere',),
'versert': ('versere',),
'verserte': ('versere',),
'versifikatorisk': ('versifikatorisk',),
'versifikatoriske': ('versifikatorisk',),
'versifikatoriskere': ('versifikatorisk',),
'versifikatoriskest': ('versifikatorisk',),
'versifikatoriskeste': ('versifikatorisk',),
'versifiserende': ('versifisere',),
'versifisert': ('versifisere',),
'versifiserte': ('versifisere',),
'versna': ('versne',),
'versnede': ('versne',),
'versnende': ('versne',),
'versnet': ('versne',),
'versnete': ('versne',),
'verst': ('verst',),
'verste': ('verst',),
'vertikal': ('vertikal',),
'vertikale': ('vertikal',),
'vertikalere': ('vertikal',),
'vertikalest': ('vertikal',),
'vertikaleste': ('vertikal',),
'vertikalt': ('vertikal',),
'vertikaldelt': ('vertikaldelt',),
'vertikaldelte': ('vertikaldelt',),
'vertikaldeltere': ('vertikaldelt',),
'vertikaldeltest': ('vertikaldelt',),
'vertikaldelteste': ('vertikaldelt',),
'verva': ('verve',),
'vervede': ('verve',),
'vervende': ('verve',),
'vervet': ('verve',),
'vervete': ('verve',),
'vesal': ('vesal',),
'vesale': ('vesal',),
'vesalere': ('vesal',),
'vesalest': ('vesal',),
'vesaleste': ('vesal',),
'vesalt': ('vesal',),
'vesensforskjellig': ('vesensforskjellig',),
'vesensforskjellige': ('vesensforskjellig',),
'vesensforskjelligere': ('vesensforskjellig',),
'vesensforskjelligst': ('vesensforskjellig',),
'vesensforskjelligste': ('vesensforskjellig',),
'vesensfremmed': ('vesensfremmed',),
'vesensfremmede': ('vesensfremmed',),
'vesensfremmedere': ('vesensfremmed',),
'vesensfremmedest': ('vesensfremmed',),
'vesensfremmedeste': ('vesensfremmed',),
'vesensfremmend': ('vesensfremmend',),
'vesensfremmende': ('vesensfremmend',),
'vesensfremmendere': ('vesensfremmend',),
'vesensfremmendest': ('vesensfremmend',),
'vesensfremmendeste': ('vesensfremmend',),
'vesensfremmendt': ('vesensfremmend',),
'vesentlig': ('vesentlig',),
'vesentlige': ('vesentlig',),
'vesentligere': ('vesentlig',),
'vesentligst': ('vesentlig',),
'vesentligste': ('vesentlig',),
'vesikuløs': ('vesikuløs',),
'vesikuløse': ('vesikuløs',),
'vesikuløsere': ('vesikuløs',),
'vesikuløsest': ('vesikuløs',),
'vesikuløseste': ('vesikuløs',),
'vesikuløst': ('vesikuløs',),
'vesle': ('vesle',),
'veslevoksen': ('veslevoksen',),
'veslevoksent': ('veslevoksen',),
'veslevoksne': ('veslevoksen',),
'veslevoksnere': ('veslevoksen',),
'veslevoksnest': ('veslevoksen',),
'veslevoksneste': ('veslevoksen',),
'vestafjelsk': ('vestafjelsk',),
'vestafjelske': ('vestafjelsk',),
'vestafjelskere': ('vestafjelsk',),
'vestafjelskest': ('vestafjelsk',),
'vestafjelskeste': ('vestafjelsk',),
'vestafrikansk': ('vestafrikansk',),
'vestafrikanske': ('vestafrikansk',),
'vestafrikanskere': ('vestafrikansk',),
'vestafrikanskest': ('vestafrikansk',),
'vestafrikanskeste': ('vestafrikansk',),
'vestalliert': ('vestalliert',),
'vestallierte': ('vestalliert',),
'vestalliertere': ('vestalliert',),
'vestalliertest': ('vestalliert',),
'vestallierteste': ('vestalliert',),
'vestalsk': ('vestalsk',),
'vestalske': ('vestalsk',),
'vestalskere': ('vestalsk',),
'vestalskest': ('vestalsk',),
'vestalskeste': ('vestalsk',),
'vestasiatisk': ('vestasiatisk',),
'vestasiatiske': ('vestasiatisk',),
'vestasiatiskere': ('vestasiatisk',),
'vestasiatiskest': ('vestasiatisk',),
'vestasiatiskeste': ('vestasiatisk',),
'vestenfjelsk': ('vestenfjelsk',),
'vestenfjelske': ('vestenfjelsk',),
'vestenfjelskere': ('vestenfjelsk',),
'vestenfjelskest': ('vestenfjelsk',),
'vestenfjelskeste': ('vestenfjelsk',),
'vesterlandsk': ('vesterlandsk',),
'vesterlandske': ('vesterlandsk',),
'vesterlandskere': ('vesterlandsk',),
'vesterlandskest': ('vesterlandsk',),
'vesterlandskeste': ('vesterlandsk',),
'vesteuropeisk': ('vesteuropeisk',),
'vesteuropeiske': ('vesteuropeisk',),
'vesteuropeiskere': ('vesteuropeisk',),
'vesteuropeiskest': ('vesteuropeisk',),
'vesteuropeiskeste': ('vesteuropeisk',),
'vestfoldsk': ('vestfoldsk',),
'vestfoldske': ('vestfoldsk',),
'vestfoldskere': ('vestfoldsk',),
'vestfoldskest': ('vestfoldsk',),
'vestfoldskeste': ('vestfoldsk',),
'vestgermansk': ('vestgermansk',),
'vestgermanske': ('vestgermansk',),
'vestgermanskere': ('vestgermansk',),
'vestgermanskest': ('vestgermansk',),
'vestgermanskeste': ('vestgermansk',),
'vestgotisk': ('vestgotisk',),
'vestgotiske': ('vestgotisk',),
'vestgotiskere': ('vestgotisk',),
'vestgotiskest': ('vestgotisk',),
'vestgotiskeste': ('vestgotisk',),
'vestgående': ('vestgående',),
'vestindisk': ('vestindisk',),
'vestindiske': ('vestindisk',),
'vestindiskere': ('vestindisk',),
'vestindiskest': ('vestindisk',),
'vestindiskeste': ('vestindisk',),
'vestlandsk': ('vestlandsk',),
'vestlandske': ('vestlandsk',),
'vestlandskere': ('vestlandsk',),
'vestlandskest': ('vestlandsk',),
'vestlandskeste': ('vestlandsk',),
'vestlig': ('vestlig',),
'vestlige': ('vestlig',),
'vestligere': ('vestlig',),
'vestligst': ('vestlig',),
'vestligste': ('vestlig',),
'vestnordisk': ('vestnordisk',),
'vestnordiske': ('vestnordisk',),
'vestnordiskere': ('vestnordisk',),
'vestnordiskest': ('vestnordisk',),
'vestnordiskeste': ('vestnordisk',),
'vestnordisk': ('vestnordisk',),
'vestnordiske': ('vestnordisk',),
'vestnordiskere': ('vestnordisk',),
'vestnordiskest': ('vestnordisk',),
'vestnordiskeste': ('vestnordisk',),
'vestnorsk': ('vestnorsk',),
'vestnorske': ('vestnorsk',),
'vestnorskere': ('vestnorsk',),
'vestnorskest': ('vestnorsk',),
'vestnorskeste': ('vestnorsk',),
'vestorientert': ('vestorientert',),
'vestorienterte': ('vestorientert',),
'vestorientertere': ('vestorientert',),
'vestorientertest': ('vestorientert',),
'vestorienterteste': ('vestorientert',),
'vestre': ('vestre',),
'vestromersk': ('vestromersk',),
'vestromerske': ('vestromersk',),
'vestromerskere': ('vestromersk',),
'vestromerskest': ('vestromersk',),
'vestromerskeste': ('vestromersk',),
'vestrøn': ('vestrøn',),
'vestrøne': ('vestrøn',),
'vestrønere': ('vestrøn',),
'vestrønest': ('vestrøn',),
'vestrøneste': ('vestrøn',),
'vestrønt': ('vestrøn',),
'vestsamoansk': ('vestsamoansk',),
'vestsamoanske': ('vestsamoansk',),
'vestsamoanskere': ('vestsamoansk',),
'vestsamoanskest': ('vestsamoansk',),
'vestsamoanskeste': ('vestsamoansk',),
'vesttysk': ('vesttysk',),
'vesttyske': ('vesttysk',),
'vesttyskere': ('vesttysk',),
'vesttyskest': ('vesttysk',),
'vesttyskeste': ('vesttysk',),
'vestvendt': ('vestvendt',),
'vestvendte': ('vestvendt',),
'vestvendtere': ('vestvendt',),
'vestvendtest': ('vestvendt',),
'vestvendteste': ('vestvendt',),
'veterinær': ('veterinær',),
'veterinære': ('veterinær',),
'veterinærere': ('veterinær',),
'veterinærest': ('veterinær',),
'veterinæreste': ('veterinær',),
'veterinært': ('veterinær',),
'vettig': ('vettig',),
'vettige': ('vettig',),
'vettigere': ('vettig',),
'vettigst': ('vettig',),
'vettigste': ('vettig',),
'vettlaus': ('vettlaus',),
'vettlause': ('vettlaus',),
'vettlausere': ('vettlaus',),
'vettlausest': ('vettlaus',),
'vettlauseste': ('vettlaus',),
'vettlaust': ('vettlaus',),
'vettløs': ('vettløs',),
'vettløse': ('vettløs',),
'vettløsere': ('vettløs',),
'vettløsest': ('vettløs',),
'vettløseste': ('vettløs',),
'vettløst': ('vettløs',),
'vettskremmende': ('vettskremme',),
'vettskremt': ('vettskremme',),
'vettskremte': ('vettskremme',),
'vettug': ('vettug',),
'vettuge': ('vettug',),
'vettugere': ('vettug',),
'vettugst': ('vettug',),
'vettugste': ('vettug',),
'veva': ('veve',),
'vevd': ('veve',),
'vevde': ('veve',),
'vevede': ('veve',),
'vevende': ('veve',),
'vevet': ('veve',),
'vevete': ('veve',),
'vever': ('vever',),
'vevert': ('vever',),
'vevre': ('vever',),
'vevrere': ('vever',),
'vevrest': ('vever',),
'vevreste': ('vever',),
'vibrerende': ('vibrere',),
'vibrert': ('vibrere',),
'vibrerte': ('vibrere',),
'vid': ('vid',),
'vide': ('vid',),
'videre': ('vid',),
'videst': ('vid',),
'videste': ('vid',),
'vidt': ('vid',),
'vida': ('vide',),
'videde': ('vide',),
'vidende': ('vide',),
'videt': ('vide',),
'videte': ('vide',),
'videreforedla': ('videreforedle',),
'videreforedlede': ('videreforedle',),
'videreforedlende': ('videreforedle',),
'videreforedlet': ('videreforedle',),
'videreforedlete': ('videreforedle',),
'videregående': ('videregående',),
'viderekommen': ('viderekommen',),
'viderekommet': ('viderekommen',),
'viderekomne': ('viderekommen',),
'viderekomnere': ('viderekommen',),
'viderekomnest': ('viderekommen',),
'viderekomneste': ('viderekommen',),
'viderekommet': ('viderekommet',),
'viderekomne': ('viderekommet',),
'viderekomnere': ('viderekommet',),
'viderekomnest': ('viderekommet',),
'viderekomneste': ('viderekommet',),
'videresendende': ('videresende',),
'videresendt': ('videresende',),
'videresendte': ('videresende',),
'videreutdanna': ('videreutdanne',),
'videreutdannede': ('videreutdanne',),
'videreutdannende': ('videreutdanne',),
'videreutdannet': ('videreutdanne',),
'videreutdannete': ('videreutdanne',),
'videreutvikla': ('videreutvikle',),
'videreutviklede': ('videreutvikle',),
'videreutviklende': ('videreutvikle',),
'videreutviklet': ('videreutvikle',),
'videreutviklete': ('videreutvikle',),
'viderverdig': ('viderverdig',),
'viderverdige': ('viderverdig',),
'viderverdigere': ('viderverdig',),
'viderverdigst': ('viderverdig',),
'viderverdigste': ('viderverdig',),
'vidgjeten': ('vidgjeten',),
'vidgjetent': ('vidgjeten',),
'vidgjetne': ('vidgjeten',),
'vidgjetnere': ('vidgjeten',),
'vidgjetnest': ('vidgjeten',),
'vidgjetneste': ('vidgjeten',),
'vidkjent': ('vidkjent',),
'vidkjente': ('vidkjent',),
'vidkjentere': ('vidkjent',),
'vidkjentest': ('vidkjent',),
'vidkjenteste': ('vidkjent',),
'vidløftig': ('vidløftig',),
'vidløftige': ('vidløftig',),
'vidløftigere': ('vidløftig',),
'vidløftigst': ('vidløftig',),
'vidløftigste': ('vidløftig',),
'vidspurt': ('vidspurt',),
'vidspurte': ('vidspurt',),
'vidspurtere': ('vidspurt',),
'vidspurtest': ('vidspurt',),
'vidspurteste': ('vidspurt',),
'vidstrakt': ('vidstrakt',),
'vidstrakte': ('vidstrakt',),
'vidstraktere': ('vidstrakt',),
'vidstraktest': ('vidstrakt',),
'vidstrakteste': ('vidstrakt',),
'vidsynt': ('vidsynt',),
'vidsynte': ('vidsynt',),
'vidsyntere': ('vidsynt',),
'vidsyntest': ('vidsynt',),
'vidsynteste': ('vidsynt',),
'vidtfamnende': ('vidtfamnende',),
'vidtfavnende': ('vidtfavnende',),
'vidtgående': ('vidtgående',),
'vidtrekkende': ('vidtrekkende',),
'vidunderlig': ('vidunderlig',),
'vidunderlige': ('vidunderlig',),
'vidunderligere': ('vidunderlig',),
'vidunderligst': ('vidunderlig',),
'vidunderligste': ('vidunderlig',),
'vidåpen': ('vidåpen',),
'vidåpent': ('vidåpen',),
'vidåpne': ('vidåpen',),
'vidåpnere': ('vidåpen',),
'vidåpnest': ('vidåpen',),
'vidåpneste': ('vidåpen',),
'via': ('vie',),
'vidd': ('vie',),
'vidde': ('vie',),
'viede': ('vie',),
'viende': ('vie',),
'viet': ('vie',),
'viete': ('vie',),
'vigd': ('vie',),
'vigde': ('vie',),
'vietnamesisk': ('vietnamesisk',),
'vietnamesiske': ('vietnamesisk',),
'vietnamesiskere': ('vietnamesisk',),
'vietnamesiskest': ('vietnamesisk',),
'vietnamesiskeste': ('vietnamesisk',),
'vifta': ('vifte',),
'viftede': ('vifte',),
'viftende': ('vifte',),
'viftet': ('vifte',),
'viftete': ('vifte',),
'vifteforma': ('vifteforma',),
'vifteformede': ('vifteformet',),
'vifteformet': ('vifteformet',),
'vifteformete': ('vifteformet',),
'vifteformetere': ('vifteformet',),
'vifteformetest': ('vifteformet',),
'vifteformeteste': ('vifteformet',),
'vigga': ('vigge',),
'viggede': ('vigge',),
'viggende': ('vigge',),
'vigget': ('vigge',),
'viggete': ('vigge',),
'vigga': ('vigge',),
'viggede': ('vigge',),
'viggende': ('vigge',),
'vigget': ('vigge',),
'viggete': ('vigge',),
'vigil': ('vigil',),
'vigile': ('vigil',),
'vigilere': ('vigil',),
'vigilest': ('vigil',),
'vigileste': ('vigil',),
'vigilt': ('vigil',),
'vigilerende': ('vigilere',),
'vigilert': ('vigilere',),
'vigilerte': ('vigilere',),
'vigla': ('vigle',),
'viglede': ('vigle',),
'viglende': ('vigle',),
'viglet': ('vigle',),
'viglete': ('vigle',),
'vigorøs': ('vigorøs',),
'vigorøse': ('vigorøs',),
'vigorøsere': ('vigorøs',),
'vigorøsest': ('vigorøs',),
'vigorøseste': ('vigorøs',),
'vigorøst': ('vigorøs',),
'vigsla': ('vigsle',),
'vigslede': ('vigsle',),
'vigslende': ('vigsle',),
'vigslet': ('vigsle',),
'vigslete': ('vigsle',),
'vikarierende': ('vikariere',),
'vikariert': ('vikariere',),
'vikarierte': ('vikariere',),
'vikka': ('vikke',),
'vikkede': ('vikke',),
'vikkende': ('vikke',),
'vikket': ('vikke',),
'vikkete': ('vikke',),
'vikka': ('vikke',),
'vikkede': ('vikke',),
'vikkende': ('vikke',),
'vikket': ('vikke',),
'vikkete': ('vikke',),
'vikla': ('vikle',),
'viklede': ('vikle',),
'viklende': ('vikle',),
'viklet': ('vikle',),
'viklete': ('vikle',),
'viksk': ('viksk',),
'vikske': ('viksk',),
'vikskere': ('viksk',),
'vikskest': ('viksk',),
'vikskeste': ('viksk',),
'vikta': ('vikte',),
'viktede': ('vikte',),
'viktende': ('vikte',),
'viktet': ('vikte',),
'viktete': ('vikte',),
'viktig': ('viktig',),
'viktige': ('viktig',),
'viktigere': ('viktig',),
'viktigst': ('viktig',),
'viktigste': ('viktig',),
'viktoriansk': ('viktoriansk',),
'viktorianske': ('viktoriansk',),
'viktorianskere': ('viktoriansk',),
'viktorianskest': ('viktoriansk',),
'viktorianskeste': ('viktoriansk',),
'vikværsk': ('vikværsk',),
'vikværske': ('vikværsk',),
'vikværskere': ('vikværsk',),
'vikværskest': ('vikværsk',),
'vikværskeste': ('vikværsk',),
'vildra': ('vildre',),
'vildrede': ('vildre',),
'vildrende': ('vildre',),
'vildret': ('vildre',),
'vildrete': ('vildre',),
'vildren': ('vildren',),
'vildrene': ('vildren',),
'vildrenere': ('vildren',),
'vildrenest': ('vildren',),
'vildreneste': ('vildren',),
'vildrent': ('vildren',),
'vildrne': ('vildren',),
'vildrnere': ('vildren',),
'vildrnest': ('vildren',),
'vildrneste': ('vildren',),
'viljefast': ('viljefast',),
'viljefaste': ('viljefast',),
'viljefastere': ('viljefast',),
'viljefastest': ('viljefast',),
'viljefasteste': ('viljefast',),
'viljelaus': ('viljelaus',),
'viljelause': ('viljelaus',),
'viljelausere': ('viljelaus',),
'viljelausest': ('viljelaus',),
'viljelauseste': ('viljelaus',),
'viljelaust': ('viljelaus',),
'viljeløs': ('viljeløs',),
'viljeløse': ('viljeløs',),
'viljeløsere': ('viljeløs',),
'viljeløsest': ('viljeløs',),
'viljeløseste': ('viljeløs',),
'viljeløst': ('viljeløs',),
'viljesterk': ('viljesterk',),
'viljesterke': ('viljesterk',),
'viljesterkere': ('viljesterk',),
'viljesterkest': ('viljesterk',),
'viljesterkeste': ('viljesterk',),
'viljesterkt': ('viljesterk',),
'viljesvak': ('viljesvak',),
'viljesvake': ('viljesvak',),
'viljesvakere': ('viljesvak',),
'viljesvakest': ('viljesvak',),
'viljesvakeste': ('viljesvak',),
'viljesvakt': ('viljesvak',),
'vilkårlig': ('vilkårlig',),
'vilkårlige': ('vilkårlig',),
'vilkårligere': ('vilkårlig',),
'vilkårligst': ('vilkårlig',),
'vilkårligste': ('vilkårlig',),
'vilkårslaus': ('vilkårslaus',),
'vilkårslause': ('vilkårslaus',),
'vilkårslausere': ('vilkårslaus',),
'vilkårslausest': ('vilkårslaus',),
'vilkårslauseste': ('vilkårslaus',),
'vilkårslaust': ('vilkårslaus',),
'vilkårsløs': ('vilkårsløs',),
'vilkårsløse': ('vilkårsløs',),
'vilkårsløsere': ('vilkårsløs',),
'vilkårsløsest': ('vilkårsløs',),
'vilkårsløseste': ('vilkårsløs',),
'vilkårsløst': ('vilkårsløs',),
'vill': ('vill',),
'ville': ('vill',),
'villere': ('vill',),
'villest': ('vill',),
'villeste': ('vill',),
'vilt': ('vill',),
'vill-leda': ('vill-lede',),
'vill-ledede': ('vill-lede',),
'vill-ledende': ('vill-lede',),
'vill-ledet': ('vill-lede',),
'vill-ledete': ('vill-lede',),
'vill-leid': ('vill-leie',),
'vill-leidd': ('vill-leie',),
'vill-leidde': ('vill-leie',),
'vill-leide': ('vill-leie',),
'vill-leiede': ('vill-leie',),
'vill-leiende': ('vill-leie',),
'vill-leiet': ('vill-leie',),
'vill-leiete': ('vill-leie',),
'villende': ('ville',),
'villet': ('ville',),
'villeda': ('villede',),
'villedede': ('villede',),
'villedende': ('villede',),
'villedet': ('villede',),
'villedete': ('villede',),
'villeid': ('villeie',),
'villeidd': ('villeie',),
'villeidde': ('villeie',),
'villeide': ('villeie',),
'villeiede': ('villeie',),
'villeiende': ('villeie',),
'villeiet': ('villeie',),
'villeiete': ('villeie',),
'villfaren': ('villfaren',),
'villfarent': ('villfaren',),
'villfarne': ('villfaren',),
'villfarnere': ('villfaren',),
'villfarnest': ('villfaren',),
'villfarneste': ('villfaren',),
'villig': ('villig',),
'villige': ('villig',),
'villigere': ('villig',),
'villigst': ('villig',),
'villigste': ('villig',),
'villrådig': ('villrådig',),
'villrådige': ('villrådig',),
'villrådigere': ('villrådig',),
'villrådigst': ('villrådig',),
'villrådigste': ('villrådig',),
'vilter': ('vilter',),
'viltert': ('vilter',),
'viltre': ('vilter',),
'viltrere': ('vilter',),
'viltrest': ('vilter',),
'viltreste': ('vilter',),
'viltvoksende': ('viltvoksende',),
'vima': ('vime',),
'vimede': ('vime',),
'vimende': ('vime',),
'vimet': ('vime',),
'vimete': ('vime',),
'vimen': ('vimen',),
'viment': ('vimen',),
'vimne': ('vimen',),
'vimnere': ('vimen',),
'vimnest': ('vimen',),
'vimneste': ('vimen',),
'vimet': ('vimet',),
'vimete': ('vimet',),
'vimetere': ('vimet',),
'vimetest': ('vimet',),
'vimeteste': ('vimet',),
'vimete': ('vimete',),
'vimra': ('vimre',),
'vimrede': ('vimre',),
'vimrende': ('vimre',),
'vimret': ('vimre',),
'vimrete': ('vimre',),
'vimsa': ('vimse',),
'vimsede': ('vimse',),
'vimsende': ('vimse',),
'vimset': ('vimse',),
'vimsete': ('vimse',),
'vimset': ('vimset',),
'vimsete': ('vimset',),
'vimsetere': ('vimset',),
'vimsetest': ('vimset',),
'vimseteste': ('vimset',),
'vimsete': ('vimsete',),
'vind': ('vind',),
'vinde': ('vind',),
'vindere': ('vind',),
'vindest': ('vind',),
'vindeste': ('vind',),
'vindt': ('vind',),
'vinddrevet': ('vinddrevet',),
'vinddrevne': ('vinddrevet',),
'vinddrevnere': ('vinddrevet',),
'vinddrevnest': ('vinddrevet',),
'vinddrevneste': ('vinddrevet',),
'vindende': ('vinde',),
'vunden': ('vinde',),
'vundet': ('vinde',),
'vundne': ('vinde',),
'vindfelt': ('vindfelt',),
'vindfelte': ('vindfelt',),
'vindfeltere': ('vindfelt',),
'vindfeltest': ('vindfelt',),
'vindfelteste': ('vindfelt',),
'vindhard': ('vindhard',),
'vindharde': ('vindhard',),
'vindhardere': ('vindhard',),
'vindhardest': ('vindhard',),
'vindhardeste': ('vindhard',),
'vindhardt': ('vindhard',),
'vindikabel': ('vindikabel',),
'vindikabelt': ('vindikabel',),
'vindikable': ('vindikabel',),
'vindikablere': ('vindikabel',),
'vindikablest': ('vindikabel',),
'vindikableste': ('vindikabel',),
'vindiserende': ('vindisere',),
'vindisert': ('vindisere',),
'vindiserte': ('vindisere',),
'vindrett': ('vindrett',),
'vindrette': ('vindrett',),
'vindrettere': ('vindrett',),
'vindrettest': ('vindrett',),
'vindretteste': ('vindrett',),
'vindskeiv': ('vindskeiv',),
'vindskeive': ('vindskeiv',),
'vindskeivere': ('vindskeiv',),
'vindskeivest': ('vindskeiv',),
'vindskeiveste': ('vindskeiv',),
'vindskeivt': ('vindskeiv',),
'vindskeiv': ('vindskeiv',),
'vindskeive': ('vindskeiv',),
'vindskeivere': ('vindskeiv',),
'vindskeivest': ('vindskeiv',),
'vindskeiveste': ('vindskeiv',),
'vindskeivt': ('vindskeiv',),
'vindskjev': ('vindskjev',),
'vindskjeve': ('vindskjev',),
'vindskjevere': ('vindskjev',),
'vindskjevest': ('vindskjev',),
'vindskjeveste': ('vindskjev',),
'vindskjevt': ('vindskjev',),
'vindskjev': ('vindskjev',),
'vindskjeve': ('vindskjev',),
'vindskjevere': ('vindskjev',),
'vindskjevest': ('vindskjev',),
'vindskjeveste': ('vindskjev',),
'vindskjevt': ('vindskjev',),
'vindtett': ('vindtett',),
'vindtette': ('vindtett',),
'vindtettere': ('vindtett',),
'vindtettest': ('vindtett',),
'vindtetteste': ('vindtett',),
'vindtørka': ('vindtørke',),
'vindtørkede': ('vindtørke',),
'vindtørkende': ('vindtørke',),
'vindtørket': ('vindtørke',),
'vindtørkete': ('vindtørke',),
'vindtørr': ('vindtørr',),
'vindtørre': ('vindtørr',),
'vindtørrere': ('vindtørr',),
'vindtørrest': ('vindtørr',),
'vindtørreste': ('vindtørr',),
'vindtørt': ('vindtørr',),
'vinga': ('vinga',),
'vinga': ('vinga',),
'vinga': ('vinga',),
'vinga': ('vinge',),
'vingede': ('vinge',),
'vingende': ('vinge',),
'vinget': ('vinge',),
'vingete': ('vinge',),
'vingeskutt': ('vingeskutt',),
'vingeskutte': ('vingeskutt',),
'vingeskuttere': ('vingeskutt',),
'vingeskuttest': ('vingeskutt',),
'vingeskutteste': ('vingeskutt',),
'vingede': ('vinget',),
'vinget': ('vinget',),
'vingete': ('vinget',),
'vingetere': ('vinget',),
'vingetest': ('vinget',),
'vingeteste': ('vinget',),
'vingede': ('vinget',),
'vinget': ('vinget',),
'vingete': ('vinget',),
'vingetere': ('vinget',),
'vingetest': ('vinget',),
'vingeteste': ('vinget',),
'vingede': ('vinget',),
'vinget': ('vinget',),
'vingete': ('vinget',),
'vingetere': ('vinget',),
'vingetest': ('vinget',),
'vingeteste': ('vinget',),
'vingla': ('vingle',),
'vinglede': ('vingle',),
'vinglende': ('vingle',),
'vinglet': ('vingle',),
'vinglete': ('vingle',),
'vinglet': ('vinglet',),
'vinglete': ('vinglet',),
'vingletere': ('vinglet',),
'vingletest': ('vinglet',),
'vingleteste': ('vinglet',),
'vinglete': ('vinglete',),
'vinka': ('vinke',),
'vinkede': ('vinke',),
'vinkende': ('vinke',),
'vinket': ('vinke',),
'vinkete': ('vinke',),
'vinkelrett': ('vinkelrett',),
'vinkelrette': ('vinkelrett',),
'vinkelrettere': ('vinkelrett',),
'vinkelrettest': ('vinkelrett',),
'vinkelretteste': ('vinkelrett',),
'vinkla': ('vinkle',),
'vinklede': ('vinkle',),
'vinklende': ('vinkle',),
'vinklet': ('vinkle',),
'vinklete': ('vinkle',),
'vinnende': ('vinnende',),
'vinnesjuk': ('vinnesjuk',),
'vinnesjuke': ('vinnesjuk',),
'vinnesjukere': ('vinnesjuk',),
'vinnesjukest': ('vinnesjuk',),
'vinnesjukeste': ('vinnesjuk',),
'vinnesjukt': ('vinnesjuk',),
'vinnesyk': ('vinnesyk',),
'vinnesyke': ('vinnesyk',),
'vinnesykere': ('vinnesyk',),
'vinnesykest': ('vinnesyk',),
'vinnesykeste': ('vinnesyk',),
'vinnesykt': ('vinnesyk',),
'vinnskipelig': ('vinnskipelig',),
'vinnskipelige': ('vinnskipelig',),
'vinnskipeligere': ('vinnskipelig',),
'vinnskipeligst': ('vinnskipelig',),
'vinnskipeligste': ('vinnskipelig',),
'vinrød': ('vinrød',),
'vinrøde': ('vinrød',),
'vinrødere': ('vinrød',),
'vinrødest': ('vinrød',),
'vinrødeste': ('vinrød',),
'vinrødt': ('vinrød',),
'vinsja': ('vinsje',),
'vinsjede': ('vinsje',),
'vinsjende': ('vinsje',),
'vinsjet': ('vinsje',),
'vinsjete': ('vinsje',),
'vintergrøn': ('vintergrøn',),
'vintergrøne': ('vintergrøn',),
'vintergrønere': ('vintergrøn',),
'vintergrønest': ('vintergrøn',),
'vintergrøneste': ('vintergrøn',),
'vintergrønt': ('vintergrøn',),
'vintergrønn': ('vintergrønn',),
'vintergrønne': ('vintergrønn',),
'vintergrønnere': ('vintergrønn',),
'vintergrønnest': ('vintergrønn',),
'vintergrønneste': ('vintergrønn',),
'vintergrønt': ('vintergrønn',),
'vinterherdig': ('vinterherdig',),
'vinterherdige': ('vinterherdig',),
'vinterherdigere': ('vinterherdig',),
'vinterherdigst': ('vinterherdig',),
'vinterherdigste': ('vinterherdig',),
'vinterisolerende': ('vinterisolere',),
'vinterisolert': ('vinterisolere',),
'vinterisolerte': ('vinterisolere',),
'vinterlig': ('vinterlig',),
'vinterlige': ('vinterlig',),
'vinterligere': ('vinterlig',),
'vinterligst': ('vinterlig',),
'vinterligste': ('vinterlig',),
'vintra': ('vintre',),
'vintrede': ('vintre',),
'vintrende': ('vintre',),
'vintret': ('vintre',),
'vintrete': ('vintre',),
'vinøs': ('vinøs',),
'vinøse': ('vinøs',),
'vinøsere': ('vinøs',),
'vinøsest': ('vinøs',),
'vinøseste': ('vinøs',),
'vinøst': ('vinøs',),
'vippa': ('vippe',),
'vippede': ('vippe',),
'vippende': ('vippe',),
'vippet': ('vippe',),
'vippete': ('vippe',),
'virende': ('vire',),
'virt': ('vire',),
'virte': ('vire',),
'viril': ('viril',),
'virile': ('viril',),
'virilere': ('viril',),
'virilest': ('viril',),
'virileste': ('viril',),
'virilt': ('viril',),
'viriliserende': ('virilisere',),
'virilisert': ('virilisere',),
'viriliserte': ('virilisere',),
'virka': ('virke',),
'virkede': ('virke',),
'virkende': ('virke',),
'virket': ('virke',),
'virkete': ('virke',),
'virkelig': ('virkelig',),
'virkelige': ('virkelig',),
'virkeligere': ('virkelig',),
'virkeligst': ('virkelig',),
'virkeligste': ('virkelig',),
'virkeliggjort': ('virkeliggjøre',),
'virkeliggjorte': ('virkeliggjøre',),
'virkeliggjørende': ('virkeliggjøre',),
'virkelighetsfjern': ('virkelighetsfjern',),
'virkelighetsfjerne': ('virkelighetsfjern',),
'virkelighetsfjernere': ('virkelighetsfjern',),
'virkelighetsfjernest': ('virkelighetsfjern',),
'virkelighetsfjerneste': ('virkelighetsfjern',),
'virkelighetsfjernt': ('virkelighetsfjern',),
'virkelighetsnær': ('virkelighetsnær',),
'virkelighetsnære': ('virkelighetsnær',),
'virkelighetsnærere': ('virkelighetsnær',),
'virkelighetsnærest': ('virkelighetsnær',),
'virkelighetsnæreste': ('virkelighetsnær',),
'virkelighetsnært': ('virkelighetsnær',),
'virkelysten': ('virkelysten',),
'virkelystent': ('virkelysten',),
'virkelystne': ('virkelysten',),
'virkelystnere': ('virkelysten',),
'virkelystnest': ('virkelysten',),
'virkelystneste': ('virkelysten',),
'virkningsfull': ('virkningsfull',),
'virkningsfulle': ('virkningsfull',),
'virkningsfullere': ('virkningsfull',),
'virkningsfullest': ('virkningsfull',),
'virkningsfulleste': ('virkningsfull',),
'virkningsfullt': ('virkningsfull',),
'virkningslaus': ('virkningslaus',),
'virkningslause': ('virkningslaus',),
'virkningslausere': ('virkningslaus',),
'virkningslausest': ('virkningslaus',),
'virkningslauseste': ('virkningslaus',),
'virkningslaust': ('virkningslaus',),
'virkningsløs': ('virkningsløs',),
'virkningsløse': ('virkningsløs',),
'virkningsløsere': ('virkningsløs',),
'virkningsløsest': ('virkningsløs',),
'virkningsløseste': ('virkningsløs',),
'virkningsløst': ('virkningsløs',),
'virksom': ('virksom',),
'virksomme': ('virksom',),
'virksommere': ('virksom',),
'virksomst': ('virksom',),
'virksomste': ('virksom',),
'virksomt': ('virksom',),
'virologisk': ('virologisk',),
'virologiske': ('virologisk',),
'virologiskere': ('virologisk',),
'virologiskest': ('virologisk',),
'virologiskeste': ('virologisk',),
'virra': ('virre',),
'virrede': ('virre',),
'virrende': ('virre',),
'virret': ('virre',),
'virrete': ('virre',),
'virtuell': ('virtuell',),
'virtuelle': ('virtuell',),
'virtuellere': ('virtuell',),
'virtuellest': ('virtuell',),
'virtuelleste': ('virtuell',),
'virtuelt': ('virtuell',),
'virtuos': ('virtuos',),
'virtuose': ('virtuos',),
'virtuosere': ('virtuos',),
'virtuosest': ('virtuos',),
'virtuoseste': ('virtuos',),
'virtuost': ('virtuos',),
'virulent': ('virulent',),
'virulente': ('virulent',),
'virulentere': ('virulent',),
'virulentest': ('virulent',),
'virulenteste': ('virulent',),
'virvellaus': ('virvellaus',),
'virvellause': ('virvellaus',),
'virvellausere': ('virvellaus',),
'virvellausest': ('virvellaus',),
'virvellauseste': ('virvellaus',),
'virvellaust': ('virvellaus',),
'virvelløs': ('virvelløs',),
'virvelløse': ('virvelløs',),
'virvelløsere': ('virvelløs',),
'virvelløsest': ('virvelløs',),
'virvelløseste': ('virvelløs',),
'virvelløst': ('virvelløs',),
'virvla': ('virvle',),
'virvlede': ('virvle',),
'virvlende': ('virvle',),
'virvlet': ('virvle',),
'virvlete': ('virvle',),
'vis': ('vis',),
'vise': ('vis',),
'visere': ('vis',),
'visest': ('vis',),
'viseste': ('vis',),
'vist': ('vis',),
'visende': ('vise',),
'vist': ('vise',),
'viste': ('vise',),
'viserende': ('visere',),
'visert': ('visere',),
'viserte': ('visere',),
'visibel': ('visibel',),
'visibelt': ('visibel',),
'visible': ('visibel',),
'visiblere': ('visibel',),
'visiblest': ('visibel',),
'visibleste': ('visibel',),
'visiterende': ('visitere',),
'visitert': ('visitere',),
'visiterte': ('visitere',),
'visjonær': ('visjonær',),
'visjonære': ('visjonær',),
'visjonærere': ('visjonær',),
'visjonærest': ('visjonær',),
'visjonæreste': ('visjonær',),
'visjonært': ('visjonær',),
'viska': ('viske',),
'viskede': ('viske',),
'viskende': ('viske',),
'visket': ('viske',),
'viskete': ('viske',),
'viskos': ('viskos',),
'viskose': ('viskos',),
'viskosere': ('viskos',),
'viskosest': ('viskos',),
'viskoseste': ('viskos',),
'viskost': ('viskos',),
'viskøs': ('viskøs',),
'viskøse': ('viskøs',),
'viskøsere': ('viskøs',),
'viskøsest': ('viskøs',),
'viskøseste': ('viskøs',),
'viskøst': ('viskøs',),
'visla': ('visle',),
'vislede': ('visle',),
'vislende': ('visle',),
'vislet': ('visle',),
'vislete': ('visle',),
'visna': ('visne',),
'visnede': ('visne',),
'visnende': ('visne',),
'visnet': ('visne',),
'visnete': ('visne',),
'vispa': ('vispe',),
'vispede': ('vispe',),
'vispende': ('vispe',),
'vispet': ('vispe',),
'vispete': ('vispe',),
'viss': ('viss',),
'visse': ('viss',),
'vissere': ('viss',),
'vissest': ('viss',),
'visseste': ('viss',),
'visst': ('viss',),
'visne': ('vissen',),
'visnere': ('vissen',),
'visnest': ('vissen',),
'visneste': ('vissen',),
'vissen': ('vissen',),
'vissent': ('vissen',),
'visualiserende': ('visualisere',),
'visualisert': ('visualisere',),
'visualiserte': ('visualisere',),
'visuell': ('visuell',),
'visuelle': ('visuell',),
'visuellere': ('visuell',),
'visuellest': ('visuell',),
'visuelleste': ('visuell',),
'visuelt': ('visuell',),
'vital': ('vital',),
'vitale': ('vital',),
'vitalere': ('vital',),
'vitalest': ('vital',),
'vitaleste': ('vital',),
'vitalt': ('vital',),
'vitaliserende': ('vitalisere',),
'vitalisert': ('vitalisere',),
'vitaliserte': ('vitalisere',),
'vitalistisk': ('vitalistisk',),
'vitalistiske': ('vitalistisk',),
'vitalistiskere': ('vitalistisk',),
'vitalistiskest': ('vitalistisk',),
'vitalistiskeste': ('vitalistisk',),
'vitaminiserende': ('vitaminisere',),
'vitaminisert': ('vitaminisere',),
'vitaminiserte': ('vitaminisere',),
'visst': ('vite',),
'visste': ('vite',),
'vitende': ('vite',),
'vitebegjærlig': ('vitebegjærlig',),
'vitebegjærlige': ('vitebegjærlig',),
'vitebegjærligere': ('vitebegjærlig',),
'vitebegjærligst': ('vitebegjærlig',),
'vitebegjærligste': ('vitebegjærlig',),
'vitelysten': ('vitelysten',),
'vitelystent': ('vitelysten',),
'vitelystne': ('vitelysten',),
'vitelystnere': ('vitelysten',),
'vitelystnest': ('vitelysten',),
'vitelystneste': ('vitelysten',),
'vitenskapelig': ('vitenskapelig',),
'vitenskapelige': ('vitenskapelig',),
'vitenskapeligere': ('vitenskapelig',),
'vitenskapeligst': ('vitenskapelig',),
'vitenskapeligste': ('vitenskapelig',),
'vitenskapelig': ('vitenskapelig',),
'vitenskapelige': ('vitenskapelig',),
'vitenskapeligere': ('vitenskapelig',),
'vitenskapeligst': ('vitenskapelig',),
'vitenskapeligste': ('vitenskapelig',),
'vitja': ('vitje',),
'vitjede': ('vitje',),
'vitjende': ('vitje',),
'vitjet': ('vitje',),
'vitjete': ('vitje',),
'vitna': ('vitne',),
'vitnede': ('vitne',),
'vitnende': ('vitne',),
'vitnet': ('vitne',),
'vitnete': ('vitne',),
'vitnefast': ('vitnefast',),
'vitnefaste': ('vitnefast',),
'vitnefastere': ('vitnefast',),
'vitnefastest': ('vitnefast',),
'vitnefasteste': ('vitnefast',),
'vitnefør': ('vitnefør',),
'vitneføre': ('vitnefør',),
'vitneførere': ('vitnefør',),
'vitneførest': ('vitnefør',),
'vitneføreste': ('vitnefør',),
'vitneført': ('vitnefør',),
'vitsa': ('vitse',),
'vitsede': ('vitse',),
'vitsende': ('vitse',),
'vitset': ('vitse',),
'vitsete': ('vitse',),
'vitskapelig': ('vitskapelig',),
'vitskapelige': ('vitskapelig',),
'vitskapeligere': ('vitskapelig',),
'vitskapeligst': ('vitskapelig',),
'vitskapeligste': ('vitskapelig',),
'vitskapelig': ('vitskapelig',),
'vitskapelige': ('vitskapelig',),
'vitskapeligere': ('vitskapelig',),
'vitskapeligst': ('vitskapelig',),
'vitskapeligste': ('vitskapelig',),
'vitterlig': ('vitterlig',),
'vitterlige': ('vitterlig',),
'vitterligere': ('vitterlig',),
'vitterligst': ('vitterlig',),
'vitterligste': ('vitterlig',),
'vittig': ('vittig',),
'vittige': ('vittig',),
'vittigere': ('vittig',),
'vittigst': ('vittig',),
'vittigste': ('vittig',),
'vivipar': ('vivipar',),
'vivipare': ('vivipar',),
'viviparere': ('vivipar',),
'viviparest': ('vivipar',),
'vivipareste': ('vivipar',),
'vivipart': ('vivipar',),
'vivisekerende': ('vivisekere',),
'vivisekert': ('vivisekere',),
'vivisekerte': ('vivisekere',),
'voffa': ('voffe',),
'voffede': ('voffe',),
'voffende': ('voffe',),
'voffet': ('voffe',),
'voffete': ('voffe',),
'vokal': ('vokal',),
'vokale': ('vokal',),
'vokalere': ('vokal',),
'vokalest': ('vokal',),
'vokaleste': ('vokal',),
'vokalt': ('vokal',),
'vokaliserende': ('vokalisere',),
'vokalisert': ('vokalisere',),
'vokaliserte': ('vokalisere',),
'vokalisk': ('vokalisk',),
'vokaliske': ('vokalisk',),
'vokaliskere': ('vokalisk',),
'vokaliskest': ('vokalisk',),
'vokaliskeste': ('vokalisk',),
'vokativisk': ('vokativisk',),
'vokativiske': ('vokativisk',),
'vokativiskere': ('vokativisk',),
'vokativiskest': ('vokativisk',),
'vokativiskeste': ('vokativisk',),
'voksa': ('vokse',),
'voksede': ('vokse',),
'voksende': ('vokse',),
'vokset': ('vokse',),
'voksete': ('vokse',),
'voksende': ('vokse',),
'vokst': ('vokse',),
'vokste': ('vokse',),
'voksen': ('voksen',),
'voksent': ('voksen',),
'voksne': ('voksen',),
'voksnere': ('voksen',),
'voksnest': ('voksen',),
'voksneste': ('voksen',),
'voksterlig': ('voksterlig',),
'voksterlige': ('voksterlig',),
'voksterligere': ('voksterlig',),
'voksterligst': ('voksterlig',),
'voksterligste': ('voksterlig',),
'vokta': ('vokte',),
'voktede': ('vokte',),
'voktende': ('vokte',),
'voktet': ('vokte',),
'voktete': ('vokte',),
'voldende': ('volde',),
'voldt': ('volde',),
'voldte': ('volde',),
'voldelig': ('voldelig',),
'voldelige': ('voldelig',),
'voldeligere': ('voldelig',),
'voldeligst': ('voldelig',),
'voldeligste': ('voldelig',),
'voldsom': ('voldsom',),
'voldsomme': ('voldsom',),
'voldsommere': ('voldsom',),
'voldsomst': ('voldsom',),
'voldsomste': ('voldsom',),
'voldsomt': ('voldsom',),
'voldtakende': ('voldta',),
'voldtatt': ('voldta',),
'voldtatte': ('voldta',),
'voltansk': ('voltansk',),
'voltanske': ('voltansk',),
'voltanskere': ('voltansk',),
'voltanskest': ('voltansk',),
'voltanskeste': ('voltansk',),
'volterende': ('voltere',),
'voltert': ('voltere',),
'volterte': ('voltere',),
'voltigerende': ('voltigere',),
'voltigert': ('voltigere',),
'voltigerte': ('voltigere',),
'volumetrisk': ('volumetrisk',),
'volumetriske': ('volumetrisk',),
'volumetriskere': ('volumetrisk',),
'volumetriskest': ('volumetrisk',),
'volumetriskeste': ('volumetrisk',),
'voluminøs': ('voluminøs',),
'voluminøse': ('voluminøs',),
'voluminøsere': ('voluminøs',),
'voluminøsest': ('voluminøs',),
'voluminøseste': ('voluminøs',),
'voluminøst': ('voluminøs',),
'vomerende': ('vomere',),
'vomert': ('vomere',),
'vomerte': ('vomere',),
'vonbroten': ('vonbroten',),
'vonbrotent': ('vonbroten',),
'vonbrotne': ('vonbroten',),
'vonbrotnere': ('vonbroten',),
'vonbrotnest': ('vonbroten',),
'vonbrotneste': ('vonbroten',),
'verre': ('vond',),
'verst': ('vond',),
'verste': ('vond',),
'vond': ('vond',),
'vonde': ('vond',),
'vondere': ('vond',),
'vondest': ('vond',),
'vondeste': ('vond',),
'vondt': ('vond',),
'vondlynt': ('vondlynt',),
'vondlynte': ('vondlynt',),
'vondlyntere': ('vondlynt',),
'vondlyntest': ('vondlynt',),
'vondlynteste': ('vondlynt',),
'vona': ('vone',),
'vonede': ('vone',),
'vonende': ('vone',),
'vonet': ('vone',),
'vonete': ('vone',),
'vont': ('vone',),
'vonte': ('vone',),
'vonløs': ('vonløs',),
'vonløse': ('vonløs',),
'vonløsere': ('vonløs',),
'vonløsest': ('vonløs',),
'vonløseste': ('vonløs',),
'vonløst': ('vonløs',),
'vordende': ('vordende',),
'vorteforma': ('vorteforma',),
'vorteformede': ('vorteformet',),
'vorteformet': ('vorteformet',),
'vorteformete': ('vorteformet',),
'vorteformetere': ('vorteformet',),
'vorteformetest': ('vorteformet',),
'vorteformeteste': ('vorteformet',),
'vortet': ('vortet',),
'vortete': ('vortet',),
'vortetere': ('vortet',),
'vortetest': ('vortet',),
'vorteteste': ('vortet',),
'vortete': ('vortete',),
'voterende': ('votere',),
'votert': ('votere',),
'voterte': ('votere',),
'vova': ('vove',),
'vovede': ('vove',),
'vovende': ('vove',),
'vovet': ('vove',),
'vovete': ('vove',),
'vovede': ('vovet',),
'vovet': ('vovet',),
'vovete': ('vovet',),
'vovetere': ('vovet',),
'vovetest': ('vovet',),
'voveteste': ('vovet',),
'vraka': ('vrake',),
'vrakede': ('vrake',),
'vrakende': ('vrake',),
'vraket': ('vrake',),
'vrakete': ('vrake',),
'vrakt': ('vrake',),
'vrakte': ('vrake',),
'vralta': ('vralte',),
'vraltede': ('vralte',),
'vraltende': ('vralte',),
'vraltet': ('vralte',),
'vraltete': ('vralte',),
'vrang': ('vrang',),
'vrange': ('vrang',),
'vrangere': ('vrang',),
'vrangest': ('vrang',),
'vrangeste': ('vrang',),
'vrangt': ('vrang',),
'vrangvillig': ('vrangvillig',),
'vrangvillige': ('vrangvillig',),
'vrangvilligere': ('vrangvillig',),
'vrangvilligst': ('vrangvillig',),
'vrangvilligste': ('vrangvillig',),
'vranten': ('vranten',),
'vrantent': ('vranten',),
'vrantne': ('vranten',),
'vrantnere': ('vranten',),
'vrantnest': ('vranten',),
'vrantneste': ('vranten',),
'vred': ('vred',),
'vrede': ('vred',),
'vredere': ('vred',),
'vredest': ('vred',),
'vredeste': ('vred',),
'vredt': ('vred',),
'vrengende': ('vrenge',),
'vrengt': ('vrenge',),
'vrengte': ('vrenge',),
'vridd': ('vri',),
'vridde': ('vri',),
'vriende': ('vri',),
'vribar': ('vribar',),
'vribare': ('vribar',),
'vribarere': ('vribar',),
'vribarest': ('vribar',),
'vribareste': ('vribar',),
'vribart': ('vribar',),
'vrien': ('vrien',),
'vriene': ('vrien',),
'vrienere': ('vrien',),
'vrienest': ('vrien',),
'vrieneste': ('vrien',),
'vrient': ('vrien',),
'vrine': ('vrien',),
'vrinere': ('vrien',),
'vrinest': ('vrien',),
'vrineste': ('vrien',),
'vrikka': ('vrikke',),
'vrikkede': ('vrikke',),
'vrikkende': ('vrikke',),
'vrikket': ('vrikke',),
'vrikkete': ('vrikke',),
'vrikla': ('vrikle',),
'vriklede': ('vrikle',),
'vriklende': ('vrikle',),
'vriklet': ('vrikle',),
'vriklete': ('vrikle',),
'vrimla': ('vrimle',),
'vrimlede': ('vrimle',),
'vrimlende': ('vrimle',),
'vrimlet': ('vrimle',),
'vrimlete': ('vrimle',),
'vringla': ('vringle',),
'vringlede': ('vringle',),
'vringlende': ('vringle',),
'vringlet': ('vringle',),
'vringlete': ('vringle',),
'vringlet': ('vringlet',),
'vringlete': ('vringlet',),
'vringletere': ('vringlet',),
'vringletest': ('vringlet',),
'vringleteste': ('vringlet',),
'vringlete': ('vringlete',),
'vrinsk': ('vrinsk',),
'vrinske': ('vrinsk',),
'vrinskere': ('vrinsk',),
'vrinskest': ('vrinsk',),
'vrinskeste': ('vrinsk',),
'vrinskt': ('vrinsk',),
'vrinska': ('vrinske',),
'vrinskede': ('vrinske',),
'vrinskende': ('vrinske',),
'vrinsket': ('vrinske',),
'vrinskete': ('vrinske',),
'vrista': ('vriste',),
'vristede': ('vriste',),
'vristende': ('vriste',),
'vristet': ('vriste',),
'vristete': ('vriste',),
'vrælende': ('vræle',),
'vrælt': ('vræle',),
'vrælte': ('vræle',),
'vrøvla': ('vrøvle',),
'vrøvlede': ('vrøvle',),
'vrøvlende': ('vrøvle',),
'vrøvlet': ('vrøvle',),
'vrøvlete': ('vrøvle',),
'vrøvlet': ('vrøvlet',),
'vrøvlete': ('vrøvlet',),
'vrøvletere': ('vrøvlet',),
'vrøvletest': ('vrøvlet',),
'vrøvleteste': ('vrøvlet',),
'vrøvlete': ('vrøvlete',),
'vugga': ('vugge',),
'vuggede': ('vugge',),
'vuggende': ('vugge',),
'vugget': ('vugge',),
'vuggete': ('vugge',),
'vulgariserende': ('vulgarisere',),
'vulgarisert': ('vulgarisere',),
'vulgariserte': ('vulgarisere',),
'vulgær': ('vulgær',),
'vulgære': ('vulgær',),
'vulgærere': ('vulgær',),
'vulgærest': ('vulgær',),
'vulgæreste': ('vulgær',),
'vulgært': ('vulgær',),
'vulkaniserende': ('vulkanisere',),
'vulkanisert': ('vulkanisere',),
'vulkaniserte': ('vulkanisere',),
'vulkanologisk': ('vulkanologisk',),
'vulkanologiske': ('vulkanologisk',),
'vulkanologiskere': ('vulkanologisk',),
'vulkanologiskest': ('vulkanologisk',),
'vulkanologiskeste': ('vulkanologisk',),
'vulkansk': ('vulkansk',),
'vulkanske': ('vulkansk',),
'vulkanskere': ('vulkansk',),
'vulkanskest': ('vulkansk',),
'vulkanskeste': ('vulkansk',),
'vulka': ('vulke',),
'vulkede': ('vulke',),
'vulkende': ('vulke',),
'vulket': ('vulke',),
'vulkete': ('vulke',),
'vunne': ('vunnen',),
'vunnen': ('vunnen',),
'vunnere': ('vunnen',),
'vunnest': ('vunnen',),
'vunneste': ('vunnen',),
'vunnet': ('vunnen',),
'vunne': ('vunnet',),
'vunnere': ('vunnet',),
'vunnest': ('vunnet',),
'vunneste': ('vunnet',),
'vunnet': ('vunnet',),
'vurderende': ('vurdere',),
'vurdert': ('vurdere',),
'vurderte': ('vurdere',),
'vyrk': ('vyrk',),
'vyrke': ('vyrk',),
'vyrkere': ('vyrk',),
'vyrkest': ('vyrk',),
'vyrkeste': ('vyrk',),
'vyrkt': ('vyrk',),
'vådelig': ('vådelig',),
'vådelige': ('vådelig',),
'vådeligere': ('vådelig',),
'vådeligst': ('vådelig',),
'vådeligste': ('vådelig',),
'vågal': ('vågal',),
'vågale': ('vågal',),
'vågalere': ('vågal',),
'vågalest': ('vågal',),
'vågaleste': ('vågal',),
'vågalt': ('vågal',),
'våga': ('våge',),
'vågd': ('våge',),
'vågde': ('våge',),
'vågede': ('våge',),
'vågende': ('våge',),
'våget': ('våge',),
'vågete': ('våge',),
'vågelig': ('vågelig',),
'vågelige': ('vågelig',),
'vågeligere': ('vågelig',),
'vågeligst': ('vågelig',),
'vågeligste': ('vågelig',),
'vågsom': ('vågsom',),
'vågsomme': ('vågsom',),
'vågsommere': ('vågsom',),
'vågsomst': ('vågsom',),
'vågsomste': ('vågsom',),
'vågsomt': ('vågsom',),
'våka': ('våke',),
'våkede': ('våke',),
'våkende': ('våke',),
'våket': ('våke',),
'våkete': ('våke',),
'våkt': ('våke',),
'våkte': ('våke',),
'våken': ('våken',),
'våkent': ('våken',),
'våkne': ('våken',),
'våknere': ('våken',),
'våknest': ('våken',),
'våkneste': ('våken',),
'våkna': ('våkne',),
'våknede': ('våkne',),
'våknende': ('våkne',),
'våknet': ('våkne',),
'våknete': ('våkne',),
'våla': ('våle',),
'vålede': ('våle',),
'vålende': ('våle',),
'vålet': ('våle',),
'vålete': ('våle',),
'vålt': ('våle',),
'vålte': ('våle',),
'vånda': ('vånde',),
'våndede': ('vånde',),
'våndende': ('vånde',),
'våndet': ('vånde',),
'våndete': ('vånde',),
'våpenfør': ('våpenfør',),
'våpenføre': ('våpenfør',),
'våpenførere': ('våpenfør',),
'våpenførest': ('våpenfør',),
'våpenføreste': ('våpenfør',),
'våpenført': ('våpenfør',),
'våpenlaus': ('våpenlaus',),
'våpenlause': ('våpenlaus',),
'våpenlausere': ('våpenlaus',),
'våpenlausest': ('våpenlaus',),
'våpenlauseste': ('våpenlaus',),
'våpenlaust': ('våpenlaus',),
'våpenløs': ('våpenløs',),
'våpenløse': ('våpenløs',),
'våpenløsere': ('våpenløs',),
'våpenløsest': ('våpenløs',),
'våpenløseste': ('våpenløs',),
'våpenløst': ('våpenløs',),
'våpenteknisk': ('våpenteknisk',),
'våpentekniske': ('våpenteknisk',),
'våpentekniskere': ('våpenteknisk',),
'våpentekniskest': ('våpenteknisk',),
'våpentekniskeste': ('våpenteknisk',),
'våpenvant': ('våpenvant',),
'våpenvante': ('våpenvant',),
'våpenvantere': ('våpenvant',),
'våpenvantest': ('våpenvant',),
'våpenvanteste': ('våpenvant',),
'vårbær': ('vårbær',),
'vårbære': ('vårbær',),
'vårbærere': ('vårbær',),
'vårbærest': ('vårbær',),
'vårbæreste': ('vårbær',),
'vårbært': ('vårbær',),
'våra': ('våre',),
'vårede': ('våre',),
'vårende': ('våre',),
'våret': ('våre',),
'vårete': ('våre',),
'vårgrøn': ('vårgrøn',),
'vårgrøne': ('vårgrøn',),
'vårgrønere': ('vårgrøn',),
'vårgrønest': ('vårgrøn',),
'vårgrøneste': ('vårgrøn',),
'vårgrønt': ('vårgrøn',),
'vårgrønn': ('vårgrønn',),
'vårgrønne': ('vårgrønn',),
'vårgrønnere': ('vårgrønn',),
'vårgrønnest': ('vårgrønn',),
'vårgrønneste': ('vårgrønn',),
'vårgrønt': ('vårgrønn',),
'vårkledd': ('vårkledd',),
'vårkledde': ('vårkledd',),
'vårkleddere': ('vårkledd',),
'vårkleddest': ('vårkledd',),
'vårkleddeste': ('vårkledd',),
'vårlig': ('vårlig',),
'vårlige': ('vårlig',),
'vårligere': ('vårlig',),
'vårligst': ('vårlig',),
'vårligste': ('vårlig',),
'vårslapp': ('vårslapp',),
'vårslappe': ('vårslapp',),
'vårslappere': ('vårslapp',),
'vårslappest': ('vårslapp',),
'vårslappeste': ('vårslapp',),
'vårslapt': ('vårslapp',),
'våryr': ('våryr',),
'våryre': ('våryr',),
'våryrere': ('våryr',),
'våryrest': ('våryr',),
'våryreste': ('våryr',),
'våryrt': ('våryr',),
'våsa': ('våse',),
'våsede': ('våse',),
'våsende': ('våse',),
'våset': ('våse',),
'våsete': ('våse',),
'våst': ('våse',),
'våste': ('våse',),
'våset': ('våset',),
'våsete': ('våset',),
'våsetere': ('våset',),
'våsetest': ('våset',),
'våseteste': ('våset',),
'våsete': ('våsete',),
'våt': ('våt',),
'våte': ('våt',),
'våtere': ('våt',),
'våtest': ('våt',),
'våteste': ('våt',),
'vått': ('våt',),
'våtlendt': ('våtlendt',),
'våtlendte': ('våtlendt',),
'våtlendtere': ('våtlendt',),
'våtlendtest': ('våtlendt',),
'våtlendteste': ('våtlendt',),
'våtna': ('våtne',),
'våtnede': ('våtne',),
'våtnende': ('våtne',),
'våtnet': ('våtne',),
'våtnete': ('våtne',),
'våtsom': ('våtsom',),
'våtsomme': ('våtsom',),
'våtsommere': ('våtsom',),
'våtsomst': ('våtsom',),
'våtsomste': ('våtsom',),
'våtsomt': ('våtsom',),
'våtøyd': ('våtøyd',),
'våtøyde': ('våtøyd',),
'våtøydere': ('våtøyd',),
'våtøydest': ('våtøyd',),
'våtøydeste': ('våtøyd',),
'væpna': ('væpne',),
'væpnede': ('væpne',),
'væpnende': ('væpne',),
'væpnet': ('væpne',),
'væpnete': ('væpne',),
'værbarka': ('værbarka',),
'værbarkede': ('værbarket',),
'værbarket': ('værbarket',),
'værbarkete': ('værbarket',),
'værbarketere': ('værbarket',),
'værbarketest': ('værbarket',),
'værbarketeste': ('værbarket',),
'værbitt': ('værbitt',),
'værbitte': ('værbitt',),
'værbittere': ('værbitt',),
'værbittest': ('værbitt',),
'værbitteste': ('værbitt',),
'væra': ('være',),
'værede': ('være',),
'værende': ('være',),
'været': ('være',),
'værete': ('være',),
'værende': ('være',),
'vært': ('være',),
'værfast': ('værfast',),
'værfaste': ('værfast',),
'værfastere': ('værfast',),
'værfastest': ('værfast',),
'værfasteste': ('værfast',),
'værhard': ('værhard',),
'værharde': ('værhard',),
'værhardere': ('værhard',),
'værhardest': ('værhard',),
'værhardeste': ('værhard',),
'værhardt': ('værhard',),
'værsjuk': ('værsjuk',),
'værsjuke': ('værsjuk',),
'værsjukere': ('værsjuk',),
'værsjukest': ('værsjuk',),
'værsjukeste': ('værsjuk',),
'værsjukt': ('værsjuk',),
'værsyk': ('værsyk',),
'værsyke': ('værsyk',),
'værsykere': ('værsyk',),
'værsykest': ('værsyk',),
'værsykeste': ('værsyk',),
'værsykt': ('værsyk',),
'væska': ('væske',),
'væskede': ('væske',),
'væskende': ('væske',),
'væsket': ('væske',),
'væskete': ('væske',),
'væskeaktig': ('væskeaktig',),
'væskeaktige': ('væskeaktig',),
'væskeaktigere': ('væskeaktig',),
'væskeaktigst': ('væskeaktig',),
'væskeaktigste': ('væskeaktig',),
'væskefylt': ('væskefylt',),
'væskefylte': ('væskefylt',),
'væskefyltere': ('væskefylt',),
'væskefyltest': ('væskefylt',),
'væskefylteste': ('væskefylt',),
'væta': ('væte',),
'vætede': ('væte',),
'vætende': ('væte',),
'vætet': ('væte',),
'vætete': ('væte',),
'vætt': ('væte',),
'vætte': ('væte',),
'vølende': ('vøle',),
'vølt': ('vøle',),
'vølte': ('vøle',),
'vørdende': ('vørde',),
'vørdt': ('vørde',),
'vørdte': ('vørde',),
'vørdsam': ('vørdsam',),
'vørdsamme': ('vørdsam',),
'vørdsammere': ('vørdsam',),
'vørdsamst': ('vørdsam',),
'vørdsamste': ('vørdsam',),
'vørdsamt': ('vørdsam',),
'vørdslaus': ('vørdslaus',),
'vørdslause': ('vørdslaus',),
'vørdslausere': ('vørdslaus',),
'vørdslausest': ('vørdslaus',),
'vørdslauseste': ('vørdslaus',),
'vørdslaust': ('vørdslaus',),
'vørdsløs': ('vørdsløs',),
'vørdsløse': ('vørdsløs',),
'vørdsløsere': ('vørdsløs',),
'vørdsløsest': ('vørdsløs',),
'vørdsløseste': ('vørdsløs',),
'vørdsløst': ('vørdsløs',),
'vørende': ('vøre',),
'vørt': ('vøre',),
'vørte': ('vøre',),
'vørsam': ('vørsam',),
'vørsamme': ('vørsam',),
'vørsammere': ('vørsam',),
'vørsamst': ('vørsam',),
'vørsamste': ('vørsam',),
'vørsamt': ('vørsam',),
'vørslaus': ('vørslaus',),
'vørslause': ('vørslaus',),
'vørslausere': ('vørslaus',),
'vørslausest': ('vørslaus',),
'vørslauseste': ('vørslaus',),
'vørslaust': ('vørslaus',),
'vørsløs': ('vørsløs',),
'vørsløse': ('vørsløs',),
'vørsløsere': ('vørsløs',),
'vørsløsest': ('vørsløs',),
'vørsløseste': ('vørsløs',),
'vørsløst': ('vørsløs',),
'wagnersk': ('wagnersk',),
'wagnerske': ('wagnersk',),
'wagnerskere': ('wagnersk',),
'wagnerskest': ('wagnersk',),
'wagnerskeste': ('wagnersk',),
'walisisk': ('walisisk',),
'walisiske': ('walisisk',),
'walisiskere': ('walisisk',),
'walisiskest': ('walisisk',),
'walisiskeste': ('walisisk',),
'wattlaus': ('wattlaus',),
'wattlause': ('wattlaus',),
'wattlausere': ('wattlaus',),
'wattlausest': ('wattlaus',),
'wattlauseste': ('wattlaus',),
'wattlaust': ('wattlaus',),
'wattløs': ('wattløs',),
'wattløse': ('wattløs',),
'wattløsere': ('wattløs',),
'wattløsest': ('wattløs',),
'wattløseste': ('wattløs',),
'wattløst': ('wattløs',),
'wattsk': ('wattsk',),
'wattske': ('wattsk',),
'wattskere': ('wattsk',),
'wattskest': ('wattsk',),
'wattskeste': ('wattsk',),
'webba': ('webbe',),
'webbede': ('webbe',),
'webbende': ('webbe',),
'webbet': ('webbe',),
'webbete': ('webbe',),
'welfisk': ('welfisk',),
'welfiske': ('welfisk',),
'welfiskere': ('welfisk',),
'welfiskest': ('welfisk',),
'welfiskeste': ('welfisk',),
'wergelandsk': ('wergelandsk',),
'wergelandske': ('wergelandsk',),
'wergelandskere': ('wergelandsk',),
'wergelandskest': ('wergelandsk',),
'wergelandskeste': ('wergelandsk',),
'westfalsk': ('westfalsk',),
'westfalske': ('westfalsk',),
'westfalskere': ('westfalsk',),
'westfalskest': ('westfalsk',),
'westfalskeste': ('westfalsk',),
'wiensk': ('wiensk',),
'wienske': ('wiensk',),
'wienskere': ('wiensk',),
'wienskest': ('wiensk',),
'wienskeste': ('wiensk',),
'xenofil': ('xenofil',),
'xenofile': ('xenofil',),
'xenofilere': ('xenofil',),
'xenofilest': ('xenofil',),
'xenofileste': ('xenofil',),
'xenofilt': ('xenofil',),
'xenofob': ('xenofob',),
'xenofobe': ('xenofob',),
'xenofobere': ('xenofob',),
'xenofobest': ('xenofob',),
'xenofobeste': ('xenofob',),
'xenofobt': ('xenofob',),
'xerograferende': ('xerografere',),
'xerografert': ('xerografere',),
'xerograferte': ('xerografere',),
'xerografisk': ('xerografisk',),
'xerografiske': ('xerografisk',),
'xerografiskere': ('xerografisk',),
'xerografiskest': ('xerografisk',),
'xerografiskeste': ('xerografisk',),
'xeromorf': ('xeromorf',),
'xeromorfe': ('xeromorf',),
'xeromorfere': ('xeromorf',),
'xeromorfest': ('xeromorf',),
'xeromorfeste': ('xeromorf',),
'xeromorft': ('xeromorf',),
'xylograferende': ('xylografere',),
'xylografert': ('xylografere',),
'xylograferte': ('xylografere',),
'xylografisk': ('xylografisk',),
'xylografiske': ('xylografisk',),
'xylografiskere': ('xylografisk',),
'xylografiskest': ('xylografisk',),
'xylografiskeste': ('xylografisk',),
'ydda': ('ydde',),
'yddede': ('ydde',),
'yddende': ('ydde',),
'yddet': ('ydde',),
'yddete': ('ydde',),
'ydmyk': ('ydmyk',),
'ydmyke': ('ydmyk',),
'ydmykere': ('ydmyk',),
'ydmykest': ('ydmyk',),
'ydmykeste': ('ydmyk',),
'ydmykt': ('ydmyk',),
'ydmyka': ('ydmyke',),
'ydmykede': ('ydmyke',),
'ydmykende': ('ydmyke',),
'ydmyket': ('ydmyke',),
'ydmykete': ('ydmyke',),
'ydmykt': ('ydmyke',),
'ydmykte': ('ydmyke',),
'yemenittisk': ('yemenittisk',),
'yemenittiske': ('yemenittisk',),
'yemenittiskere': ('yemenittisk',),
'yemenittiskest': ('yemenittisk',),
'yemenittiskeste': ('yemenittisk',),
'yemenittisk': ('yemenittisk',),
'yemenittiske': ('yemenittisk',),
'yemenittiskere': ('yemenittisk',),
'yemenittiskest': ('yemenittisk',),
'yemenittiskeste': ('yemenittisk',),
'ylende': ('yle',),
'ylt': ('yle',),
'ylte': ('yle',),
'ymis': ('ymis',),
'ymisere': ('ymis',),
'ymisest': ('ymis',),
'ymiseste': ('ymis',),
'ymist': ('ymis',),
'ymse': ('ymis',),
'ymse': ('ymse',),
'ymta': ('ymte',),
'ymtede': ('ymte',),
'ymtende': ('ymte',),
'ymtet': ('ymte',),
'ymtete': ('ymte',),
'ynda': ('ynde',),
'yndede': ('ynde',),
'yndende': ('ynde',),
'yndet': ('ynde',),
'yndete': ('ynde',),
'yndefull': ('yndefull',),
'yndefulle': ('yndefull',),
'yndefullere': ('yndefull',),
'yndefullest': ('yndefull',),
'yndefulleste': ('yndefull',),
'yndefullt': ('yndefull',),
'yndelaus': ('yndelaus',),
'yndelause': ('yndelaus',),
'yndelausere': ('yndelaus',),
'yndelausest': ('yndelaus',),
'yndelauseste': ('yndelaus',),
'yndelaust': ('yndelaus',),
'yndeløs': ('yndeløs',),
'yndeløse': ('yndeløs',),
'yndeløsere': ('yndeløs',),
'yndeløsest': ('yndeløs',),
'yndeløseste': ('yndeløs',),
'yndeløst': ('yndeløs',),
'yndig': ('yndig',),
'yndige': ('yndig',),
'yndigere': ('yndig',),
'yndigst': ('yndig',),
'yndigste': ('yndig',),
'ynga': ('ynge',),
'yngede': ('ynge',),
'yngende': ('ynge',),
'ynget': ('ynge',),
'yngete': ('ynge',),
'yngla': ('yngle',),
'ynglede': ('yngle',),
'ynglende': ('yngle',),
'ynglet': ('yngle',),
'ynglete': ('yngle',),
'ynglingaktig': ('ynglingaktig',),
'ynglingaktige': ('ynglingaktig',),
'ynglingaktigere': ('ynglingaktig',),
'ynglingaktigst': ('ynglingaktig',),
'ynglingaktigste': ('ynglingaktig',),
'yngre': ('yngre',),
'ynka': ('ynke',),
'ynkede': ('ynke',),
'ynkende': ('ynke',),
'ynket': ('ynke',),
'ynkete': ('ynke',),
'ynkelig': ('ynkelig',),
'ynkelige': ('ynkelig',),
'ynkeligere': ('ynkelig',),
'ynkeligst': ('ynkelig',),
'ynkeligste': ('ynkelig',),
'ynkverdig': ('ynkverdig',),
'ynkverdige': ('ynkverdig',),
'ynkverdigere': ('ynkverdig',),
'ynkverdigst': ('ynkverdig',),
'ynkverdigste': ('ynkverdig',),
'yppal': ('yppal',),
'yppale': ('yppal',),
'yppalere': ('yppal',),
'yppalest': ('yppal',),
'yppaleste': ('yppal',),
'yppalt': ('yppal',),
'yppa': ('yppe',),
'yppede': ('yppe',),
'yppende': ('yppe',),
'yppet': ('yppe',),
'yppete': ('yppe',),
'ypperlig': ('ypperlig',),
'ypperlige': ('ypperlig',),
'ypperligere': ('ypperlig',),
'ypperligst': ('ypperlig',),
'ypperligste': ('ypperlig',),
'ypperst': ('ypperst',),
'ypperste': ('ypperst',),
'yppig': ('yppig',),
'yppige': ('yppig',),
'yppigere': ('yppig',),
'yppigst': ('yppig',),
'yppigste': ('yppig',),
'yr': ('yr',),
'yre': ('yr',),
'yrere': ('yr',),
'yrest': ('yr',),
'yreste': ('yr',),
'yrt': ('yr',),
'yrende': ('yre',),
'yrt': ('yre',),
'yrte': ('yre',),
'yra': ('yre',),
'yrede': ('yre',),
'yrende': ('yre',),
'yret': ('yre',),
'yrete': ('yre',),
'yrt': ('yre',),
'yrte': ('yre',),
'yrka': ('yrke',),
'yrkede': ('yrke',),
'yrkende': ('yrke',),
'yrket': ('yrke',),
'yrkete': ('yrke',),
'yrkesaktiv': ('yrkesaktiv',),
'yrkesaktive': ('yrkesaktiv',),
'yrkesaktivere': ('yrkesaktiv',),
'yrkesaktivest': ('yrkesaktiv',),
'yrkesaktiveste': ('yrkesaktiv',),
'yrkesaktivt': ('yrkesaktiv',),
'yrkesarbeidende': ('yrkesarbeidende',),
'yrkesetisk': ('yrkesetisk',),
'yrkesetiske': ('yrkesetisk',),
'yrkesetiskere': ('yrkesetisk',),
'yrkesetiskest': ('yrkesetisk',),
'yrkesetiskeste': ('yrkesetisk',),
'yrkesfaglig': ('yrkesfaglig',),
'yrkesfaglige': ('yrkesfaglig',),
'yrkesfagligere': ('yrkesfaglig',),
'yrkesfagligst': ('yrkesfaglig',),
'yrkesfagligste': ('yrkesfaglig',),
'yrkeshemma': ('yrkeshemma',),
'yrkeshemmede': ('yrkeshemmet',),
'yrkeshemmet': ('yrkeshemmet',),
'yrkeshemmete': ('yrkeshemmet',),
'yrkeshemmetere': ('yrkeshemmet',),
'yrkeshemmetest': ('yrkeshemmet',),
'yrkeshemmeteste': ('yrkeshemmet',),
'yrkeshygienisk': ('yrkeshygienisk',),
'yrkeshygieniske': ('yrkeshygienisk',),
'yrkeshygieniskere': ('yrkeshygienisk',),
'yrkeshygieniskest': ('yrkeshygienisk',),
'yrkeshygieniskeste': ('yrkeshygienisk',),
'yrkesretta': ('yrkesretta',),
'yrkesrettede': ('yrkesrettet',),
'yrkesrettet': ('yrkesrettet',),
'yrkesrettete': ('yrkesrettet',),
'yrkesrettetere': ('yrkesrettet',),
'yrkesrettetest': ('yrkesrettet',),
'yrkesretteteste': ('yrkesrettet',),
'yrkesvalghemma': ('yrkesvalghemma',),
'yrkesvalghemmede': ('yrkesvalghemmet',),
'yrkesvalghemmet': ('yrkesvalghemmet',),
'yrkesvalghemmete': ('yrkesvalghemmet',),
'yrkesvalghemmetere': ('yrkesvalghemmet',),
'yrkesvalghemmetest': ('yrkesvalghemmet',),
'yrkesvalghemmeteste': ('yrkesvalghemmet',),
'ysta': ('yste',),
'ystede': ('yste',),
'ystende': ('yste',),
'ystet': ('yste',),
'ystete': ('yste',),
'yta': ('yte',),
'ytede': ('yte',),
'ytende': ('yte',),
'ytet': ('yte',),
'ytete': ('yte',),
'ytt': ('yte',),
'ytte': ('yte',),
'ytra': ('ytre',),
'ytrede': ('ytre',),
'ytrende': ('ytre',),
'ytret': ('ytre',),
'ytrete': ('ytre',),
'ytre': ('ytre',),
'ytst': ('ytre',),
'ytste': ('ytre',),
'ytterst': ('ytre',),
'ytterste': ('ytre',),
'ytresekretorisk': ('ytresekretorisk',),
'ytresekretoriske': ('ytresekretorisk',),
'ytresekretoriskere': ('ytresekretorisk',),
'ytresekretoriskest': ('ytresekretorisk',),
'ytresekretoriskeste': ('ytresekretorisk',),
'ytterligere': ('ytterligere',),
'ytterliggående': ('ytterliggående',),
'z-spunne': ('z-spunnet',),
'z-spunnere': ('z-spunnet',),
'z-spunnest': ('z-spunnet',),
'z-spunneste': ('z-spunnet',),
'z-spunnet': ('z-spunnet',),
'z-tvinna': ('z-tvinna',),
'z-tvinnede': ('z-tvinnet',),
'z-tvinnet': ('z-tvinnet',),
'z-tvinnete': ('z-tvinnet',),
'z-tvinnetere': ('z-tvinnet',),
'z-tvinnetest': ('z-tvinnet',),
'z-tvinneteste': ('z-tvinnet',),
'zairisk': ('zairisk',),
'zairiske': ('zairisk',),
'zairiskere': ('zairisk',),
'zairiskest': ('zairisk',),
'zairiskeste': ('zairisk',),
'zairsk': ('zairsk',),
'zairske': ('zairsk',),
'zairskere': ('zairsk',),
'zairskest': ('zairsk',),
'zairskeste': ('zairsk',),
'zambisk': ('zambisk',),
'zambiske': ('zambisk',),
'zambiskere': ('zambisk',),
'zambiskest': ('zambisk',),
'zambiskeste': ('zambisk',),
'zanzibarisk': ('zanzibarisk',),
'zanzibariske': ('zanzibarisk',),
'zanzibariskere': ('zanzibarisk',),
'zanzibariskest': ('zanzibarisk',),
'zanzibariskeste': ('zanzibarisk',),
'zeugmatisk': ('zeugmatisk',),
'zeugmatiske': ('zeugmatisk',),
'zeugmatiskere': ('zeugmatisk',),
'zeugmatiskest': ('zeugmatisk',),
'zeugmatiskeste': ('zeugmatisk',),
'zimbabwisk': ('zimbabwisk',),
'zimbabwiske': ('zimbabwisk',),
'zimbabwiskere': ('zimbabwisk',),
'zimbabwiskest': ('zimbabwisk',),
'zimbabwiskeste': ('zimbabwisk',),
'zodiakal': ('zodiakal',),
'zodiakale': ('zodiakal',),
'zodiakalere': ('zodiakal',),
'zodiakalest': ('zodiakal',),
'zodiakaleste': ('zodiakal',),
'zodiakalt': ('zodiakal',),
'zoografisk': ('zoografisk',),
'zoografiske': ('zoografisk',),
'zoografiskere': ('zoografisk',),
'zoografiskest': ('zoografisk',),
'zoografiskeste': ('zoografisk',),
'zoologisk': ('zoologisk',),
'zoologiske': ('zoologisk',),
'zoologiskere': ('zoologisk',),
'zoologiskest': ('zoologisk',),
'zoologiskeste': ('zoologisk',),
'zooma': ('zoome',),
'zoomede': ('zoome',),
'zoomende': ('zoome',),
'zoomet': ('zoome',),
'zoomete': ('zoome',),
'zulusk': ('zulusk',),
'zuluske': ('zulusk',),
'zuluskere': ('zulusk',),
'zuluskest': ('zulusk',),
'zuluskeste': ('zulusk',),
'zwingliansk': ('zwingliansk',),
'zwinglianske': ('zwingliansk',),
'zwinglianskere': ('zwingliansk',),
'zwinglianskest': ('zwingliansk',),
'zwinglianskeste': ('zwingliansk',),
'zygotisk': ('zygotisk',),
'zygotiske': ('zygotisk',),
'zygotiskere': ('zygotisk',),
'zygotiskest': ('zygotisk',),
'zygotiskeste': ('zygotisk',),
'åa': ('åe',),
'åede': ('åe',),
'ående': ('åe',),
'ået': ('åe',),
'åete': ('åe',),
'ågra': ('ågre',),
'ågrede': ('ågre',),
'ågrende': ('ågre',),
'ågret': ('ågre',),
'ågrete': ('ågre',),
'åkende': ('åke',),
'åkt': ('åke',),
'åkte': ('åke',),
'ålandsk': ('ålandsk',),
'ålandske': ('ålandsk',),
'ålandskere': ('ålandsk',),
'ålandskest': ('ålandsk',),
'ålandskeste': ('ålandsk',),
'åla': ('åle',),
'ålede': ('åle',),
'ålende': ('åle',),
'ålet': ('åle',),
'ålete': ('åle',),
'ålt': ('åle',),
'ålte': ('åle',),
'åleglatt': ('åleglatt',),
'åleglatte': ('åleglatt',),
'åleglattere': ('åleglatt',),
'åleglattest': ('åleglatt',),
'åleglatteste': ('åleglatt',),
'åleslank': ('åleslank',),
'åleslanke': ('åleslank',),
'åleslankere': ('åleslank',),
'åleslankest': ('åleslank',),
'åleslankeste': ('åleslank',),
'åleslankt': ('åleslank',),
'åletrang': ('åletrang',),
'åletrange': ('åletrang',),
'åletrangere': ('åletrang',),
'åletrangest': ('åletrang',),
'åletrangeste': ('åletrang',),
'åletrangt': ('åletrang',),
'ånda': ('ånde',),
'åndede': ('ånde',),
'åndende': ('ånde',),
'åndet': ('ånde',),
'åndete': ('ånde',),
'åndelaus': ('åndelaus',),
'åndelause': ('åndelaus',),
'åndelausere': ('åndelaus',),
'åndelausest': ('åndelaus',),
'åndelauseste': ('åndelaus',),
'åndelaust': ('åndelaus',),
'åndelig': ('åndelig',),
'åndelige': ('åndelig',),
'åndeligere': ('åndelig',),
'åndeligst': ('åndelig',),
'åndeligste': ('åndelig',),
'åndeløs': ('åndeløs',),
'åndeløse': ('åndeløs',),
'åndeløsere': ('åndeløs',),
'åndeløsest': ('åndeløs',),
'åndeløseste': ('åndeløs',),
'åndeløst': ('åndeløs',),
'åndfull': ('åndfull',),
'åndfulle': ('åndfull',),
'åndfullere': ('åndfull',),
'åndfullest': ('åndfull',),
'åndfulleste': ('åndfull',),
'åndfullt': ('åndfull',),
'åndlaus': ('åndlaus',),
'åndlause': ('åndlaus',),
'åndlausere': ('åndlaus',),
'åndlausest': ('åndlaus',),
'åndlauseste': ('åndlaus',),
'åndlaust': ('åndlaus',),
'åndløs': ('åndløs',),
'åndløse': ('åndløs',),
'åndløsere': ('åndløs',),
'åndløsest': ('åndløs',),
'åndløseste': ('åndløs',),
'åndløst': ('åndløs',),
'åndsbeslekta': ('åndsbeslekta',),
'åndsbeslektede': ('åndsbeslektet',),
'åndsbeslektet': ('åndsbeslektet',),
'åndsbeslektete': ('åndsbeslektet',),
'åndsbeslektetere': ('åndsbeslektet',),
'åndsbeslektetest': ('åndsbeslektet',),
'åndsbeslekteteste': ('åndsbeslektet',),
'åndsfattig': ('åndsfattig',),
'åndsfattige': ('åndsfattig',),
'åndsfattigere': ('åndsfattig',),
'åndsfattigst': ('åndsfattig',),
'åndsfattigste': ('åndsfattig',),
'åndsforlatt': ('åndsforlatt',),
'åndsforlatte': ('åndsforlatt',),
'åndsforlattere': ('åndsforlatt',),
'åndsforlattest': ('åndsforlatt',),
'åndsforlatteste': ('åndsforlatt',),
'åndsfraværende': ('åndsfraværende',),
'åndsfrisk': ('åndsfrisk',),
'åndsfriske': ('åndsfrisk',),
'åndsfriskere': ('åndsfrisk',),
'åndsfriskest': ('åndsfrisk',),
'åndsfriskeste': ('åndsfrisk',),
'åndsfriskt': ('åndsfrisk',),
'åndsnærværende': ('åndsnærværende',),
'åndssløv': ('åndssløv',),
'åndssløve': ('åndssløv',),
'åndssløvere': ('åndssløv',),
'åndssløvest': ('åndssløv',),
'åndssløveste': ('åndssløv',),
'åndssløvt': ('åndssløv',),
'åndssvak': ('åndssvak',),
'åndssvake': ('åndssvak',),
'åndssvakere': ('åndssvak',),
'åndssvakest': ('åndssvak',),
'åndssvakeste': ('åndssvak',),
'åndssvakt': ('åndssvak',),
'åndsveik': ('åndsveik',),
'åndsveike': ('åndsveik',),
'åndsveikere': ('åndsveik',),
'åndsveikest': ('åndsveik',),
'åndsveikeste': ('åndsveik',),
'åndsveikt': ('åndsveik',),
'åndsvek': ('åndsvek',),
'åndsveke': ('åndsvek',),
'åndsvekere': ('åndsvek',),
'åndsvekest': ('åndsvek',),
'åndsvekeste': ('åndsvek',),
'åndsvekt': ('åndsvek',),
'åpen': ('åpen',),
'åpent': ('åpen',),
'åpne': ('åpen',),
'åpnere': ('åpen',),
'åpnest': ('åpen',),
'åpneste': ('åpen',),
'åpenbar': ('åpenbar',),
'åpenbare': ('åpenbar',),
'åpenbarere': ('åpenbar',),
'åpenbarest': ('åpenbar',),
'åpenbareste': ('åpenbar',),
'åpenbart': ('åpenbar',),
'åpenbarende': ('åpenbare',),
'åpenbart': ('åpenbare',),
'åpenbarte': ('åpenbare',),
'åpenbarlig': ('åpenbarlig',),
'åpenbarlige': ('åpenbarlig',),
'åpenbarligere': ('åpenbarlig',),
'åpenbarligst': ('åpenbarlig',),
'åpenbarligste': ('åpenbarlig',),
'åpenhjerta': ('åpenhjerta',),
'åpenhjertede': ('åpenhjertet',),
'åpenhjertet': ('åpenhjertet',),
'åpenhjertete': ('åpenhjertet',),
'åpenhjertetere': ('åpenhjertet',),
'åpenhjertetest': ('åpenhjertet',),
'åpenhjerteteste': ('åpenhjertet',),
'åpenhjertig': ('åpenhjertig',),
'åpenhjertige': ('åpenhjertig',),
'åpenhjertigere': ('åpenhjertig',),
'åpenhjertigst': ('åpenhjertig',),
'åpenhjertigste': ('åpenhjertig',),
'åpenlys': ('åpenlys',),
'åpenlyse': ('åpenlys',),
'åpenlysere': ('åpenlys',),
'åpenlysest': ('åpenlys',),
'åpenlyseste': ('åpenlys',),
'åpenlyst': ('åpenlys',),
'åpenmunna': ('åpenmunna',),
'åpenmunnede': ('åpenmunnet',),
'åpenmunnet': ('åpenmunnet',),
'åpenmunnete': ('åpenmunnet',),
'åpenmunnetere': ('åpenmunnet',),
'åpenmunnetest': ('åpenmunnet',),
'åpenmunneteste': ('åpenmunnet',),
'åpna': ('åpne',),
'åpnede': ('åpne',),
'åpnende': ('åpne',),
'åpnet': ('åpne',),
'åpnete': ('åpne',),
'åreforkalka': ('åreforkalka',),
'åreforkalkede': ('åreforkalket',),
'åreforkalket': ('åreforkalket',),
'åreforkalkete': ('åreforkalket',),
'åreforkalketere': ('åreforkalket',),
'åreforkalketest': ('åreforkalket',),
'åreforkalketeste': ('åreforkalket',),
'årelang': ('årelang',),
'årelange': ('årelang',),
'årelangt': ('årelang',),
'årelenger': ('årelang',),
'årelengre': ('årelang',),
'årelengst': ('årelang',),
'årelengste': ('årelang',),
'årelatende': ('årelate',),
'årelatt': ('årelate',),
'årelatte': ('årelate',),
'året': ('året',),
'årete': ('året',),
'åretere': ('året',),
'åretest': ('året',),
'åreteste': ('året',),
'årete': ('årete',),
'årevenga': ('årevenga',),
'årevenga': ('årevenga',),
'årevengede': ('årevenget',),
'årevenget': ('årevenget',),
'årevengete': ('årevenget',),
'årevengetere': ('årevenget',),
'årevengetest': ('årevenget',),
'årevengeteste': ('årevenget',),
'årevengede': ('årevenget',),
'årevenget': ('årevenget',),
'årevengete': ('årevenget',),
'årevengetere': ('årevenget',),
'årevengetest': ('årevenget',),
'årevengeteste': ('årevenget',),
'årevinga': ('årevinga',),
'årevinga': ('årevinga',),
'årevingede': ('årevinget',),
'årevinget': ('årevinget',),
'årevingete': ('årevinget',),
'årevingetere': ('årevinget',),
'årevingetest': ('årevinget',),
'årevingeteste': ('årevinget',),
'årevingede': ('årevinget',),
'årevinget': ('årevinget',),
'årevingete': ('årevinget',),
'årevingetere': ('årevinget',),
'årevingetest': ('årevinget',),
'årevingeteste': ('årevinget',),
'årle': ('årle',),
'årlig': ('årlig',),
'årlige': ('årlig',),
'årligere': ('årlig',),
'årligst': ('årlig',),
'årligste': ('årlig',),
'årsaka': ('årsake',),
'årsakede': ('årsake',),
'årsakende': ('årsake',),
'årsaket': ('årsake',),
'årsakete': ('årsake',),
'årsbest': ('årsbest',),
'årseldre': ('årsgammel',),
'årseldst': ('årsgammel',),
'årseldste': ('årsgammel',),
'årsgamle': ('årsgammel',),
'årsgammel': ('årsgammel',),
'årsgammelt': ('årsgammel',),
'årvak': ('årvak',),
'årvake': ('årvak',),
'årvakere': ('årvak',),
'årvakest': ('årvak',),
'årvakeste': ('årvak',),
'årvakt': ('årvak',),
'årviss': ('årviss',),
'årvisse': ('årviss',),
'årvissere': ('årviss',),
'årvissest': ('årviss',),
'årvisseste': ('årviss',),
'årvisst': ('årviss',),
'årvåken': ('årvåken',),
'årvåkent': ('årvåken',),
'årvåkne': ('årvåken',),
'årvåknere': ('årvåken',),
'årvåknest': ('årvåken',),
'årvåkneste': ('årvåken',),
'åset': ('åset',),
'åsete': ('åset',),
'åsetere': ('åset',),
'åsetest': ('åset',),
'åseteste': ('åset',),
'åsete': ('åsete',),
'åslendt': ('åslendt',),
'åslendte': ('åslendt',),
'åslendtere': ('åslendt',),
'åslendtest': ('åslendt',),
'åslendteste': ('åslendt',),
'åttedobbel': ('åttedobbel',),
'åttedobbelt': ('åttedobbel',),
'åttedoble': ('åttedobbel',),
'åttedoblere': ('åttedobbel',),
'åttedoblest': ('åttedobbel',),
'åttedobleste': ('åttedobbel',),
'åttedobbelt': ('åttedobbelt',),
'åttedobbelte': ('åttedobbelt',),
'åttedobbeltere': ('åttedobbelt',),
'åttedobbeltest': ('åttedobbelt',),
'åttedobbelteste': ('åttedobbelt',),
'åttedobla': ('åttedoble',),
'åttedoblede': ('åttedoble',),
'åttedoblende': ('åttedoble',),
'åttedoblet': ('åttedoble',),
'åttedoblete': ('åttedoble',),
'åttekanta': ('åttekanta',),
'åttekantede': ('åttekantet',),
'åttekantet': ('åttekantet',),
'åttekantete': ('åttekantet',),
'åttekantetere': ('åttekantet',),
'åttekantetest': ('åttekantet',),
'åttekanteteste': ('åttekantet',),
'åttende': ('åttende',),
'åttesida': ('åttesida',),
'åttesidede': ('åttesidet',),
'åttesidet': ('åttesidet',),
'åttesidete': ('åttesidet',),
'åttesidetere': ('åttesidet',),
'åttesidetest': ('åttesidet',),
'åttesideteste': ('åttesidet',),
'åtteårig': ('åtteårig',),
'åtteårige': ('åtteårig',),
'åtteårigere': ('åtteårig',),
'åtteårigst': ('åtteårig',),
'åtteårigste': ('åtteårig',),
'åtteårs': ('åtteårs',),
'åttiende': ('åttiende',),
'åttiårig': ('åttiårig',),
'åttiårige': ('åttiårig',),
'åttiårigere': ('åttiårig',),
'åttiårigst': ('åttiårig',),
'åttiårigste': ('åttiårig',),
'åttiårs': ('åttiårs',),
'åtvara': ('åtvare',),
'åtvarende': ('åtvare',),
'åtvart': ('åtvare',),
'åtvarte': ('åtvare',),
'åvirka': ('åvirke',),
'åvirkede': ('åvirke',),
'åvirkende': ('åvirke',),
'åvirket': ('åvirke',),
'åvirkete': ('åvirke',),
'ærbar': ('ærbar',),
'ærbare': ('ærbar',),
'ærbarere': ('ærbar',),
'ærbarest': ('ærbar',),
'ærbareste': ('ærbar',),
'ærbart': ('ærbar',),
'ærbødig': ('ærbødig',),
'ærbødige': ('ærbødig',),
'ærbødigere': ('ærbødig',),
'ærbødigst': ('ærbødig',),
'ærbødigste': ('ærbødig',),
'æra': ('ære',),
'ærede': ('ære',),
'ærende': ('ære',),
'æret': ('ære',),
'ærete': ('ære',),
'ærefull': ('ærefull',),
'ærefulle': ('ærefull',),
'ærefullere': ('ærefull',),
'ærefullest': ('ærefull',),
'ærefulleste': ('ærefull',),
'ærefullt': ('ærefull',),
'ærekjær': ('ærekjær',),
'ærekjære': ('ærekjær',),
'ærekjærere': ('ærekjær',),
'ærekjærest': ('ærekjær',),
'ærekjæreste': ('ærekjær',),
'ærekjært': ('ærekjær',),
'ærekrenka': ('ærekrenke',),
'ærekrenkede': ('ærekrenke',),
'ærekrenkende': ('ærekrenke',),
'ærekrenket': ('ærekrenke',),
'ærekrenkete': ('ærekrenke',),
'ærekrenkt': ('ærekrenke',),
'ærekrenkte': ('ærekrenke',),
'ærelaus': ('ærelaus',),
'ærelause': ('ærelaus',),
'ærelausere': ('ærelaus',),
'ærelausest': ('ærelaus',),
'ærelauseste': ('ærelaus',),
'ærelaust': ('ærelaus',),
'æreløs': ('æreløs',),
'æreløse': ('æreløs',),
'æreløsere': ('æreløs',),
'æreløsest': ('æreløs',),
'æreløseste': ('æreløs',),
'æreløst': ('æreløs',),
'ærerik': ('ærerik',),
'ærerike': ('ærerik',),
'ærerikere': ('ærerik',),
'ærerikest': ('ærerik',),
'ærerikeste': ('ærerik',),
'ærerikt': ('ærerik',),
'ærerørig': ('ærerørig',),
'ærerørige': ('ærerørig',),
'ærerørigere': ('ærerørig',),
'ærerørigst': ('ærerørig',),
'ærerørigste': ('ærerørig',),
'æresforplikta': ('æresforplikte',),
'æresforpliktede': ('æresforplikte',),
'æresforpliktende': ('æresforplikte',),
'æresforpliktet': ('æresforplikte',),
'æresforpliktete': ('æresforplikte',),
'æresjuk': ('æresjuk',),
'æresjuke': ('æresjuk',),
'æresjukere': ('æresjuk',),
'æresjukest': ('æresjuk',),
'æresjukeste': ('æresjuk',),
'æresjukt': ('æresjuk',),
'æreskjellende': ('æreskjelle',),
'æreskjelt': ('æreskjelle',),
'æreskjelte': ('æreskjelle',),
'æreskjennende': ('æreskjenne',),
'æreskjent': ('æreskjenne',),
'æreskjente': ('æreskjenne',),
'æresyk': ('æresyk',),
'æresyke': ('æresyk',),
'æresykere': ('æresyk',),
'æresykest': ('æresyk',),
'æresykeste': ('æresyk',),
'æresykt': ('æresyk',),
'ærgjerrig': ('ærgjerrig',),
'ærgjerrige': ('ærgjerrig',),
'ærgjerrigere': ('ærgjerrig',),
'ærgjerrigst': ('ærgjerrig',),
'ærgjerrigste': ('ærgjerrig',),
'ærlig': ('ærlig',),
'ærlige': ('ærlig',),
'ærligere': ('ærlig',),
'ærligst': ('ærlig',),
'ærligste': ('ærlig',),
'ærverdig': ('ærverdig',),
'ærverdige': ('ærverdig',),
'ærverdigere': ('ærverdig',),
'ærverdigst': ('ærverdig',),
'ærverdigste': ('ærverdig',),
'ætta': ('ætte',),
'ættede': ('ætte',),
'ættende': ('ætte',),
'ættet': ('ætte',),
'ættete': ('ætte',),
'ættleda': ('ættlede',),
'ættledede': ('ættlede',),
'ættledende': ('ættlede',),
'ættledet': ('ættlede',),
'ættledete': ('ættlede',),
'ævelig': ('ævelig',),
'ævelige': ('ævelig',),
'æveligere': ('ævelig',),
'æveligst': ('ævelig',),
'æveligste': ('ævelig',),
'øda': ('øde',),
'ødede': ('øde',),
'ødende': ('øde',),
'ødet': ('øde',),
'ødete': ('øde',),
'ødt': ('øde',),
'ødte': ('øde',),
'øde': ('øde',),
'ødere': ('øde',),
'ødest': ('øde',),
'ødeste': ('øde',),
'ødt': ('øde',),
'ødelagt': ('ødelegge',),
'ødelagte': ('ødelegge',),
'ødeleggende': ('ødelegge',),
'ødematisk': ('ødematisk',),
'ødematiske': ('ødematisk',),
'ødematiskere': ('ødematisk',),
'ødematiskest': ('ødematisk',),
'ødematiskeste': ('ødematisk',),
'ødematøs': ('ødematøs',),
'ødematøse': ('ødematøs',),
'ødematøsere': ('ødematøs',),
'ødematøsest': ('ødematøs',),
'ødematøseste': ('ødematøs',),
'ødematøst': ('ødematøs',),
'ødipal': ('ødipal',),
'ødipale': ('ødipal',),
'ødipalere': ('ødipal',),
'ødipalest': ('ødipal',),
'ødipaleste': ('ødipal',),
'ødipalt': ('ødipal',),
'ødsel': ('ødsel',),
'ødselt': ('ødsel',),
'ødsle': ('ødsel',),
'ødslere': ('ødsel',),
'ødslest': ('ødsel',),
'ødsleste': ('ødsel',),
'ødsla': ('ødsle',),
'ødslede': ('ødsle',),
'ødslende': ('ødsle',),
'ødslet': ('ødsle',),
'ødslete': ('ødsle',),
'ødslig': ('ødslig',),
'ødslige': ('ødslig',),
'ødsligere': ('ødslig',),
'ødsligst': ('ødslig',),
'ødsligste': ('ødslig',),
'øka': ('øke',),
'økede': ('øke',),
'økende': ('øke',),
'øket': ('øke',),
'økete': ('øke',),
'økt': ('øke',),
'økte': ('øke',),
'økologisk': ('økologisk',),
'økologiske': ('økologisk',),
'økologiskere': ('økologisk',),
'økologiskest': ('økologisk',),
'økologiskeste': ('økologisk',),
'økonometrisk': ('økonometrisk',),
'økonometriske': ('økonometrisk',),
'økonometriskere': ('økonometrisk',),
'økonometriskest': ('økonometrisk',),
'økonometriskeste': ('økonometrisk',),
'økonomiserende': ('økonomisere',),
'økonomisert': ('økonomisere',),
'økonomiserte': ('økonomisere',),
'økonomisk': ('økonomisk',),
'økonomiske': ('økonomisk',),
'økonomiskere': ('økonomisk',),
'økonomiskest': ('økonomisk',),
'økonomiskeste': ('økonomisk',),
'øksa': ('økse',),
'øksede': ('økse',),
'øksende': ('økse',),
'økset': ('økse',),
'øksete': ('økse',),
'øksla': ('øksle',),
'økslede': ('øksle',),
'økslende': ('øksle',),
'økslet': ('øksle',),
'økslete': ('øksle',),
'økta': ('økte',),
'øktede': ('økte',),
'øktende': ('økte',),
'øktet': ('økte',),
'øktete': ('økte',),
'økumen': ('økumen',),
'økumene': ('økumen',),
'økumenere': ('økumen',),
'økumenest': ('økumen',),
'økumeneste': ('økumen',),
'økument': ('økumen',),
'økumenisk': ('økumenisk',),
'økumeniske': ('økumenisk',),
'økumeniskere': ('økumenisk',),
'økumeniskest': ('økumenisk',),
'økumeniskeste': ('økumenisk',),
'ølandsk': ('ølandsk',),
'ølandske': ('ølandsk',),
'ølandskere': ('ølandsk',),
'ølandskest': ('ølandsk',),
'ølandskeste': ('ølandsk',),
'øla': ('øle',),
'ølede': ('øle',),
'ølende': ('øle',),
'ølet': ('øle',),
'ølete': ('øle',),
'ølet': ('ølet',),
'ølete': ('ølet',),
'øletere': ('ølet',),
'øletest': ('ølet',),
'øleteste': ('ølet',),
'ølete': ('ølete',),
'øm': ('øm',),
'ømme': ('øm',),
'ømmere': ('øm',),
'ømmest': ('øm',),
'ømmeste': ('øm',),
'ømt': ('øm',),
'ømfintlig': ('ømfintlig',),
'ømfintlige': ('ømfintlig',),
'ømfintligere': ('ømfintlig',),
'ømfintligst': ('ømfintlig',),
'ømfintligste': ('ømfintlig',),
'ømhjerta': ('ømhjerta',),
'ømhjertede': ('ømhjertet',),
'ømhjertet': ('ømhjertet',),
'ømhjertete': ('ømhjertet',),
'ømhjertetere': ('ømhjertet',),
'ømhjertetest': ('ømhjertet',),
'ømhjerteteste': ('ømhjertet',),
'ømma': ('ømme',),
'ømmede': ('ømme',),
'ømmende': ('ømme',),
'ømmet': ('ømme',),
'ømmete': ('ømme',),
'ømskinna': ('ømskinna',),
'ømskinnede': ('ømskinnet',),
'ømskinnet': ('ømskinnet',),
'ømskinnete': ('ømskinnet',),
'ømskinnetere': ('ømskinnet',),
'ømskinnetest': ('ømskinnet',),
'ømskinneteste': ('ømskinnet',),
'ømtålig': ('ømtålig',),
'ømtålige': ('ømtålig',),
'ømtåligere': ('ømtålig',),
'ømtåligst': ('ømtålig',),
'ømtåligste': ('ømtålig',),
'ønska': ('ønske',),
'ønskede': ('ønske',),
'ønskende': ('ønske',),
'ønsket': ('ønske',),
'ønskete': ('ønske',),
'ønskt': ('ønske',),
'ønskte': ('ønske',),
'ønskelig': ('ønskelig',),
'ønskelige': ('ønskelig',),
'ønskeligere': ('ønskelig',),
'ønskeligst': ('ønskelig',),
'ønskeligste': ('ønskelig',),
'ønsketenkende': ('ønsketenke',),
'ønsketenkt': ('ønsketenke',),
'ønsketenkte': ('ønsketenke',),
'ønskverdig': ('ønskverdig',),
'ønskverdige': ('ønskverdig',),
'ønskverdigere': ('ønskverdig',),
'ønskverdigst': ('ønskverdig',),
'ønskverdigste': ('ønskverdig',),
'ør': ('ør',),
'øre': ('ør',),
'ørere': ('ør',),
'ørest': ('ør',),
'øreste': ('ør',),
'ørt': ('ør',),
'ørende': ('øre',),
'ørt': ('øre',),
'ørte': ('øre',),
'øredøvende': ('øredøvende',),
'øremerka': ('øremerke',),
'øremerkede': ('øremerke',),
'øremerkende': ('øremerke',),
'øremerket': ('øremerke',),
'øremerkete': ('øremerke',),
'øren': ('øren',),
'ørent': ('øren',),
'ørne': ('øren',),
'ørnere': ('øren',),
'ørnest': ('øren',),
'ørneste': ('øren',),
'ørkesløs': ('ørkesløs',),
'ørkesløse': ('ørkesløs',),
'ørkesløsere': ('ørkesløs',),
'ørkesløsest': ('ørkesløs',),
'ørkesløseste': ('ørkesløs',),
'ørkesløst': ('ørkesløs',),
'ørlille': ('ørliten',),
'ørlita': ('ørliten',),
'ørlite': ('ørliten',),
'ørliten': ('ørliten',),
'ørmindre': ('ørliten',),
'ørminst': ('ørliten',),
'ørminste': ('ørliten',),
'ørsmå': ('ørliten',),
'ørsmått': ('ørliten',),
'ørvesle': ('ørliten',),
'ørnaktig': ('ørnaktig',),
'ørnaktige': ('ørnaktig',),
'ørnaktigere': ('ørnaktig',),
'ørnaktigst': ('ørnaktig',),
'ørnaktigste': ('ørnaktig',),
'ørneaktig': ('ørneaktig',),
'ørneaktige': ('ørneaktig',),
'ørneaktigere': ('ørneaktig',),
'ørneaktigst': ('ørneaktig',),
'ørneaktigste': ('ørneaktig',),
'ørsk': ('ørsk',),
'ørske': ('ørsk',),
'ørskere': ('ørsk',),
'ørskest': ('ørsk',),
'ørskeste': ('ørsk',),
'ørskt': ('ørsk',),
'ørska': ('ørske',),
'ørskede': ('ørske',),
'ørskende': ('ørske',),
'ørsket': ('ørske',),
'ørskete': ('ørske',),
'ørsken': ('ørsken',),
'ørskent': ('ørsken',),
'ørskne': ('ørsken',),
'ørsknere': ('ørsken',),
'ørsknest': ('ørsken',),
'ørskneste': ('ørsken',),
'ørta': ('ørte',),
'ørtede': ('ørte',),
'ørtende': ('ørte',),
'ørtet': ('ørte',),
'ørtete': ('ørte',),
'ørtende': ('ørtende',),
'øs': ('øs',),
'øse': ('øs',),
'øsere': ('øs',),
'øsest': ('øs',),
'øseste': ('øs',),
'øst': ('øs',),
'øsende': ('øse',),
'øst': ('øse',),
'øste': ('øse',),
'øsende': ('øse',),
'øst': ('øse',),
'øste': ('øse',),
'øsende': ('øsende',),
'øsregna': ('øsregne',),
'øsregnede': ('øsregne',),
'øsregnende': ('øsregne',),
'øsregnet': ('øsregne',),
'øsregnete': ('øsregne',),
'øsregnt': ('øsregne',),
'øsregnte': ('øsregne',),
'østafjelsk': ('østafjelsk',),
'østafjelske': ('østafjelsk',),
'østafjelskere': ('østafjelsk',),
'østafjelskest': ('østafjelsk',),
'østafjelskeste': ('østafjelsk',),
'østasiatisk': ('østasiatisk',),
'østasiatiske': ('østasiatisk',),
'østasiatiskere': ('østasiatisk',),
'østasiatiskest': ('østasiatisk',),
'østasiatiskeste': ('østasiatisk',),
'østenfjelsk': ('østenfjelsk',),
'østenfjelske': ('østenfjelsk',),
'østenfjelskere': ('østenfjelsk',),
'østenfjelskest': ('østenfjelsk',),
'østenfjelskeste': ('østenfjelsk',),
'østerdalsk': ('østerdalsk',),
'østerdalske': ('østerdalsk',),
'østerdalskere': ('østerdalsk',),
'østerdalskest': ('østerdalsk',),
'østerdalskeste': ('østerdalsk',),
'østerlandsk': ('østerlandsk',),
'østerlandske': ('østerlandsk',),
'østerlandskere': ('østerlandsk',),
'østerlandskest': ('østerlandsk',),
'østerlandskeste': ('østerlandsk',),
'østerriksk': ('østerriksk',),
'østerrikske': ('østerriksk',),
'østerrikskere': ('østerriksk',),
'østerrikskest': ('østerriksk',),
'østerrikskeste': ('østerriksk',),
'østersjøisk': ('østersjøisk',),
'østersjøiske': ('østersjøisk',),
'østersjøiskere': ('østersjøisk',),
'østersjøiskest': ('østersjøisk',),
'østersjøiskeste': ('østersjøisk',),
'østeuropeisk': ('østeuropeisk',),
'østeuropeiske': ('østeuropeisk',),
'østeuropeiskere': ('østeuropeisk',),
'østeuropeiskest': ('østeuropeisk',),
'østeuropeiskeste': ('østeuropeisk',),
'østgermansk': ('østgermansk',),
'østgermanske': ('østgermansk',),
'østgermanskere': ('østgermansk',),
'østgermanskest': ('østgermansk',),
'østgermanskeste': ('østgermansk',),
'østgermansk': ('østgermansk',),
'østgermanske': ('østgermansk',),
'østgermanskere': ('østgermansk',),
'østgermanskest': ('østgermansk',),
'østgermanskeste': ('østgermansk',),
'østgermansk': ('østgermansk',),
'østgermanske': ('østgermansk',),
'østgermanskere': ('østgermansk',),
'østgermanskest': ('østgermansk',),
'østgermanskeste': ('østgermansk',),
'østgotisk': ('østgotisk',),
'østgotiske': ('østgotisk',),
'østgotiskere': ('østgotisk',),
'østgotiskest': ('østgotisk',),
'østgotiskeste': ('østgotisk',),
'østlandsk': ('østlandsk',),
'østlandske': ('østlandsk',),
'østlandskere': ('østlandsk',),
'østlandskest': ('østlandsk',),
'østlandskeste': ('østlandsk',),
'østlig': ('østlig',),
'østlige': ('østlig',),
'østligere': ('østlig',),
'østligst': ('østlig',),
'østligste': ('østlig',),
'østnordisk': ('østnordisk',),
'østnordiske': ('østnordisk',),
'østnordiskere': ('østnordisk',),
'østnordiskest': ('østnordisk',),
'østnordiskeste': ('østnordisk',),
'østnordisk': ('østnordisk',),
'østnordiske': ('østnordisk',),
'østnordiskere': ('østnordisk',),
'østnordiskest': ('østnordisk',),
'østnordiskeste': ('østnordisk',),
'østnordisk': ('østnordisk',),
'østnordiske': ('østnordisk',),
'østnordiskere': ('østnordisk',),
'østnordiskest': ('østnordisk',),
'østnordiskeste': ('østnordisk',),
'østnorsk': ('østnorsk',),
'østnorske': ('østnorsk',),
'østnorskere': ('østnorsk',),
'østnorskest': ('østnorsk',),
'østnorskeste': ('østnorsk',),
'østre': ('østre',),
'østrogen': ('østrogen',),
'østrogene': ('østrogen',),
'østrogenere': ('østrogen',),
'østrogenest': ('østrogen',),
'østrogeneste': ('østrogen',),
'østrogent': ('østrogen',),
'østromersk': ('østromersk',),
'østromerske': ('østromersk',),
'østromerskere': ('østromersk',),
'østromerskest': ('østromersk',),
'østromerskeste': ('østromersk',),
'østtysk': ('østtysk',),
'østtyske': ('østtysk',),
'østtyskere': ('østtysk',),
'østtyskest': ('østtysk',),
'østtyskeste': ('østtysk',),
'østvendt': ('østvendt',),
'østvendte': ('østvendt',),
'østvendtere': ('østvendt',),
'østvendtest': ('østvendt',),
'østvendteste': ('østvendt',),
'øvd': ('øvd',),
'øvde': ('øvd',),
'øvdere': ('øvd',),
'øvdest': ('øvd',),
'øvdeste': ('øvd',),
'øva': ('øve',),
'øvd': ('øve',),
'øvde': ('øve',),
'øvede': ('øve',),
'øvende': ('øve',),
'øvet': ('øve',),
'øvete': ('øve',),
'øverstkommanderende': ('øverstkommanderende',),
'øvede': ('øvet',),
'øvet': ('øvet',),
'øvete': ('øvet',),
'øvetere': ('øvet',),
'øvetest': ('øvet',),
'øveteste': ('øvet',),
'øverst': ('øvre',),
'øverste': ('øvre',),
'øvre': ('øvre',),
'øvst': ('øvre',),
'øvste': ('øvre',),
'øvrig': ('øvrig',),
'øvrige': ('øvrig',),
'øvrigere': ('øvrig',),
'øvrigst': ('øvrig',),
'øvrigste': ('øvrig',),
'øydd': ('øyde',),
'øydde': ('øyde',),
'øydende': ('øyde',),
'øyde': ('øyde',),
'øydere': ('øyde',),
'øydest': ('øyde',),
'øydeste': ('øyde',),
'øydt': ('øyde',),
'øydelagt': ('øydelegge',),
'øydelagte': ('øydelegge',),
'øydeleggende': ('øydelegge',),
'øyd': ('øye',),
'øyde': ('øye',),
'øyende': ('øye',),
'øyeblikkelig': ('øyeblikkelig',),
'øyeblikkelige': ('øyeblikkelig',),
'øyeblikkeligere': ('øyeblikkelig',),
'øyeblikkeligst': ('øyeblikkelig',),
'øyeblikkeligste': ('øyeblikkelig',),
'øyna': ('øyne',),
'øynede': ('øyne',),
'øynende': ('øyne',),
'øynet': ('øyne',),
'øynete': ('øyne',),
'ålreit': ('ålreit',),
'ålreite': ('ålreit',),
'ålreitere': ('ålreit',),
'ålreitest': ('ålreit',),
'ålreiteste': ('ålreit',),
'berust': ('berust',),
'beruste': ('berust',),
'berustere': ('berust',),
'berustest': ('berust',),
'berusteste': ('berust',),
'blauthjerta': ('blauthjerta',),
'brasa': ('brase',),
'brasede': ('brase',),
'brasende': ('brase',),
'braset': ('brase',),
'brasete': ('brase',),
'brast': ('brase',),
'braste': ('brase',),
'bredd': ('bre',),
'bredde': ('bre',),
'breende': ('bre',),
'bredaksla': ('bredaksla',),
'breiaksla': ('breiaksla',),
'brennende': ('brenne',),
'brent': ('brenne',),
'brente': ('brenne',),
'bunna': ('bunne',),
'bunnede': ('bunne',),
'bunnende': ('bunne',),
'bunnet': ('bunne',),
'bunnete': ('bunne',),
'båren': ('bære',),
'båret': ('bære',),
'bårne': ('bære',),
'bærende': ('bære',),
'flerra': ('flerre',),
'flerrede': ('flerre',),
'flerrende': ('flerre',),
'flerret': ('flerre',),
'flerrete': ('flerre',),
'flott': ('flott',),
'flott': ('flott',),
'flotte': ('flott',),
'flottere': ('flott',),
'flottest': ('flott',),
'flotteste': ('flott',),
'forbrennende': ('forbrenne',),
'forbrent': ('forbrenne',),
'forbrente': ('forbrenne',),
'forstrekkende': ('forstrekke',),
'forstrukken': ('forstrekke',),
'forstrukket': ('forstrekke',),
'forstrukne': ('forstrekke',),
'frysende': ('fryse',),
'fryst': ('fryse',),
'fryste': ('fryse',),
'fulgt': ('følge',),
'fulgte': ('følge',),
'følgende': ('følge',),
'fulgt': ('følge',),
'fulgte': ('følge',),
'følgende': ('følge',),
'gammaldags': ('gammaldags',),
'gammeldags': ('gammeldags',),
'gammaldags': ('gammaldags',),
'gammaldagse': ('gammaldags',),
'gammaldagsere': ('gammaldags',),
'gammaldagsest': ('gammaldags',),
'gammaldagseste': ('gammaldags',),
'gammeldags': ('gammeldags',),
'gammeldagse': ('gammeldags',),
'gammeldagsere': ('gammeldags',),
'gammeldagsest': ('gammeldags',),
'gammeldagseste': ('gammeldags',),
'girende': ('gire',),
'girt': ('gire',),
'girte': ('gire',),
'girende': ('gire',),
'girt': ('gire',),
'girte': ('gire',),
'gira': ('gire',),
'girede': ('gire',),
'girende': ('gire',),
'giret': ('gire',),
'girete': ('gire',),
'girt': ('gire',),
'girte': ('gire',),
'glidd': ('glide',),
'glidde': ('glide',),
'glidende': ('glide',),
'glidd': ('glide',),
'glidde': ('glide',),
'glidende': ('glide',),
'glida': ('glide',),
'glidede': ('glide',),
'glidende': ('glide',),
'glidet': ('glide',),
'glidete': ('glide',),
'glipne': ('glippe',),
'glippen': ('glippe',),
'glippende': ('glippe',),
'glippet': ('glippe',),
'glippa': ('glippe',),
'glippede': ('glippe',),
'glippende': ('glippe',),
'glippet': ('glippe',),
'glippete': ('glippe',),
'glipt': ('glippe',),
'glipte': ('glippe',),
'grovskåren': ('grovskåren',),
'grovskårent': ('grovskåren',),
'grovskårne': ('grovskåren',),
'grovskårnere': ('grovskåren',),
'grovskårnest': ('grovskåren',),
'grovskårneste': ('grovskåren',),
'grovskåren': ('grovskåren',),
'grovskåret': ('grovskåren',),
'grovskårne': ('grovskåren',),
'grovskårnere': ('grovskåren',),
'grovskårnest': ('grovskåren',),
'grovskårneste': ('grovskåren',),
'hela': ('hele',),
'helede': ('hele',),
'helende': ('hele',),
'helet': ('hele',),
'helete': ('hele',),
'hela': ('hele',),
'helede': ('hele',),
'helende': ('hele',),
'helet': ('hele',),
'helete': ('hele',),
'hela': ('hele',),
'helede': ('hele',),
'helende': ('hele',),
'helet': ('hele',),
'helete': ('hele',),
'helt': ('hele',),
'helte': ('hele',),
'hengende': ('henge',),
'hengt': ('henge',),
'hengte': ('henge',),
'hjemmebakt': ('hjemmebakt',),
'hjemmebakte': ('hjemmebakt',),
'hjemmebaktere': ('hjemmebakt',),
'hjemmebaktest': ('hjemmebakt',),
'hjemmebakteste': ('hjemmebakt',),
'hogd': ('hogge',),
'hogde': ('hogge',),
'hoggede': ('hogge',),
'hoggende': ('hogge',),
'hogget': ('hogge',),
'hoggete': ('hogge',),
'hugd': ('hugge',),
'hugde': ('hugge',),
'hugga': ('hugge',),
'huggede': ('hugge',),
'huggende': ('hugge',),
'hugget': ('hugge',),
'huggete': ('hugge',),
'hola': ('hole',),
'holende': ('hole',),
'holt': ('hole',),
'holte': ('hole',),
'hola': ('hole',),
'holede': ('hole',),
'holende': ('hole',),
'holet': ('hole',),
'holete': ('hole',),
'høghalsa': ('høghalsa',),
'høyhalsa': ('høyhalsa',),
'høglønna': ('høglønna',),
'høglønnede': ('høglønnet',),
'høglønnet': ('høglønnet',),
'høglønnete': ('høglønnet',),
'høglønnetere': ('høglønnet',),
'høglønnetest': ('høglønnet',),
'høglønneteste': ('høglønnet',),
'høglønt': ('høglønt',),
'høglønte': ('høglønt',),
'høgløntere': ('høglønt',),
'høgløntest': ('høglønt',),
'høglønteste': ('høglønt',),
'høylønna': ('høylønna',),
'høylønnede': ('høylønnet',),
'høylønnet': ('høylønnet',),
'høylønnete': ('høylønnet',),
'høylønnetere': ('høylønnet',),
'høylønnetest': ('høylønnet',),
'høylønneteste': ('høylønnet',),
'høylønt': ('høylønt',),
'høylønte': ('høylønt',),
'høyløntere': ('høylønt',),
'høyløntest': ('høylønt',),
'høylønteste': ('høylønt',),
'høytlønna': ('høytlønna',),
'høytlønnede': ('høytlønnet',),
'høytlønnet': ('høytlønnet',),
'høytlønnete': ('høytlønnet',),
'høytlønnetere': ('høytlønnet',),
'høytlønnetest': ('høytlønnet',),
'høytlønneteste': ('høytlønnet',),
'kei': ('kei',),
'keie': ('kei',),
'keiere': ('kei',),
'keiest': ('kei',),
'keieste': ('kei',),
'keit': ('kei',),
'keitt': ('kei',),
'klekk': ('klekk',),
'klekke': ('klekk',),
'klekkere': ('klekk',),
'klekkest': ('klekk',),
'klekkeste': ('klekk',),
'klekt': ('klekk',),
'klessende': ('klesse',),
'klest': ('klesse',),
'kleste': ('klesse',),
'kullende': ('kulle',),
'kullt': ('kulle',),
'kullte': ('kulle',),
'kulla': ('kulle',),
'kullede': ('kulle',),
'kullende': ('kulle',),
'kullet': ('kulle',),
'kullete': ('kulle',),
'kura': ('kure',),
'kurede': ('kure',),
'kurende': ('kure',),
'kuret': ('kure',),
'kurete': ('kure',),
'kura': ('kure',),
'kurede': ('kure',),
'kurende': ('kure',),
'kuret': ('kure',),
'kurete': ('kure',),
'kurt': ('kure',),
'kurte': ('kure',),
'kvekkende': ('kvekke',),
'kvekt': ('kvekke',),
'kvekte': ('kvekke',),
'kvekka': ('kvekke',),
'kvekkede': ('kvekke',),
'kvekkende': ('kvekke',),
'kvekket': ('kvekke',),
'kvekkete': ('kvekke',),
'kveppende': ('kveppe',),
'kvept': ('kveppe',),
'kvepte': ('kveppe',),
'ladd': ('la',),
'ladde': ('la',),
'laende': ('la',),
'leid': ('leie',),
'leidd': ('leie',),
'leidde': ('leie',),
'leide': ('leie',),
'leiede': ('leie',),
'leiende': ('leie',),
'leiet': ('leie',),
'leiete': ('leie',),
'leid': ('leie',),
'leide': ('leie',),
'leiede': ('leie',),
'leiende': ('leie',),
'leiet': ('leie',),
'leiete': ('leie',),
'leika': ('leike',),
'leikede': ('leike',),
'leikende': ('leike',),
'leiket': ('leike',),
'leikete': ('leike',),
'leikt': ('leike',),
'leikte': ('leike',),
'lausrevet': ('lausrevet',),
'lausrevne': ('lausrevet',),
'lausrevnere': ('lausrevet',),
'lausrevnest': ('lausrevet',),
'lausrevneste': ('lausrevet',),
'løsrevet': ('løsrevet',),
'løsrevne': ('løsrevet',),
'løsrevnere': ('løsrevet',),
'løsrevnest': ('løsrevet',),
'løsrevneste': ('løsrevet',),
'låglønt': ('låglønt',),
'låglønte': ('låglønt',),
'lågløntere': ('låglønt',),
'lågløntest': ('låglønt',),
'låglønteste': ('låglønt',),
'leita': ('leite',),
'leitede': ('leite',),
'leitende': ('leite',),
'leitet': ('leite',),
'leitete': ('leite',),
'leitt': ('leite',),
'leitte': ('leite',),
'leika': ('leike',),
'leikede': ('leike',),
'leikende': ('leike',),
'leiket': ('leike',),
'leikete': ('leike',),
'leikt': ('leike',),
'leikte': ('leike',),
'lova': ('love',),
'lovede': ('love',),
'lovende': ('love',),
'lovet': ('love',),
'lovete': ('love',),
'malende': ('male',),
'malt': ('male',),
'malte': ('male',),
'masa': ('mase',),
'masede': ('mase',),
'masende': ('mase',),
'maset': ('mase',),
'masete': ('mase',),
'mast': ('mase',),
'maste': ('mase',),
'masa': ('mase',),
'masede': ('mase',),
'masende': ('mase',),
'maset': ('mase',),
'masete': ('mase',),
'mast': ('mase',),
'maste': ('mase',),
'missende': ('misse',),
'mist': ('misse',),
'miste': ('misse',),
'missa': ('misse',),
'missede': ('misse',),
'missende': ('misse',),
'misset': ('misse',),
'missete': ('misse',),
'mo': ('mo',),
'moe': ('mo',),
'moere': ('mo',),
'moest': ('mo',),
'moeste': ('mo',),
'mott': ('mo',),
'mosa': ('mose',),
'mosede': ('mose',),
'mosende': ('mose',),
'moset': ('mose',),
'mosete': ('mose',),
'mosa': ('mose',),
'mosede': ('mose',),
'mosende': ('mose',),
'moset': ('mose',),
'mosete': ('mose',),
'most': ('mose',),
'moste': ('mose',),
'mjuka': ('mjuke',),
'mjukede': ('mjuke',),
'mjukende': ('mjuke',),
'mjuket': ('mjuke',),
'mjukete': ('mjuke',),
'mjukt': ('mjuke',),
'mjukte': ('mjuke',),
'neurastenisk': ('neurastenisk',),
'neurasteniske': ('neurastenisk',),
'neurasteniskere': ('neurastenisk',),
'neurasteniskest': ('neurastenisk',),
'neurasteniskeste': ('neurastenisk',),
'nevrastenisk': ('nevrastenisk',),
'nevrasteniske': ('nevrastenisk',),
'nevrasteniskere': ('nevrastenisk',),
'nevrasteniskest': ('nevrastenisk',),
'nevrasteniskeste': ('nevrastenisk',),
'pilla': ('pille',),
'pillede': ('pille',),
'pillende': ('pille',),
'pillet': ('pille',),
'pillete': ('pille',),
'pilt': ('pille',),
'pilte': ('pille',),
'pilla': ('pille',),
'pillede': ('pille',),
'pillende': ('pille',),
'pillet': ('pille',),
'pillete': ('pille',),
'pilt': ('pille',),
'pilte': ('pille',),
'rekka': ('rekke',),
'rekkede': ('rekke',),
'rekkende': ('rekke',),
'rekket': ('rekke',),
'rekkete': ('rekke',),
'rekkt': ('rekke',),
'rekkte': ('rekke',),
'rekt': ('rekke',),
'rekte': ('rekke',),
'rennende': ('renne',),
'rent': ('renne',),
'rente': ('renne',),
'rømmende': ('rømme',),
'rømt': ('rømme',),
'rømte': ('rømme',),
'rømma': ('rømme',),
'rømmede': ('rømme',),
'rømmende': ('rømme',),
'rømmet': ('rømme',),
'rømmete': ('rømme',),
'seilende': ('seile',),
'seilt': ('seile',),
'seilte': ('seile',),
'selvforsørgende': ('selvforsørgende',),
'sjølforsørgende': ('sjølforsørgende',),
'skallede': ('skallet',),
'skallet': ('skallet',),
'skallete': ('skallet',),
'skalletere': ('skallet',),
'skalletest': ('skallet',),
'skalleteste': ('skallet',),
'skallet': ('skallet',),
'skallete': ('skallet',),
'skalletere': ('skallet',),
'skalletest': ('skallet',),
'skalleteste': ('skallet',),
'skyede': ('skyet',),
'skyet': ('skyet',),
'skyete': ('skyet',),
'skyetere': ('skyet',),
'skyetest': ('skyet',),
'skyeteste': ('skyet',),
'skyet': ('skyet',),
'skyete': ('skyet',),
'skyetere': ('skyet',),
'skyetest': ('skyet',),
'skyeteste': ('skyet',),
'slengende': ('slenge',),
'slengt': ('slenge',),
'slengte': ('slenge',),
'sleppende': ('sleppe',),
'slept': ('sleppe',),
'slepte': ('sleppe',),
'sløya': ('sløye',),
'sløyd': ('sløye',),
'sløyde': ('sløye',),
'sløyede': ('sløye',),
'sløyende': ('sløye',),
'sløyet': ('sløye',),
'sløyete': ('sløye',),
'smellende': ('smelle',),
'smelt': ('smelle',),
'smelte': ('smelle',),
'snikende': ('snike',),
'snikt': ('snike',),
'snikte': ('snike',),
'spredd': ('spre',),
'spredde': ('spre',),
'spredt': ('spre',),
'spredte': ('spre',),
'spreende': ('spre',),
'spredd': ('spre',),
'spredde': ('spre',),
'spredt': ('spre',),
'spredte': ('spre',),
'spreende': ('spre',),
'stemna': ('stemne',),
'stemnede': ('stemne',),
'stemnende': ('stemne',),
'stemnet': ('stemne',),
'stemnete': ('stemne',),
'stemnt': ('stemne',),
'stemnte': ('stemne',),
'stevna': ('stevne',),
'stevnede': ('stevne',),
'stevnende': ('stevne',),
'stevnet': ('stevne',),
'stevnete': ('stevne',),
'stevnt': ('stevne',),
'stevnte': ('stevne',),
'stemna': ('stemne',),
'stemnede': ('stemne',),
'stemnende': ('stemne',),
'stemnet': ('stemne',),
'stemnete': ('stemne',),
'stevna': ('stevne',),
'stevnede': ('stevne',),
'stevnende': ('stevne',),
'stevnet': ('stevne',),
'stevnete': ('stevne',),
'stima': ('stime',),
'stimede': ('stime',),
'stimende': ('stime',),
'stimet': ('stime',),
'stimete': ('stime',),
'stima': ('stime',),
'stimede': ('stime',),
'stimende': ('stime',),
'stimet': ('stime',),
'stimete': ('stime',),
'stimt': ('stime',),
'stimte': ('stime',),
'strekkende': ('strekke',),
'strukken': ('strekke',),
'strukket': ('strekke',),
'strukne': ('strekke',),
'strihårede': ('strihåret',),
'strihåret': ('strihåret',),
'strihårete': ('strihåret',),
'strihåretere': ('strihåret',),
'strihåretest': ('strihåret',),
'strihåreteste': ('strihåret',),
'støkkende': ('støkke',),
'støkt': ('støkke',),
'støkte': ('støkke',),
'sveisende': ('sveise',),
'sveist': ('sveise',),
'sveiste': ('sveise',),
'sveisa': ('sveise',),
'sveisede': ('sveise',),
'sveisende': ('sveise',),
'sveiset': ('sveise',),
'sveisete': ('sveise',),
'sveist': ('sveise',),
'sveiste': ('sveise',),
'svidd': ('svi',),
'svidde': ('svi',),
'sviende': ('svi',),
'søkkende': ('søkke',),
'søkt': ('søkke',),
'søkte': ('søkke',),
'trettende': ('trettende',),
'trettende': ('trettende',),
'tørra': ('tørre',),
'tørrede': ('tørre',),
'tørrende': ('tørre',),
'tørret': ('tørre',),
'tørrete': ('tørre',),
'ugreid': ('ugreie',),
'ugreidd': ('ugreie',),
'ugreidde': ('ugreie',),
'ugreide': ('ugreie',),
'ugreiede': ('ugreie',),
'ugreiende': ('ugreie',),
'ugreiet': ('ugreie',),
'ugreiete': ('ugreie',),
'utleid': ('utleie',),
'utleide': ('utleie',),
'utleiede': ('utleie',),
'utleiende': ('utleie',),
'utleiet': ('utleie',),
'utleiete': ('utleie',),
'vikende': ('vike',),
'vikt': ('vike',),
'vikte': ('vike',),
'vikende': ('vike',),
'vikt': ('vike',),
'vikte': ('vike',),
'vikende': ('vike',),
'vikt': ('vike',),
'vikte': ('vike',),
'vinnende': ('vinne',),
'vint': ('vinne',),
'vinte': ('vinne',),
'vinnende': ('vinne',),
'vunne': ('vinne',),
'vunnen': ('vinne',),
'vunnet': ('vinne',),
'vogga': ('vogge',),
'voggede': ('vogge',),
'voggende': ('vogge',),
'vogget': ('vogge',),
'voggete': ('vogge',),
'brasa': ('brase',),
'brasende': ('brase',),
'brast': ('brase',),
'braste': ('brase',),
'bredd': ('bre',),
'bredde': ('bre',),
'bredt': ('bre',),
'bredte': ('bre',),
'breende': ('bre',),
'brennende': ('brenne',),
'brent': ('brenne',),
'brente': ('brenne',),
'forbrennende': ('forbrenne',),
'forbrent': ('forbrenne',),
'forbrente': ('forbrenne',),
'forstrakt': ('forstrekke',),
'forstrakte': ('forstrekke',),
'forstrekkende': ('forstrekke',),
'forstrekt': ('forstrekke',),
'forstrekte': ('forstrekke',),
'forstrukken': ('forstrekke',),
'forstrukket': ('forstrekke',),
'forstrukne': ('forstrekke',),
'frosne': ('fryse',),
'frossen': ('fryse',),
'frosset': ('fryse',),
'fryse': ('fryse',),
'frysende': ('fryse',),
'hengende': ('henge',),
'hengt': ('henge',),
'hengte': ('henge',),
'klesne': ('klesse',),
'klessen': ('klesse',),
'klessende': ('klesse',),
'klesset': ('klesse',),
'kvepne': ('kveppe',),
'kveppen': ('kveppe',),
'kveppende': ('kveppe',),
'kveppet': ('kveppe',),
'latende': ('la',),
'latt': ('la',),
'latte': ('la',),
'latende': ('la',),
'latt': ('la',),
'latte': ('la',),
'leita': ('leite',),
'leitede': ('leite',),
'leitende': ('leite',),
'leitet': ('leite',),
'leitete': ('leite',),
'leitt': ('leite',),
'leitte': ('leite',),
'lett': ('leite',),
'lette': ('leite',),
'lova': ('love',),
'lovd': ('love',),
'lovde': ('love',),
'lovede': ('love',),
'lovende': ('love',),
'lovet': ('love',),
'lovete': ('love',),
'lovt': ('love',),
'lovte': ('love',),
'malende': ('male',),
'malt': ('male',),
'malte': ('male',),
'mo': ('mo',),
'moe': ('mo',),
'moere': ('mo',),
'moest': ('mo',),
'moeste': ('mo',),
'rekkende': ('rekke',),
'rukken': ('rekke',),
'rukket': ('rekke',),
'rukne': ('rekke',),
'rakt': ('rekke',),
'rakte': ('rekke',),
'rekkende': ('rekke',),
'rennende': ('renne',),
'rent': ('renne',),
'rente': ('renne',),
'slengende': ('slenge',),
'slengt': ('slenge',),
'slengte': ('slenge',),
'sleppende': ('sleppe',),
'slupne': ('sleppe',),
'sluppen': ('sleppe',),
'sluppet': ('sleppe',),
'sløgd': ('sløye',),
'sløgde': ('sløye',),
'sløya': ('sløye',),
'sløyd': ('sløye',),
'sløyde': ('sløye',),
'sløyede': ('sløye',),
'sløyende': ('sløye',),
'sløyet': ('sløye',),
'sløyete': ('sløye',),
'smellende': ('smelle',),
'smelt': ('smelle',),
'smelte': ('smelle',),
'sneken': ('snike',),
'sneket': ('snike',),
'snekne': ('snike',),
'snikende': ('snike',),
'strakt': ('strekke',),
'strakte': ('strekke',),
'strekkende': ('strekke',),
'strekt': ('strekke',),
'strekte': ('strekke',),
'strukken': ('strekke',),
'strukket': ('strekke',),
'strukne': ('strekke',),
'støkken': ('støkke',),
'støkkende': ('støkke',),
'støkket': ('støkke',),
'støkne': ('støkke',),
'støkt': ('støkke',),
'støkte': ('støkke',),
'svidd': ('svi',),
'svidde': ('svi',),
'sviende': ('svi',),
'søkken': ('søkke',),
'søkkende': ('søkke',),
'søkket': ('søkke',),
'søkne': ('søkke',),
'veken': ('vike',),
'veket': ('vike',),
'vekne': ('vike',),
'vikende': ('vike',),
'veken': ('vike',),
'veket': ('vike',),
'vekne': ('vike',),
'vikende': ('vike',),
'veken': ('vike',),
'veket': ('vike',),
'vekne': ('vike',),
'vikende': ('vike',),
'veken': ('vike',),
'veket': ('vike',),
'vekne': ('vike',),
'vikende': ('vike',),
'adskillende': ('adskille',),
'adskilt': ('adskille',),
'adskilte': ('adskille',),
'adskilt': ('adskilt',),
'adskilte': ('adskilt',),
'adskiltere': ('adskilt',),
'adskiltest': ('adskilt',),
'adskilteste': ('adskilt',),
'alkoholfri': ('alkoholfri',),
'alkoholfrie': ('alkoholfri',),
'alkoholfriere': ('alkoholfri',),
'alkoholfriest': ('alkoholfri',),
'alkoholfrieste': ('alkoholfri',),
'alkoholfritt': ('alkoholfri',),
'alliansefri': ('alliansefri',),
'alliansefrie': ('alliansefri',),
'alliansefriere': ('alliansefri',),
'alliansefriest': ('alliansefri',),
'alliansefrieste': ('alliansefri',),
'alliansefritt': ('alliansefri',),
'årseldre': ('årsgammal',),
'årseldst': ('årsgammal',),
'årseldste': ('årsgammal',),
'årsgamle': ('årsgammal',),
'årsgammal': ('årsgammal',),
'årsgammalt': ('årsgammal',),
'annenhands': ('annenhands',),
'ansvarsfri': ('ansvarsfri',),
'ansvarsfrie': ('ansvarsfri',),
'ansvarsfriere': ('ansvarsfri',),
'ansvarsfriest': ('ansvarsfri',),
'ansvarsfrieste': ('ansvarsfri',),
'ansvarsfritt': ('ansvarsfri',),
'arbeidssky': ('arbeidssky',),
'arbeidsskye': ('arbeidssky',),
'arbeidsskyere': ('arbeidssky',),
'arbeidsskyest': ('arbeidssky',),
'arbeidsskyeste': ('arbeidssky',),
'atomfri': ('atomfri',),
'atomfrie': ('atomfri',),
'atomfriere': ('atomfri',),
'atomfriest': ('atomfri',),
'atomfrieste': ('atomfri',),
'atomfritt': ('atomfri',),
'atstadig': ('atstadig',),
'atstadige': ('atstadig',),
'atstadigere': ('atstadig',),
'atstadigst': ('atstadig',),
'atstadigste': ('atstadig',),
'austnorsk': ('austnorsk',),
'austnorske': ('austnorsk',),
'austnorskere': ('austnorsk',),
'austnorskest': ('austnorsk',),
'austnorskeste': ('austnorsk',),
'østnorsk': ('østnorsk',),
'østnorske': ('østnorsk',),
'østnorskere': ('østnorsk',),
'østnorskest': ('østnorsk',),
'østnorskeste': ('østnorsk',),
'bakteriefri': ('bakteriefri',),
'bakteriefrie': ('bakteriefri',),
'bakteriefriere': ('bakteriefri',),
'bakteriefriest': ('bakteriefri',),
'bakteriefrieste': ('bakteriefri',),
'bakteriefritt': ('bakteriefri',),
'berrarmede': ('berrarmet',),
'berrarmet': ('berrarmet',),
'berrarmete': ('berrarmet',),
'berrarmetere': ('berrarmet',),
'berrarmetest': ('berrarmet',),
'berrarmeteste': ('berrarmet',),
'berrfotede': ('berrfotet',),
'berrfotet': ('berrfotet',),
'berrfotete': ('berrfotet',),
'berrfotetere': ('berrfotet',),
'berrfotetest': ('berrfotet',),
'berrfoteteste': ('berrfotet',),
'berrfrosne': ('berrfrossen',),
'berrfrosnere': ('berrfrossen',),
'berrfrosnest': ('berrfrossen',),
'berrfrosneste': ('berrfrossen',),
'berrfrossen': ('berrfrossen',),
'berrfrosset': ('berrfrossen',),
'berrfrosne': ('berrfrosset',),
'berrfrosnere': ('berrfrosset',),
'berrfrosnest': ('berrfrosset',),
'berrfrosneste': ('berrfrosset',),
'berrfrosset': ('berrfrosset',),
'berrhoda': ('berrhoda',),
'berrhodede': ('berrhodet',),
'berrhodet': ('berrhodet',),
'berrhodete': ('berrhodet',),
'berrhodetere': ('berrhodet',),
'berrhodetest': ('berrhodet',),
'berrhodeteste': ('berrhodet',),
'beinfri': ('beinfri',),
'beinfrie': ('beinfri',),
'beinfriere': ('beinfri',),
'beinfriest': ('beinfri',),
'beinfrieste': ('beinfri',),
'beinfritt': ('beinfri',),
'benfri': ('benfri',),
'benfrie': ('benfri',),
'benfriere': ('benfri',),
'benfriest': ('benfri',),
'benfrieste': ('benfri',),
'benfritt': ('benfri',),
'beinlaus': ('beinlaus',),
'beinlause': ('beinlaus',),
'beinlausere': ('beinlaus',),
'beinlausest': ('beinlaus',),
'beinlauseste': ('beinlaus',),
'beinlaust': ('beinlaus',),
'berrfotede': ('berrfotet',),
'berrfotet': ('berrfotet',),
'berrfotete': ('berrfotet',),
'berrfotetere': ('berrfotet',),
'berrfotetest': ('berrfotet',),
'berrfoteteste': ('berrfotet',),
'bilfri': ('bilfri',),
'bilfrie': ('bilfri',),
'bilfriere': ('bilfri',),
'bilfriest': ('bilfri',),
'bilfrieste': ('bilfri',),
'bilfritt': ('bilfri',),
'bindegæren': ('bindegæren',),
'bindegærent': ('bindegæren',),
'bindegærne': ('bindegæren',),
'bindegærnere': ('bindegæren',),
'bindegærnest': ('bindegæren',),
'bindegærneste': ('bindegæren',),
'bisla': ('bisle',),
'bislede': ('bisle',),
'bislende': ('bisle',),
'bislet': ('bisle',),
'bislete': ('bisle',),
'bleknebbede': ('bleknebbet',),
'bleknebbet': ('bleknebbet',),
'bleknebbetere': ('bleknebbet',),
'bleknebbetest': ('bleknebbet',),
'bleknebbeteste': ('bleknebbet',),
'blekrosa': ('blekrosa',),
'bleikrosa': ('bleikrosa',),
'blyfri': ('blyfri',),
'blyfrie': ('blyfri',),
'blyfriere': ('blyfri',),
'blyfriest': ('blyfri',),
'blyfrieste': ('blyfri',),
'blyfritt': ('blyfri',),
'bortfallende': ('bortfalle',),
'bortfalt': ('bortfalle',),
'bortfalte': ('bortfalle',),
'brennheit': ('brennheit',),
'brennheite': ('brennheit',),
'brennheitere': ('brennheit',),
'brennheitest': ('brennheit',),
'brennheiteste': ('brennheit',),
'brennheitt': ('brennheit',),
'brennhett': ('brennheit',),
'bråstansa': ('bråstanse',),
'bråstansede': ('bråstanse',),
'bråstansende': ('bråstanse',),
'bråstanset': ('bråstanse',),
'bråstansete': ('bråstanse',),
'bonnfellende': ('bonnfelle',),
'bonnfelt': ('bonnfelle',),
'bonnfelte': ('bonnfelle',),
'bunnfordervede': ('bunnfordervet',),
'bunnfordervet': ('bunnfordervet',),
'bunnfordervete': ('bunnfordervet',),
'bunnfordervetere': ('bunnfordervet',),
'bunnfordervetest': ('bunnfordervet',),
'bunnforderveteste': ('bunnfordervet',),
'bonnlaus': ('bonnlaus',),
'bonnlause': ('bonnlaus',),
'bonnlausere': ('bonnlaus',),
'bonnlausest': ('bonnlaus',),
'bonnlauseste': ('bonnlaus',),
'bonnlaust': ('bonnlaus',),
'bonnløs': ('bonnløs',),
'bonnløse': ('bonnløs',),
'bonnløsere': ('bonnløs',),
'bonnløsest': ('bonnløs',),
'bonnløseste': ('bonnløs',),
'bonnløst': ('bonnløs',),
'bonnskrapa': ('bonnskrape',),
'bonnskrapede': ('bonnskrape',),
'bonnskrapende': ('bonnskrape',),
'bonnskrapet': ('bonnskrape',),
'bonnskrapete': ('bonnskrape',),
'bonnskrapt': ('bonnskrape',),
'bonnskrapte': ('bonnskrape',),
'crawla': ('crawle',),
'crawlede': ('crawle',),
'crawlende': ('crawle',),
'crawlet': ('crawle',),
'crawlete': ('crawle',),
'dobbeltbonnede': ('dobbeltbonnet',),
'dobbeltbonnet': ('dobbeltbonnet',),
'dobbeltbonnete': ('dobbeltbonnet',),
'dobbeltbonnetere': ('dobbeltbonnet',),
'dobbeltbonnetest': ('dobbeltbonnet',),
'dobbeltbonneteste': ('dobbeltbonnet',),
'dradd': ('dra',),
'dradde': ('dra',),
'dragende': ('dra',),
'dratt': ('dra',),
'dratte': ('dra',),
'dødsstille': ('dødsstille',),
'døgneldre': ('døgngammal',),
'døgneldst': ('døgngammal',),
'døgneldste': ('døgngammal',),
'døgngamle': ('døgngammal',),
'døgngammal': ('døgngammal',),
'døgngammalt': ('døgngammal',),
'dauvstum': ('dauvstum',),
'dauvstumme': ('dauvstum',),
'dauvstummere': ('dauvstum',),
'dauvstummest': ('dauvstum',),
'dauvstummeste': ('dauvstum',),
'dauvstumt': ('dauvstum',),
'eidsvoren': ('eidsvoren',),
'eidsvorent': ('eidsvoren',),
'eidsvorne': ('eidsvoren',),
'eidsvornere': ('eidsvoren',),
'eidsvornest': ('eidsvoren',),
'eidsvorneste': ('eidsvoren',),
'ekry': ('ekry',),
'eldeldre': ('eldgammal',),
'eldeldst': ('eldgammal',),
'eldeldste': ('eldgammal',),
'eldgamle': ('eldgammal',),
'eldgammal': ('eldgammal',),
'eldgammalt': ('eldgammal',),
'etterfulgt': ('etterfølge',),
'etterfulgte': ('etterfølge',),
'etterfølgende': ('etterfølge',),
'etterkommen': ('etterkomme',),
'etterkommende': ('etterkomme',),
'etterkommet': ('etterkomme',),
'etterkomne': ('etterkomme',),
'fastslående': ('fastslå',),
'fastslått': ('fastslå',),
'fastslåtte': ('fastslå',),
'feberfri': ('feberfri',),
'feberfrie': ('feberfri',),
'feberfriere': ('feberfri',),
'feberfriest': ('feberfri',),
'feberfrieste': ('feberfri',),
'feberfritt': ('feberfri',),
'feberheit': ('feberheit',),
'feberheite': ('feberheit',),
'feberheitere': ('feberheit',),
'feberheitest': ('feberheit',),
'feberheiteste': ('feberheit',),
'feberheitt': ('feberheit',),
'feberhett': ('feberheit',),
'feilfri': ('feilfri',),
'feilfrie': ('feilfri',),
'feilfriere': ('feilfri',),
'feilfriest': ('feilfri',),
'feilfrieste': ('feilfri',),
'feilfritt': ('feilfri',),
'ferskenfarga': ('ferskenfarga',),
'feudal': ('feudal',),
'feudale': ('feudal',),
'feudalere': ('feudal',),
'feudalest': ('feudal',),
'feudaleste': ('feudal',),
'feudalt': ('feudal',),
'fjøra': ('fjøre',),
'fjørede': ('fjøre',),
'fjørende': ('fjøre',),
'fjøret': ('fjøre',),
'fjørete': ('fjøre',),
'flatbonnede': ('flatbonnet',),
'flatbonnet': ('flatbonnet',),
'flatbonnete': ('flatbonnet',),
'flatbonnetere': ('flatbonnet',),
'flatbonnetest': ('flatbonnet',),
'flatbonneteste': ('flatbonnet',),
'flekkfri': ('flekkfri',),
'flekkfrie': ('flekkfri',),
'flekkfriere': ('flekkfri',),
'flekkfriest': ('flekkfri',),
'flekkfrieste': ('flekkfri',),
'flekkfritt': ('flekkfri',),
'flerfarga': ('flerfarga',),
'flaumherja': ('flaumherja',),
'flaumherjede': ('flaumherjet',),
'flaumherjet': ('flaumherjet',),
'flaumherjete': ('flaumherjet',),
'flaumherjetere': ('flaumherjet',),
'flaumherjetest': ('flaumherjet',),
'flaumherjeteste': ('flaumherjet',),
'folkesky': ('folkesky',),
'folkeskye': ('folkesky',),
'folkeskyere': ('folkesky',),
'folkeskyest': ('folkesky',),
'folkeskyeste': ('folkesky',),
'folketom': ('folketom',),
'folketomme': ('folketom',),
'folketommere': ('folketom',),
'folketommest': ('folketom',),
'folketommeste': ('folketom',),
'folketomt': ('folketom',),
'fordomsfri': ('fordomsfri',),
'fordomsfrie': ('fordomsfri',),
'fordomsfriere': ('fordomsfri',),
'fordomsfriest': ('fordomsfri',),
'fordomsfrieste': ('fordomsfri',),
'fordomsfritt': ('fordomsfri',),
'frafallende': ('frafalle',),
'frafalt': ('frafalle',),
'frafalte': ('frafalle',),
'fraktfri': ('fraktfri',),
'fraktfrie': ('fraktfri',),
'fraktfriere': ('fraktfri',),
'fraktfriest': ('fraktfri',),
'fraktfrieste': ('fraktfri',),
'fraktfritt': ('fraktfri',),
'frambragt': ('frambringe',),
'frambragte': ('frambringe',),
'frambrakt': ('frambringe',),
'frambrakte': ('frambringe',),
'frambringende': ('frambringe',),
'frembragt': ('frembringe',),
'frembragte': ('frembringe',),
'frembrakt': ('frembringe',),
'frembrakte': ('frembringe',),
'frembringende': ('frembringe',),
'frambudt': ('framby',),
'frambudte': ('framby',),
'frambydd': ('framby',),
'frambydde': ('framby',),
'frambyende': ('framby',),
'frembudt': ('fremby',),
'frembudte': ('fremby',),
'frembydd': ('fremby',),
'frembydde': ('fremby',),
'frembyende': ('fremby',),
'framkommen': ('framkomme',),
'framkommende': ('framkomme',),
'framkommet': ('framkomme',),
'framkomne': ('framkomme',),
'fremkommen': ('fremkomme',),
'fremkommende': ('fremkomme',),
'fremkommet': ('fremkomme',),
'fremkomne': ('fremkomme',),
'framtredende': ('framtre',),
'framtrådt': ('framtre',),
'framtrådte': ('framtre',),
'fremtredende': ('fremtre',),
'fremtrådt': ('fremtre',),
'fremtrådte': ('fremtre',),
'framtvingende': ('framtvinge',),
'framtvungen': ('framtvinge',),
'framtvunget': ('framtvinge',),
'framtvungne': ('framtvinge',),
'fremtvingende': ('fremtvinge',),
'fremtvungen': ('fremtvinge',),
'fremtvunget': ('fremtvinge',),
'fremtvungne': ('fremtvinge',),
'frifinnende': ('frifinne',),
'frifunne': ('frifinne',),
'frifunnen': ('frifinne',),
'frifunnet': ('frifinne',),
'frostfri': ('frostfri',),
'frostfrie': ('frostfri',),
'frostfriere': ('frostfri',),
'frostfriest': ('frostfri',),
'frostfrieste': ('frostfri',),
'frostfritt': ('frostfri',),
'gæren': ('gæren',),
'gærent': ('gæren',),
'gærne': ('gæren',),
'gærnere': ('gæren',),
'gærnest': ('gæren',),
'gærneste': ('gæren',),
'gapledd': ('gaple',),
'gapledde': ('gaple',),
'gapleende': ('gaple',),
'generende': ('genere',),
'genert': ('genere',),
'generte': ('genere',),
'genert': ('genert',),
'generte': ('genert',),
'genertere': ('genert',),
'genertest': ('genert',),
'generteste': ('genert',),
'generøs': ('generøs',),
'generøse': ('generøs',),
'generøsere': ('generøs',),
'generøsest': ('generøs',),
'generøseste': ('generøs',),
'generøst': ('generøs',),
'gjendreven': ('gjendrive',),
'gjendrevet': ('gjendrive',),
'gjendrevne': ('gjendrive',),
'gjendrivende': ('gjendrive',),
'gjenfinnende': ('gjenfinne',),
'gjenfunne': ('gjenfinne',),
'gjenfunnen': ('gjenfinne',),
'gjenfunnet': ('gjenfinne',),
'gjenfødd': ('gjenføde',),
'gjenfødde': ('gjenføde',),
'gjenfødende': ('gjenføde',),
'gjenfødt': ('gjenføde',),
'gjenfødte': ('gjenføde',),
'gjenstående': ('gjenstå',),
'gjenstått': ('gjenstå',),
'gjenståtte': ('gjenstå',),
'gjenvinnende': ('gjenvinne',),
'gjenvunne': ('gjenvinne',),
'gjenvunnen': ('gjenvinne',),
'gjenvunnet': ('gjenvinne',),
'gloheit': ('gloheit',),
'gloheite': ('gloheit',),
'gloheitere': ('gloheit',),
'gloheitest': ('gloheit',),
'gloheiteste': ('gloheit',),
'gloheitt': ('gloheit',),
'glohett': ('gloheit',),
'glutenfri': ('glutenfri',),
'glutenfrie': ('glutenfri',),
'glutenfriere': ('glutenfri',),
'glutenfriest': ('glutenfri',),
'glutenfrieste': ('glutenfri',),
'glutenfritt': ('glutenfri',),
'grata': ('grate',),
'gratede': ('grate',),
'gratende': ('grate',),
'gratet': ('grate',),
'gratete': ('grate',),
'grunda': ('grunde',),
'grundede': ('grunde',),
'grundende': ('grunde',),
'grundet': ('grunde',),
'grundete': ('grunde',),
'gumla': ('gumle',),
'gumlede': ('gumle',),
'gumlende': ('gumle',),
'gumlet': ('gumle',),
'gumlete': ('gumle',),
'halvfeit': ('halvfeit',),
'halvfeite': ('halvfeit',),
'halvfeitere': ('halvfeit',),
'halvfeitest': ('halvfeit',),
'halvfeiteste': ('halvfeit',),
'halvfeitt': ('halvfeit',),
'halvfett': ('halvfeit',),
'halveldre': ('halvgammal',),
'halveldst': ('halvgammal',),
'halveldste': ('halvgammal',),
'halvgamle': ('halvgammal',),
'halvgammal': ('halvgammal',),
'halvgammalt': ('halvgammal',),
'hardbarka': ('hardbarka',),
'horva': ('horve',),
'horvede': ('horve',),
'horvende': ('horve',),
'horvet': ('horve',),
'horvete': ('horve',),
'heimkommen': ('heimkomme',),
'heimkommende': ('heimkomme',),
'heimkommet': ('heimkomme',),
'heimkomne': ('heimkomme',),
'hjemkommen': ('hjemkomme',),
'hjemkommende': ('hjemkomme',),
'hjemkommet': ('hjemkomme',),
'hjemkomne': ('hjemkomme',),
'helfeit': ('helfeit',),
'helfeite': ('helfeit',),
'helfeitere': ('helfeit',),
'helfeitest': ('helfeit',),
'helfeiteste': ('helfeit',),
'helfeitt': ('helfeit',),
'helfett': ('helfeit',),
'heilfeit': ('heilfeit',),
'heilfeite': ('heilfeit',),
'heilfeitere': ('heilfeit',),
'heilfeitest': ('heilfeit',),
'heilfeiteste': ('heilfeit',),
'heilfeitt': ('heilfeit',),
'heilfett': ('heilfeit',),
'henfallende': ('henfalle',),
'henfalt': ('henfalle',),
'henfalte': ('henfalle',),
'henreven': ('henrive',),
'henrevet': ('henrive',),
'henrevne': ('henrive',),
'henrivende': ('henrive',),
'henstående': ('henstå',),
'henstått': ('henstå',),
'henståtte': ('henstå',),
'herpeserende': ('herpesere',),
'herpesert': ('herpesere',),
'herpeserte': ('herpesere',),
'horva': ('horve',),
'horvede': ('horve',),
'horvende': ('horve',),
'horvet': ('horve',),
'horvete': ('horve',),
'handhelsende': ('handhelse',),
'handhelst': ('handhelse',),
'handhelste': ('handhelse',),
'imøtekommen': ('imøtekomme',),
'imøtekommende': ('imøtekomme',),
'imøtekommet': ('imøtekomme',),
'imøtekomne': ('imøtekomme',),
'inkompetent': ('inkompetent',),
'inkompetente': ('inkompetent',),
'inkompetentere': ('inkompetent',),
'inkompetentest': ('inkompetent',),
'inkompetenteste': ('inkompetent',),
'inkongruent': ('inkongruent',),
'inkongruente': ('inkongruent',),
'inkongruentere': ('inkongruent',),
'inkongruentest': ('inkongruent',),
'inkongruenteste': ('inkongruent',),
'inkonsekvent': ('inkonsekvent',),
'inkonsekvente': ('inkonsekvent',),
'inkonsekventere': ('inkonsekvent',),
'inkonsekventest': ('inkonsekvent',),
'inkonsekventeste': ('inkonsekvent',),
'innestående': ('innestå',),
'innestått': ('innestå',),
'inneståtte': ('innestå',),
'innrøkt': ('innrøkt',),
'innrøkte': ('innrøkt',),
'innrøktere': ('innrøkt',),
'innrøktest': ('innrøkt',),
'innrøkteste': ('innrøkt',),
'innstemna': ('innstemne',),
'innstemnede': ('innstemne',),
'innstemnende': ('innstemne',),
'innstemnet': ('innstemne',),
'innstemnete': ('innstemne',),
'innstemnt': ('innstemne',),
'innstemnte': ('innstemne',),
'innstemna': ('innstemne',),
'innstemnede': ('innstemne',),
'innstemnende': ('innstemne',),
'innstemnet': ('innstemne',),
'innstemnete': ('innstemne',),
'innstemnt': ('innstemne',),
'innstemnte': ('innstemne',),
'insolvent': ('insolvent',),
'insolvente': ('insolvent',),
'insolventere': ('insolvent',),
'insolventest': ('insolvent',),
'insolventeste': ('insolvent',),
'intolerant': ('intolerant',),
'intolerante': ('intolerant',),
'intolerantere': ('intolerant',),
'intolerantest': ('intolerant',),
'intoleranteste': ('intolerant',),
'irrelevant': ('irrelevant',),
'irrelevante': ('irrelevant',),
'irrelevantere': ('irrelevant',),
'irrelevantest': ('irrelevant',),
'irrelevanteste': ('irrelevant',),
'isfri': ('isfri',),
'isfrie': ('isfri',),
'isfriere': ('isfri',),
'isfriest': ('isfri',),
'isfrieste': ('isfri',),
'isfritt': ('isfri',),
'jevneldre': ('jevngammal',),
'jevneldst': ('jevngammal',),
'jevneldste': ('jevngammal',),
'jevngamle': ('jevngammal',),
'jevngammal': ('jevngammal',),
'jevngammalt': ('jevngammal',),
'jameldre': ('jamgammal',),
'jameldst': ('jamgammal',),
'jameldste': ('jamgammal',),
'jamgamle': ('jamgammal',),
'jamgammal': ('jamgammal',),
'jamgammalt': ('jamgammal',),
'jurisprudens': ('jurisprudens',),
'karakterfri': ('karakterfri',),
'karakterfrie': ('karakterfri',),
'karakterfriere': ('karakterfri',),
'karakterfriest': ('karakterfri',),
'karakterfrieste': ('karakterfri',),
'karakterfritt': ('karakterfri',),
'kjøpslående': ('kjøpslå',),
'kjøpslått': ('kjøpslå',),
'kjøpslåtte': ('kjøpslå',),
'knirkefri': ('knirkefri',),
'knirkefrie': ('knirkefri',),
'knirkefriere': ('knirkefri',),
'knirkefriest': ('knirkefri',),
'knirkefrieste': ('knirkefri',),
'knirkefritt': ('knirkefri',),
'kokeekte': ('kokeekte',),
'kokekte': ('kokekte',),
'kopparbrun': ('kopparbrun',),
'kopparbrune': ('kopparbrun',),
'kopparbrunere': ('kopparbrun',),
'kopparbrunest': ('kopparbrun',),
'kopparbruneste': ('kopparbrun',),
'kopparbrunt': ('kopparbrun',),
'krympefri': ('krympefri',),
'krympefrie': ('krympefri',),
'krympefriere': ('krympefri',),
'krympefriest': ('krympefri',),
'krympefrieste': ('krympefri',),
'krympefritt': ('krympefri',),
'kurla': ('kurle',),
'kurlede': ('kurle',),
'kurlende': ('kurle',),
'kurlet': ('kurle',),
'kurlete': ('kurle',),
'lågtlønna': ('lågtlønna',),
'lågtlønnede': ('lågtlønnet',),
'lågtlønnet': ('lågtlønnet',),
'lågtlønnete': ('lågtlønnet',),
'lågtlønnetere': ('lågtlønnet',),
'lågtlønnetest': ('lågtlønnet',),
'lågtlønneteste': ('lågtlønnet',),
'lågtlønt': ('lågtlønt',),
'lågtlønte': ('lågtlønt',),
'lågtløntere': ('lågtlønt',),
'lågtløntest': ('lågtlønt',),
'lågtlønteste': ('lågtlønt',),
'løsreven': ('løsrive',),
'løsrevet': ('løsrive',),
'løsrevne': ('løsrive',),
'løsrivende': ('løsrive',),
'lausreven': ('lausrive',),
'lausrevet': ('lausrive',),
'lausrevne': ('lausrive',),
'lausrivende': ('lausrive',),
'leken': ('leken',),
'lekent': ('leken',),
'lekne': ('leken',),
'leknere': ('leken',),
'leknest': ('leken',),
'lekneste': ('leken',),
'leiken': ('leiken',),
'leikent': ('leiken',),
'leikne': ('leiken',),
'leiknere': ('leiken',),
'leiknest': ('leiken',),
'leikneste': ('leiken',),
'lippeblomstra': ('lippeblomstra',),
'lepeblomstra': ('lepeblomstra',),
'lippeblomsta': ('lippeblomsta',),
'lippeblomstret': ('lippeblomstret',),
'lippeblomstrete': ('lippeblomstret',),
'lippeblomstretere': ('lippeblomstret',),
'lippeblomstretest': ('lippeblomstret',),
'lippeblomstreteste': ('lippeblomstret',),
'lettrøkt': ('lettrøkt',),
'lettrøkte': ('lettrøkt',),
'lettrøktere': ('lettrøkt',),
'lettrøktest': ('lettrøkt',),
'lettrøkteste': ('lettrøkt',),
'levna': ('levne',),
'levnede': ('levne',),
'levnende': ('levne',),
'levnet': ('levne',),
'levnete': ('levne',),
'likesinna': ('likesinna',),
'lyssky': ('lyssky',),
'lysskye': ('lyssky',),
'lysskyere': ('lyssky',),
'lysskyest': ('lyssky',),
'lysskyeste': ('lyssky',),
'lytefri': ('lytefri',),
'lytefrie': ('lytefri',),
'lytefriere': ('lytefri',),
'lytefriest': ('lytefri',),
'lytefrieste': ('lytefri',),
'lytefritt': ('lytefri',),
'maktstelende': ('maktstele',),
'maktstålen': ('maktstele',),
'maktstålet': ('maktstele',),
'maktstålne': ('maktstele',),
'medtatt': ('medtatt',),
'medtatte': ('medtatt',),
'medtattere': ('medtatt',),
'medtattest': ('medtatt',),
'medtatteste': ('medtatt',),
'medels': ('medels',),
'motsagt': ('motsi',),
'motsagte': ('motsi',),
'motsiende': ('motsi',),
'motstående': ('motstå',),
'motstått': ('motstå',),
'motståtte': ('motstå',),
'nagelfast': ('nagelfast',),
'nagelfaste': ('nagelfast',),
'nagelfastere': ('nagelfast',),
'nagelfastest': ('nagelfast',),
'nagelfasteste': ('nagelfast',),
'naturtro': ('naturtro',),
'naturtru': ('naturtru',),
'naturtrue': ('naturtru',),
'naturtruere': ('naturtru',),
'naturtruest': ('naturtru',),
'naturtrueste': ('naturtru',),
'nasevis': ('nasevis',),
'nasevise': ('nasevis',),
'nasevisere': ('nasevis',),
'nasevisest': ('nasevis',),
'naseviseste': ('nasevis',),
'nasevist': ('nasevis',),
'oppbudt': ('oppby',),
'oppbudte': ('oppby',),
'oppbydd': ('oppby',),
'oppbydde': ('oppby',),
'oppbyende': ('oppby',),
'oppdreven': ('oppdrive',),
'oppdrevet': ('oppdrive',),
'oppdrevne': ('oppdrive',),
'oppdrivende': ('oppdrive',),
'overbudt': ('overby',),
'overbudte': ('overby',),
'overbydd': ('overby',),
'overbydde': ('overby',),
'overbyende': ('overby',),
'overdreven': ('overdrive',),
'overdrevet': ('overdrive',),
'overdrevne': ('overdrive',),
'overdrivende': ('overdrive',),
'overfallende': ('overfalle',),
'overfalt': ('overfalle',),
'overfalte': ('overfalle',),
'planfri': ('planfri',),
'planfrie': ('planfri',),
'planfriere': ('planfri',),
'planfriest': ('planfri',),
'planfrieste': ('planfri',),
'planfritt': ('planfri',),
'planka': ('planke',),
'plankede': ('planke',),
'plankende': ('planke',),
'planket': ('planke',),
'plankete': ('planke',),
'pocherende': ('pochere',),
'pochert': ('pochere',),
'pocherte': ('pochere',),
'prikkfri': ('prikkfri',),
'prikkfrie': ('prikkfri',),
'prikkfriere': ('prikkfri',),
'prikkfriest': ('prikkfri',),
'prikkfrieste': ('prikkfri',),
'prikkfritt': ('prikkfri',),
'problemfri': ('problemfri',),
'problemfrie': ('problemfri',),
'problemfriere': ('problemfri',),
'problemfriest': ('problemfri',),
'problemfrieste': ('problemfri',),
'problemfritt': ('problemfri',),
'protegérende': ('protegére',),
'protegért': ('protegére',),
'protegérte': ('protegére',),
'raida': ('raide',),
'raidede': ('raide',),
'raidende': ('raide',),
'raidet': ('raide',),
'raidete': ('raide',),
'ravnsvart': ('ravnsvart',),
'ravnsvarte': ('ravnsvart',),
'ravnsvartere': ('ravnsvart',),
'ravnsvartest': ('ravnsvart',),
'ravnsvarteste': ('ravnsvart',),
'ramnsvart': ('ramnsvart',),
'ramnsvarte': ('ramnsvart',),
'ramnsvartere': ('ramnsvart',),
'ramnsvartest': ('ramnsvart',),
'ramnsvarteste': ('ramnsvart',),
'rustfri': ('rustfri',),
'rustfrie': ('rustfri',),
'rustfriere': ('rustfri',),
'rustfriest': ('rustfri',),
'rustfrieste': ('rustfri',),
'rustfritt': ('rustfri',),
'raudglødende': ('raudglødende',),
'raudmussede': ('raudmusset',),
'raudmusset': ('raudmusset',),
'raudmussete': ('raudmusset',),
'raudmussetere': ('raudmusset',),
'raudmussetest': ('raudmusset',),
'raudmusseteste': ('raudmusset',),
'raudøyd': ('raudøyd',),
'raudøyde': ('raudøyd',),
'raudøydere': ('raudøyd',),
'raudøydest': ('raudøyd',),
'raudøydeste': ('raudøyd',),
'røsta': ('røste',),
'røstede': ('røste',),
'røstende': ('røste',),
'røstet': ('røste',),
'røstete': ('røste',),
'rådslående': ('rådslå',),
'rådslått': ('rådslå',),
'rådslåtte': ('rådslå',),
'samsvara': ('samsvare',),
'samsvarende': ('samsvare',),
'samsvart': ('samsvare',),
'samsvarte': ('samsvare',),
'scanna': ('scanne',),
'scannede': ('scanne',),
'scannende': ('scanne',),
'scannet': ('scanne',),
'scannete': ('scanne',),
'sentenkt': ('sentenkt',),
'sentenkte': ('sentenkt',),
'sentenktere': ('sentenkt',),
'sentenktest': ('sentenkt',),
'sentenkteste': ('sentenkt',),
'seintenkt': ('seintenkt',),
'seintenkte': ('seintenkt',),
'seintenktere': ('seintenkt',),
'seintenktest': ('seintenkt',),
'seintenkteste': ('seintenkt',),
'sætra': ('sætre',),
'sætrede': ('sætre',),
'sætrende': ('sætre',),
'sætret': ('sætre',),
'sætrete': ('sætre',),
'sjokkrosa': ('sjokkrosa',),
'skadefri': ('skadefri',),
'skadefrie': ('skadefri',),
'skadefriere': ('skadefri',),
'skadefriest': ('skadefri',),
'skadefrieste': ('skadefri',),
'skadefritt': ('skadefri',),
'skambitende': ('skambite',),
'skambitt': ('skambite',),
'skambitte': ('skambite',),
'skamslående': ('skamslå',),
'skamslått': ('skamslå',),
'skamslåtte': ('skamslå',),
'skattefri': ('skattefri',),
'skattefrie': ('skattefri',),
'skattefriere': ('skattefri',),
'skattefriest': ('skattefri',),
'skattefrieste': ('skattefri',),
'skattefritt': ('skattefri',),
'skattfri': ('skattfri',),
'skattfrie': ('skattfri',),
'skattfriere': ('skattfri',),
'skattfriest': ('skattfri',),
'skattfrieste': ('skattfri',),
'skattfritt': ('skattfri',),
'skinn- og benfri': ('skinn- og benfri',),
'skinn- og benfrie': ('skinn- og benfri',),
'skinn- og benfriere': ('skinn- og benfri',),
'skinn- og benfriest': ('skinn- og benfri',),
'skinn- og benfrieste': ('skinn- og benfri',),
'skinn- og benfritt': ('skinn- og benfri',),
'skoggerledd': ('skoggerle',),
'skoggerledde': ('skoggerle',),
'skoggerleende': ('skoggerle',),
'skaukledd': ('skaukledd',),
'skaukledde': ('skaukledd',),
'skaukleddere': ('skaukledd',),
'skaukleddest': ('skaukledd',),
'skaukleddeste': ('skaukledd',),
'skauredd': ('skauredd',),
'skauredde': ('skauredd',),
'skaureddere': ('skauredd',),
'skaureddest': ('skauredd',),
'skaureddeste': ('skauredd',),
'skridd': ('skri',),
'skridde': ('skri',),
'skriende': ('skri',),
'skuddfri': ('skuddfri',),
'skuddfrie': ('skuddfri',),
'skuddfriere': ('skuddfri',),
'skuddfriest': ('skuddfri',),
'skuddfrieste': ('skuddfri',),
'skuddfritt': ('skuddfri',),
'skottfri': ('skottfri',),
'skottfrie': ('skottfri',),
'skottfriere': ('skottfri',),
'skottfriest': ('skottfri',),
'skottfrieste': ('skottfri',),
'skottfritt': ('skottfri',),
'skyfri': ('skyfri',),
'skyfrie': ('skyfri',),
'skyfriere': ('skyfri',),
'skyfriest': ('skyfri',),
'skyfrieste': ('skyfri',),
'skyfritt': ('skyfri',),
'skyldfri': ('skyldfri',),
'skyldfrie': ('skyldfri',),
'skyldfriere': ('skyldfri',),
'skyldfriest': ('skyldfri',),
'skyldfrieste': ('skyldfri',),
'skyldfritt': ('skyldfri',),
'skåldhet': ('skåldhet',),
'skåldhete': ('skåldhet',),
'skåldhetere': ('skåldhet',),
'skåldhetest': ('skåldhet',),
'skåldheteste': ('skåldhet',),
'skåldhett': ('skåldhet',),
'sløkka': ('sløkke',),
'sløkkede': ('sløkke',),
'sløkkende': ('sløkke',),
'sløkket': ('sløkke',),
'sløkkete': ('sløkke',),
'sløkt': ('sløkke',),
'sløkte': ('sløkke',),
'sludda': ('sludde',),
'sluddede': ('sludde',),
'sluddende': ('sludde',),
'sluddet': ('sludde',),
'sluddete': ('sludde',),
'smertefri': ('smertefri',),
'smertefrie': ('smertefri',),
'smertefriere': ('smertefri',),
'smertefriest': ('smertefri',),
'smertefrieste': ('smertefri',),
'smertefritt': ('smertefri',),
'smørefri': ('smørefri',),
'smørefrie': ('smørefri',),
'smørefriere': ('smørefri',),
'smørefriest': ('smørefri',),
'smørefrieste': ('smørefri',),
'smørefritt': ('smørefri',),
'småforlovede': ('småforlovet',),
'småforlovet': ('småforlovet',),
'småforlovete': ('småforlovet',),
'småforlovetere': ('småforlovet',),
'småforlovetest': ('småforlovet',),
'småforloveteste': ('småforlovet',),
'stekende': ('stekende',),
'steikende': ('steikende',),
'stjelende': ('stjele',),
'stjålen': ('stjele',),
'stjålet': ('stjele',),
'stjålne': ('stjele',),
'sukkerfri': ('sukkerfri',),
'sukkerfrie': ('sukkerfri',),
'sukkerfriere': ('sukkerfri',),
'sukkerfriest': ('sukkerfri',),
'sukkerfrieste': ('sukkerfri',),
'sukkerfritt': ('sukkerfri',),
'syttiende': ('syttiende',),
'syvende': ('syvende',),
'sønderreven': ('sønderrive',),
'sønderrevet': ('sønderrive',),
'sønderrevne': ('sønderrive',),
'sønderrivende': ('sønderrive',),
'søraustlig': ('søraustlig',),
'søraustlige': ('søraustlig',),
'søraustligere': ('søraustlig',),
'søraustligst': ('søraustlig',),
'søraustligste': ('søraustlig',),
'sætende': ('sæte',),
'sætt': ('sæte',),
'sætte': ('sæte',),
'tilbudt': ('tilby',),
'tilbudte': ('tilby',),
'tilbydd': ('tilby',),
'tilbydde': ('tilby',),
'tilbyende': ('tilby',),
'tilsvara': ('tilsvare',),
'tilsvarende': ('tilsvare',),
'tilsvart': ('tilsvare',),
'tilsvarte': ('tilsvare',),
'tiltrudd': ('tiltru',),
'tiltrudde': ('tiltru',),
'tiltruende': ('tiltru',),
'tjørebredd': ('tjørebre',),
'tjørebredde': ('tjørebre',),
'tjørebreende': ('tjørebre',),
'tollfri': ('tollfri',),
'tollfrie': ('tollfri',),
'tollfriere': ('tollfri',),
'tollfriest': ('tollfri',),
'tollfrieste': ('tollfri',),
'tollfritt': ('tollfri',),
'toucherende': ('touchere',),
'touchert': ('touchere',),
'toucherte': ('touchere',),
'trancherende': ('tranchere',),
'tranchert': ('tranchere',),
'trancherte': ('tranchere',),
'tredevte': ('tredevte',),
'tvunne': ('tvunnen',),
'tvunnen': ('tvunnen',),
'tvunnere': ('tvunnen',),
'tvunnest': ('tvunnen',),
'tvunneste': ('tvunnen',),
'tvunnet': ('tvunnen',),
'tvunne': ('tvunnet',),
'tvunnere': ('tvunnet',),
'tvunnest': ('tvunnet',),
'tvunneste': ('tvunnet',),
'tvunnet': ('tvunnet',),
'tyvende': ('tyvende',),
'uimottakelig': ('uimottakelig',),
'uimottakelige': ('uimottakelig',),
'uimottakeligere': ('uimottakelig',),
'uimottakeligst': ('uimottakelig',),
'uimottakeligste': ('uimottakelig',),
'underslående': ('underslå',),
'underslått': ('underslå',),
'underslåtte': ('underslå',),
'unnsleppende': ('unnsleppe',),
'unnslupne': ('unnsleppe',),
'unnsluppen': ('unnsleppe',),
'unnsluppet': ('unnsleppe',),
'unntagelseslaus': ('unntagelseslaus',),
'unntagelseslause': ('unntagelseslaus',),
'unntagelseslausere': ('unntagelseslaus',),
'unntagelseslausest': ('unntagelseslaus',),
'unntagelseslauseste': ('unntagelseslaus',),
'unntagelseslaust': ('unntagelseslaus',),
'unntagelsesløs': ('unntagelsesløs',),
'unntagelsesløse': ('unntagelsesløs',),
'unntagelsesløsere': ('unntagelsesløs',),
'unntagelsesløsest': ('unntagelsesløs',),
'unntagelsesløseste': ('unntagelsesløs',),
'unntagelsesløst': ('unntagelsesløs',),
'ureinskede': ('ureinsket',),
'ureinsket': ('ureinsket',),
'ureinskete': ('ureinsket',),
'ureinsketere': ('ureinsket',),
'ureinsketest': ('ureinsket',),
'ureinsketeste': ('ureinsket',),
'ureinskede': ('ureinsket',),
'ureinsket': ('ureinsket',),
'ureinskete': ('ureinsket',),
'ureinsketere': ('ureinsket',),
'ureinsketest': ('ureinsket',),
'ureinsketeste': ('ureinsket',),
'ureldre': ('urgammal',),
'ureldst': ('urgammal',),
'ureldste': ('urgammal',),
'urgamle': ('urgammal',),
'urgammal': ('urgammal',),
'urgammalt': ('urgammal',),
'urøkt': ('urøkt',),
'urøkte': ('urøkt',),
'urøktere': ('urøkt',),
'urøktest': ('urøkt',),
'urøkteste': ('urøkt',),
'uskaplig': ('uskaplig',),
'uskaplige': ('uskaplig',),
'uskapligere': ('uskaplig',),
'uskapligst': ('uskaplig',),
'uskapligste': ('uskaplig',),
'utbredd': ('utbre',),
'utbredde': ('utbre',),
'utbredt': ('utbre',),
'utbredte': ('utbre',),
'utbreende': ('utbre',),
'utsløkt': ('utsløkt',),
'utsløkte': ('utsløkt',),
'utsløktere': ('utsløkt',),
'utsløktest': ('utsløkt',),
'utsløkteste': ('utsløkt',),
'utvunne': ('utvunnen',),
'utvunnen': ('utvunnen',),
'utvunnere': ('utvunnen',),
'utvunnest': ('utvunnen',),
'utvunneste': ('utvunnen',),
'utvunnet': ('utvunnen',),
'utvunne': ('utvunnet',),
'utvunnere': ('utvunnet',),
'utvunnest': ('utvunnet',),
'utvunneste': ('utvunnet',),
'utvunnet': ('utvunnet',),
'valgfri': ('valgfri',),
'valgfrie': ('valgfri',),
'valgfriere': ('valgfri',),
'valgfriest': ('valgfri',),
'valgfrieste': ('valgfri',),
'valgfritt': ('valgfri',),
'vannfri': ('vannfri',),
'vannfrie': ('vannfri',),
'vannfriere': ('vannfri',),
'vannfriest': ('vannfri',),
'vannfrieste': ('vannfri',),
'vannfritt': ('vannfri',),
'vassfri': ('vassfri',),
'vassfrie': ('vassfri',),
'vassfriere': ('vassfri',),
'vassfriest': ('vassfri',),
'vassfrieste': ('vassfri',),
'vassfritt': ('vassfri',),
'vantruende': ('vantruende',),
'vaskeekte': ('vaskeekte',),
'vaskekte': ('vaskekte',),
'veikna': ('veikne',),
'veiknede': ('veikne',),
'veiknende': ('veikne',),
'veiknet': ('veikne',),
'veiknete': ('veikne',),
'vekna': ('vekne',),
'veknede': ('vekne',),
'veknende': ('vekne',),
'veknet': ('vekne',),
'veknete': ('vekne',),
'vibrasjonsfri': ('vibrasjonsfri',),
'vibrasjonsfrie': ('vibrasjonsfri',),
'vibrasjonsfriere': ('vibrasjonsfri',),
'vibrasjonsfriest': ('vibrasjonsfri',),
'vibrasjonsfrieste': ('vibrasjonsfri',),
'vibrasjonsfritt': ('vibrasjonsfri',),
'vindstille': ('vindstille',),
'virkelighetstro': ('virkelighetstro',),
'virkelighetstru': ('virkelighetstru',),
'virkelighetstrue': ('virkelighetstru',),
'virkelighetstruere': ('virkelighetstru',),
'virkelighetstruest': ('virkelighetstru',),
'virkelighetstrueste': ('virkelighetstru',),
'vonlaus': ('vonlaus',),
'vonlause': ('vonlaus',),
'vonlausere': ('vonlaus',),
'vonlausest': ('vonlaus',),
'vonlauseste': ('vonlaus',),
'vonlaust': ('vonlaus',),
'z-tvunne': ('z-tvunnen',),
'z-tvunnen': ('z-tvunnen',),
'z-tvunnere': ('z-tvunnen',),
'z-tvunnest': ('z-tvunnen',),
'z-tvunneste': ('z-tvunnen',),
'z-tvunnet': ('z-tvunnen',),
'z-tvunne': ('z-tvunnet',),
'z-tvunnere': ('z-tvunnet',),
'z-tvunnest': ('z-tvunnet',),
'z-tvunneste': ('z-tvunnet',),
'z-tvunnet': ('z-tvunnet',),
'adskillig': ('adskillig',),
'adskillige': ('adskillig',),
'adskilligere': ('adskillig',),
'adskilligst': ('adskillig',),
'adskilligste': ('adskillig',),
'adspredd': ('adsprede',),
'adspredde': ('adsprede',),
'adspredende': ('adsprede',),
'adspredt': ('adsprede',),
'adspredte': ('adsprede',),
'adspredd': ('adspre',),
'adspredde': ('adspre',),
'adspredt': ('adspre',),
'adspredte': ('adspre',),
'adspreende': ('adspre',),
'antagelig': ('antagelig',),
'antagelige': ('antagelig',),
'antageligere': ('antagelig',),
'antageligst': ('antagelig',),
'antageligste': ('antagelig',),
'antikonsepsjonell': ('antikonsepsjonell',),
'antikonsepsjonelle': ('antikonsepsjonell',),
'antikonsepsjonellere': ('antikonsepsjonell',),
'antikonsepsjonellest': ('antikonsepsjonell',),
'antikonsepsjonelleste': ('antikonsepsjonell',),
'antikonsepsjonelt': ('antikonsepsjonell',),
'berr': ('berr',),
'berre': ('berr',),
'berrere': ('berr',),
'berrest': ('berr',),
'berreste': ('berr',),
'bert': ('berr',),
'berrarma': ('berrarma',),
'berrbeint': ('berrbeint',),
'berrbeinte': ('berrbeint',),
'berrbeintere': ('berrbeint',),
'berrbeintest': ('berrbeint',),
'berrbeinteste': ('berrbeint',),
'berrføtt': ('berrføtt',),
'berrføtte': ('berrføtt',),
'berrføttere': ('berrføtt',),
'berrføttest': ('berrføtt',),
'berrføtteste': ('berrføtt',),
'berr': ('berr',),
'berre': ('berr',),
'berrere': ('berr',),
'berrest': ('berr',),
'berreste': ('berr',),
'bert': ('berr',),
'berrbeint': ('berrbeint',),
'berrbeinte': ('berrbeint',),
'berrbeintere': ('berrbeint',),
'berrbeintest': ('berrbeint',),
'berrbeinteste': ('berrbeint',),
'berrføtt': ('berrføtt',),
'berrføtte': ('berrføtt',),
'berrføttere': ('berrføtt',),
'berrføttest': ('berrføtt',),
'berrføtteste': ('berrføtt',),
'bleknebba': ('bleknebba',),
'blodraud': ('blodraud',),
'blodraude': ('blodraud',),
'blodraudere': ('blodraud',),
'blodraudest': ('blodraud',),
'blodraudeste': ('blodraud',),
'blodraudt': ('blodraud',),
'brannraud': ('brannraud',),
'brannraude': ('brannraud',),
'brannraudere': ('brannraud',),
'brannraudest': ('brannraud',),
'brannraudeste': ('brannraud',),
'brannraudt': ('brannraud',),
'brennraud': ('brennraud',),
'brennraude': ('brennraud',),
'brennraudere': ('brennraud',),
'brennraudest': ('brennraud',),
'brennraudeste': ('brennraud',),
'brennraudt': ('brennraud',),
'bunnfrysende': ('bunnfryse',),
'bunnfryst': ('bunnfryse',),
'bunnfryste': ('bunnfryse',),
'botnfrysende': ('botnfryse',),
'botnfryst': ('botnfryse',),
'botnfryste': ('botnfryse',),
'burgunderraud': ('burgunderraud',),
'burgunderraude': ('burgunderraud',),
'burgunderraudere': ('burgunderraud',),
'burgunderraudest': ('burgunderraud',),
'burgunderraudeste': ('burgunderraud',),
'burgunderraudt': ('burgunderraud',),
'castillansk': ('castillansk',),
'castillanske': ('castillansk',),
'castillanskere': ('castillansk',),
'castillanskest': ('castillansk',),
'castillanskeste': ('castillansk',),
'catalonsk': ('catalonsk',),
'catalonske': ('catalonsk',),
'catalonskere': ('catalonsk',),
'catalonskest': ('catalonsk',),
'catalonskeste': ('catalonsk',),
'charismatisk': ('charismatisk',),
'charismatiske': ('charismatisk',),
'charismatiskere': ('charismatisk',),
'charismatiskest': ('charismatisk',),
'charismatiskeste': ('charismatisk',),
'charmant': ('charmant',),
'charmante': ('charmant',),
'charmantere': ('charmant',),
'charmantest': ('charmant',),
'charmanteste': ('charmant',),
'cracka': ('cracke',),
'crackede': ('cracke',),
'crackende': ('cracke',),
'cracket': ('cracke',),
'crackete': ('cracke',),
'dauv': ('dauv',),
'dauve': ('dauv',),
'dauvere': ('dauv',),
'dauvest': ('dauv',),
'dauveste': ('dauv',),
'dauvt': ('dauv',),
'dobbeltbonna': ('dobbeltbonna',),
'dypraud': ('dypraud',),
'dypraude': ('dypraud',),
'dypraudere': ('dypraud',),
'dypraudest': ('dypraud',),
'dypraudeste': ('dypraud',),
'dypraudt': ('dypraud',),
'djupraud': ('djupraud',),
'djupraude': ('djupraud',),
'djupraudere': ('djupraud',),
'djupraudest': ('djupraud',),
'djupraudeste': ('djupraud',),
'djupraudt': ('djupraud',),
'dauv': ('dauv',),
'dauve': ('dauv',),
'dauvere': ('dauv',),
'dauvest': ('dauv',),
'dauveste': ('dauv',),
'dauvt': ('dauv',),
'dauvfødd': ('dauvfødd',),
'dauvfødde': ('dauvfødd',),
'dauvføddere': ('dauvfødd',),
'dauvføddest': ('dauvfødd',),
'dauvføddeste': ('dauvfødd',),
'dauvfødt': ('dauvfødt',),
'dauvfødte': ('dauvfødt',),
'dauvfødtere': ('dauvfødt',),
'dauvfødtest': ('dauvfødt',),
'dauvfødteste': ('dauvfødt',),
'dauvhørt': ('dauvhørt',),
'dauvhørte': ('dauvhørt',),
'dauvhørtere': ('dauvhørt',),
'dauvhørtest': ('dauvhørt',),
'dauvhørteste': ('dauvhørt',),
'eksa': ('ekse',),
'eksede': ('ekse',),
'eksende': ('ekse',),
'ekset': ('ekse',),
'eksete': ('ekse',),
'eldraud': ('eldraud',),
'eldraude': ('eldraud',),
'eldraudere': ('eldraud',),
'eldraudest': ('eldraud',),
'eldraudeste': ('eldraud',),
'eldraudt': ('eldraud',),
'ildraud': ('ildraud',),
'ildraude': ('ildraud',),
'ildraudere': ('ildraud',),
'ildraudest': ('ildraud',),
'ildraudeste': ('ildraud',),
'ildraudt': ('ildraud',),
'eldraud': ('eldraud',),
'eldraude': ('eldraud',),
'eldraudere': ('eldraud',),
'eldraudest': ('eldraud',),
'eldraudeste': ('eldraud',),
'eldraudt': ('eldraud',),
'ildraud': ('ildraud',),
'ildraude': ('ildraud',),
'ildraudere': ('ildraud',),
'ildraudest': ('ildraud',),
'ildraudeste': ('ildraud',),
'ildraudt': ('ildraud',),
'finregna': ('finregne',),
'finregnede': ('finregne',),
'finregnende': ('finregne',),
'finregnet': ('finregne',),
'finregnete': ('finregne',),
'finrekna': ('finrekne',),
'finreknede': ('finrekne',),
'finreknende': ('finrekne',),
'finreknet': ('finrekne',),
'finreknete': ('finrekne',),
'flatbonna': ('flatbonna',),
'forutsagt': ('forutsi',),
'forutsagte': ('forutsi',),
'forutsiende': ('forutsi',),
'gjenlydd': ('gjenlyde',),
'gjenlydde': ('gjenlyde',),
'gjenlydende': ('gjenlyde',),
'gjenlydt': ('gjenlyde',),
'gjenlydte': ('gjenlyde',),
'gjenoppstående': ('gjenoppstå',),
'gjenoppstått': ('gjenoppstå',),
'gjenoppståtte': ('gjenoppstå',),
'gloraud': ('gloraud',),
'gloraude': ('gloraud',),
'gloraudere': ('gloraud',),
'gloraudest': ('gloraud',),
'gloraudeste': ('gloraud',),
'gloraudt': ('gloraud',),
'gloraud': ('gloraud',),
'gloraude': ('gloraud',),
'gloraudere': ('gloraud',),
'gloraudest': ('gloraud',),
'gloraudeste': ('gloraud',),
'gloraudt': ('gloraud',),
'halshogd': ('halshogge',),
'halshogde': ('halshogge',),
'halshoggede': ('halshogge',),
'halshoggende': ('halshogge',),
'halshogget': ('halshogge',),
'halshoggete': ('halshogge',),
'halshugd': ('halshugge',),
'halshugde': ('halshugge',),
'halshugga': ('halshugge',),
'halshuggede': ('halshugge',),
'halshuggende': ('halshugge',),
'halshugget': ('halshugge',),
'halshuggete': ('halshugge',),
'hika': ('hike',),
'hikede': ('hike',),
'hikende': ('hike',),
'hiket': ('hike',),
'hikete': ('hike',),
'hika': ('hike',),
'hikede': ('hike',),
'hikende': ('hike',),
'hiket': ('hike',),
'hikete': ('hike',),
'hika': ('hike',),
'hikede': ('hike',),
'hikende': ('hike',),
'hiket': ('hike',),
'hikete': ('hike',),
'hua': ('hue',),
'huede': ('hue',),
'huende': ('hue',),
'huet': ('hue',),
'huete': ('hue',),
'ildraud': ('ildraud',),
'ildraude': ('ildraud',),
'ildraudere': ('ildraud',),
'ildraudest': ('ildraud',),
'ildraudeste': ('ildraud',),
'ildraudt': ('ildraud',),
'eldraud': ('eldraud',),
'eldraude': ('eldraud',),
'eldraudere': ('eldraud',),
'eldraudest': ('eldraud',),
'eldraudeste': ('eldraud',),
'eldraudt': ('eldraud',),
'illraud': ('illraud',),
'illraude': ('illraud',),
'illraudere': ('illraud',),
'illraudest': ('illraud',),
'illraudeste': ('illraud',),
'illraudt': ('illraud',),
'infraraud': ('infraraud',),
'infraraude': ('infraraud',),
'infraraudere': ('infraraud',),
'infraraudest': ('infraraud',),
'infraraudeste': ('infraraud',),
'infraraudt': ('infraraud',),
'innhugd': ('innhugd',),
'innhugde': ('innhugd',),
'innhugdere': ('innhugd',),
'innhugdest': ('innhugd',),
'innhugdeste': ('innhugd',),
'kampucheansk': ('kampucheansk',),
'kampucheanske': ('kampucheansk',),
'kampucheanskere': ('kampucheansk',),
'kampucheanskest': ('kampucheansk',),
'kampucheanskeste': ('kampucheansk',),
'karminraud': ('karminraud',),
'karminraude': ('karminraud',),
'karminraudere': ('karminraud',),
'karminraudest': ('karminraud',),
'karminraudeste': ('karminraud',),
'karminraudt': ('karminraud',),
'klukkledd': ('klukkle',),
'klukkledde': ('klukkle',),
'klukkleende': ('klukkle',),
'klyppende': ('klyppe',),
'klypt': ('klyppe',),
'klypte': ('klyppe',),
'konfeksjonssydd': ('konfeksjonssydd',),
'konfeksjonssydde': ('konfeksjonssydd',),
'konfeksjonssyddere': ('konfeksjonssydd',),
'konfeksjonssyddest': ('konfeksjonssydd',),
'konfeksjonssyddeste': ('konfeksjonssydd',),
'kromraudt': ('kromraudt',),
'kromraudte': ('kromraudt',),
'kromraudtere': ('kromraudt',),
'kromraudtest': ('kromraudt',),
'kromraudteste': ('kromraudt',),
'kromraudtt': ('kromraudt',),
'krongla': ('krongle',),
'kronglede': ('krongle',),
'kronglende': ('krongle',),
'kronglet': ('krongle',),
'kronglete': ('krongle',),
'krungla': ('krungle',),
'krunglede': ('krungle',),
'krunglende': ('krungle',),
'krunglet': ('krungle',),
'krunglete': ('krungle',),
'krungla': ('krungle',),
'krunglede': ('krungle',),
'krunglende': ('krungle',),
'krunglet': ('krungle',),
'krunglete': ('krungle',),
'krongla': ('krongle',),
'kronglede': ('krongle',),
'kronglende': ('krongle',),
'kronglet': ('krongle',),
'kronglete': ('krongle',),
'kvevd': ('kveve',),
'kvevde': ('kveve',),
'kvevende': ('kveve',),
'lakkraud': ('lakkraud',),
'lakkraude': ('lakkraud',),
'lakkraudere': ('lakkraud',),
'lakkraudest': ('lakkraud',),
'lakkraudeste': ('lakkraud',),
'lakkraudt': ('lakkraud',),
'lakseraud': ('lakseraud',),
'lakseraude': ('lakseraud',),
'lakseraudere': ('lakseraud',),
'lakseraudest': ('lakseraud',),
'lakseraudeste': ('lakseraud',),
'lakseraudt': ('lakseraud',),
'laksraud': ('laksraud',),
'laksraude': ('laksraud',),
'laksraudere': ('laksraud',),
'laksraudest': ('laksraud',),
'laksraudeste': ('laksraud',),
'laksraudt': ('laksraud',),
'lakseraud': ('lakseraud',),
'lakseraude': ('lakseraud',),
'lakseraudere': ('lakseraud',),
'lakseraudest': ('lakseraud',),
'lakseraudeste': ('lakseraud',),
'lakseraudt': ('lakseraud',),
'laksraud': ('laksraud',),
'laksraude': ('laksraud',),
'laksraudere': ('laksraud',),
'laksraudest': ('laksraud',),
'laksraudeste': ('laksraud',),
'laksraudt': ('laksraud',),
'laksraud': ('laksraud',),
'laksraude': ('laksraud',),
'laksraudere': ('laksraud',),
'laksraudest': ('laksraud',),
'laksraudeste': ('laksraud',),
'laksraudt': ('laksraud',),
'lakseraud': ('lakseraud',),
'lakseraude': ('lakseraud',),
'lakseraudere': ('lakseraud',),
'lakseraudest': ('lakseraud',),
'lakseraudeste': ('lakseraud',),
'lakseraudt': ('lakseraud',),
'løslatende': ('løslate',),
'løslatt': ('løslate',),
'løslatte': ('løslate',),
'lauslatende': ('lauslate',),
'lauslatt': ('lauslate',),
'lauslatte': ('lauslate',),
'lettisk': ('lettisk',),
'lettiske': ('lettisk',),
'lettiskere': ('lettisk',),
'lettiskest': ('lettisk',),
'lettiskeste': ('lettisk',),
'luffa': ('luffe',),
'luffede': ('luffe',),
'luffende': ('luffe',),
'luffet': ('luffe',),
'luffete': ('luffe',),
'lydisolerende': ('lydisolere',),
'lydisolert': ('lydisolere',),
'lydisolerte': ('lydisolere',),
'lettbent': ('lettbent',),
'lettbente': ('lettbent',),
'lettbentere': ('lettbent',),
'lettbentest': ('lettbent',),
'lettbenteste': ('lettbent',),
'lyseraud': ('lyseraud',),
'lyseraude': ('lyseraud',),
'lyseraudere': ('lyseraud',),
'lyseraudest': ('lyseraud',),
'lyseraudeste': ('lyseraud',),
'lyseraudt': ('lyseraud',),
'lysraud': ('lysraud',),
'lysraude': ('lysraud',),
'lysraudere': ('lysraud',),
'lysraudest': ('lysraud',),
'lysraudeste': ('lysraud',),
'lysraudt': ('lysraud',),
'lysraud': ('lysraud',),
'lysraude': ('lysraud',),
'lysraudere': ('lysraud',),
'lysraudest': ('lysraud',),
'lysraudeste': ('lysraud',),
'lysraudt': ('lysraud',),
'lyseraud': ('lyseraud',),
'lyseraude': ('lyseraud',),
'lyseraudere': ('lyseraud',),
'lyseraudest': ('lyseraud',),
'lyseraudeste': ('lyseraud',),
'lyseraudt': ('lyseraud',),
'målbåren': ('målbære',),
'målbåret': ('målbære',),
'målbårne': ('målbære',),
'målbærende': ('målbære',),
'mottagelig': ('mottagelig',),
'mottagelige': ('mottagelig',),
'mottageligere': ('mottagelig',),
'mottageligst': ('mottagelig',),
'mottageligste': ('mottagelig',),
'mørkeraud': ('mørkeraud',),
'mørkeraude': ('mørkeraud',),
'mørkeraudere': ('mørkeraud',),
'mørkeraudest': ('mørkeraud',),
'mørkeraudeste': ('mørkeraud',),
'mørkeraudt': ('mørkeraud',),
'mørkraud': ('mørkraud',),
'mørkraude': ('mørkraud',),
'mørkraudere': ('mørkraud',),
'mørkraudest': ('mørkraud',),
'mørkraudeste': ('mørkraud',),
'mørkraudt': ('mørkraud',),
'mørkraud': ('mørkraud',),
'mørkraude': ('mørkraud',),
'mørkraudere': ('mørkraud',),
'mørkraudest': ('mørkraud',),
'mørkraudeste': ('mørkraud',),
'mørkraudt': ('mørkraud',),
'mørkeraud': ('mørkeraud',),
'mørkeraude': ('mørkeraud',),
'mørkeraudere': ('mørkeraud',),
'mørkeraudest': ('mørkeraud',),
'mørkeraudeste': ('mørkeraud',),
'mørkeraudt': ('mørkeraud',),
'mørkraud': ('mørkraud',),
'mørkraude': ('mørkraud',),
'mørkraudere': ('mørkraud',),
'mørkraudest': ('mørkraud',),
'mørkraudeste': ('mørkraud',),
'mørkraudt': ('mørkraud',),
'mørkeraud': ('mørkeraud',),
'mørkeraude': ('mørkeraud',),
'mørkeraudere': ('mørkeraud',),
'mørkeraudest': ('mørkeraud',),
'mørkeraudeste': ('mørkeraud',),
'mørkeraudt': ('mørkeraud',),
'obscøn': ('obscøn',),
'obscøne': ('obscøn',),
'obscønere': ('obscøn',),
'obscønest': ('obscøn',),
'obscøneste': ('obscøn',),
'obscønt': ('obscøn',),
'OK': ('OK',),
'ok': ('ok',),
'oppreidd': ('oppreidd',),
'oppreidde': ('oppreidd',),
'oppreiddere': ('oppreidd',),
'oppreiddest': ('oppreidd',),
'oppreiddeste': ('oppreidd',),
'oppebåren': ('oppebære',),
'oppebåret': ('oppebære',),
'oppebårne': ('oppebære',),
'oppebærende': ('oppebære',),
'pelma': ('pelme',),
'pelmede': ('pelme',),
'pelmende': ('pelme',),
'pelmet': ('pelme',),
'pelmete': ('pelme',),
'påtagelig': ('påtagelig',),
'påtagelige': ('påtagelig',),
'påtageligere': ('påtagelig',),
'påtageligst': ('påtagelig',),
'påtageligste': ('påtagelig',),
'raud': ('raud',),
'raude': ('raud',),
'raudere': ('raud',),
'raudest': ('raud',),
'raudeste': ('raud',),
'raudt': ('raud',),
'reinska': ('reinske',),
'reinskede': ('reinske',),
'reinskende': ('reinske',),
'reinsket': ('reinske',),
'reinskete': ('reinske',),
'reinska': ('reinske',),
'reinskede': ('reinske',),
'reinskende': ('reinske',),
'reinsket': ('reinske',),
'reinskete': ('reinske',),
'rosenraud': ('rosenraud',),
'rosenraude': ('rosenraud',),
'rosenraudere': ('rosenraud',),
'rosenraudest': ('rosenraud',),
'rosenraudeste': ('rosenraud',),
'rosenraudt': ('rosenraud',),
'roseraud': ('roseraud',),
'roseraude': ('roseraud',),
'roseraudere': ('roseraud',),
'roseraudest': ('roseraud',),
'roseraudeste': ('roseraud',),
'roseraudt': ('roseraud',),
'rubinraud': ('rubinraud',),
'rubinraude': ('rubinraud',),
'rubinraudere': ('rubinraud',),
'rubinraudest': ('rubinraud',),
'rubinraudeste': ('rubinraud',),
'rubinraudt': ('rubinraud',),
'rustraud': ('rustraud',),
'rustraude': ('rustraud',),
'rustraudere': ('rustraud',),
'rustraudest': ('rustraud',),
'rustraudeste': ('rustraud',),
'rustraudt': ('rustraud',),
'raud': ('raud',),
'raude': ('raud',),
'raudere': ('raud',),
'raudest': ('raud',),
'raudeste': ('raud',),
'raudt': ('raud',),
'raudmussa': ('raudmussa',),
'raudsprengt': ('raudsprengt',),
'raudsprengte': ('raudsprengt',),
'raudsprengtere': ('raudsprengt',),
'raudsprengtest': ('raudsprengt',),
'raudsprengteste': ('raudsprengt',),
'røka': ('røke',),
'røkede': ('røke',),
'røkende': ('røke',),
'røket': ('røke',),
'røkete': ('røke',),
'røkt': ('røke',),
'røkte': ('røke',),
'sidræva': ('sidræva',),
'sjansa': ('sjanse',),
'sjansede': ('sjanse',),
'sjansende': ('sjanse',),
'sjanset': ('sjanse',),
'sjansete': ('sjanse',),
'snauhogd': ('snauhogge',),
'snauhogde': ('snauhogge',),
'snauhoggede': ('snauhogge',),
'snauhoggende': ('snauhogge',),
'snauhogget': ('snauhogge',),
'snauhoggete': ('snauhogge',),
'snauhugd': ('snauhugge',),
'snauhugde': ('snauhugge',),
'snauhugga': ('snauhugge',),
'snauhuggede': ('snauhugge',),
'snauhuggende': ('snauhugge',),
'snauhugget': ('snauhugge',),
'snauhuggete': ('snauhugge',),
'sultefôra': ('sultefôre',),
'sultefôrede': ('sultefôre',),
'sultefôrende': ('sultefôre',),
'sultefôret': ('sultefôre',),
'sultefôrete': ('sultefôre',),
'sultefôrt': ('sultefôre',),
'sultefôrte': ('sultefôre',),
'sultefôra': ('sultefôre',),
'sultefôrede': ('sultefôre',),
'sultefôrende': ('sultefôre',),
'sultefôret': ('sultefôre',),
'sultefôrete': ('sultefôre',),
'sultefôrt': ('sultefôre',),
'sultefôrte': ('sultefôre',),
'signalraud': ('signalraud',),
'signalraude': ('signalraud',),
'signalraudere': ('signalraud',),
'signalraudest': ('signalraud',),
'signalraudeste': ('signalraud',),
'signalraudt': ('signalraud',),
'sinoberraud': ('sinoberraud',),
'sinoberraude': ('sinoberraud',),
'sinoberraudere': ('sinoberraud',),
'sinoberraudest': ('sinoberraud',),
'sinoberraudeste': ('sinoberraud',),
'sinoberraudt': ('sinoberraud',),
'sleisk': ('sleisk',),
'sleiske': ('sleisk',),
'sleiskere': ('sleisk',),
'sleiskest': ('sleisk',),
'sleiskeste': ('sleisk',),
'sleiska': ('sleiske',),
'sleiskede': ('sleiske',),
'sleiskende': ('sleiske',),
'sleisket': ('sleiske',),
'sleiskete': ('sleiske',),
'sleisk': ('sleisk',),
'sleiske': ('sleisk',),
'sleiskere': ('sleisk',),
'sleiskest': ('sleisk',),
'sleiskeste': ('sleisk',),
'sleiskt': ('sleisk',),
'sleiska': ('sleiske',),
'sleiskede': ('sleiske',),
'sleiskende': ('sleiske',),
'sleisket': ('sleiske',),
'sleiskete': ('sleiske',),
'sprengraud': ('sprengraud',),
'sprengraude': ('sprengraud',),
'sprengraudere': ('sprengraud',),
'sprengraudest': ('sprengraud',),
'sprengraudeste': ('sprengraud',),
'sprengraudt': ('sprengraud',),
'sprutraud': ('sprutraud',),
'sprutraude': ('sprutraud',),
'sprutraudere': ('sprutraud',),
'sprutraudest': ('sprutraud',),
'sprutraudeste': ('sprutraud',),
'sprutraudt': ('sprutraud',),
'stemningsfull': ('stemningsfull',),
'stemningsfulle': ('stemningsfull',),
'stemningsfullere': ('stemningsfull',),
'stemningsfullest': ('stemningsfull',),
'stemningsfulleste': ('stemningsfull',),
'stemningsfullt': ('stemningsfull',),
'stemningsfylt': ('stemningsfylt',),
'stemningsfylte': ('stemningsfylt',),
'stemningsfyltere': ('stemningsfylt',),
'stemningsfyltest': ('stemningsfylt',),
'stemningsfylteste': ('stemningsfylt',),
'stemningsskapende': ('stemningsskapende',),
'stemoderlig': ('stemoderlig',),
'stemoderlige': ('stemoderlig',),
'stemoderligere': ('stemoderlig',),
'stemoderligst': ('stemoderlig',),
'stemoderligste': ('stemoderlig',),
'stempelpliktig': ('stempelpliktig',),
'stempelpliktige': ('stempelpliktig',),
'stempelpliktigere': ('stempelpliktig',),
'stempelpliktigst': ('stempelpliktig',),
'stempelpliktigste': ('stempelpliktig',),
'stempla': ('stemple',),
'stemplede': ('stemple',),
'stemplende': ('stemple',),
'stemplet': ('stemple',),
'stemplete': ('stemple',),
'stendig': ('stendig',),
'stendige': ('stendig',),
'stendigere': ('stendig',),
'stendigst': ('stendig',),
'stendigste': ('stendig',),
'stengende': ('stenge',),
'stengt': ('stenge',),
'stengte': ('stenge',),
'stenka': ('stenke',),
'stenkede': ('stenke',),
'stenkende': ('stenke',),
'stenket': ('stenke',),
'stenkete': ('stenke',),
'stenograferende': ('stenografere',),
'stenografert': ('stenografere',),
'stenograferte': ('stenografere',),
'stenografisk': ('stenografisk',),
'stenografiske': ('stenografisk',),
'stenografiskere': ('stenografisk',),
'stenografiskest': ('stenografisk',),
'stenografiskeste': ('stenografisk',),
'stensilerende': ('stensilere',),
'stensilert': ('stensilere',),
'stensilerte': ('stensilere',),
'steppa': ('steppe',),
'steppede': ('steppe',),
'steppende': ('steppe',),
'steppet': ('steppe',),
'steppete': ('steppe',),
'stereofonisk': ('stereofonisk',),
'stereofoniske': ('stereofonisk',),
'stereofoniskere': ('stereofonisk',),
'stereofoniskest': ('stereofonisk',),
'stereofoniskeste': ('stereofonisk',),
'stereometrisk': ('stereometrisk',),
'stereometriske': ('stereometrisk',),
'stereometriskere': ('stereometrisk',),
'stereometriskest': ('stereometrisk',),
'stereometriskeste': ('stereometrisk',),
'stereoskopisk': ('stereoskopisk',),
'stereoskopiske': ('stereoskopisk',),
'stereoskopiskere': ('stereoskopisk',),
'stereoskopiskest': ('stereoskopisk',),
'stereoskopiskeste': ('stereoskopisk',),
'stereotyp': ('stereotyp',),
'stereotype': ('stereotyp',),
'stereotypere': ('stereotyp',),
'stereotypest': ('stereotyp',),
'stereotypeste': ('stereotyp',),
'stereotypt': ('stereotyp',),
'stereotyperende': ('stereotypere',),
'stereotypert': ('stereotypere',),
'stereotyperte': ('stereotypere',),
'steril': ('steril',),
'sterile': ('steril',),
'sterilere': ('steril',),
'sterilest': ('steril',),
'sterileste': ('steril',),
'sterilt': ('steril',),
'steriliserende': ('sterilisere',),
'sterilisert': ('sterilisere',),
'steriliserte': ('sterilisere',),
'sterk': ('sterk',),
'sterke': ('sterk',),
'sterkere': ('sterk',),
'sterkest': ('sterk',),
'sterkeste': ('sterk',),
'sterkt': ('sterk',),
'sterkna': ('sterkne',),
'sterknede': ('sterkne',),
'sterknende': ('sterkne',),
'sterknet': ('sterkne',),
'sterknete': ('sterkne',),
'sterta': ('sterte',),
'stertede': ('sterte',),
'stertende': ('sterte',),
'stertet': ('sterte',),
'stertete': ('sterte',),
'stett': ('stette',),
'stette': ('stette',),
'stettende': ('stette',),
'stevja': ('stevje',),
'stevjede': ('stevje',),
'stevjende': ('stevje',),
'stevjet': ('stevje',),
'stevjete': ('stevje',),
'stifta': ('stifte',),
'stiftede': ('stifte',),
'stiftende': ('stifte',),
'stiftet': ('stifte',),
'stiftete': ('stifte',),
'stifta': ('stifte',),
'stiftede': ('stifte',),
'stiftende': ('stifte',),
'stiftet': ('stifte',),
'stiftete': ('stifte',),
'stegen': ('stige',),
'steget': ('stige',),
'stegne': ('stige',),
'stigende': ('stige',),
'stigmatiserende': ('stigmatisere',),
'stigmatisert': ('stigmatisere',),
'stigmatiserte': ('stigmatisere',),
'stigmatisk': ('stigmatisk',),
'stigmatiske': ('stigmatisk',),
'stigmatiskere': ('stigmatisk',),
'stigmatiskest': ('stigmatisk',),
'stigmatiskeste': ('stigmatisk',),
'stikkende': ('stikke',),
'stukken': ('stikke',),
'stukket': ('stikke',),
'stukne': ('stikke',),
'stikkende': ('stikke',),
'stukken': ('stikke',),
'stukket': ('stikke',),
'stukne': ('stikke',),
'stikla': ('stikle',),
'stiklede': ('stikle',),
'stiklende': ('stikle',),
'stiklet': ('stikle',),
'stiklete': ('stikle',),
'stila': ('stile',),
'stilede': ('stile',),
'stilende': ('stile',),
'stilet': ('stile',),
'stilete': ('stile',),
'stilt': ('stile',),
'stilte': ('stile',),
'stilfull': ('stilfull',),
'stilfulle': ('stilfull',),
'stilfullere': ('stilfull',),
'stilfullest': ('stilfull',),
'stilfulleste': ('stilfull',),
'stilfullt': ('stilfull',),
'stilig': ('stilig',),
'stilige': ('stilig',),
'stiligere': ('stilig',),
'stiligst': ('stilig',),
'stiligste': ('stilig',),
'stiliserende': ('stilisere',),
'stilisert': ('stilisere',),
'stiliserte': ('stilisere',),
'stilistisk': ('stilistisk',),
'stilistiske': ('stilistisk',),
'stilistiskere': ('stilistisk',),
'stilistiskest': ('stilistisk',),
'stilistiskeste': ('stilistisk',),
'still': ('still',),
'stille': ('still',),
'stillere': ('still',),
'stillest': ('still',),
'stilleste': ('still',),
'stilt': ('still',),
'stillbar': ('stillbar',),
'stillbare': ('stillbar',),
'stillbarere': ('stillbar',),
'stillbarest': ('stillbar',),
'stillbareste': ('stillbar',),
'stillbart': ('stillbar',),
'stille': ('stille',),
'stillere': ('stille',),
'stillest': ('stille',),
'stilla': ('stille',),
'stillede': ('stille',),
'stillende': ('stille',),
'stillet': ('stille',),
'stillete': ('stille',),
'stilt': ('stille',),
'stilte': ('stille',),
'stillede': ('stille',),
'stillende': ('stille',),
'stillet': ('stille',),
'stillete': ('stille',),
'stilt': ('stille',),
'stilte': ('stille',),
'stillegående': ('stillegående',),
'stillesittende': ('stillesittende',),
'stillestående': ('stillestående',),
'stillfarende': ('stillfarende',),
'stillferdig': ('stillferdig',),
'stillferdige': ('stillferdig',),
'stillferdigere': ('stillferdig',),
'stillferdigst': ('stillferdig',),
'stillferdigste': ('stillferdig',),
'stilltiende': ('stilltiende',),
'storkjefta': ('storkjefta',),
'storkjeftede': ('storkjeftet',),
'storkjeftet': ('storkjeftet',),
'storkjeftete': ('storkjeftet',),
'storkjeftetere': ('storkjeftet',),
'storkjeftetest': ('storkjeftet',),
'storkjefteteste': ('storkjeftet',),
'storlaten': ('storlaten',),
'storlatent': ('storlaten',),
'storlatne': ('storlaten',),
'storlatnere': ('storlaten',),
'storlatnest': ('storlaten',),
'storlatneste': ('storlaten',),
'storledd': ('storle',),
'storledde': ('storle',),
'storleende': ('storle',),
'storlemma': ('storlemma',),
'stormannsgal': ('stormannsgal',),
'stormannsgale': ('stormannsgal',),
'stormannsgalere': ('stormannsgal',),
'stormannsgalest': ('stormannsgal',),
'stormannsgaleste': ('stormannsgal',),
'stormannsgalt': ('stormannsgal',),
'storma': ('storme',),
'stormede': ('storme',),
'stormende': ('storme',),
'stormet': ('storme',),
'stormete': ('storme',),
'stormfull': ('stormfull',),
'stormfulle': ('stormfull',),
'stormfullere': ('stormfull',),
'stormfullest': ('stormfull',),
'stormfulleste': ('stormfull',),
'stormfullt': ('stormfull',),
'stormgjødd': ('stormgjø',),
'stormgjødde': ('stormgjø',),
'stormgjøende': ('stormgjø',),
'straight': ('straight',),
'straighte': ('straight',),
'straightere': ('straight',),
'straightest': ('straight',),
'straighteste': ('straight',),
'swinga': ('swinge',),
'swingede': ('swinge',),
'swingende': ('swinge',),
'swinget': ('swinge',),
'swingete': ('swinge',),
'swingt': ('swinge',),
'swingte': ('swinge',),
'tvangsfôra': ('tvangsfôre',),
'tvangsfôrede': ('tvangsfôre',),
'tvangsfôrende': ('tvangsfôre',),
'tvangsfôret': ('tvangsfôre',),
'tvangsfôrete': ('tvangsfôre',),
'tvangsfôrt': ('tvangsfôre',),
'tvangsfôrte': ('tvangsfôre',),
'taxa': ('taxe',),
'taxede': ('taxe',),
'taxende': ('taxe',),
'taxet': ('taxe',),
'taxete': ('taxe',),
'teglraud': ('teglraud',),
'teglraude': ('teglraud',),
'teglraudere': ('teglraud',),
'teglraudest': ('teglraud',),
'teglraudeste': ('teglraud',),
'teglraudt': ('teglraud',),
'territoriell': ('territoriell',),
'territorielle': ('territoriell',),
'territoriellere': ('territoriell',),
'territoriellest': ('territoriell',),
'territorielleste': ('territoriell',),
'territorielt': ('territoriell',),
'tirolsk': ('tirolsk',),
'tirolske': ('tirolsk',),
'tirolskere': ('tirolsk',),
'tirolskest': ('tirolsk',),
'tirolskeste': ('tirolsk',),
'tomatraud': ('tomatraud',),
'tomatraude': ('tomatraud',),
'tomatraudere': ('tomatraud',),
'tomatraudest': ('tomatraud',),
'tomatraudeste': ('tomatraud',),
'tomatraudt': ('tomatraud',),
'treisk': ('treisk',),
'treiske': ('treisk',),
'treiskere': ('treisk',),
'treiskest': ('treisk',),
'treiskeste': ('treisk',),
'treiskt': ('treisk',),
'treisk': ('treisk',),
'treiske': ('treisk',),
'treiskere': ('treisk',),
'treiskest': ('treisk',),
'treiskeste': ('treisk',),
'treiskt': ('treisk',),
'uantagelig': ('uantagelig',),
'uantagelige': ('uantagelig',),
'uantageligere': ('uantagelig',),
'uantageligst': ('uantagelig',),
'uantageligste': ('uantagelig',),
'uimottagelig': ('uimottagelig',),
'uimottagelige': ('uimottagelig',),
'uimottageligere': ('uimottagelig',),
'uimottageligst': ('uimottagelig',),
'uimottageligste': ('uimottagelig',),
'uinntagelig': ('uinntagelig',),
'uinntagelige': ('uinntagelig',),
'uinntageligere': ('uinntagelig',),
'uinntageligst': ('uinntagelig',),
'uinntageligste': ('uinntagelig',),
'uklypt': ('uklypt',),
'uklypte': ('uklypt',),
'uklyptere': ('uklypt',),
'uklyptest': ('uklypt',),
'uklypteste': ('uklypt',),
'ultraraud': ('ultraraud',),
'ultraraude': ('ultraraud',),
'ultraraudere': ('ultraraud',),
'ultraraudest': ('ultraraud',),
'ultraraudeste': ('ultraraud',),
'ultraraudt': ('ultraraud',),
'uoppreidd': ('uoppreidd',),
'uoppreidde': ('uoppreidd',),
'uoppreiddere': ('uoppreidd',),
'uoppreiddest': ('uoppreidd',),
'uoppreiddeste': ('uoppreidd',),
'upleidd': ('upleidd',),
'upleidde': ('upleidd',),
'upleiddere': ('upleidd',),
'upleiddest': ('upleidd',),
'upleiddeste': ('upleidd',),
'vinraud': ('vinraud',),
'vinraude': ('vinraud',),
'vinraudere': ('vinraud',),
'vinraudest': ('vinraud',),
'vinraudeste': ('vinraud',),
'vinraudt': ('vinraud',),
'vinraud': ('vinraud',),
'vinraude': ('vinraud',),
'vinraudere': ('vinraud',),
'vinraudest': ('vinraud',),
'vinraudeste': ('vinraud',),
'vinraudt': ('vinraud',),
'utspeida': ('utspeide',),
'utspeidede': ('utspeide',),
'utspeidende': ('utspeide',),
'utspeidet': ('utspeide',),
'utspeidete': ('utspeide',),
'x-a': ('x-e',),
'x-ede': ('x-e',),
'x-ende': ('x-e',),
'x-et': ('x-e',),
'x-ete': ('x-e',),
'still going strong': ('still going strong',),
'bonna': ('bonne',),
'bonnede': ('bonne',),
'bonnende': ('bonne',),
'bonnet': ('bonne',),
'bonnete': ('bonne',),
'bonnfrysende': ('bonnfryse',),
'bonnfryst': ('bonnfryse',),
'bonnfryste': ('bonnfryse',),
'ettersløkka': ('ettersløkke',),
'ettersløkkede': ('ettersløkke',),
'ettersløkkende': ('ettersløkke',),
'ettersløkket': ('ettersløkke',),
'ettersløkkete': ('ettersløkke',),
'ettersløkt': ('ettersløkke',),
'ettersløkte': ('ettersløkke',),
'kaldrøkende': ('kaldrøke',),
'kaldrøkt': ('kaldrøke',),
'kaldrøkte': ('kaldrøke',),
'kjederøkende': ('kjederøke',),
'kjederøkt': ('kjederøke',),
'kjederøkte': ('kjederøke',),
'maskinklyppende': ('maskinklyppe',),
'maskinklypt': ('maskinklyppe',),
'maskinklypte': ('maskinklyppe',),
'skamklyppende': ('skamklyppe',),
'skamklypt': ('skamklyppe',),
'skamklypte': ('skamklyppe',),
'snauklyppende': ('snauklyppe',),
'snauklypt': ('snauklyppe',),
'snauklypte': ('snauklyppe',),
'ureinska': ('ureinska',),
'varmrøkende': ('varmrøke',),
'varmrøkt': ('varmrøke',),
'varmrøkte': ('varmrøke',),
'veldreidd': ('veldreidd',),
'veldreidde': ('veldreidd',),
'veldreiddere': ('veldreidd',),
'veldreiddest': ('veldreidd',),
'veldreiddeste': ('veldreidd',),
'spektakulær': ('spektakulær',),
'spektakulære': ('spektakulær',),
'spektakulærere': ('spektakulær',),
'spektakulærest': ('spektakulær',),
'spektakulæreste': ('spektakulær',),
'spektakulært': ('spektakulær',),
'adoptiv': ('adoptiv',),
'adoptive': ('adoptiv',),
'adoptivere': ('adoptiv',),
'adoptivest': ('adoptiv',),
'adoptiveste': ('adoptiv',),
'adoptivt': ('adoptiv',),
'aggregerende': ('aggregere',),
'aggregert': ('aggregere',),
'aggregerte': ('aggregere',),
'aksesserende': ('aksessere',),
'aksessert': ('aksessere',),
'aksesserte': ('aksessere',),
'aktorerende': ('aktorere',),
'aktorert': ('aktorere',),
'aktorerte': ('aktorere',),
'allmennspråklig': ('allmennspråklig',),
'allmennspråklige': ('allmennspråklig',),
'allmennspråkligere': ('allmennspråklig',),
'allmennspråkligst': ('allmennspråklig',),
'allmennspråkligste': ('allmennspråklig',),
'altoverskyggende': ('altoverskyggende',),
'anonymiserende': ('anonymisere',),
'anonymisert': ('anonymisere',),
'anonymiserte': ('anonymisere',),
'anvendbar': ('anvendbar',),
'anvendbare': ('anvendbar',),
'anvendbarere': ('anvendbar',),
'anvendbarest': ('anvendbar',),
'anvendbareste': ('anvendbar',),
'anvendbart': ('anvendbar',),
'avvigsla': ('avvigsle',),
'avvigslede': ('avvigsle',),
'avvigslende': ('avvigsle',),
'avvigslet': ('avvigsle',),
'avvigslete': ('avvigsle',),
'båsa': ('båse',),
'båsede': ('båse',),
'båsende': ('båse',),
'båset': ('båse',),
'båsete': ('båse',),
'båst': ('båse',),
'båste': ('båse',),
'burmesisk': ('burmesisk',),
'burmesiske': ('burmesisk',),
'burmesiskere': ('burmesisk',),
'burmesiskest': ('burmesisk',),
'burmesiskeste': ('burmesisk',),
'charmerende': ('charmere',),
'charmert': ('charmere',),
'charmerte': ('charmere',),
'daua': ('daue',),
'dauede': ('daue',),
'dauende': ('daue',),
'dauet': ('daue',),
'dauete': ('daue',),
'dedikerende': ('dedikere',),
'dedikert': ('dedikere',),
'dedikerte': ('dedikere',),
'dement': ('dement',),
'demente': ('dement',),
'dementere': ('dement',),
'dementest': ('dement',),
'dementeste': ('dement',),
'dikotomisk': ('dikotomisk',),
'dikotomiske': ('dikotomisk',),
'dikotomiskere': ('dikotomisk',),
'dikotomiskest': ('dikotomisk',),
'dikotomiskeste': ('dikotomisk',),
'dispergerende': ('dispergere',),
'dispergert': ('dispergere',),
'dispergerte': ('dispergere',),
'duknakka': ('duknakka',),
'duknakkede': ('duknakket',),
'duknakket': ('duknakket',),
'duknakkete': ('duknakket',),
'duknakketere': ('duknakket',),
'duknakketest': ('duknakket',),
'duknakketeste': ('duknakket',),
'eksponentiell': ('eksponentiell',),
'eksponentielle': ('eksponentiell',),
'eksponentiellere': ('eksponentiell',),
'eksponentiellest': ('eksponentiell',),
'eksponentielleste': ('eksponentiell',),
'eksponentielt': ('eksponentiell',),
'ekstruderende': ('ekstrudere',),
'ekstrudert': ('ekstrudere',),
'ekstruderte': ('ekstrudere',),
'elitær': ('elitær',),
'elitære': ('elitær',),
'elitærere': ('elitær',),
'elitærest': ('elitær',),
'elitæreste': ('elitær',),
'elitært': ('elitær',),
'elitistisk': ('elitistisk',),
'elitistiske': ('elitistisk',),
'elitistiskere': ('elitistisk',),
'elitistiskest': ('elitistisk',),
'elitistiskeste': ('elitistisk',),
'emansipatorisk': ('emansipatorisk',),
'emansipatoriske': ('emansipatorisk',),
'emansipatoriskere': ('emansipatorisk',),
'emansipatoriskest': ('emansipatorisk',),
'emansipatoriskeste': ('emansipatorisk',),
'enegga': ('enegga',),
'eneggede': ('enegget',),
'enegget': ('enegget',),
'eneggete': ('enegget',),
'eneggetere': ('enegget',),
'eneggetest': ('enegget',),
'eneggeteste': ('enegget',),
'ergonomisk': ('ergonomisk',),
'ergonomiske': ('ergonomisk',),
'ergonomiskere': ('ergonomisk',),
'ergonomiskest': ('ergonomisk',),
'ergonomiskeste': ('ergonomisk',),
'euforisk': ('euforisk',),
'euforiske': ('euforisk',),
'euforiskere': ('euforisk',),
'euforiskest': ('euforisk',),
'euforiskeste': ('euforisk',),
'feministisk': ('feministisk',),
'feministiske': ('feministisk',),
'feministiskere': ('feministisk',),
'feministiskest': ('feministisk',),
'feministiskeste': ('feministisk',),
'finslipende': ('finslipe',),
'finslipt': ('finslipe',),
'finslipte': ('finslipe',),
'firehjulsdrevet': ('firehjulsdrevet',),
'firehjulsdrevne': ('firehjulsdrevet',),
'firehjulsdrevnere': ('firehjulsdrevet',),
'firehjulsdrevnest': ('firehjulsdrevet',),
'firehjulsdrevneste': ('firehjulsdrevet',),
'firhjulsdrevet': ('firhjulsdrevet',),
'firhjulsdrevne': ('firhjulsdrevet',),
'firhjulsdrevnere': ('firhjulsdrevet',),
'firhjulsdrevnest': ('firhjulsdrevet',),
'firhjulsdrevneste': ('firhjulsdrevet',),
'fôra': ('fôre',),
'fôrede': ('fôre',),
'fôrende': ('fôre',),
'fôret': ('fôre',),
'fôrete': ('fôre',),
'fôrt': ('fôre',),
'fôrte': ('fôre',),
'fjonet': ('fjonet',),
'fjonete': ('fjonet',),
'fjonetere': ('fjonet',),
'fjonetest': ('fjonet',),
'fjoneteste': ('fjonet',),
'fjonete': ('fjonete',),
'forutsigbar': ('forutsigbar',),
'forutsigbare': ('forutsigbar',),
'forutsigbarere': ('forutsigbar',),
'forutsigbarest': ('forutsigbar',),
'forutsigbareste': ('forutsigbar',),
'forutsigbart': ('forutsigbar',),
'fosforiserende': ('fosforisere',),
'fosforisert': ('fosforisere',),
'fosforiserte': ('fosforisere',),
'funka': ('funke',),
'funkede': ('funke',),
'funkende': ('funke',),
'funket': ('funke',),
'funkete': ('funke',),
'geléaktig': ('geléaktig',),
'geléaktige': ('geléaktig',),
'geléaktigere': ('geléaktig',),
'geléaktigst': ('geléaktig',),
'geléaktigste': ('geléaktig',),
'globaliserende': ('globalisere',),
'globalisert': ('globalisere',),
'globaliserte': ('globalisere',),
'grenseoverskridende': ('grenseoverskridende',),
'grensesprengende': ('grensesprengende',),
'havsens': ('havsens',),
'heltent': ('heltent',),
'heltente': ('heltent',),
'heltentere': ('heltent',),
'heltentest': ('heltent',),
'heltenteste': ('heltent',),
'henregna': ('henregne',),
'henregnede': ('henregne',),
'henregnende': ('henregne',),
'henregnet': ('henregne',),
'henregnete': ('henregne',),
'hinta': ('hinte',),
'hintede': ('hinte',),
'hintende': ('hinte',),
'hintet': ('hinte',),
'hintete': ('hinte',),
'holistisk': ('holistisk',),
'holistiske': ('holistisk',),
'holistiskere': ('holistisk',),
'holistiskest': ('holistisk',),
'holistiskeste': ('holistisk',),
'homolog': ('homolog',),
'homologe': ('homolog',),
'homologere': ('homolog',),
'homologest': ('homolog',),
'homologeste': ('homolog',),
'homologt': ('homolog',),
'hullsalig': ('hullsalig',),
'hullsalige': ('hullsalig',),
'hullsaligere': ('hullsalig',),
'hullsaligst': ('hullsalig',),
'hullsaligste': ('hullsalig',),
'hydrologisk': ('hydrologisk',),
'hydrologiske': ('hydrologisk',),
'hydrologiskere': ('hydrologisk',),
'hydrologiskest': ('hydrologisk',),
'hydrologiskeste': ('hydrologisk',),
'idéhistorisk': ('idéhistorisk',),
'idéhistoriske': ('idéhistorisk',),
'idéhistoriskere': ('idéhistorisk',),
'idéhistoriskest': ('idéhistorisk',),
'idéhistoriskeste': ('idéhistorisk',),
'idérik': ('idérik',),
'idérike': ('idérik',),
'idérikere': ('idérik',),
'idérikest': ('idérik',),
'idérikeste': ('idérik',),
'idérikt': ('idérik',),
'idoliserende': ('idolisere',),
'idolisert': ('idolisere',),
'idoliserte': ('idolisere',),
'improvisatorisk': ('improvisatorisk',),
'improvisatoriske': ('improvisatorisk',),
'improvisatoriskere': ('improvisatorisk',),
'improvisatoriskest': ('improvisatorisk',),
'improvisatoriskeste': ('improvisatorisk',),
'jappet': ('jappet',),
'jappete': ('jappet',),
'jappetere': ('jappet',),
'jappetest': ('jappet',),
'jappeteste': ('jappet',),
'jappete': ('jappete',),
'kabla': ('kable',),
'kablede': ('kable',),
'kablende': ('kable',),
'kablet': ('kable',),
'kablete': ('kable',),
'kakifarga': ('kakifarga',),
'kakifargede': ('kakifarget',),
'kakifarget': ('kakifarget',),
'kakifargete': ('kakifarget',),
'kakifargetere': ('kakifarget',),
'kakifargetest': ('kakifarget',),
'kakifargeteste': ('kakifarget',),
'kardiologisk': ('kardiologisk',),
'kardiologiske': ('kardiologisk',),
'kardiologiskere': ('kardiologisk',),
'kardiologiskest': ('kardiologisk',),
'kardiologiskeste': ('kardiologisk',),
'kjip': ('kjip',),
'kjipe': ('kjip',),
'kjipere': ('kjip',),
'kjipest': ('kjip',),
'kjipeste': ('kjip',),
'kjipt': ('kjip',),
'kobberrød': ('kobberrød',),
'kobberrøde': ('kobberrød',),
'kobberrødere': ('kobberrød',),
'kobberrødest': ('kobberrød',),
'kobberrødeste': ('kobberrød',),
'kobberrødt': ('kobberrød',),
'konfigurerende': ('konfigurere',),
'konfigurert': ('konfigurere',),
'konfigurerte': ('konfigurere',),
'konseptuell': ('konseptuell',),
'konseptuelle': ('konseptuell',),
'konseptuellere': ('konseptuell',),
'konseptuellest': ('konseptuell',),
'konseptuelleste': ('konseptuell',),
'konseptuelt': ('konseptuell',),
'korrelerende': ('korrelere',),
'korrelert': ('korrelere',),
'korrelerte': ('korrelere',),
'livsalig': ('livsalig',),
'livsalige': ('livsalig',),
'livsaligere': ('livsalig',),
'livsaligst': ('livsalig',),
'livsaligste': ('livsalig',),
'lobotomerende': ('lobotomere',),
'lobotomert': ('lobotomere',),
'lobotomerte': ('lobotomere',),
'magmatisk': ('magmatisk',),
'magmatiske': ('magmatisk',),
'magmatiskere': ('magmatisk',),
'magmatiskest': ('magmatisk',),
'magmatiskeste': ('magmatisk',),
'mangearta': ('mangearta',),
'meditativ': ('meditativ',),
'meditative': ('meditativ',),
'meditativere': ('meditativ',),
'meditativest': ('meditativ',),
'meditativeste': ('meditativ',),
'meditativt': ('meditativ',),
'megaloman': ('megaloman',),
'megalomane': ('megaloman',),
'megalomanere': ('megaloman',),
'megalomanest': ('megaloman',),
'megalomaneste': ('megaloman',),
'megalomant': ('megaloman',),
'minimalistisk': ('minimalistisk',),
'minimalistiske': ('minimalistisk',),
'minimalistiskere': ('minimalistisk',),
'minimalistiskest': ('minimalistisk',),
'minimalistiskeste': ('minimalistisk',),
'narkoleptisk': ('narkoleptisk',),
'narkoleptiske': ('narkoleptisk',),
'narkoleptiskere': ('narkoleptisk',),
'narkoleptiskest': ('narkoleptisk',),
'narkoleptiskeste': ('narkoleptisk',),
'natal': ('natal',),
'natale': ('natal',),
'natalere': ('natal',),
'natalest': ('natal',),
'nataleste': ('natal',),
'natalt': ('natal',),
'nedbetalende': ('nedbetale',),
'nedbetalt': ('nedbetale',),
'nedbetalte': ('nedbetale',),
'nederlagsdømt': ('nederlagsdømt',),
'nederlagsdømte': ('nederlagsdømt',),
'nederlagsdømtere': ('nederlagsdømt',),
'nederlagsdømtest': ('nederlagsdømt',),
'nederlagsdømteste': ('nederlagsdømt',),
'norsk-norsk': ('norsk-norsk',),
'norsk-norske': ('norsk-norsk',),
'norsk-norskere': ('norsk-norsk',),
'norsk-norskest': ('norsk-norsk',),
'norsk-norskeste': ('norsk-norsk',),
'omnipotent': ('omnipotent',),
'omnipotente': ('omnipotent',),
'omnipotentere': ('omnipotent',),
'omnipotentest': ('omnipotent',),
'omnipotenteste': ('omnipotent',),
'oppmjuka': ('oppmjuke',),
'oppmjukede': ('oppmjuke',),
'oppmjukende': ('oppmjuke',),
'oppmjuket': ('oppmjuke',),
'oppmjukete': ('oppmjuke',),
'oppmjukt': ('oppmjuke',),
'oppmjukte': ('oppmjuke',),
'oppmyka': ('oppmyke',),
'oppmykede': ('oppmyke',),
'oppmykende': ('oppmyke',),
'oppmyket': ('oppmyke',),
'oppmykete': ('oppmyke',),
'oppmykt': ('oppmyke',),
'oppmykte': ('oppmyke',),
'ortofonisk': ('ortofonisk',),
'ortofoniske': ('ortofonisk',),
'ortofoniskere': ('ortofonisk',),
'ortofoniskest': ('ortofonisk',),
'ortofoniskeste': ('ortofonisk',),
'overgripende': ('overgripende',),
'perlebrodert': ('perlebrodert',),
'perlebroderte': ('perlebrodert',),
'perlebrodertere': ('perlebrodert',),
'perlebrodertest': ('perlebrodert',),
'perlebroderteste': ('perlebrodert',),
'protokollær': ('protokollær',),
'protokollære': ('protokollær',),
'protokollærere': ('protokollær',),
'protokollærest': ('protokollær',),
'protokollæreste': ('protokollær',),
'protokollært': ('protokollær',),
'psykologiserende': ('psykologisere',),
'psykologisert': ('psykologisere',),
'psykologiserte': ('psykologisere',),
'reforhandla': ('reforhandle',),
'reforhandlede': ('reforhandle',),
'reforhandlende': ('reforhandle',),
'reforhandlet': ('reforhandle',),
'reforhandlete': ('reforhandle',),
'reklamefinansiert': ('reklamefinansiert',),
'reklamefinansierte': ('reklamefinansiert',),
'reklamefinansiertere': ('reklamefinansiert',),
'reklamefinansiertest': ('reklamefinansiert',),
'reklamefinansierteste': ('reklamefinansiert',),
'rekylerende': ('rekylere',),
'rekylert': ('rekylere',),
'rekylerte': ('rekylere',),
'repetitiv': ('repetitiv',),
'repetitive': ('repetitiv',),
'repetitivere': ('repetitiv',),
'repetitivest': ('repetitiv',),
'repetitiveste': ('repetitiv',),
'repetitivt': ('repetitiv',),
'sammensunket': ('sammensunket',),
'sammensunkne': ('sammensunket',),
'sammensunknere': ('sammensunket',),
'sammensunknest': ('sammensunket',),
'sammensunkneste': ('sammensunket',),
'sammenvevd': ('sammenvevd',),
'sammenvevde': ('sammenvevd',),
'sammenvevdere': ('sammenvevd',),
'sammenvevdest': ('sammenvevd',),
'sammenvevdeste': ('sammenvevd',),
'semiologisk': ('semiologisk',),
'semiologiske': ('semiologisk',),
'semiologiskere': ('semiologisk',),
'semiologiskest': ('semiologisk',),
'semiologiskeste': ('semiologisk',),
'sexistisk': ('sexistisk',),
'sexistiske': ('sexistisk',),
'sexistiskere': ('sexistisk',),
'sexistiskest': ('sexistisk',),
'sexistiskeste': ('sexistisk',),
'smugrøyka': ('smugrøyke',),
'smugrøykede': ('smugrøyke',),
'smugrøykende': ('smugrøyke',),
'smugrøyket': ('smugrøyke',),
'smugrøykete': ('smugrøyke',),
'smugrøykt': ('smugrøyke',),
'smugrøykte': ('smugrøyke',),
'sparsommelig': ('sparsommelig',),
'sparsommelige': ('sparsommelig',),
'sparsommeligere': ('sparsommelig',),
'sparsommeligst': ('sparsommelig',),
'sparsommeligste': ('sparsommelig',),
'stereotypisk': ('stereotypisk',),
'stereotypiske': ('stereotypisk',),
'stereotypiskere': ('stereotypisk',),
'stereotypiskest': ('stereotypisk',),
'stereotypiskeste': ('stereotypisk',),
'sultefôra': ('sultefôre',),
'sultefôrede': ('sultefôre',),
'sultefôrende': ('sultefôre',),
'sultefôret': ('sultefôre',),
'sultefôrete': ('sultefôre',),
'sultefôrt': ('sultefôre',),
'sultefôrte': ('sultefôre',),
'svitsja': ('svitsje',),
'svitsjede': ('svitsje',),
'svitsjende': ('svitsje',),
'svitsjet': ('svitsje',),
'svitsjete': ('svitsje',),
'sykdomsframkallende': ('sykdomsframkallende',),
'sykdomsfremkallende': ('sykdomsfremkallende',),
'syndikerende': ('syndikere',),
'syndikert': ('syndikere',),
'syndikerte': ('syndikere',),
'synshemma': ('synshemma',),
'synshemmede': ('synshemmet',),
'synshemmet': ('synshemmet',),
'synshemmete': ('synshemmet',),
'synshemmetere': ('synshemmet',),
'synshemmetest': ('synshemmet',),
'synshemmeteste': ('synshemmet',),
'tabloidiserende': ('tabloidisere',),
'tabloidisert': ('tabloidisere',),
'tabloidiserte': ('tabloidisere',),
'tabuerende': ('tabuere',),
'tabuert': ('tabuere',),
'tabuerte': ('tabuere',),
'tamilsk': ('tamilsk',),
'tamilske': ('tamilsk',),
'tamilskere': ('tamilsk',),
'tamilskest': ('tamilsk',),
'tamilskeste': ('tamilsk',),
'tanketom': ('tanketom',),
'tanketomme': ('tanketom',),
'tanketommere': ('tanketom',),
'tanketommest': ('tanketom',),
'tanketommeste': ('tanketom',),
'tanketomt': ('tanketom',),
'terminerende': ('terminere',),
'terminert': ('terminere',),
'terminerte': ('terminere',),
'tidels': ('tidels',),
'tiendedels': ('tiendedels',),
'trafikksikker': ('trafikksikker',),
'trafikksikkert': ('trafikksikker',),
'trafikksikre': ('trafikksikker',),
'trafikksikrere': ('trafikksikker',),
'trafikksikrest': ('trafikksikker',),
'trafikksikreste': ('trafikksikker',),
'tredjedels': ('tredjedels',),
'tredveårig': ('tredveårig',),
'tredveårige': ('tredveårig',),
'tredveårigere': ('tredveårig',),
'tredveårigst': ('tredveårig',),
'tredveårigste': ('tredveårig',),
'trendy': ('trendy',),
'ubleika': ('ubleika',),
'ubleikede': ('ubleiket',),
'ubleiket': ('ubleiket',),
'ubleikete': ('ubleiket',),
'ubleiketere': ('ubleiket',),
'ubleiketest': ('ubleiket',),
'ubleiketeste': ('ubleiket',),
'utbyttbar': ('utbyttbar',),
'utbyttbare': ('utbyttbar',),
'utbyttbarere': ('utbyttbar',),
'utbyttbarest': ('utbyttbar',),
'utbyttbareste': ('utbyttbar',),
'utbyttbart': ('utbyttbar',),
'valmet': ('valmet',),
'valmete': ('valmet',),
'valmetere': ('valmet',),
'valmetest': ('valmet',),
'valmeteste': ('valmet',),
'vektlagt': ('vektlegge',),
'vektlagte': ('vektlegge',),
'vektleggende': ('vektlegge',),
'videreformidla': ('videreformidle',),
'videreformidlede': ('videreformidle',),
'videreformidlende': ('videreformidle',),
'videreformidlet': ('videreformidle',),
'videreformidlete': ('videreformidle',),
'åndrik': ('åndrik',),
'åndrike': ('åndrik',),
'åndrikere': ('åndrik',),
'åndrikest': ('åndrik',),
'åndrikeste': ('åndrik',),
'åndrikt': ('åndrik',),
'nykter': ('nykter',),
'nyktert': ('nykter',),
'nyktre': ('nykter',),
'nyktrere': ('nykter',),
'nyktrest': ('nykter',),
'nyktreste': ('nykter',),
'jugd': ('juge',),
'jugde': ('juge',),
'jugende': ('juge',),
'fora': ('fore',),
'forede': ('fore',),
'forende': ('fore',),
'foret': ('fore',),
'forete': ('fore',),
'fort': ('fore',),
'forte': ('fore',),
'bølende': ('bøle',),
'bølt': ('bøle',),
'bølte': ('bøle',),
'blitt': ('bli',),
'blitte': ('bli',),
'blivende': ('bli',),
'botnfrosne': ('botnfryse',),
'botnfrossen': ('botnfryse',),
'botnfrosset': ('botnfryse',),
'botnfryse': ('botnfryse',),
'botnfrysende': ('botnfryse',),
'bunnfrosne': ('bunnfryse',),
'bunnfrossen': ('bunnfryse',),
'bunnfrosset': ('bunnfryse',),
'bunnfryse': ('bunnfryse',),
'bunnfrysende': ('bunnfryse',),
'dypgående': ('dypgående',),
'fora': ('fore',),
'forede': ('fore',),
'forende': ('fore',),
'foret': ('fore',),
'forete': ('fore',),
'fort': ('fore',),
'forte': ('fore',),
'irende': ('ire',),
'irt': ('ire',),
'irte': ('ire',),
'material': ('material',),
'materiale': ('material',),
'materialere': ('material',),
'materialest': ('material',),
'materialeste': ('material',),
'materialt': ('material',),
'mava': ('mave',),
'mavende': ('mave',),
'mavet': ('mave',),
'mavete': ('mave',),
'tolla': ('tolle',),
'tollende': ('tolle',),
'tollet': ('tolle',),
'tollete': ('tolle',),
'styla': ('style',),
'stylede': ('style',),
'stylende': ('style',),
'stylet': ('style',),
'stylete': ('style',),
'hvirvla': ('hvirvle',),
'hvirvlede': ('hvirvle',),
'hvirvlende': ('hvirvle',),
'hvirvlet': ('hvirvle',),
'hvirvlete': ('hvirvle',),
'iberekna': ('iberekne',),
'ibereknede': ('iberekne',),
'ibereknende': ('iberekne',),
'ibereknet': ('iberekne',),
'ibereknete': ('iberekne',),
'henregna': ('henregne',),
'henregnede': ('henregne',),
'henregnende': ('henregne',),
'henregnet': ('henregne',),
'henregnete': ('henregne',),
'sprøstekende': ('sprøsteke',),
'sprøstekt': ('sprøsteke',),
'sprøstekte': ('sprøsteke',),
'striregna': ('striregne',),
'striregnede': ('striregne',),
'striregnende': ('striregne',),
'striregnet': ('striregne',),
'striregnete': ('striregne',),
'unnslippende': ('unnslippe',),
'unnslupne': ('unnslippe',),
'unnsluppen': ('unnslippe',),
'unnsluppet': ('unnslippe',),
'berrfota': ('berrfota',),
'charmerende': ('charmere',),
'charmert': ('charmere',),
'charmerte': ('charmere',),
'e-maila': ('e-maile',),
'e-mailede': ('e-maile',),
'e-mailende': ('e-maile',),
'e-mailet': ('e-maile',),
'e-mailete': ('e-maile',),
'maks': ('maks',),
'hanka': ('hanke',),
'hankede': ('hanke',),
'hankende': ('hanke',),
'hanket': ('hanke',),
'hankete': ('hanke',),
'harry': ('harry',),
'pinglete': ('pinglete',),
'kasakhstansk': ('kasakhstansk',),
'kasakhstanske': ('kasakhstansk',),
'kasakhstanskere': ('kasakhstansk',),
'kasakhstanskest': ('kasakhstansk',),
'kasakhstanskeste': ('kasakhstansk',),
'varskodd': ('varsko',),
'varskodde': ('varsko',),
'varskoende': ('varsko',),
'masokistisk': ('masokistisk',),
'masokistiske': ('masokistisk',),
'masokistiskere': ('masokistisk',),
'masokistiskest': ('masokistisk',),
'masokistiskeste': ('masokistisk',),
'sadomasokistisk': ('sadomasokistisk',),
'sadomasokistiske': ('sadomasokistisk',),
'sadomasokistiskere': ('sadomasokistisk',),
'sadomasokistiskest': ('sadomasokistisk',),
'sadomasokistiskeste': ('sadomasokistisk',),
'nonsjalant': ('nonsjalant',),
'nonsjalante': ('nonsjalant',),
'nonsjalantere': ('nonsjalant',),
'nonsjalantest': ('nonsjalant',),
'nonsjalanteste': ('nonsjalant',),
'nonsjalerende': ('nonsjalere',),
'nonsjalert': ('nonsjalere',),
'nonsjalerte': ('nonsjalere',),
'sørva': ('sørve',),
'sørvede': ('sørve',),
'sørvende': ('sørve',),
'sørvet': ('sørve',),
'sørvete': ('sørve',),
'adspredt': ('adspredt',),
'adspredte': ('adspredt',),
'adspredtere': ('adspredt',),
'adspredtest': ('adspredt',),
'adspredteste': ('adspredt',),
'fortrudd': ('fortryde',),
'fortrudde': ('fortryde',),
'fortrydende': ('fortryde',),
'fortrydelig': ('fortrydelig',),
'fortrydelige': ('fortrydelig',),
'fortrydeligere': ('fortrydelig',),
'fortrydeligst': ('fortrydelig',),
'fortrydeligste': ('fortrydelig',),
'hæla': ('hæle',),
'hælede': ('hæle',),
'hælende': ('hæle',),
'hælet': ('hæle',),
'hælete': ('hæle',),
'tredd': ('tre',),
'tredde': ('tre',),
'treende': ('tre',),
'træla': ('træle',),
'trælede': ('træle',),
'trælende': ('træle',),
'trælet': ('træle',),
'trælete': ('træle',),
'trælsom': ('trælsom',),
'trælsomme': ('trælsom',),
'trælsommere': ('trælsom',),
'trælsomst': ('trælsom',),
'trælsomste': ('trælsom',),
'trælsomt': ('trælsom',),
'ølla': ('ølle',),
'øllede': ('ølle',),
'øllende': ('ølle',),
'øllet': ('ølle',),
'øllete': ('ølle',),
'pela': ('pele',),
'pelede': ('pele',),
'pelende': ('pele',),
'pelet': ('pele',),
'pelete': ('pele',),
'pelt': ('pele',),
'pelte': ('pele',),
'uvegsom': ('uvegsom',),
'uvegsomme': ('uvegsom',),
'uvegsommere': ('uvegsom',),
'uvegsomst': ('uvegsom',),
'uvegsomste': ('uvegsom',),
'uvegsomt': ('uvegsom',),
'abiotisk': ('abiotisk',),
'abiotiske': ('abiotisk',),
'abiotiskere': ('abiotisk',),
'abiotiskest': ('abiotisk',),
'abiotiskeste': ('abiotisk',),
'aboriginsk': ('aboriginsk',),
'aboriginske': ('aboriginsk',),
'aboriginskere': ('aboriginsk',),
'aboriginskest': ('aboriginsk',),
'aboriginskeste': ('aboriginsk',),
'advokerende': ('advokere',),
'advokert': ('advokere',),
'advokerte': ('advokere',),
'agglomererende': ('agglomerere',),
'agglomerert': ('agglomerere',),
'agglomererte': ('agglomerere',),
'akrostisk': ('akrostisk',),
'akrostiske': ('akrostisk',),
'akrostiskere': ('akrostisk',),
'akrostiskest': ('akrostisk',),
'akrostiskeste': ('akrostisk',),
'albinotisk': ('albinotisk',),
'albinotiske': ('albinotisk',),
'albinotiskere': ('albinotisk',),
'albinotiskest': ('albinotisk',),
'albinotiskeste': ('albinotisk',),
'alderssvekka': ('alderssvekka',),
'alderssvekkede': ('alderssvekket',),
'alderssvekket': ('alderssvekket',),
'alderssvekkete': ('alderssvekket',),
'alderssvekketere': ('alderssvekket',),
'alderssvekketest': ('alderssvekket',),
'alderssvekketeste': ('alderssvekket',),
'alderssvekt': ('alderssvekt',),
'alderssvekte': ('alderssvekt',),
'alderssvektere': ('alderssvekt',),
'alderssvektest': ('alderssvekt',),
'alderssvekteste': ('alderssvekt',),
'alikvant': ('alikvant',),
'alikvante': ('alikvant',),
'alikvantere': ('alikvant',),
'alikvantest': ('alikvant',),
'alikvanteste': ('alikvant',),
'alikvot': ('alikvot',),
'alikvote': ('alikvot',),
'alikvotere': ('alikvot',),
'alikvotest': ('alikvot',),
'alikvoteste': ('alikvot',),
'allmenngjort': ('allmenngjøre',),
'allmenngjorte': ('allmenngjøre',),
'allmenngjørende': ('allmenngjøre',),
'allround': ('allround',),
'amenoreisk': ('amenoreisk',),
'amenoreiske': ('amenoreisk',),
'amenoreiskere': ('amenoreisk',),
'amenoreiskest': ('amenoreisk',),
'amenoreiskeste': ('amenoreisk',),
'anamnestisk': ('anamnestisk',),
'anamnestiske': ('anamnestisk',),
'anamnestiskere': ('anamnestisk',),
'anamnestiskest': ('anamnestisk',),
'anamnestiskeste': ('anamnestisk',),
'anglosaksisk': ('anglosaksisk',),
'anglosaksiske': ('anglosaksisk',),
'anglosaksiskere': ('anglosaksisk',),
'anglosaksiskest': ('anglosaksisk',),
'anglosaksiskeste': ('anglosaksisk',),
'anorektisk': ('anorektisk',),
'anorektiske': ('anorektisk',),
'anorektiskere': ('anorektisk',),
'anorektiskest': ('anorektisk',),
'anorektiskeste': ('anorektisk',),
'antet': ('ante',),
'antete': ('ante',),
'anta': ('ante',),
'antede': ('ante',),
'antende': ('ante',),
'antecedent': ('antecedent',),
'antecedente': ('antecedent',),
'antecedentere': ('antecedent',),
'antecedentest': ('antecedent',),
'antecedenteste': ('antecedent',),
'antecederende': ('antecedere',),
'antecedert': ('antecedere',),
'antecederte': ('antecedere',),
'antiviral': ('antiviral',),
'antivirale': ('antiviral',),
'antiviralere': ('antiviral',),
'antiviralest': ('antiviral',),
'antiviraleste': ('antiviral',),
'antiviralt': ('antiviral',),
'antroposentrisk': ('antroposentrisk',),
'antroposentriske': ('antroposentrisk',),
'antroposentriskere': ('antroposentrisk',),
'antroposentriskest': ('antroposentrisk',),
'antroposentriskeste': ('antroposentrisk',),
'arkimedisk': ('arkimedisk',),
'arkimediske': ('arkimedisk',),
'arkimediskere': ('arkimedisk',),
'arkimediskest': ('arkimedisk',),
'arkimediskeste': ('arkimedisk',),
'aspartam': ('aspartam',),
'aspartame': ('aspartam',),
'aspartamere': ('aspartam',),
'aspartamest': ('aspartam',),
'aspartameste': ('aspartam',),
'atopisk': ('atopisk',),
'atopiske': ('atopisk',),
'atopiskere': ('atopisk',),
'atopiskest': ('atopisk',),
'atopiskeste': ('atopisk',),
'attendels': ('attendels',),
'attribuerende': ('attribuere',),
'attribuert': ('attribuere',),
'attribuerte': ('attribuere',),
'autentifiserende': ('autentifisere',),
'autentifisert': ('autentifisere',),
'autentifiserte': ('autentifisere',),
'autentiserende': ('autentisere',),
'autentisert': ('autentisere',),
'autentiserte': ('autentisere',),
'avgifta': ('avgifte',),
'avgiftede': ('avgifte',),
'avgiftende': ('avgifte',),
'avgiftet': ('avgifte',),
'avgiftete': ('avgifte',),
'besj': ('besj',),
'besje': ('besj',),
'besjere': ('besj',),
'besjest': ('besj',),
'besjeste': ('besj',),
'besjt': ('besj',),
'billiontedels': ('billiontedels',),
'biogenetisk': ('biogenetisk',),
'biogenetiske': ('biogenetisk',),
'biogenetiskere': ('biogenetisk',),
'biogenetiskest': ('biogenetisk',),
'biogenetiskeste': ('biogenetisk',),
'biogenetisktt': ('biogenetisk',),
'blatant': ('blatant',),
'blatante': ('blatant',),
'blatantere': ('blatant',),
'blatantest': ('blatant',),
'blatanteste': ('blatant',),
'blubbet': ('blubbet',),
'blubbete': ('blubbet',),
'blubbetere': ('blubbet',),
'blubbetest': ('blubbet',),
'blubbeteste': ('blubbet',),
'blubbete': ('blubbete',),
'bosnjakisk': ('bosnjakisk',),
'bosnjakiske': ('bosnjakisk',),
'bosnjakiskere': ('bosnjakisk',),
'bosnjakiskest': ('bosnjakisk',),
'bosnjakiskeste': ('bosnjakisk',),
'brazzavillekongolesisk': ('brazzavillekongolesisk',),
'brazzavillekongolesiske': ('brazzavillekongolesisk',),
'brazzavillekongolesiskere': ('brazzavillekongolesisk',),
'brazzavillekongolesiskest': ('brazzavillekongolesisk',),
'brazzavillekongolesiskeste': ('brazzavillekongolesisk',),
'breial': ('breial',),
'breiale': ('breial',),
'breialere': ('breial',),
'breialest': ('breial',),
'breialeste': ('breial',),
'breialt': ('breial',),
'bufra': ('bufre',),
'bufrende': ('bufre',),
'bufret': ('bufre',),
'bufrete': ('bufre',),
'bulimisk': ('bulimisk',),
'bulimiske': ('bulimisk',),
'bulimiskere': ('bulimisk',),
'bulimiskest': ('bulimisk',),
'bulimiskeste': ('bulimisk',),
'bunnforderva': ('bunnforderva',),
'croona': ('croone',),
'croonede': ('croone',),
'croonende': ('croone',),
'croonet': ('croone',),
'croonete': ('croone',),
'dekontaminerende': ('dekontaminere',),
'dekontaminert': ('dekontaminere',),
'dekontaminerte': ('dekontaminere',),
'dekrypterende': ('dekryptere',),
'dekryptert': ('dekryptere',),
'dekrypterte': ('dekryptere',),
'demoniserende': ('demonisere',),
'demonisert': ('demonisere',),
'demoniserte': ('demonisere',),
'deplasserende': ('deplassere',),
'deplassert': ('deplassere',),
'deplasserte': ('deplassere',),
'devonisk': ('devonisk',),
'devoniske': ('devonisk',),
'devoniskere': ('devonisk',),
'devoniskest': ('devonisk',),
'devoniskeste': ('devonisk',),
'dialytisk': ('dialytisk',),
'dialytiske': ('dialytisk',),
'dialytiskere': ('dialytisk',),
'dialytiskest': ('dialytisk',),
'dialytiskeste': ('dialytisk',),
'dikotom': ('dikotom',),
'dikotome': ('dikotom',),
'dikotomere': ('dikotom',),
'dikotomest': ('dikotom',),
'dikotomeste': ('dikotom',),
'dikotomt': ('dikotom',),
'dioptrisk': ('dioptrisk',),
'dioptriske': ('dioptrisk',),
'dioptriskere': ('dioptrisk',),
'dioptriskest': ('dioptrisk',),
'dioptriskeste': ('dioptrisk',),
'disharmonerende': ('disharmonere',),
'disharmonert': ('disharmonere',),
'disharmonerte': ('disharmonere',),
'dissonant': ('dissonant',),
'dissonante': ('dissonant',),
'dissonantere': ('dissonant',),
'dissonantest': ('dissonant',),
'dissonanteste': ('dissonant',),
'djevelbesatt': ('djevelbesatt',),
'djevelbesatte': ('djevelbesatt',),
'djevelbesattere': ('djevelbesatt',),
'djevelbesattest': ('djevelbesatt',),
'djevelbesatteste': ('djevelbesatt',),
'domestiserende': ('domestisere',),
'domestisert': ('domestisere',),
'domestiserte': ('domestisere',),
'dysmenoreisk': ('dysmenoreisk',),
'dysmenoreiske': ('dysmenoreisk',),
'dysmenoreiskere': ('dysmenoreisk',),
'dysmenoreiskest': ('dysmenoreisk',),
'dysmenoreiskeste': ('dysmenoreisk',),
'dyspneisk': ('dyspneisk',),
'dyspneiske': ('dyspneisk',),
'dyspneiskere': ('dyspneisk',),
'dyspneiskest': ('dyspneisk',),
'dyspneiskeste': ('dyspneisk',),
'dødskjedelig': ('dødskjedelig',),
'dødskjedelige': ('dødskjedelig',),
'dødskjedeligere': ('dødskjedelig',),
'dødskjedeligst': ('dødskjedelig',),
'dødskjedeligste': ('dødskjedelig',),
'eksiterende': ('eksitere',),
'eksitert': ('eksitere',),
'eksiterte': ('eksitere',),
'eksotiserende': ('eksotisere',),
'eksotisert': ('eksotisere',),
'eksotiserte': ('eksotisere',),
'ekstraktiv': ('ekstraktiv',),
'ekstraktive': ('ekstraktiv',),
'ekstraktivere': ('ekstraktiv',),
'ekstraktivest': ('ekstraktiv',),
'ekstraktiveste': ('ekstraktiv',),
'ekstraktivt': ('ekstraktiv',),
'elga': ('elge',),
'elgede': ('elge',),
'elgende': ('elge',),
'elget': ('elge',),
'elgete': ('elge',),
'ellevedels': ('ellevedels',),
'ellevtedels': ('ellevtedels',),
'emblematisk': ('emblematisk',),
'emblematiske': ('emblematisk',),
'emblematiskere': ('emblematisk',),
'emblematiskest': ('emblematisk',),
'emblematiskeste': ('emblematisk',),
'emiratarabisk': ('emiratarabisk',),
'emiratarabiske': ('emiratarabisk',),
'emiratarabiskere': ('emiratarabisk',),
'emiratarabiskest': ('emiratarabisk',),
'emiratarabiskeste': ('emiratarabisk',),
'empatisk': ('empatisk',),
'empatiske': ('empatisk',),
'empatiskere': ('empatisk',),
'empatiskest': ('empatisk',),
'empatiskeste': ('empatisk',),
'ensella': ('ensella',),
'ensellede': ('ensellet',),
'ensellet': ('ensellet',),
'ensellete': ('ensellet',),
'enselletere': ('ensellet',),
'enselletest': ('ensellet',),
'enselleteste': ('ensellet',),
'ensyklisk': ('ensyklisk',),
'ensykliske': ('ensyklisk',),
'ensykliskere': ('ensyklisk',),
'ensykliskest': ('ensyklisk',),
'ensykliskeste': ('ensyklisk',),
'ensyklopedisk': ('ensyklopedisk',),
'ensyklopediske': ('ensyklopedisk',),
'ensyklopediskere': ('ensyklopedisk',),
'ensyklopediskest': ('ensyklopedisk',),
'ensyklopediskeste': ('ensyklopedisk',),
'eolisk': ('eolisk',),
'eoliske': ('eolisk',),
'eoliskere': ('eolisk',),
'eoliskest': ('eolisk',),
'eoliskeste': ('eolisk',),
'eplekjekk': ('eplekjekk',),
'eplekjekke': ('eplekjekk',),
'eplekjekkere': ('eplekjekk',),
'eplekjekkest': ('eplekjekk',),
'eplekjekkeste': ('eplekjekk',),
'eplekjekt': ('eplekjekk',),
'e-posta': ('e-poste',),
'e-postede': ('e-poste',),
'e-postende': ('e-poste',),
'e-postet': ('e-poste',),
'e-postete': ('e-poste',),
'etterreformatorisk': ('etterreformatorisk',),
'etterreformatoriske': ('etterreformatorisk',),
'etterreformatoriskere': ('etterreformatorisk',),
'etterreformatoriskest': ('etterreformatorisk',),
'etterreformatoriskeste': ('etterreformatorisk',),
'ettervisende': ('ettervise',),
'ettervist': ('ettervise',),
'etterviste': ('ettervise',),
'eudaimonistisk': ('eudaimonistisk',),
'eudaimonistiske': ('eudaimonistisk',),
'eudaimonistiskere': ('eudaimonistisk',),
'eudaimonistiskest': ('eudaimonistisk',),
'eudaimonistiskeste': ('eudaimonistisk',),
'evklidsk': ('evklidsk',),
'evklidske': ('evklidsk',),
'evklidskere': ('evklidsk',),
'evklidskest': ('evklidsk',),
'evklidskeste': ('evklidsk',),
'faita': ('faite',),
'faitede': ('faite',),
'faitende': ('faite',),
'faitet': ('faite',),
'faitete': ('faite',),
'fakla': ('fakle',),
'faklende': ('fakle',),
'faklet': ('fakle',),
'faklete': ('fakle',),
'fasinerende': ('fasinere',),
'fasinert': ('fasinere',),
'fasinerte': ('fasinere',),
'fasistisk': ('fasistisk',),
'fasistiske': ('fasistisk',),
'fasistiskere': ('fasistisk',),
'fasistiskest': ('fasistisk',),
'fasistiskeste': ('fasistisk',),
'femdels': ('femdels',),
'femstrøken': ('femstrøken',),
'femstrøket': ('femstrøken',),
'femstrøkne': ('femstrøken',),
'femstrøknere': ('femstrøken',),
'femstrøknest': ('femstrøken',),
'femstrøkneste': ('femstrøken',),
'femstrøkede': ('femstrøket',),
'femstrøket': ('femstrøket',),
'femstrøkete': ('femstrøket',),
'femstrøketere': ('femstrøket',),
'femstrøketest': ('femstrøket',),
'femstrøketeste': ('femstrøket',),
'femtedels': ('femtedels',),
'femtidels': ('femtidels',),
'fetisjerende': ('fetisjere',),
'fetisjert': ('fetisjere',),
'fetisjerte': ('fetisjere',),
'fetladen': ('fetladen',),
'fetladent': ('fetladen',),
'fetladne': ('fetladen',),
'fetladnere': ('fetladen',),
'fetladnest': ('fetladen',),
'fetladneste': ('fetladen',),
'fibret': ('fibret',),
'fibrete': ('fibret',),
'fibretere': ('fibret',),
'fibretest': ('fibret',),
'fibreteste': ('fibret',),
'fibrete': ('fibrete',),
'fifla': ('fifle',),
'fiflende': ('fifle',),
'fiflet': ('fifle',),
'fiflete': ('fifle',),
'fiksjonaliserende': ('fiksjonalisere',),
'fiksjonalisert': ('fiksjonalisere',),
'fiksjonaliserte': ('fiksjonalisere',),
'filtsa': ('filtse',),
'filtsende': ('filtse',),
'filtset': ('filtse',),
'filtsete': ('filtse',),
'firedels': ('firedels',),
'firefots': ('firefots',),
'firemanns': ('firemanns',),
'firfelta': ('firfelta',),
'firfeltet': ('firfeltet',),
'firfeltete': ('firfeltet',),
'firfeltetere': ('firfeltet',),
'firfeltetest': ('firfeltet',),
'firfelteteste': ('firfeltet',),
'firfelts': ('firfelts',),
'firfots': ('firfots',),
'fista': ('fiste',),
'fistede': ('fiste',),
'fistende': ('fiste',),
'fistet': ('fiste',),
'fistete': ('fiste',),
'fjerdedels': ('fjerdedels',),
'fjortendels': ('fjortendels',),
'flersella': ('flersella',),
'flersellet': ('flersellet',),
'flersellete': ('flersellet',),
'flerselletere': ('flersellet',),
'flerselletest': ('flersellet',),
'flerselleteste': ('flersellet',),
'fluffy': ('fluffy',),
'flyvedyktig': ('flyvedyktig',),
'flyvedyktige': ('flyvedyktig',),
'flyvedyktigere': ('flyvedyktig',),
'flyvedyktigst': ('flyvedyktig',),
'flyvedyktigste': ('flyvedyktig',),
'flyveferdig': ('flyveferdig',),
'flyveferdige': ('flyveferdig',),
'flyveferdigere': ('flyveferdig',),
'flyveferdigst': ('flyveferdig',),
'flyveferdigste': ('flyveferdig',),
'fonderende': ('fondere',),
'fondert': ('fondere',),
'fonderte': ('fondere',),
'forfrosne': ('forfrossen',),
'forfrosnere': ('forfrossen',),
'forfrosnest': ('forfrossen',),
'forfrosneste': ('forfrossen',),
'forfrossen': ('forfrossen',),
'forfrossent': ('forfrossen',),
'forfrosset': ('forfrossen',),
'forfrosne': ('forfrosset',),
'forfrosnere': ('forfrosset',),
'forfrosnest': ('forfrosset',),
'forfrosneste': ('forfrosset',),
'forfrosset': ('forfrosset',),
'fossiliserende': ('fossilisere',),
'fossilisert': ('fossilisere',),
'fossiliserte': ('fossilisere',),
'frihetlig': ('frihetlig',),
'frihetlige': ('frihetlig',),
'frihetligere': ('frihetlig',),
'frihetligst': ('frihetlig',),
'frihetligste': ('frihetlig',),
'fronta': ('fronte',),
'frontede': ('fronte',),
'frontende': ('fronte',),
'frontet': ('fronte',),
'frontete': ('fronte',),
'fruktig': ('fruktig',),
'fruktige': ('fruktig',),
'fruktigere': ('fruktig',),
'fruktigst': ('fruktig',),
'fruktigste': ('fruktig',),
'fylogenetisk': ('fylogenetisk',),
'fylogenetiske': ('fylogenetisk',),
'fylogenetiskere': ('fylogenetisk',),
'fylogenetiskest': ('fylogenetisk',),
'fylogenetiskeste': ('fylogenetisk',),
'førreformatorisk': ('førreformatorisk',),
'førreformatoriske': ('førreformatorisk',),
'førreformatoriskere': ('førreformatorisk',),
'førreformatoriskest': ('førreformatorisk',),
'førreformatoriskeste': ('førreformatorisk',),
'førtidels': ('førtidels',),
'gaida': ('gaide',),
'gaidede': ('gaide',),
'gaidende': ('gaide',),
'gaidet': ('gaide',),
'gaidete': ('gaide',),
'gampa': ('gampe',),
'gampede': ('gampe',),
'gampende': ('gampe',),
'gampet': ('gampe',),
'gampete': ('gampe',),
'gem': ('gem',),
'geme': ('gem',),
'gemere': ('gem',),
'gemest': ('gem',),
'gemeste': ('gem',),
'gemt': ('gem',),
'glassa': ('glasse',),
'glassede': ('glasse',),
'glassende': ('glasse',),
'glasset': ('glasse',),
'glassete': ('glasse',),
'grapsa': ('grapse',),
'grapsende': ('grapse',),
'grapset': ('grapse',),
'grapsete': ('grapse',),
'grapset': ('grapset',),
'grapsete': ('grapset',),
'grapsetere': ('grapset',),
'grapsetest': ('grapset',),
'grapseteste': ('grapset',),
'grapsete': ('grapsete',),
'gymma': ('gymme',),
'gymmede': ('gymme',),
'gymmende': ('gymme',),
'gymmet': ('gymme',),
'gymmete': ('gymme',),
'hacka': ('hacke',),
'hackede': ('hacke',),
'hackende': ('hacke',),
'hacket': ('hacke',),
'hackete': ('hacke',),
'halal': ('halal',),
'halvspråklig': ('halvspråklig',),
'halvspråklige': ('halvspråklig',),
'halvspråkligere': ('halvspråklig',),
'halvspråkligst': ('halvspråklig',),
'halvspråkligste': ('halvspråklig',),
'handfri': ('handfri',),
'handfrie': ('handfri',),
'handfriere': ('handfri',),
'handfriest': ('handfri',),
'handfrieste': ('handfri',),
'handfritt': ('handfri',),
'haram': ('haram',),
'hedda': ('hedde',),
'heddede': ('hedde',),
'heddende': ('hedde',),
'heddet': ('hedde',),
'heddete': ('hedde',),
'hegemonisk': ('hegemonisk',),
'hegemoniske': ('hegemonisk',),
'hegemoniskere': ('hegemonisk',),
'hegemoniskest': ('hegemonisk',),
'hegemoniskeste': ('hegemonisk',),
'heilhvit': ('heilhvit',),
'heilhvite': ('heilhvit',),
'heilhvitere': ('heilhvit',),
'heilhvitest': ('heilhvit',),
'heilhviteste': ('heilhvit',),
'heilhvitt': ('heilhvit',),
'heilkvit': ('heilkvit',),
'heilkvite': ('heilkvit',),
'heilkvitere': ('heilkvit',),
'heilkvitest': ('heilkvit',),
'heilkviteste': ('heilkvit',),
'heilkvitt': ('heilkvit',),
'heiltent': ('heiltent',),
'heiltente': ('heiltent',),
'heiltentere': ('heiltent',),
'heiltentest': ('heiltent',),
'heiltenteste': ('heiltent',),
'herpa': ('herpe',),
'herpede': ('herpe',),
'herpende': ('herpe',),
'herpet': ('herpe',),
'herpete': ('herpe',),
'heterolog': ('heterolog',),
'heterologe': ('heterolog',),
'heterologere': ('heterolog',),
'heterologest': ('heterolog',),
'heterologeste': ('heterolog',),
'heterologt': ('heterolog',),
'hivpositiv': ('hivpositiv',),
'hivpositive': ('hivpositiv',),
'hivpositivere': ('hivpositiv',),
'hivpositivest': ('hivpositiv',),
'hivpositiveste': ('hivpositiv',),
'hivpositivt': ('hivpositiv',),
'homeopatisk': ('homeopatisk',),
'homeopatiske': ('homeopatisk',),
'homeopatiskere': ('homeopatisk',),
'homeopatiskest': ('homeopatisk',),
'homeopatiskeste': ('homeopatisk',),
'homologerende': ('homologere',),
'homologert': ('homologere',),
'homologerte': ('homologere',),
'horet': ('horet',),
'horete': ('horet',),
'horetere': ('horet',),
'horetest': ('horet',),
'horeteste': ('horet',),
'horete': ('horete',),
'hundredels': ('hundredels',),
'hybridiserende': ('hybridisere',),
'hybridisert': ('hybridisere',),
'hybridiserte': ('hybridisere',),
'hydrogenerende': ('hydrogenere',),
'hydrogenert': ('hydrogenere',),
'hydrogenerte': ('hydrogenere',),
'hygieniserende': ('hygienisere',),
'hygienisert': ('hygienisere',),
'hygieniserte': ('hygienisere',),
'håndfri': ('håndfri',),
'håndfrie': ('håndfri',),
'håndfriere': ('håndfri',),
'håndfriest': ('håndfri',),
'håndfrieste': ('håndfri',),
'håndfritt': ('håndfri',),
'ihopkrøket': ('ihopkrøket',),
'ihopkrøkete': ('ihopkrøket',),
'ihopkrøketere': ('ihopkrøket',),
'ihopkrøketest': ('ihopkrøket',),
'ihopkrøketeste': ('ihopkrøket',),
'imbesil': ('imbesil',),
'imbesile': ('imbesil',),
'imbesilere': ('imbesil',),
'imbesilest': ('imbesil',),
'imbesileste': ('imbesil',),
'imbesilt': ('imbesil',),
'informasjonsteknologisk': ('informasjonsteknologisk',),
'informasjonsteknologiske': ('informasjonsteknologisk',),
'informasjonsteknologiskere': ('informasjonsteknologisk',),
'informasjonsteknologiskest': ('informasjonsteknologisk',),
'informasjonsteknologiskeste': ('informasjonsteknologisk',),
'informatisk': ('informatisk',),
'informatiske': ('informatisk',),
'informatiskere': ('informatisk',),
'informatiskest': ('informatisk',),
'informatiskeste': ('informatisk',),
'innbyggede': ('innbygget',),
'innbygget': ('innbygget',),
'innbyggete': ('innbygget',),
'innbyggetere': ('innbygget',),
'innbyggetest': ('innbygget',),
'innbyggeteste': ('innbygget',),
'innebyggede': ('innebygget',),
'innebygget': ('innebygget',),
'innebyggete': ('innebygget',),
'innebyggetere': ('innebygget',),
'innebyggetest': ('innebygget',),
'innebyggeteste': ('innebygget',),
'innfasa': ('innfase',),
'innfasede': ('innfase',),
'innfasende': ('innfase',),
'innfaset': ('innfase',),
'innfasete': ('innfase',),
'innhuggede': ('innhugget',),
'innhugget': ('innhugget',),
'innhuggete': ('innhugget',),
'innhuggetere': ('innhugget',),
'innhuggetest': ('innhugget',),
'innhuggeteste': ('innhugget',),
'innvevede': ('innvevet',),
'innvevet': ('innvevet',),
'innvevete': ('innvevet',),
'innvevetere': ('innvevet',),
'innvevetest': ('innvevet',),
'innveveteste': ('innvevet',),
'insestuøs': ('insestuøs',),
'insestuøse': ('insestuøs',),
'insestuøsere': ('insestuøs',),
'insestuøsest': ('insestuøs',),
'insestuøseste': ('insestuøs',),
'insestuøst': ('insestuøs',),
'insiterende': ('insitere',),
'insitert': ('insitere',),
'insiterte': ('insitere',),
'internaliserende': ('internalisere',),
'internalisert': ('internalisere',),
'internaliserte': ('internalisere',),
'interpunkterende': ('interpunktere',),
'interpunktert': ('interpunktere',),
'interpunkterte': ('interpunktere',),
'intimiserende': ('intimisere',),
'intimisert': ('intimisere',),
'intimiserte': ('intimisere',),
'intrasellulær': ('intrasellulær',),
'intrasellulære': ('intrasellulær',),
'intrasellulærere': ('intrasellulær',),
'intrasellulærest': ('intrasellulær',),
'intrasellulæreste': ('intrasellulær',),
'intrasellulært': ('intrasellulær',),
'inuittisk': ('inuittisk',),
'inuittiske': ('inuittisk',),
'inuittiskere': ('inuittisk',),
'inuittiskest': ('inuittisk',),
'inuittiskeste': ('inuittisk',),
'isenesatt': ('isenesette',),
'isenesatte': ('isenesette',),
'isenesettende': ('isenesette',),
'islamistisk': ('islamistisk',),
'islamistiske': ('islamistisk',),
'islamistiskere': ('islamistisk',),
'islamistiskest': ('islamistisk',),
'islamistiskeste': ('islamistisk',),
'jentegal': ('jentegal',),
'jentegale': ('jentegal',),
'jentegalere': ('jentegal',),
'jentegalest': ('jentegal',),
'jentegaleste': ('jentegal',),
'jentegalt': ('jentegal',),
'jettdrevet': ('jettdrevet',),
'jettdrevne': ('jettdrevet',),
'jettdrevnere': ('jettdrevet',),
'jettdrevnest': ('jettdrevet',),
'jettdrevneste': ('jettdrevet',),
'karamelliserende': ('karamellisere',),
'karamellisert': ('karamellisere',),
'karamelliserte': ('karamellisere',),
'kartfesta': ('kartfeste',),
'kartfestede': ('kartfeste',),
'kartfestende': ('kartfeste',),
'kartfestet': ('kartfeste',),
'kartfestete': ('kartfeste',),
'khmerisk': ('khmerisk',),
'khmeriske': ('khmerisk',),
'khmeriskere': ('khmerisk',),
'khmeriskest': ('khmerisk',),
'khmeriskeste': ('khmerisk',),
'klinkbyggede': ('klinkbygget',),
'klinkbygget': ('klinkbygget',),
'klinkbyggete': ('klinkbygget',),
'klinkbyggetere': ('klinkbygget',),
'klinkbyggetest': ('klinkbygget',),
'klinkbyggeteste': ('klinkbygget',),
'klinsja': ('klinsje',),
'klinsjede': ('klinsje',),
'klinsjende': ('klinsje',),
'klinsjet': ('klinsje',),
'klinsjete': ('klinsje',),
'kommitterende': ('kommittere',),
'kommittert': ('kommittere',),
'kommitterte': ('kommittere',),
'kommunefarga': ('kommunefarga',),
'kommunefargede': ('kommunefarget',),
'kommunefarget': ('kommunefarget',),
'kommunefargete': ('kommunefarget',),
'kommunefargetere': ('kommunefarget',),
'kommunefargetest': ('kommunefarget',),
'kommunefargeteste': ('kommunefarget',),
'kommunikativ': ('kommunikativ',),
'kommunikative': ('kommunikativ',),
'kommunikativere': ('kommunikativ',),
'kommunikativest': ('kommunikativ',),
'kommunikativeste': ('kommunikativ',),
'kommunikativt': ('kommunikativ',),
'konfutsiansk': ('konfutsiansk',),
'konfutsianske': ('konfutsiansk',),
'konfutsianskere': ('konfutsiansk',),
'konfutsianskest': ('konfutsiansk',),
'konfutsianskeste': ('konfutsiansk',),
'konseptualiserende': ('konseptualisere',),
'konseptualisert': ('konseptualisere',),
'konseptualiserte': ('konseptualisere',),
'kontemporær': ('kontemporær',),
'kontemporære': ('kontemporær',),
'kontemporærere': ('kontemporær',),
'kontemporærest': ('kontemporær',),
'kontemporæreste': ('kontemporær',),
'kontemporært': ('kontemporær',),
'kopperrød': ('kopperrød',),
'kopperrøde': ('kopperrød',),
'kopperrødere': ('kopperrød',),
'kopperrødest': ('kopperrød',),
'kopperrødeste': ('kopperrød',),
'kopperrødt': ('kopperrød',),
'korny': ('korny',),
'kosovisk': ('kosovisk',),
'kosoviske': ('kosovisk',),
'kosoviskere': ('kosovisk',),
'kosoviskest': ('kosovisk',),
'kosoviskeste': ('kosovisk',),
'kravellbyggede': ('kravellbygget',),
'kravellbygget': ('kravellbygget',),
'kravellbyggete': ('kravellbygget',),
'kravellbyggetere': ('kravellbygget',),
'kravellbyggetest': ('kravellbygget',),
'kravellbyggeteste': ('kravellbygget',),
'kretaisk': ('kretaisk',),
'kretaiske': ('kretaisk',),
'kretaiskere': ('kretaisk',),
'kretaiskest': ('kretaisk',),
'kretaiskeste': ('kretaisk',),
'kuraterende': ('kuratere',),
'kuratert': ('kuratere',),
'kuraterte': ('kuratere',),
'leprøs': ('leprøs',),
'leprøse': ('leprøs',),
'leprøsere': ('leprøs',),
'leprøsest': ('leprøs',),
'leprøseste': ('leprøs',),
'leprøst': ('leprøs',),
'leviterende': ('levitere',),
'levitert': ('levitere',),
'leviterte': ('levitere',),
'litisk': ('litisk',),
'litiske': ('litisk',),
'litiskere': ('litisk',),
'litiskest': ('litisk',),
'litiskeste': ('litisk',),
'ln': ('ln',),
'lumbal': ('lumbal',),
'lumbale': ('lumbal',),
'lumbalere': ('lumbal',),
'lumbalest': ('lumbal',),
'lumbaleste': ('lumbal',),
'lumbalt': ('lumbal',),
'mafiøs': ('mafiøs',),
'mafiøse': ('mafiøs',),
'mafiøsere': ('mafiøs',),
'mafiøsest': ('mafiøs',),
'mafiøseste': ('mafiøs',),
'mafiøst': ('mafiøs',),
'maila': ('maile',),
'mailede': ('maile',),
'mailende': ('maile',),
'mailet': ('maile',),
'mailete': ('maile',),
'maorisk': ('maorisk',),
'maoriske': ('maorisk',),
'maoriskere': ('maorisk',),
'maoriskest': ('maorisk',),
'maoriskeste': ('maorisk',),
'marginaliserende': ('marginalisere',),
'marginalisert': ('marginalisere',),
'marginaliserte': ('marginalisere',),
'medierende': ('mediere',),
'mediert': ('mediere',),
'medierte': ('mediere',),
'medikaliserende': ('medikalisere',),
'medikalisert': ('medikalisere',),
'medikaliserte': ('medikalisere',),
'medioker': ('medioker',),
'mediokert': ('medioker',),
'mediokre': ('medioker',),
'mediokrere': ('medioker',),
'mediokrest': ('medioker',),
'mediokreste': ('medioker',),
'meliorativ': ('meliorativ',),
'meliorative': ('meliorativ',),
'meliorativere': ('meliorativ',),
'meliorativest': ('meliorativ',),
'meliorativeste': ('meliorativ',),
'meliorativt': ('meliorativ',),
'metonymisk': ('metonymisk',),
'metonymiske': ('metonymisk',),
'metonymiskere': ('metonymisk',),
'metonymiskest': ('metonymisk',),
'metonymiskeste': ('metonymisk',),
'mikronesisk': ('mikronesisk',),
'mikronesiske': ('mikronesisk',),
'mikronesiskere': ('mikronesisk',),
'mikronesiskest': ('mikronesisk',),
'mikronesiskeste': ('mikronesisk',),
'mintgrønn': ('mintgrønn',),
'mintgrønne': ('mintgrønn',),
'mintgrønnere': ('mintgrønn',),
'mintgrønnest': ('mintgrønn',),
'mintgrønneste': ('mintgrønn',),
'mintgrønt': ('mintgrønn',),
'monitorerende': ('monitorere',),
'monitorert': ('monitorere',),
'monitorerte': ('monitorere',),
'monofon': ('monofon',),
'monofone': ('monofon',),
'monofonere': ('monofon',),
'monofonest': ('monofon',),
'monofoneste': ('monofon',),
'monofont': ('monofon',),
'monofonisk': ('monofonisk',),
'monofoniske': ('monofonisk',),
'monofoniskere': ('monofonisk',),
'monofoniskest': ('monofonisk',),
'monofoniskeste': ('monofonisk',),
'monokromatisk': ('monokromatisk',),
'monokromatiske': ('monokromatisk',),
'monokromatiskere': ('monokromatisk',),
'monokromatiskest': ('monokromatisk',),
'monokromatiskeste': ('monokromatisk',),
'monotypisk': ('monotypisk',),
'monotypiske': ('monotypisk',),
'monotypiskere': ('monotypisk',),
'monotypiskest': ('monotypisk',),
'monotypiskeste': ('monotypisk',),
'multimedial': ('multimedial',),
'multimediale': ('multimedial',),
'multimedialere': ('multimedial',),
'multimedialest': ('multimedial',),
'multimedialeste': ('multimedial',),
'multimedialt': ('multimedial',),
'nebuløs': ('nebuløs',),
'nebuløse': ('nebuløs',),
'nebuløsere': ('nebuløs',),
'nebuløsest': ('nebuløs',),
'nebuløseste': ('nebuløs',),
'nebuløst': ('nebuløs',),
'nedbemanna': ('nedbemanne',),
'nedbemannede': ('nedbemanne',),
'nedbemannende': ('nedbemanne',),
'nedbemannet': ('nedbemanne',),
'nedbemannete': ('nedbemanne',),
'nerdet': ('nerdet',),
'nerdete': ('nerdet',),
'nerdetere': ('nerdet',),
'nerdetest': ('nerdet',),
'nerdeteste': ('nerdet',),
'nerdete': ('nerdete',),
'nidels': ('nidels',),
'niendedels': ('niendedels',),
'nittendels': ('nittendels',),
'nittidels': ('nittidels',),
'nokturn': ('nokturn',),
'nokturne': ('nokturn',),
'nokturnere': ('nokturn',),
'nokturnest': ('nokturn',),
'nokturneste': ('nokturn',),
'nokturnt': ('nokturn',),
'nonprofit': ('nonprofit',),
'norskbyggede': ('norskbygget',),
'norskbygget': ('norskbygget',),
'norskbyggete': ('norskbygget',),
'norskbyggetere': ('norskbygget',),
'norskbyggetest': ('norskbygget',),
'norskbyggeteste': ('norskbygget',),
'nøkka': ('nøkke',),
'nøkkede': ('nøkke',),
'nøkkende': ('nøkke',),
'nøkket': ('nøkke',),
'nøkkete': ('nøkke',),
'nøkt': ('nøkke',),
'nøkte': ('nøkke',),
'nåblek': ('nåblek',),
'nåbleke': ('nåblek',),
'nåblekere': ('nåblek',),
'nåblekest': ('nåblek',),
'nåblekeste': ('nåblek',),
'nåblekt': ('nåblek',),
'oksitansk': ('oksitansk',),
'oksitanske': ('oksitansk',),
'oksitanskere': ('oksitansk',),
'oksitanskest': ('oksitansk',),
'oksitanskeste': ('oksitansk',),
'ombyggede': ('ombygget',),
'ombygget': ('ombygget',),
'ombyggete': ('ombygget',),
'ombyggetere': ('ombygget',),
'ombyggetest': ('ombygget',),
'ombyggeteste': ('ombygget',),
'omforenede': ('omforenet',),
'omforenet': ('omforenet',),
'omforenete': ('omforenet',),
'omforenetere': ('omforenet',),
'omforenetest': ('omforenet',),
'omforeneteste': ('omforenet',),
'omsøkt': ('omsøkt',),
'omsøkte': ('omsøkt',),
'omsøktere': ('omsøkt',),
'omsøktest': ('omsøkt',),
'omsøkteste': ('omsøkt',),
'opphuggede': ('opphugget',),
'opphugget': ('opphugget',),
'opphuggete': ('opphugget',),
'opphuggetere': ('opphugget',),
'opphuggetest': ('opphugget',),
'opphuggeteste': ('opphugget',),
'orbital': ('orbital',),
'orbitale': ('orbital',),
'orbitalere': ('orbital',),
'orbitalest': ('orbital',),
'orbitaleste': ('orbital',),
'orbitalt': ('orbital',),
'ostinat': ('ostinat',),
'ostinate': ('ostinat',),
'ostinatere': ('ostinat',),
'ostinatest': ('ostinat',),
'ostinateste': ('ostinat',),
'overbyggede': ('overbygget',),
'overbygget': ('overbygget',),
'overbyggete': ('overbygget',),
'overbyggetere': ('overbygget',),
'overbyggetest': ('overbygget',),
'overbyggeteste': ('overbygget',),
'parafinsk': ('parafinsk',),
'parafinske': ('parafinsk',),
'parafinskere': ('parafinsk',),
'parafinskest': ('parafinsk',),
'parafinskeste': ('parafinsk',),
'paralympisk': ('paralympisk',),
'paralympiske': ('paralympisk',),
'paralympiskere': ('paralympisk',),
'paralympiskest': ('paralympisk',),
'paralympiskeste': ('paralympisk',),
'periodiserende': ('periodisere',),
'periodisert': ('periodisere',),
'periodiserte': ('periodisere',),
'pierca': ('pierce',),
'piercede': ('pierce',),
'piercende': ('pierce',),
'piercet': ('pierce',),
'piercete': ('pierce',),
'pinglet': ('pinglet',),
'pinglete': ('pinglet',),
'pingletere': ('pinglet',),
'pingletest': ('pinglet',),
'pingleteste': ('pinglet',),
'pirsa': ('pirse',),
'pirsede': ('pirse',),
'pirsende': ('pirse',),
'pirset': ('pirse',),
'pirsete': ('pirse',),
'polysem': ('polysem',),
'polyseme': ('polysem',),
'polysemere': ('polysem',),
'polysemest': ('polysem',),
'polysemeste': ('polysem',),
'polysemt': ('polysem',),
'predaterende': ('predatere',),
'predatert': ('predatere',),
'predaterte': ('predatere',),
'privateiede': ('privateiet',),
'privateiet': ('privateiet',),
'privateiete': ('privateiet',),
'privateietere': ('privateiet',),
'privateietest': ('privateiet',),
'privateieteste': ('privateiet',),
'promoterende': ('promotere',),
'promotert': ('promotere',),
'promoterte': ('promotere',),
'prosedabel': ('prosedabel',),
'prosedabelt': ('prosedabel',),
'prosedable': ('prosedabel',),
'prosedablere': ('prosedabel',),
'prosedablest': ('prosedabel',),
'prosedableste': ('prosedabel',),
'psoriatisk': ('psoriatisk',),
'psoriatiske': ('psoriatisk',),
'psoriatiskere': ('psoriatisk',),
'psoriatiskest': ('psoriatisk',),
'psoriatiskeste': ('psoriatisk',),
'pubertal': ('pubertal',),
'pubertale': ('pubertal',),
'pubertalere': ('pubertal',),
'pubertalest': ('pubertal',),
'pubertaleste': ('pubertal',),
'pubertalt': ('pubertal',),
'pyreneisk': ('pyreneisk',),
'pyreneiske': ('pyreneisk',),
'pyreneiskere': ('pyreneisk',),
'pyreneiskest': ('pyreneisk',),
'pyreneiskeste': ('pyreneisk',),
'pønal': ('pønal',),
'pønale': ('pønal',),
'pønalere': ('pønal',),
'pønalest': ('pønal',),
'pønaleste': ('pønal',),
'pønalt': ('pønal',),
'påkrevede': ('påkrevet',),
'påkrevet': ('påkrevet',),
'påkrevete': ('påkrevet',),
'påkrevetere': ('påkrevet',),
'påkrevetest': ('påkrevet',),
'påkreveteste': ('påkrevet',),
'påver': ('påver',),
'påvert': ('påver',),
'påvre': ('påver',),
'påvrere': ('påver',),
'påvrest': ('påver',),
'påvreste': ('påver',),
'ravgæren': ('ravgæren',),
'ravgærent': ('ravgæren',),
'ravgærne': ('ravgæren',),
'ravgærnere': ('ravgæren',),
'ravgærnest': ('ravgæren',),
'ravgærneste': ('ravgæren',),
'regrederende': ('regredere',),
'regredert': ('regredere',),
'regrederte': ('regredere',),
'reidd': ('reide',),
'reidde': ('reide',),
'reidede': ('reide',),
'reidende': ('reide',),
'reidet': ('reide',),
'reidete': ('reide',),
'resatt': ('resette',),
'resatte': ('resette',),
'resettende': ('resette',),
'retentiv': ('retentiv',),
'retentive': ('retentiv',),
'retentivere': ('retentiv',),
'retentivest': ('retentiv',),
'retentiveste': ('retentiv',),
'retentivt': ('retentiv',),
'rocka': ('rocka',),
'rockede': ('rocket',),
'rocket': ('rocket',),
'rockete': ('rocket',),
'rocketere': ('rocket',),
'rocketest': ('rocket',),
'rocketeste': ('rocket',),
'rundlura': ('rundlure',),
'rundlurede': ('rundlure',),
'rundlurende': ('rundlure',),
'rundluret': ('rundlure',),
'rundlurete': ('rundlure',),
'rundlurt': ('rundlure',),
'rundlurte': ('rundlure',),
'rutiniserende': ('rutinisere',),
'rutinisert': ('rutinisere',),
'rutiniserte': ('rutinisere',),
'rødlett': ('rødlett',),
'rødlette': ('rødlett',),
'rødlettere': ('rødlett',),
'rødlettest': ('rødlett',),
'rødletteste': ('rødlett',),
'rølpa': ('rølpe',),
'rølpede': ('rølpe',),
'rølpende': ('rølpe',),
'rølpet': ('rølpe',),
'rølpete': ('rølpe',),
'råskrella': ('råskrelle',),
'råskrellede': ('råskrelle',),
'råskrellende': ('råskrelle',),
'råskrellet': ('råskrelle',),
'råskrellete': ('råskrelle',),
'råskrelt': ('råskrelle',),
'råskrelte': ('råskrelle',),
'sammenkrøkede': ('sammenkrøket',),
'sammenkrøket': ('sammenkrøket',),
'sammenkrøkete': ('sammenkrøket',),
'sammenkrøketere': ('sammenkrøket',),
'sammenkrøketest': ('sammenkrøket',),
'sammenkrøketeste': ('sammenkrøket',),
'sauterende': ('sautere',),
'sautert': ('sautere',),
'sauterte': ('sautere',),
'secernerende': ('secernere',),
'secernert': ('secernere',),
'secernerte': ('secernere',),
'seif': ('seif',),
'seifa': ('seife',),
'seifede': ('seife',),
'seifende': ('seife',),
'seifet': ('seife',),
'seifete': ('seife',),
'seilonsk': ('seilonsk',),
'seilonske': ('seilonsk',),
'seilonskere': ('seilonsk',),
'seilonskest': ('seilonsk',),
'seilonskeste': ('seilonsk',),
'seksdels': ('seksdels',),
'sekstidels': ('sekstidels',),
'seleber': ('seleber',),
'selebert': ('seleber',),
'selebre': ('seleber',),
'selebrere': ('seleber',),
'selebrest': ('seleber',),
'selebreste': ('seleber',),
'selebrerende': ('selebrere',),
'selebrert': ('selebrere',),
'selebrerte': ('selebrere',),
'sella': ('sella',),
'sellular': ('sellular',),
'sellulare': ('sellular',),
'sellularere': ('sellular',),
'sellularest': ('sellular',),
'sellulareste': ('sellular',),
'sellulart': ('sellular',),
'sellulær': ('sellulær',),
'sellulære': ('sellulær',),
'sellulærere': ('sellulær',),
'sellulærest': ('sellulær',),
'sellulæreste': ('sellulær',),
'sellulært': ('sellulær',),
'senisk': ('senisk',),
'seniske': ('senisk',),
'seniskere': ('senisk',),
'seniskest': ('senisk',),
'seniskeste': ('senisk',),
'seponerende': ('seponere',),
'seponert': ('seponere',),
'seponerte': ('seponere',),
'sientologisk': ('sientologisk',),
'sientologiske': ('sientologisk',),
'sientologiskere': ('sientologisk',),
'sientologiskest': ('sientologisk',),
'sientologiskeste': ('sientologisk',),
'sirkumpolar': ('sirkumpolar',),
'sirkumpolare': ('sirkumpolar',),
'sirkumpolarere': ('sirkumpolar',),
'sirkumpolarest': ('sirkumpolar',),
'sirkumpolareste': ('sirkumpolar',),
'sirkumpolart': ('sirkumpolar',),
'sirkumpolær': ('sirkumpolær',),
'sirkumpolære': ('sirkumpolær',),
'sirkumpolærere': ('sirkumpolær',),
'sirkumpolærest': ('sirkumpolær',),
'sirkumpolæreste': ('sirkumpolær',),
'sirkumpolært': ('sirkumpolær',),
'sisiliansk': ('sisiliansk',),
'sisilianske': ('sisiliansk',),
'sisilianskere': ('sisiliansk',),
'sisilianskest': ('sisiliansk',),
'sisilianskeste': ('sisiliansk',),
'sjartra': ('sjartre',),
'sjartrende': ('sjartre',),
'sjartret': ('sjartre',),
'sjartrete': ('sjartre',),
'sjettedels': ('sjettedels',),
'sjudels': ('sjudels',),
'sjuendedels': ('sjuendedels',),
'sjukdomsframkallende': ('sjukdomsframkallende',),
'sjukdomsfremkallende': ('sjukdomsfremkallende',),
'sjåka': ('sjåke',),
'sjåkede': ('sjåke',),
'sjåkende': ('sjåke',),
'sjåket': ('sjåke',),
'sjåkete': ('sjåke',),
'skripta': ('skripte',),
'skriptende': ('skripte',),
'skriptet': ('skripte',),
'skriptete': ('skripte',),
'slagordprega': ('slagordprega',),
'slagordpreget': ('slagordpreget',),
'slagordpregete': ('slagordpreget',),
'slagordpregetere': ('slagordpreget',),
'slagordpregetest': ('slagordpreget',),
'slagordpregeteste': ('slagordpreget',),
'slående': ('slående',),
'smuglesende': ('smuglese',),
'smuglest': ('smuglese',),
'smugleste': ('smuglese',),
'smugrøkende': ('smugrøke',),
'smugrøkt': ('smugrøke',),
'smugrøkte': ('smugrøke',),
'småforlova': ('småforlova',),
'snaksy': ('snaksy',),
'snikfotograferende': ('snikfotografere',),
'snikfotografert': ('snikfotografere',),
'snikfotograferte': ('snikfotografere',),
'snillistisk': ('snillistisk',),
'snillistiske': ('snillistisk',),
'snillistiskere': ('snillistisk',),
'snillistiskest': ('snillistisk',),
'snillistiskeste': ('snillistisk',),
'spinngal': ('spinngal',),
'spinngale': ('spinngal',),
'spinngalere': ('spinngal',),
'spinngalest': ('spinngal',),
'spinngaleste': ('spinngal',),
'spinngalt': ('spinngal',),
'spinngalen': ('spinngalen',),
'spinngalent': ('spinngalen',),
'spinngalne': ('spinngalen',),
'spinngalnere': ('spinngalen',),
'spinngalnest': ('spinngalen',),
'spinngalneste': ('spinngalen',),
'spinngæren': ('spinngæren',),
'spinngærent': ('spinngæren',),
'spinngærne': ('spinngæren',),
'spinngærnere': ('spinngæren',),
'spinngærnest': ('spinngæren',),
'spinngærneste': ('spinngæren',),
'sporbar': ('sporbar',),
'sporbare': ('sporbar',),
'sporbarere': ('sporbar',),
'sporbarest': ('sporbar',),
'sporbareste': ('sporbar',),
'sporbart': ('sporbar',),
'språkteknologisk': ('språkteknologisk',),
'språkteknologiske': ('språkteknologisk',),
'språkteknologiskere': ('språkteknologisk',),
'språkteknologiskest': ('språkteknologisk',),
'språkteknologiskeste': ('språkteknologisk',),
'spuriøs': ('spuriøs',),
'spuriøse': ('spuriøs',),
'spuriøsere': ('spuriøs',),
'spuriøsest': ('spuriøs',),
'spuriøseste': ('spuriøs',),
'spuriøst': ('spuriøs',),
'stetsevarende': ('stetsevarende',),
'stevnelei': ('stevnelei',),
'stevneleie': ('stevnelei',),
'stevneleiere': ('stevnelei',),
'stevneleiest': ('stevnelei',),
'stevneleieste': ('stevnelei',),
'stevneleit': ('stevnelei',),
'stevneleitt': ('stevnelei',),
'storladen': ('storladen',),
'storladent': ('storladen',),
'storladne': ('storladen',),
'storladnere': ('storladen',),
'storladnest': ('storladen',),
'storladneste': ('storladen',),
'storlemmede': ('storlemmet',),
'storlemmet': ('storlemmet',),
'storlemmete': ('storlemmet',),
'storlemmetere': ('storlemmet',),
'storlemmetest': ('storlemmet',),
'storlemmeteste': ('storlemmet',),
'straighta': ('straighte',),
'straightede': ('straighte',),
'straightende': ('straighte',),
'straightet': ('straighte',),
'straightete': ('straighte',),
'stribar': ('stribar',),
'stribare': ('stribar',),
'stribarere': ('stribar',),
'stribarest': ('stribar',),
'stribareste': ('stribar',),
'stribart': ('stribar',),
'stunta': ('stunte',),
'stuntede': ('stunte',),
'stuntende': ('stunte',),
'stuntet': ('stunte',),
'stuntete': ('stunte',),
'støpsla': ('støpsle',),
'støpslende': ('støpsle',),
'støpslet': ('støpsle',),
'støpslete': ('støpsle',),
'syklamen': ('syklamen',),
'synergerende': ('synergere',),
'synergert': ('synergere',),
'synergerte': ('synergere',),
'syttendels': ('syttendels',),
'syttidels': ('syttidels',),
'syvarma': ('syvarma',),
'syvarmede': ('syvarmet',),
'syvarmet': ('syvarmet',),
'syvarmete': ('syvarmet',),
'syvarmetere': ('syvarmet',),
'syvarmetest': ('syvarmet',),
'syvarmeteste': ('syvarmet',),
'syvdels': ('syvdels',),
'syvdobbel': ('syvdobbel',),
'syvdobbelt': ('syvdobbel',),
'syvdoble': ('syvdobbel',),
'syvdoblere': ('syvdobbel',),
'syvdoblest': ('syvdobbel',),
'syvdobleste': ('syvdobbel',),
'syvdobbelt': ('syvdobbelt',),
'syvdobbelte': ('syvdobbelt',),
'syvdobbeltere': ('syvdobbelt',),
'syvdobbeltest': ('syvdobbelt',),
'syvdobbelteste': ('syvdobbelt',),
'syvdobla': ('syvdoble',),
'syvdoblede': ('syvdoble',),
'syvdoblende': ('syvdoble',),
'syvdoblet': ('syvdoble',),
'syvdoblete': ('syvdoble',),
'syvendedels': ('syvendedels',),
'syvårig': ('syvårig',),
'syvårige': ('syvårig',),
'syvårigere': ('syvårig',),
'syvårigst': ('syvårig',),
'syvårigste': ('syvårig',),
'syvårs': ('syvårs',),
'sølibatær': ('sølibatær',),
'sølibatære': ('sølibatær',),
'sølibatærere': ('sølibatær',),
'sølibatærest': ('sølibatær',),
'sølibatæreste': ('sølibatær',),
'sølibatært': ('sølibatær',),
'søtladen': ('søtladen',),
'søtladent': ('søtladen',),
'søtladne': ('søtladen',),
'søtladnere': ('søtladen',),
'søtladnest': ('søtladen',),
'søtladneste': ('søtladen',),
'tabloid': ('tabloid',),
'tabloide': ('tabloid',),
'tabloidere': ('tabloid',),
'tabloidest': ('tabloid',),
'tabloideste': ('tabloid',),
'tabuiserende': ('tabuisere',),
'tabuisert': ('tabuisere',),
'tabuiserte': ('tabuisere',),
'taima': ('taime',),
'taimede': ('taime',),
'taimende': ('taime',),
'taimet': ('taime',),
'taimete': ('taime',),
'teksansk': ('teksansk',),
'teksanske': ('teksansk',),
'teksanskere': ('teksansk',),
'teksanskest': ('teksansk',),
'teksanskeste': ('teksansk',),
'tettbyggede': ('tettbygget',),
'tettbygget': ('tettbygget',),
'tettbyggete': ('tettbygget',),
'tettbyggetere': ('tettbygget',),
'tettbyggetest': ('tettbygget',),
'tettbyggeteste': ('tettbygget',),
'texansk': ('texansk',),
'texanske': ('texansk',),
'texanskere': ('texansk',),
'texanskest': ('texansk',),
'texanskeste': ('texansk',),
'tilsatt': ('tilsatt',),
'tilsatte': ('tilsatt',),
'tilsattere': ('tilsatt',),
'tilsattest': ('tilsatt',),
'tilsatteste': ('tilsatt',),
'tiltalt': ('tiltalt',),
'tiltalte': ('tiltalt',),
'tiltaltere': ('tiltalt',),
'tiltaltest': ('tiltalt',),
'tiltalteste': ('tiltalt',),
'tilta': ('tilte',),
'tiltede': ('tilte',),
'tiltende': ('tilte',),
'tiltet': ('tilte',),
'tiltete': ('tilte',),
'timoresisk': ('timoresisk',),
'timoresiske': ('timoresisk',),
'timoresiskere': ('timoresisk',),
'timoresiskest': ('timoresisk',),
'timoresiskeste': ('timoresisk',),
'tofrøblada': ('tofrøblada',),
'tofrøbladede': ('tofrøbladet',),
'tofrøbladet': ('tofrøbladet',),
'tofrøbladete': ('tofrøbladet',),
'tofrøbladetere': ('tofrøbladet',),
'tofrøbladetest': ('tofrøbladet',),
'tofrøbladeteste': ('tofrøbladet',),
'tolvdels': ('tolvdels',),
'tolvtedels': ('tolvtedels',),
'tonedøv': ('tonedøv',),
'tonedøve': ('tonedøv',),
'tonedøvere': ('tonedøv',),
'tonedøvest': ('tonedøv',),
'tonedøveste': ('tonedøv',),
'tonedøvt': ('tonedøv',),
'transendent': ('transendent',),
'transendente': ('transendent',),
'transendentere': ('transendent',),
'transendentest': ('transendent',),
'transendenteste': ('transendent',),
'transendental': ('transendental',),
'transendentale': ('transendental',),
'transendentalere': ('transendental',),
'transendentalest': ('transendental',),
'transendentaleste': ('transendental',),
'transendentalt': ('transendental',),
'transenderende': ('transendere',),
'transendert': ('transendere',),
'transenderte': ('transendere',),
'transseksuell': ('transseksuell',),
'transseksuelle': ('transseksuell',),
'transseksuellere': ('transseksuell',),
'transseksuellest': ('transseksuell',),
'transseksuelleste': ('transseksuell',),
'transseksuelt': ('transseksuell',),
'traumatiserende': ('traumatisere',),
'traumatisert': ('traumatisere',),
'traumatiserte': ('traumatisere',),
'tredels': ('tredels',),
'treig': ('treig',),
'treige': ('treig',),
'treigere': ('treig',),
'treigest': ('treig',),
'treigeste': ('treig',),
'treigt': ('treig',),
'trettendels': ('trettendels',),
'trettidels': ('trettidels',),
'trilliondels': ('trilliondels',),
'trillionte': ('trillionte',),
'trunkerende': ('trunkere',),
'trunkert': ('trunkere',),
'trunkerte': ('trunkere',),
'trøbla': ('trøble',),
'trøblende': ('trøble',),
'trøblet': ('trøble',),
'trøblete': ('trøble',),
'trøblet': ('trøblet',),
'trøblete': ('trøblet',),
'trøbletere': ('trøblet',),
'trøbletest': ('trøblet',),
'trøbleteste': ('trøblet',),
'trøblete': ('trøblete',),
'tsjadisk': ('tsjadisk',),
'tsjadiske': ('tsjadisk',),
'tsjadiskere': ('tsjadisk',),
'tsjadiskest': ('tsjadisk',),
'tsjadiskeste': ('tsjadisk',),
'tsjetsjensk': ('tsjetsjensk',),
'tsjetsjenske': ('tsjetsjensk',),
'tsjetsjenskere': ('tsjetsjensk',),
'tsjetsjenskest': ('tsjetsjensk',),
'tsjetsjenskeste': ('tsjetsjensk',),
'tvikrøkede': ('tvikrøket',),
'tvikrøket': ('tvikrøket',),
'tvikrøkete': ('tvikrøket',),
'tvikrøketere': ('tvikrøket',),
'tvikrøketest': ('tvikrøket',),
'tvikrøketeste': ('tvikrøket',),
'ubebyggede': ('ubebygget',),
'ubebygget': ('ubebygget',),
'ubebyggete': ('ubebygget',),
'ubebyggetere': ('ubebygget',),
'ubebyggetest': ('ubebygget',),
'ubebyggeteste': ('ubebygget',),
'ultimat': ('ultimat',),
'ultimate': ('ultimat',),
'ultimatere': ('ultimat',),
'ultimatest': ('ultimat',),
'ultimateste': ('ultimat',),
'up-to-date': ('up-to-date',),
'upåkrevede': ('upåkrevet',),
'upåkrevet': ('upåkrevet',),
'upåkrevete': ('upåkrevet',),
'upåkrevetere': ('upåkrevet',),
'upåkrevetest': ('upåkrevet',),
'upåkreveteste': ('upåkrevet',),
'USA-amerikansk': ('USA-amerikansk',),
'USA-amerikanske': ('USA-amerikansk',),
'USA-amerikanskere': ('USA-amerikansk',),
'USA-amerikanskest': ('USA-amerikansk',),
'USA-amerikanskeste': ('USA-amerikansk',),
'uskrellede': ('uskrellet',),
'uskrellet': ('uskrellet',),
'uskrellete': ('uskrellet',),
'uskrelletere': ('uskrellet',),
'uskrelletest': ('uskrellet',),
'uskrelleteste': ('uskrellet',),
'utagbar': ('utagbar',),
'utagbare': ('utagbar',),
'utagbarere': ('utagbar',),
'utagbarest': ('utagbar',),
'utagbareste': ('utagbar',),
'utagbart': ('utagbar',),
'utagerende': ('utagere',),
'utagert': ('utagere',),
'utagerte': ('utagere',),
'utdaterende': ('utdatere',),
'utdatert': ('utdatere',),
'utdaterte': ('utdatere',),
'utfasa': ('utfase',),
'utfasede': ('utfase',),
'utfasende': ('utfase',),
'utfaset': ('utfase',),
'utfasete': ('utfase',),
'uthuggede': ('uthugget',),
'uthugget': ('uthugget',),
'uthuggete': ('uthugget',),
'uthuggetere': ('uthugget',),
'uthuggetest': ('uthugget',),
'uthuggeteste': ('uthugget',),
'utskyllede': ('utskyllet',),
'utskyllet': ('utskyllet',),
'utskyllete': ('utskyllet',),
'utskylletere': ('utskyllet',),
'utskylletest': ('utskyllet',),
'utskylleteste': ('utskyllet',),
'valma': ('valma',),
'vampyrisk': ('vampyrisk',),
'vampyriske': ('vampyrisk',),
'vampyriskere': ('vampyrisk',),
'vampyriskest': ('vampyrisk',),
'vampyriskeste': ('vampyrisk',),
'vebba': ('vebbe',),
'vebbede': ('vebbe',),
'vebbende': ('vebbe',),
'vebbet': ('vebbe',),
'vebbete': ('vebbe',),
'vekta': ('vekte',),
'vektede': ('vekte',),
'vektende': ('vekte',),
'vektet': ('vekte',),
'vektete': ('vekte',),
'velbyggede': ('velbygget',),
'velbygget': ('velbygget',),
'velbyggete': ('velbygget',),
'velbyggetere': ('velbygget',),
'velbyggetest': ('velbygget',),
'velbyggeteste': ('velbygget',),
'velnærede': ('velnæret',),
'velnæret': ('velnæret',),
'velnærete': ('velnæret',),
'velnæretere': ('velnæret',),
'velnæretest': ('velnæret',),
'velnæreteste': ('velnæret',),
'viral': ('viral',),
'virale': ('viral',),
'viralere': ('viral',),
'viralest': ('viral',),
'viraleste': ('viral',),
'viralt': ('viral',),
'vokka': ('vokke',),
'vokkede': ('vokke',),
'vokkende': ('vokke',),
'vokket': ('vokke',),
'vokkete': ('vokke',),
'volatil': ('volatil',),
'volatile': ('volatil',),
'volatilere': ('volatil',),
'volatilest': ('volatil',),
'volatileste': ('volatil',),
'volatilt': ('volatil',),
'voluntaristisk': ('voluntaristisk',),
'voluntaristiske': ('voluntaristisk',),
'voluntaristiskere': ('voluntaristisk',),
'voluntaristiskest': ('voluntaristisk',),
'voluntaristiskeste': ('voluntaristisk',),
'wokka': ('wokke',),
'wokkede': ('wokke',),
'wokkende': ('wokke',),
'wokket': ('wokke',),
'wokkete': ('wokke',),
'zappa': ('zappe',),
'zappede': ('zappe',),
'zappende': ('zappe',),
'zappet': ('zappe',),
'zappete': ('zappe',),
'ønologisk': ('ønologisk',),
'ønologiske': ('ønologisk',),
'ønologiskere': ('ønologisk',),
'ønologiskest': ('ønologisk',),
'ønologiskeste': ('ønologisk',),
'åttedels': ('åttedels',),
'åttendedels': ('åttendedels',),
'åttidels': ('åttidels',),
'omskåren': ('omskåren',),
'omskåret': ('omskåren',),
'omskårne': ('omskåren',),
'omskårnere': ('omskåren',),
'omskårnest': ('omskåren',),
'omskårneste': ('omskåren',),
'omskåret': ('omskåret',),
'omskårne': ('omskåret',),
'omskårnere': ('omskåret',),
'omskårnest': ('omskåret',),
'omskårneste': ('omskåret',),
'avtagbar': ('avtagbar',),
'avtagbare': ('avtagbar',),
'avtagbarere': ('avtagbar',),
'avtagbarest': ('avtagbar',),
'avtagbareste': ('avtagbar',),
'avtagbart': ('avtagbar',),
'bakfull': ('bakfull',),
'bakfulle': ('bakfull',),
'bakfullere': ('bakfull',),
'bakfullest': ('bakfull',),
'bakfulleste': ('bakfull',),
'bakfullt': ('bakfull',),
'bimedial': ('bimedial',),
'bimediale': ('bimedial',),
'bimedialere': ('bimedial',),
'bimedialest': ('bimedial',),
'bimedialeste': ('bimedial',),
'bimedialt': ('bimedial',),
'foldrik': ('foldrik',),
'foldrike': ('foldrik',),
'foldrikere': ('foldrik',),
'foldrikest': ('foldrik',),
'foldrikeste': ('foldrik',),
'foldrikt': ('foldrik',),
'monotyp': ('monotyp',),
'monotype': ('monotyp',),
'monotypere': ('monotyp',),
'monotypest': ('monotyp',),
'monotypeste': ('monotyp',),
'monotypt': ('monotyp',),
'okulær': ('okulær',),
'okulære': ('okulær',),
'okulærere': ('okulær',),
'okulærest': ('okulær',),
'okulæreste': ('okulær',),
'okulært': ('okulær',),
'proaktiv': ('proaktiv',),
'proaktive': ('proaktiv',),
'proaktivere': ('proaktiv',),
'proaktivest': ('proaktiv',),
'proaktiveste': ('proaktiv',),
'proaktivt': ('proaktiv',),
'skalar': ('skalar',),
'skalare': ('skalar',),
'skalarere': ('skalar',),
'skalarest': ('skalar',),
'skalareste': ('skalar',),
'skalart': ('skalar',),
'subversiv': ('subversiv',),
'subversive': ('subversiv',),
'subversivere': ('subversiv',),
'subversivest': ('subversiv',),
'subversiveste': ('subversiv',),
'subversivt': ('subversiv',),
'initiell': ('initiell',),
'initielle': ('initiell',),
'initiellere': ('initiell',),
'initiellest': ('initiell',),
'initielleste': ('initiell',),
'initielt': ('initiell',),
'kommunegrå': ('kommunegrå',),
'kommunegråe': ('kommunegrå',),
'kommunegråere': ('kommunegrå',),
'kommunegråest': ('kommunegrå',),
'kommunegråeste': ('kommunegrå',),
'kommunegrått': ('kommunegrå',),
'delirisk': ('delirisk',),
'deliriske': ('delirisk',),
'deliriskere': ('delirisk',),
'deliriskest': ('delirisk',),
'deliriskeste': ('delirisk',),
'dobbeltspent': ('dobbeltspent',),
'dobbeltspente': ('dobbeltspent',),
'dobbeltspentere': ('dobbeltspent',),
'dobbeltspentest': ('dobbeltspent',),
'dobbeltspenteste': ('dobbeltspent',),
'dystopisk': ('dystopisk',),
'dystopiske': ('dystopisk',),
'dystopiskere': ('dystopisk',),
'dystopiskest': ('dystopisk',),
'dystopiskeste': ('dystopisk',),
'flydykig': ('flydykig',),
'flydykige': ('flydykig',),
'flydykigere': ('flydykig',),
'flydykigest': ('flydykig',),
'flydykigeste': ('flydykig',),
'letargisk': ('letargisk',),
'letargiske': ('letargisk',),
'letargiskere': ('letargisk',),
'letargiskest': ('letargisk',),
'letargiskeste': ('letargisk',),
'lulesamisk': ('lulesamisk',),
'lulesamiske': ('lulesamisk',),
'lulesamiskere': ('lulesamisk',),
'lulesamiskest': ('lulesamisk',),
'lulesamiskeste': ('lulesamisk',),
'møllspist': ('møllspist',),
'møllspiste': ('møllspist',),
'møllspistere': ('møllspist',),
'møllspistest': ('møllspist',),
'møllspisteste': ('møllspist',),
'nordistisk': ('nordistisk',),
'nordistiske': ('nordistisk',),
'nordistiskere': ('nordistisk',),
'nordistiskest': ('nordistisk',),
'nordistiskeste': ('nordistisk',),
'rånet': ('rånet',),
'rånete': ('rånet',),
'rånetere': ('rånet',),
'rånetest': ('rånet',),
'råneteste': ('rånet',),
'selvhøgtidelig': ('selvhøgtidelig',),
'selvhøgtidelige': ('selvhøgtidelig',),
'selvhøgtideligere': ('selvhøgtidelig',),
'selvhøgtideligst': ('selvhøgtidelig',),
'selvhøgtideligste': ('selvhøgtidelig',),
'sjølhøgtidelig': ('sjølhøgtidelig',),
'sjølhøgtidelige': ('sjølhøgtidelig',),
'sjølhøgtideligere': ('sjølhøgtidelig',),
'sjølhøgtideligst': ('sjølhøgtidelig',),
'sjølhøgtideligste': ('sjølhøgtidelig',),
'sjølhøytidelig': ('sjølhøytidelig',),
'sjølhøytidelige': ('sjølhøytidelig',),
'sjølhøytideligere': ('sjølhøytidelig',),
'sjølhøytideligst': ('sjølhøytidelig',),
'sjølhøytideligste': ('sjølhøytidelig',),
'snøet': ('snøet',),
'snøete': ('snøet',),
'snøetere': ('snøet',),
'snøetest': ('snøet',),
'snøeteste': ('snøet',),
'uadskillelig': ('uadskillelig',),
'uadskillelige': ('uadskillelig',),
'uadskilleligere': ('uadskillelig',),
'uadskilleligst': ('uadskillelig',),
'uadskilleligste': ('uadskillelig',),
'innrøkede': ('innrøket',),
'innrøket': ('innrøket',),
'innrøkete': ('innrøket',),
'innrøketere': ('innrøket',),
'innrøketest': ('innrøket',),
'innrøketeste': ('innrøket',),
'innrøykede': ('innrøyket',),
'innrøyket': ('innrøyket',),
'innrøykete': ('innrøyket',),
'innrøyketere': ('innrøyket',),
'innrøyketest': ('innrøyket',),
'innrøyketeste': ('innrøyket',),
'krokbøyede': ('krokbøyet',),
'krokbøyet': ('krokbøyet',),
'krokbøyete': ('krokbøyet',),
'krokbøyetere': ('krokbøyet',),
'krokbøyetest': ('krokbøyet',),
'krokbøyeteste': ('krokbøyet',),
'krumbøyede': ('krumbøyet',),
'krumbøyet': ('krumbøyet',),
'krumbøyete': ('krumbøyet',),
'krumbøyetere': ('krumbøyet',),
'krumbøyetest': ('krumbøyet',),
'krumbøyeteste': ('krumbøyet',),
'lettrøkede': ('lettrøket',),
'lettrøket': ('lettrøket',),
'lettrøkete': ('lettrøket',),
'lettrøketere': ('lettrøket',),
'lettrøketest': ('lettrøket',),
'lettrøketeste': ('lettrøket',),
'lettrøykede': ('lettrøyket',),
'lettrøyket': ('lettrøyket',),
'lettrøykete': ('lettrøyket',),
'lettrøyketere': ('lettrøyket',),
'lettrøyketest': ('lettrøyket',),
'lettrøyketeste': ('lettrøyket',),
'sammenvevede': ('sammenvevet',),
'sammenvevet': ('sammenvevet',),
'sammenvevete': ('sammenvevet',),
'sammenvevetere': ('sammenvevet',),
'sammenvevetest': ('sammenvevet',),
'sammenveveteste': ('sammenvevet',),
'avbleika': ('avbleika',),
'avbleka': ('avbleka',),
'diagonalveva': ('diagonalveva',),
'innveva': ('innveva',),
'rånete': ('rånete',),
'snøete': ('snøete',),
'tredvedels': ('tredvedels',),
'attra': ('attre',),
'attrede': ('attre',),
'attrende': ('attre',),
'attret': ('attre',),
'attrete': ('attre',),
'grisebanka': ('grisebanke',),
'grisebankede': ('grisebanke',),
'grisebankende': ('grisebanke',),
'grisebanket': ('grisebanke',),
'grisebankete': ('grisebanke',),
'mingla': ('mingle',),
'minglede': ('mingle',),
'minglende': ('mingle',),
'minglet': ('mingle',),
'minglete': ('mingle',),
'arbitrerende': ('arbitrere',),
'arbitrert': ('arbitrere',),
'arbitrerte': ('arbitrere',),
'ballasterende': ('ballastere',),
'ballastert': ('ballastere',),
'ballasterte': ('ballastere',),
'diversifiserende': ('diversifisere',),
'diversifisert': ('diversifisere',),
'diversifiserte': ('diversifisere',),
'eksilerende': ('eksilere',),
'eksilert': ('eksilere',),
'eksilerte': ('eksilere',),
'filialiserende': ('filialisere',),
'filialisert': ('filialisere',),
'filialiserte': ('filialisere',),
'inkriminerende': ('inkriminere',),
'inkriminert': ('inkriminere',),
'inkriminerte': ('inkriminere',),
'kontemplerende': ('kontemplere',),
'kontemplert': ('kontemplere',),
'kontemplerte': ('kontemplere',),
'sekrerende': ('sekrere',),
'sekrert': ('sekrere',),
'sekrerte': ('sekrere',),
'sjablonerende': ('sjablonere',),
'sjablonert': ('sjablonere',),
'sjablonerte': ('sjablonere',),
'vakuumerende': ('vakuumere',),
'vakuumert': ('vakuumere',),
'vakuumerte': ('vakuumere',),
'medgående': ('medgå',),
'medgått': ('medgå',),
'medgåtte': ('medgå',),
'femtendels': ('femtendels',),
'billionte': ('billionte',),
'femtendedels': ('femtendedels',),
'fjortendedels': ('fjortendedels',),
'hundrededels': ('hundrededels',)
}
